(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    551904,      16218]*)
(*NotebookOutlinePosition[    552963,      16251]*)
(*  CellTagsIndexPosition[    552919,      16247]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(\(@\)\(ARTICLE\)\) {Singer : 
          1998, \[IndentingNewLine]AUTHOR = {Singer, \(\(H\)\(.\)\)}, \
\[IndentingNewLine]TITLE = {{Continuous\ Panel\ Models\ with\ Time\ Dependent\
\ Parameters}}, \[IndentingNewLine]JOURNAL = {Journal\ of\ Mathematical\ \
Sociology}, \[IndentingNewLine]VOLUME = {23}, \[IndentingNewLine]PAGES = \
{\(77--\) 98}, \[IndentingNewLine]YEAR = {1998}}\)], "Input",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    RowBox[{
      StyleBox["papers",
        FontColor->RGBColor[0, 1, 0]], 
      StyleBox["/",
        FontColor->RGBColor[0, 1, 0]], 
      StyleBox[\(growth . pdf\),
        FontColor->RGBColor[0, 1, 0]]}]], "Input"],

Cell[CellGroupData[{

Cell["load files", "Subsection",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< init.m\), "\[IndentingNewLine]", 
    \(<< code`Kronecker`\), "\n", 
    \(<< code`LSD`\), "\n", 
    \(<< Kuba.Impl.m\), "\[IndentingNewLine]", 
    \(<< Kalman.Exakt.impl.m\)}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \(" "\)], "Output"],

Cell[BoxData[
    \(Clear::"wrsym" \(\(:\)\(\ \)\) 
      "Symbol \!\(RandomMultinomial\) is Protected."\)], "Message"],

Cell[BoxData[
    \(SetDelayed::"write" \(\(:\)\(\ \)\) 
      "Tag \!\(RandomMultinomial\) in \!\(RandomMultinomial[\(\(xij_, pij_, \
n_\)\)]\) is Protected."\)], "Message"],

Cell[BoxData[
    \(Clear::"wrsym" \(\(:\)\(\ \)\) 
      "Symbol \!\(RandomNumbers\) is Protected."\)], "Message"],

Cell[BoxData[
    \(SetDelayed::"write" \(\(:\)\(\ \)\) 
      "Tag \!\(RandomNumbers\) in \!\(RandomNumbers[\(\(\(\({x1_, x2_, dx_}\)\
\), density_, n_\)\)]\) is Protected."\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Specification", "Subsection",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Clear[fBrownianBridge,gBrownianBridge,Jacobif,mue,sigma,h,Jacobih,R,\

\t\tB,t,BT,Ts,sigma,alpha];
\t\t
\t\t
fBrownianBridge[B_,t_,{\[Alpha]_,\[Sigma]_}]:= -\[Alpha](B-BT)/(Ts-t[[1]])
gBrownianBridge[B_,t_,{\[Alpha]_,\[Sigma]_}]:= {{\[Sigma]}} 


Jacobif[B_,t_,{\[Alpha]_,\[Sigma]_}] = 
\t\tOuter[D,fBrownianBridge[{B},t,{\[Alpha],\[Sigma]}],{B}]
\t \t\t
mue[t_,theta_] := {0.}

sigma[t_,theta_] := {{10.^16}}

h[B_,t_,theta_] := B;

Jacobih[B_,t_,theta_] = IdentityMatrix[1];

R[B_,t_,theta_] = .001 IdentityMatrix[1];
\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(gBrownianBridge\)\" is \
similar to existing symbol \"\!\(fBrownianBridge\)\"."\)], "Message"],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(t \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message"],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(t \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\) is longer than depth of object."\)], "Message"],

Cell[BoxData[
    \({{\(-\(\[Alpha]\/\(Ts - 
                t\[LeftDoubleBracket]1\[RightDoubleBracket]\)\)\)}}\)], \
"Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation", "Subsection",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
k = 1; p = 1; q = 1; 
n = 1; T = 200; 
SeedRandom[9997+10];

B0 = {1};
BT = {2};
Ts = 1.;

Theta = {alpha = 1, sig = 1}//N
dt = Ts/T//N
X = Shape[Range[0,T] dt,{T+1,q}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({1.`, 1.`}\)], "Output"],

Cell[BoxData[
    \(0.005`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
X
Ts\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0}, {0.005`}, {0.01`}, {0.015`}, {0.02`}, {0.025`}, {0.03`}, \
{0.035`}, {0.04`}, {0.045`}, {0.05`}, {0.055`}, {0.06`}, {0.065`}, {0.07`}, \
{0.075`}, {0.08`}, {0.085`}, {0.09`}, {0.095`}, {0.1`}, {0.105`}, {0.11`}, \
{0.115`}, {0.12`}, {0.125`}, {0.13`}, {0.135`}, {0.14`}, {0.145`}, {0.15`}, \
{0.155`}, {0.16`}, {0.165`}, {0.17`}, {0.17500000000000002`}, {0.18`}, \
{0.185`}, {0.19`}, {0.195`}, {0.2`}, {0.20500000000000002`}, {0.21`}, \
{0.215`}, {0.22`}, {0.225`}, {0.23`}, {0.23500000000000001`}, {0.24`}, \
{0.245`}, {0.25`}, {0.255`}, {0.26`}, {0.265`}, {0.27`}, {0.275`}, {0.28`}, \
{0.28500000000000003`}, {0.29`}, {0.295`}, {0.3`}, {0.305`}, {0.31`}, \
{0.315`}, {0.32`}, {0.325`}, {0.33`}, {0.335`}, {0.34`}, \
{0.34500000000000003`}, {0.35000000000000003`}, {0.355`}, {0.36`}, {0.365`}, \
{0.37`}, {0.375`}, {0.38`}, {0.385`}, {0.39`}, {0.395`}, {0.4`}, {0.405`}, \
{0.41000000000000003`}, {0.41500000000000004`}, {0.42`}, {0.425`}, {0.43`}, \
{0.435`}, {0.44`}, {0.445`}, {0.45`}, {0.455`}, {0.46`}, {0.465`}, \
{0.47000000000000003`}, {0.47500000000000003`}, {0.48`}, {0.485`}, {0.49`}, \
{0.495`}, {0.5`}, {0.505`}, {0.51`}, {0.515`}, {0.52`}, {0.525`}, {0.53`}, \
{0.535`}, {0.54`}, {0.545`}, {0.55`}, {0.555`}, {0.56`}, \
{0.5650000000000001`}, {0.5700000000000001`}, {0.5750000000000001`}, {0.58`}, \
{0.585`}, {0.59`}, {0.595`}, {0.6`}, {0.605`}, {0.61`}, {0.615`}, {0.62`}, \
{0.625`}, {0.63`}, {0.635`}, {0.64`}, {0.645`}, {0.65`}, {0.655`}, {0.66`}, \
{0.665`}, {0.67`}, {0.675`}, {0.68`}, {0.685`}, {0.6900000000000001`}, \
{0.6950000000000001`}, {0.7000000000000001`}, {0.705`}, {0.71`}, {0.715`}, \
{0.72`}, {0.725`}, {0.73`}, {0.735`}, {0.74`}, {0.745`}, {0.75`}, {0.755`}, \
{0.76`}, {0.765`}, {0.77`}, {0.775`}, {0.78`}, {0.785`}, {0.79`}, {0.795`}, \
{0.8`}, {0.805`}, {0.81`}, {0.8150000000000001`}, {0.8200000000000001`}, \
{0.8250000000000001`}, {0.8300000000000001`}, {0.835`}, {0.84`}, {0.845`}, \
{0.85`}, {0.855`}, {0.86`}, {0.865`}, {0.87`}, {0.875`}, {0.88`}, {0.885`}, \
{0.89`}, {0.895`}, {0.9`}, {0.905`}, {0.91`}, {0.915`}, {0.92`}, {0.925`}, \
{0.93`}, {0.935`}, {0.9400000000000001`}, {0.9450000000000001`}, \
{0.9500000000000001`}, {0.9550000000000001`}, {0.96`}, {0.965`}, {0.97`}, \
{0.975`}, {0.98`}, {0.985`}, {0.99`}, {0.995`}, {1.`}}\)], "Output"],

Cell[BoxData[
    \(1.`\)], "Output"]
}, Open  ]],

Cell["\<\
B = \
Table[RungeKutta[fBrownianBridge,gBrownianBridge,B0,X,T,dt,Theta,GaussC,\
EulerStep],{10}];
\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
SetOptions[plot1,PlotJoined->True,Frame->True,dicke->0.007,
\tgestrichelt->Array[1&,200],color->Range[200],
\tDisplayFunction->$DisplayFunction,farbmodell->eigene];
\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
plot1[flatten[B,{2,3}]//Transpose//AddTimeAxis[#,{0,Ts,dt}]&,
\tfarbmodell->Hue,PlotRange->{All,{0,3}},dicke->.001];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{201, 11}\),
      SequenceForm[ "Dimension der Daten  ", {201, 11}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 0.206011 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
gsave
.97619 .40873 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .20601 m
.02857 .23152 L
.03333 .25006 L
.0381 .23536 L
.04286 .23234 L
.04762 .22865 L
.05238 .23151 L
.05714 .22653 L
.0619 .23908 L
.06667 .22579 L
.07143 .23424 L
.07619 .23472 L
.08095 .23437 L
.08571 .22561 L
.09048 .23047 L
.09524 .22171 L
.1 .21237 L
.10476 .21816 L
.10952 .21559 L
.11429 .22329 L
.11905 .22537 L
.12381 .24692 L
.12857 .22822 L
.13333 .2255 L
.1381 .23847 L
.14286 .23818 L
.14762 .23083 L
.15238 .24725 L
.15714 .27247 L
.1619 .28816 L
.16667 .30231 L
.17143 .31433 L
.17619 .32347 L
.18095 .355 L
.18571 .35435 L
.19048 .32826 L
.19524 .32446 L
.2 .33931 L
.20476 .34686 L
.20952 .316 L
.21429 .32167 L
.21905 .33171 L
.22381 .32406 L
.22857 .30922 L
.23333 .29662 L
.2381 .304 L
.24286 .28309 L
.24762 .26454 L
.25238 .24233 L
.25714 .25934 L
Mistroke
.2619 .27818 L
.26667 .25704 L
.27143 .25912 L
.27619 .24072 L
.28095 .26185 L
.28571 .24566 L
.29048 .25073 L
.29524 .24209 L
.3 .26279 L
.30476 .25263 L
.30952 .23967 L
.31429 .24869 L
.31905 .25202 L
.32381 .23167 L
.32857 .19863 L
.33333 .18908 L
.3381 .18834 L
.34286 .1903 L
.34762 .19839 L
.35238 .18758 L
.35714 .18457 L
.3619 .18543 L
.36667 .18359 L
.37143 .16317 L
.37619 .16146 L
.38095 .15407 L
.38571 .12958 L
.39048 .12808 L
.39524 .1335 L
.4 .11315 L
.40476 .10874 L
.40952 .10556 L
.41429 .11119 L
.41905 .11816 L
.42381 .11891 L
.42857 .11704 L
.43333 .13276 L
.4381 .15402 L
.44286 .1233 L
.44762 .14718 L
.45238 .14479 L
.45714 .14301 L
.4619 .13951 L
.46667 .1388 L
.47143 .11595 L
.47619 .09438 L
.48095 .08451 L
.48571 .08894 L
.49048 .09767 L
.49524 .09143 L
Mistroke
.5 .08889 L
.50476 .10577 L
.50952 .10662 L
.51429 .10782 L
.51905 .11274 L
.52381 .13548 L
.52857 .16511 L
.53333 .15681 L
.5381 .16735 L
.54286 .15361 L
.54762 .16585 L
.55238 .18205 L
.55714 .19264 L
.5619 .19373 L
.56667 .22222 L
.57143 .2015 L
.57619 .21534 L
.58095 .23032 L
.58571 .2125 L
.59048 .21263 L
.59524 .2273 L
.6 .20461 L
.60476 .20885 L
.60952 .23863 L
.61429 .21747 L
.61905 .22153 L
.62381 .23505 L
.62857 .20195 L
.63333 .20502 L
.6381 .19547 L
.64286 .17602 L
.64762 .168 L
.65238 .18699 L
.65714 .19613 L
.6619 .21158 L
.66667 .2268 L
.67143 .21043 L
.67619 .22454 L
.68095 .22944 L
.68571 .23187 L
.69048 .25942 L
.69524 .27216 L
.7 .29722 L
.70476 .29646 L
.70952 .29762 L
.71429 .3061 L
.71905 .29723 L
.72381 .31097 L
.72857 .30767 L
.73333 .3113 L
Mistroke
.7381 .32009 L
.74286 .31173 L
.74762 .32411 L
.75238 .30671 L
.75714 .30172 L
.7619 .31075 L
.76667 .30348 L
.77143 .28618 L
.77619 .29467 L
.78095 .31796 L
.78571 .31615 L
.79048 .32018 L
.79524 .31475 L
.8 .32118 L
.80476 .31389 L
.80952 .3136 L
.81429 .31179 L
.81905 .30594 L
.82381 .29296 L
.82857 .2975 L
.83333 .30137 L
.8381 .30306 L
.84286 .29923 L
.84762 .32258 L
.85238 .29624 L
.85714 .29109 L
.8619 .29588 L
.86667 .31723 L
.87143 .33255 L
.87619 .32191 L
.88095 .35182 L
.88571 .35417 L
.89048 .36267 L
.89524 .38453 L
.9 .37368 L
.90476 .36617 L
.90952 .3402 L
.91429 .34756 L
.91905 .37185 L
.92381 .3547 L
.92857 .3373 L
.93333 .35772 L
.9381 .37188 L
.94286 .34716 L
.94762 .35082 L
.95238 .36799 L
.95714 .36971 L
.9619 .38484 L
.96667 .41385 L
.97143 .41349 L
Mistroke
.97619 .40873 L
Mfstroke
1 0 .6 r
gsave
.97619 .40956 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .21059 L
.03333 .20141 L
.0381 .1754 L
.04286 .18462 L
.04762 .20554 L
.05238 .20705 L
.05714 .21238 L
.0619 .20246 L
.06667 .20584 L
.07143 .20357 L
.07619 .19101 L
.08095 .19184 L
.08571 .20795 L
.09048 .20229 L
.09524 .21969 L
.1 .23247 L
.10476 .2235 L
.10952 .22908 L
.11429 .21529 L
.11905 .21773 L
.12381 .21983 L
.12857 .2362 L
.13333 .24546 L
.1381 .21477 L
.14286 .20029 L
.14762 .17531 L
.15238 .17141 L
.15714 .1655 L
.1619 .1702 L
.16667 .16133 L
.17143 .17408 L
.17619 .14917 L
.18095 .14434 L
.18571 .1838 L
.19048 .17602 L
.19524 .20222 L
.2 .19081 L
.20476 .23643 L
.20952 .23714 L
.21429 .24056 L
.21905 .23402 L
.22381 .22321 L
.22857 .20544 L
.23333 .23056 L
.2381 .21912 L
.24286 .22806 L
.24762 .2373 L
.25238 .25132 L
.25714 .26875 L
Mistroke
.2619 .28795 L
.26667 .29009 L
.27143 .27853 L
.27619 .26423 L
.28095 .26323 L
.28571 .27298 L
.29048 .27843 L
.29524 .2874 L
.3 .27208 L
.30476 .2509 L
.30952 .25239 L
.31429 .24382 L
.31905 .24922 L
.32381 .24021 L
.32857 .24843 L
.33333 .25107 L
.3381 .24901 L
.34286 .25382 L
.34762 .22867 L
.35238 .21342 L
.35714 .2218 L
.3619 .22416 L
.36667 .21533 L
.37143 .20653 L
.37619 .20529 L
.38095 .20532 L
.38571 .19424 L
.39048 .18905 L
.39524 .19729 L
.4 .21236 L
.40476 .20538 L
.40952 .18103 L
.41429 .19077 L
.41905 .18745 L
.42381 .19477 L
.42857 .20974 L
.43333 .19359 L
.4381 .19457 L
.44286 .21067 L
.44762 .22452 L
.45238 .21491 L
.45714 .21722 L
.4619 .22883 L
.46667 .26181 L
.47143 .27021 L
.47619 .28761 L
.48095 .26569 L
.48571 .29084 L
.49048 .28139 L
.49524 .28162 L
Mistroke
.5 .2595 L
.50476 .2846 L
.50952 .25987 L
.51429 .24606 L
.51905 .26022 L
.52381 .25066 L
.52857 .24707 L
.53333 .25576 L
.5381 .25434 L
.54286 .25179 L
.54762 .26201 L
.55238 .23156 L
.55714 .24896 L
.5619 .25185 L
.56667 .25917 L
.57143 .24741 L
.57619 .26674 L
.58095 .28267 L
.58571 .27269 L
.59048 .25984 L
.59524 .2678 L
.6 .29029 L
.60476 .32603 L
.60952 .3142 L
.61429 .29515 L
.61905 .28228 L
.62381 .26553 L
.62857 .28128 L
.63333 .32074 L
.6381 .33084 L
.64286 .34727 L
.64762 .35378 L
.65238 .33637 L
.65714 .32047 L
.6619 .33433 L
.66667 .34432 L
.67143 .34161 L
.67619 .34338 L
.68095 .3372 L
.68571 .31965 L
.69048 .32302 L
.69524 .32807 L
.7 .3385 L
.70476 .34997 L
.70952 .36507 L
.71429 .38653 L
.71905 .40952 L
.72381 .39434 L
.72857 .40648 L
.73333 .42116 L
Mistroke
.7381 .40593 L
.74286 .41606 L
.74762 .42775 L
.75238 .43896 L
.75714 .43338 L
.7619 .4361 L
.76667 .43351 L
.77143 .40591 L
.77619 .40294 L
.78095 .41656 L
.78571 .42124 L
.79048 .43458 L
.79524 .44461 L
.8 .47339 L
.80476 .44372 L
.80952 .44661 L
.81429 .46768 L
.81905 .4617 L
.82381 .46312 L
.82857 .45108 L
.83333 .42157 L
.8381 .41903 L
.84286 .44133 L
.84762 .43236 L
.85238 .43785 L
.85714 .45488 L
.8619 .44218 L
.86667 .43103 L
.87143 .42652 L
.87619 .42031 L
.88095 .42297 L
.88571 .43923 L
.89048 .43835 L
.89524 .44268 L
.9 .425 L
.90476 .41887 L
.90952 .39777 L
.91429 .38904 L
.91905 .37354 L
.92381 .35517 L
.92857 .36642 L
.93333 .37436 L
.9381 .37788 L
.94286 .38754 L
.94762 .3829 L
.95238 .37488 L
.95714 .38976 L
.9619 .40727 L
.96667 .37982 L
.97143 .3934 L
Mistroke
.97619 .40956 L
Mfstroke
.8 0 1 r
gsave
.97619 .41434 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .20373 L
.03333 .23025 L
.0381 .21849 L
.04286 .22507 L
.04762 .26755 L
.05238 .27735 L
.05714 .30582 L
.0619 .30843 L
.06667 .29057 L
.07143 .30671 L
.07619 .31136 L
.08095 .29795 L
.08571 .2706 L
.09048 .28038 L
.09524 .27811 L
.1 .24598 L
.10476 .22991 L
.10952 .24108 L
.11429 .26719 L
.11905 .27931 L
.12381 .2989 L
.12857 .30131 L
.13333 .30514 L
.1381 .28863 L
.14286 .26826 L
.14762 .239 L
.15238 .21552 L
.15714 .21545 L
.1619 .21772 L
.16667 .22899 L
.17143 .21477 L
.17619 .18939 L
.18095 .21657 L
.18571 .2212 L
.19048 .22215 L
.19524 .22394 L
.2 .22235 L
.20476 .20587 L
.20952 .18703 L
.21429 .18673 L
.21905 .21148 L
.22381 .20607 L
.22857 .19373 L
.23333 .2097 L
.2381 .21656 L
.24286 .2451 L
.24762 .23064 L
.25238 .24307 L
.25714 .22615 L
Mistroke
.2619 .22489 L
.26667 .21681 L
.27143 .22812 L
.27619 .235 L
.28095 .23722 L
.28571 .23939 L
.29048 .24014 L
.29524 .24495 L
.3 .23801 L
.30476 .2263 L
.30952 .22472 L
.31429 .25017 L
.31905 .2506 L
.32381 .24305 L
.32857 .25453 L
.33333 .27643 L
.3381 .27251 L
.34286 .28131 L
.34762 .30393 L
.35238 .29334 L
.35714 .26613 L
.3619 .2585 L
.36667 .30443 L
.37143 .31532 L
.37619 .29834 L
.38095 .30357 L
.38571 .2996 L
.39048 .30498 L
.39524 .30419 L
.4 .31066 L
.40476 .29604 L
.40952 .27618 L
.41429 .25441 L
.41905 .25952 L
.42381 .26482 L
.42857 .27197 L
.43333 .27844 L
.4381 .30586 L
.44286 .31365 L
.44762 .32319 L
.45238 .3506 L
.45714 .35457 L
.4619 .35484 L
.46667 .33635 L
.47143 .34866 L
.47619 .34074 L
.48095 .34511 L
.48571 .34122 L
.49048 .35004 L
.49524 .35867 L
Mistroke
.5 .3493 L
.50476 .35264 L
.50952 .34299 L
.51429 .34949 L
.51905 .36452 L
.52381 .34588 L
.52857 .33947 L
.53333 .37046 L
.5381 .36039 L
.54286 .38422 L
.54762 .38801 L
.55238 .36695 L
.55714 .38892 L
.5619 .40372 L
.56667 .39774 L
.57143 .4035 L
.57619 .38869 L
.58095 .3787 L
.58571 .36661 L
.59048 .36875 L
.59524 .37171 L
.6 .366 L
.60476 .39085 L
.60952 .3959 L
.61429 .40608 L
.61905 .40434 L
.62381 .39941 L
.62857 .40648 L
.63333 .41806 L
.6381 .42402 L
.64286 .40052 L
.64762 .39861 L
.65238 .39354 L
.65714 .38433 L
.6619 .37667 L
.66667 .38323 L
.67143 .36559 L
.67619 .37528 L
.68095 .3957 L
.68571 .36576 L
.69048 .35367 L
.69524 .37038 L
.7 .38391 L
.70476 .40256 L
.70952 .41566 L
.71429 .44446 L
.71905 .43744 L
.72381 .46307 L
.72857 .44133 L
.73333 .42626 L
Mistroke
.7381 .42193 L
.74286 .38314 L
.74762 .36781 L
.75238 .36945 L
.75714 .36436 L
.7619 .38556 L
.76667 .37413 L
.77143 .38264 L
.77619 .38807 L
.78095 .38208 L
.78571 .38948 L
.79048 .38786 L
.79524 .3932 L
.8 .38787 L
.80476 .37291 L
.80952 .38899 L
.81429 .35779 L
.81905 .37505 L
.82381 .38385 L
.82857 .4228 L
.83333 .41755 L
.8381 .44022 L
.84286 .42735 L
.84762 .43498 L
.85238 .41219 L
.85714 .40475 L
.8619 .41662 L
.86667 .43206 L
.87143 .43151 L
.87619 .41278 L
.88095 .3811 L
.88571 .40882 L
.89048 .43012 L
.89524 .42423 L
.9 .42069 L
.90476 .42959 L
.90952 .42913 L
.91429 .41792 L
.91905 .40724 L
.92381 .41849 L
.92857 .40186 L
.93333 .40393 L
.9381 .42571 L
.94286 .41915 L
.94762 .40899 L
.95238 .43003 L
.95714 .44235 L
.9619 .43172 L
.96667 .41001 L
.97143 .39197 L
Mistroke
.97619 .41434 L
Mfstroke
.2 0 1 r
gsave
.97619 .40198 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .21141 L
.03333 .22478 L
.0381 .22688 L
.04286 .21467 L
.04762 .23411 L
.05238 .25354 L
.05714 .26798 L
.0619 .29762 L
.06667 .30259 L
.07143 .32416 L
.07619 .31685 L
.08095 .31624 L
.08571 .32673 L
.09048 .32149 L
.09524 .31983 L
.1 .31763 L
.10476 .31429 L
.10952 .32269 L
.11429 .29538 L
.11905 .3021 L
.12381 .30392 L
.12857 .31031 L
.13333 .32746 L
.1381 .31563 L
.14286 .33658 L
.14762 .32719 L
.15238 .30767 L
.15714 .33431 L
.1619 .35758 L
.16667 .37355 L
.17143 .36056 L
.17619 .37811 L
.18095 .35761 L
.18571 .37277 L
.19048 .3648 L
.19524 .3761 L
.2 .37073 L
.20476 .37259 L
.20952 .34909 L
.21429 .34591 L
.21905 .36608 L
.22381 .39559 L
.22857 .38418 L
.23333 .36713 L
.2381 .37834 L
.24286 .37163 L
.24762 .36157 L
.25238 .36567 L
.25714 .36491 L
Mistroke
.2619 .3617 L
.26667 .36721 L
.27143 .34971 L
.27619 .33034 L
.28095 .32759 L
.28571 .31151 L
.29048 .28956 L
.29524 .26997 L
.3 .27333 L
.30476 .29123 L
.30952 .28574 L
.31429 .27837 L
.31905 .27652 L
.32381 .29829 L
.32857 .31592 L
.33333 .29348 L
.3381 .29389 L
.34286 .28051 L
.34762 .27931 L
.35238 .29675 L
.35714 .3052 L
.3619 .31569 L
.36667 .3104 L
.37143 .29941 L
.37619 .30064 L
.38095 .30637 L
.38571 .29241 L
.39048 .27516 L
.39524 .29289 L
.4 .30411 L
.40476 .2949 L
.40952 .29027 L
.41429 .26639 L
.41905 .26158 L
.42381 .25784 L
.42857 .26428 L
.43333 .2686 L
.4381 .28131 L
.44286 .28107 L
.44762 .28092 L
.45238 .31 L
.45714 .30332 L
.4619 .287 L
.46667 .28616 L
.47143 .28413 L
.47619 .2977 L
.48095 .30113 L
.48571 .31019 L
.49048 .30995 L
.49524 .30892 L
Mistroke
.5 .32233 L
.50476 .30537 L
.50952 .31104 L
.51429 .33919 L
.51905 .3465 L
.52381 .35708 L
.52857 .35089 L
.53333 .35351 L
.5381 .35218 L
.54286 .3464 L
.54762 .36033 L
.55238 .36302 L
.55714 .38241 L
.5619 .35429 L
.56667 .34885 L
.57143 .34153 L
.57619 .34115 L
.58095 .36081 L
.58571 .36876 L
.59048 .38738 L
.59524 .39349 L
.6 .41342 L
.60476 .39486 L
.60952 .37548 L
.61429 .40177 L
.61905 .38022 L
.62381 .41871 L
.62857 .42975 L
.63333 .42778 L
.6381 .41883 L
.64286 .4354 L
.64762 .45166 L
.65238 .44305 L
.65714 .42898 L
.6619 .44921 L
.66667 .45435 L
.67143 .46368 L
.67619 .46541 L
.68095 .48574 L
.68571 .4946 L
.69048 .49133 L
.69524 .48831 L
.7 .47583 L
.70476 .45052 L
.70952 .4729 L
.71429 .47514 L
.71905 .4582 L
.72381 .4622 L
.72857 .45551 L
.73333 .44859 L
Mistroke
.7381 .43963 L
.74286 .4312 L
.74762 .40783 L
.75238 .39284 L
.75714 .4193 L
.7619 .41818 L
.76667 .41611 L
.77143 .39724 L
.77619 .3877 L
.78095 .37984 L
.78571 .3816 L
.79048 .39311 L
.79524 .41843 L
.8 .41126 L
.80476 .42411 L
.80952 .41925 L
.81429 .43163 L
.81905 .42377 L
.82381 .41703 L
.82857 .39464 L
.83333 .38524 L
.8381 .38183 L
.84286 .40046 L
.84762 .38881 L
.85238 .40481 L
.85714 .40417 L
.8619 .40273 L
.86667 .38635 L
.87143 .37121 L
.87619 .39279 L
.88095 .39405 L
.88571 .38732 L
.89048 .41593 L
.89524 .42349 L
.9 .42217 L
.90476 .42985 L
.90952 .44404 L
.91429 .44562 L
.91905 .43366 L
.92381 .43643 L
.92857 .40687 L
.93333 .41923 L
.9381 .40852 L
.94286 .40419 L
.94762 .40512 L
.95238 .39486 L
.95714 .40081 L
.9619 .38456 L
.96667 .39216 L
.97143 .40929 L
Mistroke
.97619 .40198 L
Mfstroke
0 .4 1 r
gsave
.97619 .39555 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .21483 L
.03333 .22678 L
.0381 .24189 L
.04286 .25576 L
.04762 .26929 L
.05238 .30833 L
.05714 .28777 L
.0619 .29181 L
.06667 .2776 L
.07143 .28559 L
.07619 .28663 L
.08095 .29015 L
.08571 .29986 L
.09048 .33397 L
.09524 .3253 L
.1 .31682 L
.10476 .33725 L
.10952 .33928 L
.11429 .35805 L
.11905 .35061 L
.12381 .354 L
.12857 .35554 L
.13333 .36031 L
.1381 .35388 L
.14286 .3503 L
.14762 .32731 L
.15238 .31433 L
.15714 .30302 L
.1619 .28118 L
.16667 .28444 L
.17143 .29744 L
.17619 .31815 L
.18095 .3246 L
.18571 .33359 L
.19048 .32515 L
.19524 .34531 L
.2 .34761 L
.20476 .37664 L
.20952 .39156 L
.21429 .39876 L
.21905 .3942 L
.22381 .37944 L
.22857 .39099 L
.23333 .41179 L
.2381 .39766 L
.24286 .37372 L
.24762 .37753 L
.25238 .36257 L
.25714 .36809 L
Mistroke
.2619 .354 L
.26667 .37159 L
.27143 .35612 L
.27619 .35741 L
.28095 .33315 L
.28571 .33692 L
.29048 .35963 L
.29524 .3817 L
.3 .38296 L
.30476 .38134 L
.30952 .37832 L
.31429 .34159 L
.31905 .34776 L
.32381 .34661 L
.32857 .35171 L
.33333 .34326 L
.3381 .35095 L
.34286 .32514 L
.34762 .3604 L
.35238 .32771 L
.35714 .3255 L
.3619 .33546 L
.36667 .30115 L
.37143 .32105 L
.37619 .34663 L
.38095 .34924 L
.38571 .34112 L
.39048 .33322 L
.39524 .31159 L
.4 .3048 L
.40476 .29306 L
.40952 .29844 L
.41429 .286 L
.41905 .29183 L
.42381 .29597 L
.42857 .28026 L
.43333 .27902 L
.4381 .29469 L
.44286 .26317 L
.44762 .26293 L
.45238 .24789 L
.45714 .25461 L
.4619 .26482 L
.46667 .26406 L
.47143 .26044 L
.47619 .26371 L
.48095 .25747 L
.48571 .26149 L
.49048 .29469 L
.49524 .30201 L
Mistroke
.5 .30029 L
.50476 .29978 L
.50952 .293 L
.51429 .27013 L
.51905 .26252 L
.52381 .28226 L
.52857 .25361 L
.53333 .24461 L
.5381 .24435 L
.54286 .23116 L
.54762 .23601 L
.55238 .25605 L
.55714 .24521 L
.5619 .25057 L
.56667 .25799 L
.57143 .25943 L
.57619 .26452 L
.58095 .27129 L
.58571 .27857 L
.59048 .26833 L
.59524 .2843 L
.6 .29188 L
.60476 .32414 L
.60952 .33953 L
.61429 .33087 L
.61905 .33173 L
.62381 .3424 L
.62857 .36303 L
.63333 .36726 L
.6381 .37154 L
.64286 .37505 L
.64762 .39608 L
.65238 .40228 L
.65714 .43277 L
.6619 .43249 L
.66667 .45084 L
.67143 .47707 L
.67619 .45192 L
.68095 .44256 L
.68571 .434 L
.69048 .42949 L
.69524 .43018 L
.7 .41351 L
.70476 .4134 L
.70952 .39614 L
.71429 .38457 L
.71905 .3762 L
.72381 .38825 L
.72857 .37823 L
.73333 .38445 L
Mistroke
.7381 .3784 L
.74286 .40631 L
.74762 .39172 L
.75238 .39877 L
.75714 .40716 L
.7619 .39566 L
.76667 .39619 L
.77143 .35532 L
.77619 .34895 L
.78095 .33444 L
.78571 .32019 L
.79048 .32945 L
.79524 .36615 L
.8 .35376 L
.80476 .33784 L
.80952 .32915 L
.81429 .34395 L
.81905 .32247 L
.82381 .31147 L
.82857 .30065 L
.83333 .31163 L
.8381 .32891 L
.84286 .33769 L
.84762 .31156 L
.85238 .304 L
.85714 .31169 L
.8619 .31338 L
.86667 .3187 L
.87143 .32973 L
.87619 .32587 L
.88095 .31969 L
.88571 .31511 L
.89048 .33783 L
.89524 .35048 L
.9 .33366 L
.90476 .32771 L
.90952 .34124 L
.91429 .34122 L
.91905 .31787 L
.92381 .32158 L
.92857 .30682 L
.93333 .31824 L
.9381 .36049 L
.94286 .35524 L
.94762 .33937 L
.95238 .34941 L
.95714 .35933 L
.9619 .36656 L
.96667 .38001 L
.97143 .38632 L
Mistroke
.97619 .39555 L
Mfstroke
0 1 1 r
gsave
.97619 .37098 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .21041 L
.03333 .19909 L
.0381 .21274 L
.04286 .24162 L
.04762 .26133 L
.05238 .23626 L
.05714 .24478 L
.0619 .24497 L
.06667 .24061 L
.07143 .24429 L
.07619 .26564 L
.08095 .2773 L
.08571 .29382 L
.09048 .31364 L
.09524 .30261 L
.1 .31517 L
.10476 .30904 L
.10952 .31511 L
.11429 .33087 L
.11905 .33319 L
.12381 .33593 L
.12857 .33369 L
.13333 .32923 L
.1381 .30713 L
.14286 .30682 L
.14762 .33668 L
.15238 .3086 L
.15714 .29245 L
.1619 .31125 L
.16667 .315 L
.17143 .30715 L
.17619 .32543 L
.18095 .32849 L
.18571 .3441 L
.19048 .35912 L
.19524 .36002 L
.2 .34698 L
.20476 .35673 L
.20952 .36011 L
.21429 .37684 L
.21905 .38067 L
.22381 .37945 L
.22857 .37165 L
.23333 .36785 L
.2381 .35966 L
.24286 .35155 L
.24762 .36017 L
.25238 .34943 L
.25714 .34747 L
Mistroke
.2619 .37907 L
.26667 .38677 L
.27143 .40087 L
.27619 .42044 L
.28095 .43218 L
.28571 .42355 L
.29048 .40859 L
.29524 .42609 L
.3 .39508 L
.30476 .39069 L
.30952 .3808 L
.31429 .36972 L
.31905 .37993 L
.32381 .37633 L
.32857 .38953 L
.33333 .40882 L
.3381 .39864 L
.34286 .39763 L
.34762 .3931 L
.35238 .38209 L
.35714 .40274 L
.3619 .41179 L
.36667 .41273 L
.37143 .40675 L
.37619 .39963 L
.38095 .39472 L
.38571 .40266 L
.39048 .40537 L
.39524 .39062 L
.4 .40366 L
.40476 .38647 L
.40952 .37167 L
.41429 .37252 L
.41905 .37722 L
.42381 .3595 L
.42857 .37559 L
.43333 .38848 L
.4381 .37084 L
.44286 .38375 L
.44762 .38423 L
.45238 .40021 L
.45714 .39499 L
.4619 .40895 L
.46667 .41224 L
.47143 .40174 L
.47619 .39733 L
.48095 .42557 L
.48571 .40435 L
.49048 .40412 L
.49524 .40459 L
Mistroke
.5 .39045 L
.50476 .39933 L
.50952 .39447 L
.51429 .38355 L
.51905 .40155 L
.52381 .39711 L
.52857 .4125 L
.53333 .42228 L
.5381 .45468 L
.54286 .45299 L
.54762 .47974 L
.55238 .48508 L
.55714 .48534 L
.5619 .49036 L
.56667 .47992 L
.57143 .47868 L
.57619 .47563 L
.58095 .47943 L
.58571 .48839 L
.59048 .47905 L
.59524 .48597 L
.6 .47566 L
.60476 .45887 L
.60952 .44742 L
.61429 .45103 L
.61905 .43631 L
.62381 .44975 L
.62857 .46017 L
.63333 .46204 L
.6381 .45544 L
.64286 .46879 L
.64762 .45197 L
.65238 .44495 L
.65714 .43461 L
.6619 .41386 L
.66667 .37497 L
.67143 .35956 L
.67619 .37545 L
.68095 .37563 L
.68571 .36965 L
.69048 .37506 L
.69524 .37921 L
.7 .35716 L
.70476 .3587 L
.70952 .35601 L
.71429 .34758 L
.71905 .35502 L
.72381 .34162 L
.72857 .34317 L
.73333 .34294 L
Mistroke
.7381 .35603 L
.74286 .36806 L
.74762 .33774 L
.75238 .32357 L
.75714 .30971 L
.7619 .29759 L
.76667 .29841 L
.77143 .29113 L
.77619 .29487 L
.78095 .28496 L
.78571 .29347 L
.79048 .29649 L
.79524 .31133 L
.8 .32995 L
.80476 .32448 L
.80952 .32754 L
.81429 .32718 L
.81905 .34988 L
.82381 .3332 L
.82857 .3406 L
.83333 .33214 L
.8381 .34996 L
.84286 .3706 L
.84762 .41208 L
.85238 .41828 L
.85714 .41408 L
.8619 .4341 L
.86667 .4174 L
.87143 .40595 L
.87619 .41422 L
.88095 .40383 L
.88571 .39214 L
.89048 .39635 L
.89524 .37022 L
.9 .37824 L
.90476 .36412 L
.90952 .39345 L
.91429 .41703 L
.91905 .44263 L
.92381 .41672 L
.92857 .40583 L
.93333 .40097 L
.9381 .41142 L
.94286 .44127 L
.94762 .41547 L
.95238 .41657 L
.95714 .42131 L
.9619 .4086 L
.96667 .39436 L
.97143 .39874 L
Mistroke
.97619 .37098 L
Mfstroke
0 1 .4 r
gsave
.97619 .39407 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .20883 L
.03333 .18589 L
.0381 .18144 L
.04286 .16892 L
.04762 .17233 L
.05238 .18406 L
.05714 .18963 L
.0619 .18502 L
.06667 .19544 L
.07143 .19075 L
.07619 .18669 L
.08095 .19237 L
.08571 .19615 L
.09048 .19512 L
.09524 .17815 L
.1 .17475 L
.10476 .19407 L
.10952 .18562 L
.11429 .18952 L
.11905 .20934 L
.12381 .19971 L
.12857 .18252 L
.13333 .15714 L
.1381 .14091 L
.14286 .13243 L
.14762 .11158 L
.15238 .10973 L
.15714 .11551 L
.1619 .1159 L
.16667 .11637 L
.17143 .09789 L
.17619 .10824 L
.18095 .1285 L
.18571 .12294 L
.19048 .15318 L
.19524 .13712 L
.2 .1462 L
.20476 .134 L
.20952 .14139 L
.21429 .14841 L
.21905 .14593 L
.22381 .14288 L
.22857 .1424 L
.23333 .13934 L
.2381 .16417 L
.24286 .16827 L
.24762 .1721 L
.25238 .15829 L
.25714 .15821 L
Mistroke
.2619 .1724 L
.26667 .20564 L
.27143 .20107 L
.27619 .17745 L
.28095 .16429 L
.28571 .16232 L
.29048 .1663 L
.29524 .1665 L
.3 .181 L
.30476 .16317 L
.30952 .15876 L
.31429 .16274 L
.31905 .18826 L
.32381 .19419 L
.32857 .19288 L
.33333 .19163 L
.3381 .19236 L
.34286 .18659 L
.34762 .19771 L
.35238 .17698 L
.35714 .1629 L
.3619 .18281 L
.36667 .20825 L
.37143 .2103 L
.37619 .20869 L
.38095 .23237 L
.38571 .2395 L
.39048 .24841 L
.39524 .26982 L
.4 .30381 L
.40476 .29254 L
.40952 .31309 L
.41429 .3186 L
.41905 .30508 L
.42381 .27951 L
.42857 .26387 L
.43333 .25315 L
.4381 .24341 L
.44286 .27174 L
.44762 .29591 L
.45238 .30188 L
.45714 .31836 L
.4619 .3534 L
.46667 .35688 L
.47143 .36187 L
.47619 .36147 L
.48095 .3713 L
.48571 .37393 L
.49048 .38829 L
.49524 .39548 L
Mistroke
.5 .40095 L
.50476 .39422 L
.50952 .37861 L
.51429 .36056 L
.51905 .37475 L
.52381 .37011 L
.52857 .36661 L
.53333 .35285 L
.5381 .38413 L
.54286 .4039 L
.54762 .41709 L
.55238 .43406 L
.55714 .44009 L
.5619 .45278 L
.56667 .44938 L
.57143 .46753 L
.57619 .44777 L
.58095 .46208 L
.58571 .46325 L
.59048 .43881 L
.59524 .4405 L
.6 .43623 L
.60476 .43975 L
.60952 .4534 L
.61429 .46211 L
.61905 .46424 L
.62381 .46878 L
.62857 .49961 L
.63333 .49731 L
.6381 .49439 L
.64286 .49899 L
.64762 .49853 L
.65238 .47884 L
.65714 .45982 L
.6619 .45106 L
.66667 .46679 L
.67143 .48312 L
.67619 .4744 L
.68095 .48602 L
.68571 .48931 L
.69048 .48409 L
.69524 .45741 L
.7 .46086 L
.70476 .44743 L
.70952 .4645 L
.71429 .45986 L
.71905 .48092 L
.72381 .47395 L
.72857 .48968 L
.73333 .50217 L
Mistroke
.7381 .48217 L
.74286 .47052 L
.74762 .47028 L
.75238 .47909 L
.75714 .46433 L
.7619 .48027 L
.76667 .49291 L
.77143 .47789 L
.77619 .47432 L
.78095 .47821 L
.78571 .47355 L
.79048 .47527 L
.79524 .46347 L
.8 .4392 L
.80476 .42814 L
.80952 .42726 L
.81429 .4181 L
.81905 .40316 L
.82381 .3977 L
.82857 .41724 L
.83333 .417 L
.8381 .41879 L
.84286 .41749 L
.84762 .397 L
.85238 .38639 L
.85714 .36844 L
.8619 .38802 L
.86667 .40604 L
.87143 .38982 L
.87619 .38582 L
.88095 .37458 L
.88571 .37602 L
.89048 .35911 L
.89524 .34258 L
.9 .35014 L
.90476 .3348 L
.90952 .33553 L
.91429 .30735 L
.91905 .33255 L
.92381 .34496 L
.92857 .35888 L
.93333 .35827 L
.9381 .36063 L
.94286 .38295 L
.94762 .38774 L
.95238 .38589 L
.95714 .38629 L
.9619 .39298 L
.96667 .40117 L
.97143 .40948 L
Mistroke
.97619 .39407 L
Mfstroke
.2 1 0 r
gsave
.97619 .43631 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .2147 L
.03333 .20367 L
.0381 .20451 L
.04286 .20604 L
.04762 .22604 L
.05238 .24026 L
.05714 .24882 L
.0619 .24268 L
.06667 .24434 L
.07143 .25581 L
.07619 .26663 L
.08095 .26788 L
.08571 .27283 L
.09048 .26608 L
.09524 .24518 L
.1 .26398 L
.10476 .28148 L
.10952 .28178 L
.11429 .26372 L
.11905 .27365 L
.12381 .29688 L
.12857 .29055 L
.13333 .30022 L
.1381 .30383 L
.14286 .3047 L
.14762 .29387 L
.15238 .30575 L
.15714 .30624 L
.1619 .30709 L
.16667 .32508 L
.17143 .323 L
.17619 .29516 L
.18095 .30708 L
.18571 .30831 L
.19048 .32712 L
.19524 .32432 L
.2 .32332 L
.20476 .31512 L
.20952 .33322 L
.21429 .31392 L
.21905 .31609 L
.22381 .29059 L
.22857 .28249 L
.23333 .30429 L
.2381 .3013 L
.24286 .30433 L
.24762 .2852 L
.25238 .29524 L
.25714 .26808 L
Mistroke
.2619 .27297 L
.26667 .27908 L
.27143 .25801 L
.27619 .26685 L
.28095 .27682 L
.28571 .29027 L
.29048 .29494 L
.29524 .2917 L
.3 .31571 L
.30476 .3209 L
.30952 .35263 L
.31429 .35566 L
.31905 .33777 L
.32381 .36099 L
.32857 .35164 L
.33333 .3494 L
.3381 .35644 L
.34286 .35911 L
.34762 .37492 L
.35238 .36921 L
.35714 .36557 L
.3619 .39042 L
.36667 .41786 L
.37143 .41648 L
.37619 .41716 L
.38095 .41266 L
.38571 .41557 L
.39048 .41138 L
.39524 .41273 L
.4 .42673 L
.40476 .44166 L
.40952 .43141 L
.41429 .42739 L
.41905 .41556 L
.42381 .41261 L
.42857 .41708 L
.43333 .41222 L
.4381 .40994 L
.44286 .40561 L
.44762 .39186 L
.45238 .37952 L
.45714 .3965 L
.4619 .39593 L
.46667 .389 L
.47143 .39706 L
.47619 .37547 L
.48095 .35978 L
.48571 .35572 L
.49048 .34787 L
.49524 .33865 L
Mistroke
.5 .32216 L
.50476 .3271 L
.50952 .30833 L
.51429 .31175 L
.51905 .31753 L
.52381 .32847 L
.52857 .32834 L
.53333 .33092 L
.5381 .31277 L
.54286 .33036 L
.54762 .30113 L
.55238 .2951 L
.55714 .27736 L
.5619 .27412 L
.56667 .26268 L
.57143 .25641 L
.57619 .26006 L
.58095 .26558 L
.58571 .25089 L
.59048 .23949 L
.59524 .22693 L
.6 .23694 L
.60476 .22195 L
.60952 .23501 L
.61429 .229 L
.61905 .22519 L
.62381 .25444 L
.62857 .27699 L
.63333 .27568 L
.6381 .27947 L
.64286 .27901 L
.64762 .27613 L
.65238 .26302 L
.65714 .26749 L
.6619 .23991 L
.66667 .23293 L
.67143 .24635 L
.67619 .27172 L
.68095 .28162 L
.68571 .27868 L
.69048 .29424 L
.69524 .2951 L
.7 .30957 L
.70476 .30493 L
.70952 .30253 L
.71429 .29865 L
.71905 .30057 L
.72381 .28205 L
.72857 .27927 L
.73333 .27484 L
Mistroke
.7381 .27641 L
.74286 .27911 L
.74762 .30103 L
.75238 .29127 L
.75714 .27644 L
.7619 .26152 L
.76667 .28639 L
.77143 .28407 L
.77619 .29399 L
.78095 .3121 L
.78571 .30552 L
.79048 .30122 L
.79524 .31093 L
.8 .30063 L
.80476 .3193 L
.80952 .33833 L
.81429 .34199 L
.81905 .34212 L
.82381 .34204 L
.82857 .34058 L
.83333 .35463 L
.8381 .33943 L
.84286 .35288 L
.84762 .37188 L
.85238 .36807 L
.85714 .39793 L
.8619 .39797 L
.86667 .39652 L
.87143 .41624 L
.87619 .41265 L
.88095 .40264 L
.88571 .42497 L
.89048 .43402 L
.89524 .43289 L
.9 .42802 L
.90476 .41919 L
.90952 .41718 L
.91429 .43119 L
.91905 .42076 L
.92381 .39134 L
.92857 .4142 L
.93333 .42746 L
.9381 .43381 L
.94286 .44129 L
.94762 .44196 L
.95238 .44318 L
.95714 .45625 L
.9619 .4455 L
.96667 .42693 L
.97143 .41148 L
Mistroke
.97619 .43631 L
Mfstroke
.8 1 0 r
gsave
.97619 .44583 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .20452 L
.03333 .2205 L
.0381 .22397 L
.04286 .20457 L
.04762 .17875 L
.05238 .18875 L
.05714 .2015 L
.0619 .20478 L
.06667 .17854 L
.07143 .16896 L
.07619 .17522 L
.08095 .18392 L
.08571 .20431 L
.09048 .20333 L
.09524 .20092 L
.1 .20781 L
.10476 .22103 L
.10952 .23032 L
.11429 .23838 L
.11905 .25018 L
.12381 .28081 L
.12857 .27735 L
.13333 .25345 L
.1381 .23058 L
.14286 .21473 L
.14762 .19915 L
.15238 .16202 L
.15714 .16331 L
.1619 .18017 L
.16667 .16931 L
.17143 .18597 L
.17619 .19807 L
.18095 .18566 L
.18571 .17785 L
.19048 .16459 L
.19524 .18801 L
.2 .1937 L
.20476 .20864 L
.20952 .20993 L
.21429 .20123 L
.21905 .22332 L
.22381 .21241 L
.22857 .1931 L
.23333 .18277 L
.2381 .17189 L
.24286 .18423 L
.24762 .1871 L
.25238 .20484 L
.25714 .23223 L
Mistroke
.2619 .26282 L
.26667 .28158 L
.27143 .2981 L
.27619 .28373 L
.28095 .26373 L
.28571 .26825 L
.29048 .27359 L
.29524 .28148 L
.3 .26499 L
.30476 .26157 L
.30952 .25998 L
.31429 .26202 L
.31905 .24707 L
.32381 .26493 L
.32857 .25418 L
.33333 .25338 L
.3381 .23683 L
.34286 .24819 L
.34762 .2913 L
.35238 .29318 L
.35714 .29266 L
.3619 .30478 L
.36667 .30056 L
.37143 .32269 L
.37619 .33675 L
.38095 .35435 L
.38571 .3483 L
.39048 .34744 L
.39524 .3311 L
.4 .3196 L
.40476 .32127 L
.40952 .33196 L
.41429 .32413 L
.41905 .33899 L
.42381 .33512 L
.42857 .31501 L
.43333 .28947 L
.4381 .30333 L
.44286 .30168 L
.44762 .29532 L
.45238 .27854 L
.45714 .2955 L
.4619 .31264 L
.46667 .32076 L
.47143 .30759 L
.47619 .2913 L
.48095 .28689 L
.48571 .28242 L
.49048 .27701 L
.49524 .27502 L
Mistroke
.5 .26554 L
.50476 .2421 L
.50952 .26245 L
.51429 .27093 L
.51905 .24808 L
.52381 .23893 L
.52857 .24319 L
.53333 .24033 L
.5381 .22624 L
.54286 .22275 L
.54762 .25501 L
.55238 .24086 L
.55714 .22543 L
.5619 .22079 L
.56667 .22283 L
.57143 .2255 L
.57619 .22139 L
.58095 .22297 L
.58571 .21761 L
.59048 .21975 L
.59524 .20561 L
.6 .20854 L
.60476 .23195 L
.60952 .21173 L
.61429 .23016 L
.61905 .21321 L
.62381 .23411 L
.62857 .26354 L
.63333 .25688 L
.6381 .24988 L
.64286 .24216 L
.64762 .2295 L
.65238 .21116 L
.65714 .2243 L
.6619 .23694 L
.66667 .22961 L
.67143 .22216 L
.67619 .25849 L
.68095 .27282 L
.68571 .2649 L
.69048 .27154 L
.69524 .2622 L
.7 .27323 L
.70476 .25801 L
.70952 .26589 L
.71429 .26973 L
.71905 .27203 L
.72381 .26233 L
.72857 .24426 L
.73333 .24828 L
Mistroke
.7381 .23779 L
.74286 .24629 L
.74762 .25678 L
.75238 .24742 L
.75714 .23531 L
.7619 .23092 L
.76667 .22222 L
.77143 .25671 L
.77619 .25186 L
.78095 .25223 L
.78571 .22989 L
.79048 .25278 L
.79524 .26091 L
.8 .25237 L
.80476 .26091 L
.80952 .24077 L
.81429 .26643 L
.81905 .25261 L
.82381 .29141 L
.82857 .2796 L
.83333 .28924 L
.8381 .2784 L
.84286 .26042 L
.84762 .26547 L
.85238 .27367 L
.85714 .25583 L
.8619 .26386 L
.86667 .25535 L
.87143 .27097 L
.87619 .25442 L
.88095 .26268 L
.88571 .24678 L
.89048 .23075 L
.89524 .25325 L
.9 .26528 L
.90476 .27466 L
.90952 .27655 L
.91429 .27897 L
.91905 .27672 L
.92381 .29876 L
.92857 .31814 L
.93333 .35498 L
.9381 .348 L
.94286 .38095 L
.94762 .4064 L
.95238 .39149 L
.95714 .39128 L
.9619 .39566 L
.96667 .42182 L
.97143 .40435 L
Mistroke
.97619 .44583 L
Mfstroke
1 .6 0 r
gsave
.97619 .40623 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .20601 m
.02857 .20941 L
.03333 .22839 L
.0381 .23498 L
.04286 .22575 L
.04762 .21962 L
.05238 .22904 L
.05714 .22574 L
.0619 .22416 L
.06667 .23633 L
.07143 .24092 L
.07619 .24628 L
.08095 .25438 L
.08571 .24886 L
.09048 .2715 L
.09524 .28854 L
.1 .25856 L
.10476 .26735 L
.10952 .28095 L
.11429 .27182 L
.11905 .27991 L
.12381 .30651 L
.12857 .30322 L
.13333 .30224 L
.1381 .3364 L
.14286 .33655 L
.14762 .35692 L
.15238 .34237 L
.15714 .31701 L
.1619 .32427 L
.16667 .30085 L
.17143 .28777 L
.17619 .30194 L
.18095 .30828 L
.18571 .31356 L
.19048 .30712 L
.19524 .31407 L
.2 .30962 L
.20476 .33169 L
.20952 .31134 L
.21429 .31974 L
.21905 .29628 L
.22381 .28097 L
.22857 .28894 L
.23333 .3002 L
.2381 .3101 L
.24286 .29973 L
.24762 .30818 L
.25238 .31971 L
.25714 .34615 L
Mistroke
.2619 .3479 L
.26667 .35634 L
.27143 .36838 L
.27619 .35851 L
.28095 .35717 L
.28571 .35104 L
.29048 .35744 L
.29524 .36211 L
.3 .35681 L
.30476 .35381 L
.30952 .39525 L
.31429 .42562 L
.31905 .43108 L
.32381 .45356 L
.32857 .45834 L
.33333 .48264 L
.3381 .47754 L
.34286 .48981 L
.34762 .48036 L
.35238 .46725 L
.35714 .46036 L
.3619 .47207 L
.36667 .49057 L
.37143 .45399 L
.37619 .44734 L
.38095 .43757 L
.38571 .44013 L
.39048 .45038 L
.39524 .45228 L
.4 .44343 L
.40476 .44063 L
.40952 .47061 L
.41429 .45484 L
.41905 .43649 L
.42381 .45495 L
.42857 .44509 L
.43333 .41312 L
.4381 .38991 L
.44286 .37755 L
.44762 .37936 L
.45238 .34955 L
.45714 .33632 L
.4619 .32264 L
.46667 .29634 L
.47143 .3143 L
.47619 .3077 L
.48095 .29465 L
.48571 .29749 L
.49048 .30621 L
.49524 .30113 L
Mistroke
.5 .31311 L
.50476 .30201 L
.50952 .30786 L
.51429 .32287 L
.51905 .34154 L
.52381 .33144 L
.52857 .31595 L
.53333 .31795 L
.5381 .29641 L
.54286 .30529 L
.54762 .32561 L
.55238 .33072 L
.55714 .31864 L
.5619 .29953 L
.56667 .29932 L
.57143 .31042 L
.57619 .34577 L
.58095 .33486 L
.58571 .35569 L
.59048 .34389 L
.59524 .36096 L
.6 .35318 L
.60476 .33408 L
.60952 .34593 L
.61429 .33405 L
.61905 .34207 L
.62381 .32957 L
.62857 .33038 L
.63333 .34216 L
.6381 .33742 L
.64286 .3247 L
.64762 .29409 L
.65238 .30128 L
.65714 .30487 L
.6619 .30805 L
.66667 .3338 L
.67143 .33716 L
.67619 .35222 L
.68095 .33578 L
.68571 .3637 L
.69048 .36246 L
.69524 .40471 L
.7 .41496 L
.70476 .43988 L
.70952 .42834 L
.71429 .42419 L
.71905 .46864 L
.72381 .48031 L
.72857 .4682 L
.73333 .44842 L
Mistroke
.7381 .42595 L
.74286 .44027 L
.74762 .44909 L
.75238 .44274 L
.75714 .46982 L
.7619 .47339 L
.76667 .44547 L
.77143 .44951 L
.77619 .44052 L
.78095 .42297 L
.78571 .42387 L
.79048 .42697 L
.79524 .41914 L
.8 .41799 L
.80476 .40011 L
.80952 .42145 L
.81429 .41451 L
.81905 .41712 L
.82381 .41281 L
.82857 .42597 L
.83333 .38689 L
.8381 .38248 L
.84286 .38217 L
.84762 .3991 L
.85238 .39383 L
.85714 .41655 L
.8619 .42545 L
.86667 .44207 L
.87143 .43474 L
.87619 .45444 L
.88095 .45519 L
.88571 .45113 L
.89048 .46242 L
.89524 .47213 L
.9 .46791 L
.90476 .44032 L
.90952 .4464 L
.91429 .41575 L
.91905 .39576 L
.92381 .36153 L
.92857 .38101 L
.93333 .36677 L
.9381 .36097 L
.94286 .36865 L
.94762 .3837 L
.95238 .39355 L
.95714 .40799 L
.9619 .41779 L
.96667 .40583 L
.97143 .4141 L
Mistroke
.97619 .40623 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{281.438, 173.875},
  ImageMargins->{{33, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`007@3oool2000002P0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000008@3oool2
000000@0oooo00<000000?ooo`3oool00`3oool300000240oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000R0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000:03oool3
000000T0oooo000L0?ooo`040000003oool0oooo000002H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool07`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000803oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo
0?ooo`080?ooo`00703oool010000000oooo0?ooo`00000V0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`0000070?ooo`D00000803oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000803oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo0?ooo`080?ooo`00
703oool010000000oooo0?ooo`00000V0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool07`3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo00000240oooo00@0
00000?ooo`3oool000001`3oool400000240oooo00@000000?ooo`3oool00000203oool3000002T0
oooo00<000000?ooo`3oool0203oool001`0oooo00@000000?ooo`3oool000009P3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000803oool010000000oooo0?ooo`00
00080?ooo`030000003oool000000240oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0R0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000X0?oo
o`030000003oool0oooo00P0oooo000L0?ooo`040000003oool0oooo000002H0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool000000200oooo00@000000?ooo`3oool00000
2@3oool200000240oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0Q0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`8000002P3oool0
01d0oooo0P00000X0?ooo`8000002@3oool300000280oooo0P00000;0?ooo`030000003oool0oooo
0200oooo0P00000:0?ooo`8000008P3oool2000000T0oooo0`00000Y0?ooo`030000003oool0oooo
00P0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo000H0?oo
ooh000000`3oool001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003o
ool0oooo0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0nP3oool0
0`000000oooo0?ooo`010?ooo`00603oool200000?X0oooo0P0000030?ooo`00603oool00`000000
oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo0?X0oooo
00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?oo
o`010?ooo`00603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?oo
o`800000nP3oool2000000<0oooo000H0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3o
ool00@3oool001P0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`010?ooo`00603o
ool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0
oooo0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo0P00003j0?ooo`8000000`3oool001P0
oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo
0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo0?X0oooo00<0
00000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`01
0?ooo`00603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`80
0000M`3oool20?l00840oooo0P0000030?ooo`00603oool00`000000oooo0?ooo`1f0?ooo`030?l0
003oool0o`000080oooo00<0o`000?ooo`3oool0O03oool00`000000oooo0?ooo`010?ooo`001@3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0M@3o
ool01@3o0000oooo0?ooo`3o0000oooo0080o`00OP3oool00`000000oooo0?ooo`010?ooo`00103o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`1e0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0?l0001n0?ooo`030000003oool0
oooo0040oooo00040?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0X0?ooo`03003oIP3oool0oooo04X0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`1k0?ooo`030000003oool0oooo0040oooo00040?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool00P3oool2000002T0oooo00<00?mV0?ooo`3oool0>@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0N@3oool3
000000<0oooo00040?ooo`040000003oool0oooo000000L0oooo100000050?ooo`030000003oool0
oooo02P0oooo0P00ofHi0?ooo`030?l0003oool0o`0000h0oooo00<0o`000?ooo`3oool01@3oool4
0?l007X0oooo00<000000?ooo`3oool00@3oool000@0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo0`00ofH20?ooo`03003oIP3oool0
0?mV03P0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool0M`3oool00`000000oooo0?ooo`010?ooo`001@3oool2000000P0oooo1@000004
0?ooo`030000003oool0oooo0280oooo00<00?mV0?ooo`3oool00`00ofH20?ooo`03003oIP3oool0
oooo03D0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`1g0?ooo`030000003oool0oooo0040oooo000H
0?ooo`030000003oool0oooo0280oooo00<00?mV0?ooo`3oool01@3oool00`00ofH0oooo0?ooo`0e
0?ooo`030?l0003oool0oooo0080oooo0`3o000:0?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool0M`3oool00`000000oooo0?ooo`010?ooo`00603oool200000280oooo00<00?mV0?oo
o`3oool01P3oool00`00ofH0oooo003oIP0e0?ooo`030?l0003oool0oooo00@0oooo00D0o`000?oo
o`3oool0oooo0?l000060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0MP3oool2
000000<0oooo000H0?ooo`030000003oool0oooo0240oooo00<00?mV0?ooo`3oool01`3oool2003o
IS80oooo0`3o00080?ooo`040?l0003oool0oooo0?l000H0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo
0240oooo00<00?mV0?ooo`3oool0203oool00`00ofH0oooo0?ooo`0_0?ooo`040?l0003oool0o`00
0?l000P0oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo07H0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool08@3oool0
0`00ofH0oooo0?ooo`080?ooo`03003oIP3oool00?mV0080oooo00<00?mV0?ooo`3oool0:P3oool0
103o0000oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0?l000D0oooo00<0o`000?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`1f0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003o
ool0oooo0200oooo00<00?mV0?ooo`3oool02@3oool00`00ofH0oooo003oIP020?ooo`03003oIP3o
ool0oooo00@0oooo00<00?mV0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003o
ool0o`000?l00080oooo0`3o000=0?ooo`030?l0003oool0oooo07H0oooo00<000000?ooo`3oool0
0@3oool001P0oooo0P00000Q0?ooo`03003oIP3oool0oooo00L0oooo0P3o09T00`3oool00?mV003o
IP02003oIP040?ooo`00ofH0oooo0?ooo`@00?mV9@3oool00`3o0000oooo0?ooo`0:0?ooo`80o`00
00@0oooo0?l0003o0000o`00403oool00`3o0000oooo0?ooo`1e0?ooo`8000000`3oool001P0oooo
00<000000?ooo`3oool0803oool00`00ofH0oooo0?ooo`060?ooo`070?l0V@3oool0o`2I0?ooo`00
ofH0oooo003oIP030?ooo`800?mV0`3oool00`00ofH0oooo0?ooo`0R0?ooo`030?l0003oool0oooo
00/0oooo0P3o00000`3oool0o`000?ooo`0A0?ooo`030?l0003oool0oooo07H0oooo00<000000?oo
o`3oool00@3oool001P0oooo00<000000?ooo`3oool07`3oool00`00ofH0oooo0?ooo`070?ooo`05
0?l0V@3oool0o`2I0?ooo`00ofH02P3oool00`00ofH0oooo0?ooo`0R0?ooo`030?l0003oool0oooo
00`0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`1f0?ooo`030000003oool0oooo
0040oooo000H0?ooo`030000003oool0oooo01l0oooo00<00?mV0?ooo`3oool01`3oool01@3o09T0
oooo0?l0V@3oool00?mV00/0oooo00<00?mV0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo01<0oooo00D0o`000?ooo`3o0000oooo0?l0001c0?ooo`030000003oool0
oooo0040oooo000H0?ooo`030000003oool0oooo01l0oooo00<00?mV0?ooo`3oool01`3oool00`3o
09T0oooo0?l0V@0=0?ooo`04003oIP3oool0oooo0?ooo`800?mV303oool00`00ofH0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo0280oooo00D0o`000?ooo`3o0000oooo0?l0001c0?ooo`030000003o
ool0oooo0040oooo000H0?ooo`800000803oool01000ofH0oooo0?ooo`3oool30<co00030?ooo`3o
09T0o`2I0080oooo00<0o`2I0?ooo`3<o`002`3oool01000ofH0oooo0?ooo`3oool2003oIPD0oooo
0P00ofH40?ooo`03003oIP3oool00?mV00X0oooo00@00?mV0?ooo`3oool0oooo0P3o000U0?ooo`80
o`0000@0oooo0?l0003oool0o`00L@3oool2000000<0oooo000H0?ooo`030000003oool0oooo00P0
oooo00<00?mV0?ooo`3oool0103oool00`3<o`00oooo0?ooo`0<0?ooo`03003oIP3oool0oooo0080
oooo00@0c?l00?l0V@3<o`00oooo0P3o09T30?ooo`030?l0V@3<o`00oooo00/0oooo00<00?mV0?oo
o`00ofH00P3oool00`00ofH0oooo0?ooo`020?ooo`04003oIP3oool00?mV003oIP80oooo00<00?mV
0?ooo`00ofH02P3oool01@00ofH0oooo0?ooo`3oool0o`0002H0oooo00H0o`000?ooo`3oool0o`00
0?ooo`3o000I0?ooo`030?l0003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool001P0oooo
00<000000?ooo`3oool0203oool2003oIPD0oooo00<0c?l00?ooo`3oool0303oool00`00ofH0oooo
0?ooo`020?ooo`060<co003oool0c?l00?l0V@3<o`00o`2I0`3oool00`3o09T0c?l00?ooo`0:0?oo
o`030<co003oool00?mV00<0oooo00<00?mV0?ooo`3oool00P3oool01000ofH0oooo0?ooo`00ofH2
0?ooo`04003oIP3oool0oooo003oIPT0oooo00D00?mV0?ooo`3oool0oooo0?l0000[0?ooo`030?l0
003oool0oooo01H0oooo0P3o001H0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003o
ool0oooo00H0oooo00@0o`2I003oIP3oool00?mV103oool00`3<o`00oooo0<co00050?ooo`03003o
IP3oool0oooo00D0oooo00H00?mV0?ooo`3oool0oooo0?l0V@3<o`020?ooo`80c?l000@0o`2I0?oo
o`3oool0oooo0P3<o`0;0?ooo`030<co003oool0oooo00<0oooo00D00?mV0?ooo`3oool0oooo003o
IP040?ooo`800?mV0`3oool00`00ofH0oooo0?ooo`060?ooo`05003oIP3oool00?mV0?ooo`3o0000
;03oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0o`0005P0oooo00<000000?ooo`3oool0
0@3oool001P0oooo00<000000?ooo`3oool01P3oool01@3o09T00?mV0?ooo`3<o`000?mV00<0oooo
00<0c?l00?ooo`3<o`00103oool2003oIPH0oooo00<00?mV0?ooo`3oool00P3oool0103o09T0c?l0
0?ooo`3oool20<co00@0oooo00<0c?l00?l0V@3<o`002@3oool00`3<o`00oooo0<co00040?ooo`05
003oIP3oool0oooo0?ooo`00ofH0103oool2003oIP<0oooo00<00?mV0?ooo`3oool01P3oool01@00
ofH0oooo003oIP3oool0o`0002d0oooo00<0o`000?ooo`3oool0503oool0103o0000oooo0?ooo`3o
001G0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo00H0oooo00D00?mV
0?ooo`3o09T0c?l0003oIP030?ooo`040<co003oool0oooo0<co00<0oooo0P00ofH60?ooo`03003o
IP3oool0oooo0080oooo00<0c?l00?ooo`3oool00`3oool01`3<o`00oooo0?ooo`3oool0c?l00?l0
V@3<o`002@3oool00`3<o`00oooo0<co00040?ooo`05003oIP3oool0oooo0?ooo`00ofH01@3oool0
0`00ofH0oooo0?ooo`020?ooo`03003oIP3oool0oooo00D0oooo00<00?mV0?l00000ofH00P3o0009
0?ooo`030?l0V@3oool0oooo0240oooo00<0o`000?ooo`3oool0503oool0103o0000oooo0?ooo`3o
001G0?ooo`030000003oool0oooo0040oooo000H0?ooo`8000001P3oool01000ofH0o`2I0?ooo`3o
09T20<co00070?ooo`00ofH00?mV0<co003oool00?mV0<co00030?ooo`05003oIP3oool00?mV0?oo
o`00ofH00`3oool00`00ofH0oooo0?ooo`020?ooo`030<co003oool0oooo00<0oooo00L0c?l00?oo
o`3oool0c?l00?ooo`3o09T0c?l000<0oooo0P3<0?l40?ooo`040<co003oool0oooo0<co00<0oooo
00@00?mV0?ooo`3oool00?mV2`3oool01@00ofH0oooo0?ooo`3oool0o`0000800?mV00@0oooo003o
IP3oool00?mV2`3oool20?l0V@030?ooo`3o09T0oooo0200oooo00<0o`000?ooo`3oool04P3oool0
1@3o0000oooo0?ooo`3oool0o`0005H0oooo0P0000030?ooo`00603oool00`000000oooo0?ooo`05
0?ooo`04003oIP3oool0oooo0?l0V@80c?l000X00?mV0?ooo`00ofH0c?l0003oIP3o09T00?mV0<co
003oool00?mV0P3oool2003oIP050?ooo`00ofH0oooo0?ooo`00ofH00`3oool00`3o09T0c?l00?oo
o`040?ooo`040<co003<0?l0oooo0<co0080oooo00@0c?l00?l0V@3oool0oooo0P3<0?l30?ooo`05
0<co003oool0oooo0?ooo`3<o`00103oool00`00ofH0oooo003oIP0;0?ooo`03003oIP3oool0oooo
00800?mV00@0oooo003oIP00ofH0o`000P3oool00`00ofH0oooo0?ooo`030?ooo`80o`2I0`3oool0
103o09T0oooo0?l0V@3o09TR0?ooo`030?l0003oool0oooo0140oooo00D0o`000?ooo`3oool0oooo
0?l0001G0?ooo`030000003oool0oooo0040oooo000@0?ooo`<000001@3oool00`000000oooo0?oo
o`050?ooo`06003oIP3oool0oooo0<co003oool0c?l00P3oool00`3<o`000?mV0?ooo`020?l0V@03
0<co0000ofH00?mV0080oooo00H00?mV0?ooo`3oool00?mV0?ooo`00ofH40?ooo`030?l0V@3<o`00
oooo00D0oooo0P3<o`030?ooo`040?l0V@3<o`00oooo0?ooo`80c03o0`3oool00`3<o`00oooo0?oo
o`020?ooo`070<co003oool0oooo0?ooo`00ofH0oooo003oIP0<0?ooo`800?mV00D0o`000?ooo`3o
ool0o`00003oIP030?ooo`03003oIP3oool0oooo0080oooo00<0o`2I0?ooo`3o09T00`3oool01P3o
09T0oooo0?ooo`3oool0o`2I0?ooo`<0o`2I7P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0E03oool00`000000oooo0?ooo`010?ooo`004@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00/00?mV0?ooo`3oool0c?l00?l0
V@3oool0c?l00?ooo`3<o`00oooo0?l0V@020?ooo`030<co003oool0oooo00D0oooo00<00?mV0?oo
o`00ofH0103oool00`3o09T0c?l00?ooo`050?ooo`030<co003oool0oooo0080oooo00H0o`2I0<co
003oool0c03o0?ooo`3<0?l30?ooo`030<co003oool0oooo0080oooo00@0c?l00?ooo`3oool0oooo
0P00ofH>0?ooo`030?l0003oool0oooo0080oooo00D00?mV0?ooo`3oool0oooo003oIP040?ooo`06
0?l0V@3oool0oooo0?l0V@3oool0o`2I103oool01@3o09T0oooo0?l0V@3oool0o`2I01h0oooo00<0
o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo05@0oooo00<0
00000?ooo`3oool00@3oool00140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`070<co000co`00<ol003?o003<o`00o`2I0?ooo`030<co00050?ooo`3o09T0oooo0?ooo`3o
09T00`3<o`050?ooo`800?mV103oool00`3o09T0c?l00?ooo`050?ooo`80c03o0`3oool20?l0V@08
0<co003<0?l0oooo0<co003<0?l0oooo0<co003<0?l40?ooo`040<co003oool0oooo0?ooo`800?mV
3P3oool00`3o0000oooo0?ooo`070?ooo`04003oIP3oool0oooo0?l0V@<0oooo00<0o`2I0?ooo`3o
09T0103oool01@3o09T0oooo0?l0V@3oool0o`2I01h0oooo00<0o`000?ooo`3o00003P3oool20?l0
00D0oooo00<0o`000?ooo`3oool0E03oool00`000000oooo0?ooo`010?ooo`004@3oool00`000000
oooo0?ooo`040?ooo`800000103oool00`3oV@00c?l003?o00020?ooo`070<co003o09T0o`2I0?oo
o`3o09T0c?l00?l0V@040?ooo`80o`2I00<0oooo0<co003oool00`3oool00`00ofH0oooo0?ooo`03
0?ooo`030?l0V@3<o`00oooo00@0oooo00<0c03o0?ooo`3<0?l01@3oool0103<o`00c03o0?ooo`3<
o`020<`0o`030<co003o09T0c03o00@0oooo00@0c?l00?ooo`3oool00?mV3`3oool00`3o0000oooo
0?ooo`070?ooo`04003oIP3o09T0o`2I0?l0V@@0oooo0P3o09T50?ooo`050?l0V@3oool0oooo0?oo
o`3o09T07@3oool00`3o0000oooo0?l000050?ooo`<0c?l01P3oool20?l000H0oooo00<0o`000?oo
o`3oool0D@3oool3000000<0oooo000A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool01P0co`00oiT00?ooo`00ool0c?l003?o0080oooo00<0o`2I0?ooo`3oool01P3oool0
0`3o09T0oooo0<co00040?ooo`03003oIP3oool0oooo0080oooo00<0o`2I0<co003oool01@3oool0
0`3<0?l0oooo0<`0o`050?ooo`090?l0V@3<o`00c?l00<co003<0?l0c?l00?ooo`3o09T0c03o00@0
oooo00<0c?l00?ooo`3oool0403oool00`3o0000oooo0?ooo`080?ooo`800?mV1@3oool00`3o09T0
oooo0?ooo`040?ooo`050?l0V@3oool0oooo0?ooo`3o09T07P3oool30?l00080oooo00L0o`000?oo
o`3<o`00oooo0<co003o0000c?l000@0oooo00<0o`000?ooo`3oool00`3oool00`3<o`00oooo0?l0
00020?ooo`030?l0003oool0oooo0500oooo00<000000?ooo`3oool00@3oool00100oooo0P000006
0?ooo`030000003oool0oooo00<0oooo00H0o`000?nI003<o`000?oo0<co000co`0<0?ooo`030?l0
V@3<o`00oooo0080o`0000<0o`2I0?ooo`3oool00`3oool00`3o09T0c?l00?ooo`030<`0o`80oooo
00@0c03o0?ooo`3oool0c03o103oool0103<0?l0oooo0?ooo`3oool20<co0080o`2I00<0c03o0?oo
o`3oool00P3oool00`3<o`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo00<0oooo00L0o`2I0?oo
o`3oool0oooo0?l0V@3oool00?mV0100oooo00<0o`2I0?ooo`3o09T0703oool00`3o0000oooo0?l0
00020?ooo`090?l0003<o`00oooo0?l0003<o`00o`000<co003oool0c?l00080oooo00<0o`000?oo
o`3oool00`3oool00`3<o`00oooo0?l000020?ooo`030?l0003oool0oooo0500oooo00<000000?oo
o`3oool00@3oool00140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`07
0?l0003oV@00c?l0003oo`3<o`00<`3o0?nI000;0?ooo`050?l0V@3oool0c?l00?ooo`3o00000`3o
09T30?ooo`040?l0V@3<o`00oooo0<`0o`80oooo00<0c03o0?ooo`3<0?l00P3oool00`3<0?l0oooo
0?ooo`020?ooo`060<`0o`3oool0oooo0?ooo`3<o`00oooo0P3o09T00`3oool0c03o0?ooo`020?oo
o`040<co003oool0oooo0<`0o`h0oooo00<0o`000?ooo`3oool0103oool0103o09T0oooo0?ooo`3o
09T20?ooo`03003oIP3oool0oooo00h0oooo00@0o`2I0?ooo`3o09T0o`2I6`3oool00`3o0000oooo
0?l000020?ooo`80c?l000L0oooo0?l0003<o`00o`000<co003o0000c?l00080oooo00<0o`000?oo
o`3oool00`3oool20<co00040?l0003oool0o`000?l00580oooo00<000000?ooo`3oool00@3oool0
01P0oooo00<000000?ooo`3oool0103oool00`3o0000oiT00<co000203<0o`030?nI003oool0oooo
0080oiT01`3oool00`3o09T0oooo0<co00020?ooo`030?l0V@3oool0o`2I00<0oooo00@0o`2I0<co
003oool0c03o0P3oool00`3<0?l0oooo0<`0o`030?ooo`@0c03o00H0o`2I0?ooo`3oool0oooo0<co
003o09T20?ooo`030?l0V@3<0?l0oooo00<0oooo00<0c?l00?ooo`3<0?l03P3oool00`3o0000oooo
0?ooo`040?ooo`<0o`2I0`3oool00`00ofH0oooo0?ooo`0?0?ooo`030?l0V@3oool0o`2I01D0oooo
00<0c?l00?ooo`3oool00P3oool20<co00040?ooo`3<o`00c?l00<co0080oooo0P3o00000`3oool0
c?l00?ooo`030<co00030?l0003oool0oooo00<0oooo00@0c?l00?ooo`3<o`00oooo0P3o00000`3<
o`00o`000?ooo`0E0?ooo`030<co003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool001P0
oooo0P0000050?ooo`060?l0003oV@00<`3o003oo`3oV@00<ol00P3oV@000`3oool0oiT00?l00004
0?ooo`0:0?l0003oool0o`2I0?ooo`3o09T0c?l00?l0V@3oool0o`000?l0V@<0o`0000@0c?l00?oo
o`3oool0c03o0`3oool00`3<0?l0oooo0?ooo`060?ooo`030?l0V@3oool0oooo0080oooo00H0o`2I
0?ooo`3oool0o`2I0<`0o`3o09T30?ooo`040<co003<0?l0oooo0<`0o`P0oooo0P3<0?l30?ooo`03
0?l0003oool0oooo00<0oooo00<0o`2I0?ooo`3oool01@3oool00`00ofH0oooo0?ooo`0>0?ooo`04
0?l0V@3oool0oooo0?l0VA<0oooo0P3<o`030?ooo`050<co003oool0oooo0<co003oool00P3o0002
0?ooo`0903?o003oool0oooo0<co003o0000c?l003?o003<o`00o`0000D0oooo00D0c?l00?ooo`3<
o`00oooo0?l000020<co00030?l0003oool0oooo01<0oooo0P3<o`0i0?ooo`8000000`3oool001P0
oooo00<000000?ooo`3oool0103oool02`3o0000oiT00?ooo`3oV@00c03o03?o003oV@00o`000?oo
o`3oV@00o`0000<0oooo0140o`000?ooo`3o0000oooo0?l0V@3<0?l0oooo0<co003oool0o`000?oo
o`3o09T0oooo0?l0003<o`00oooo0<`0o`040?ooo`030<`0o`3oool0oooo00L0oooo00@0o`2I0?oo
o`3oool0o`2I0`3oool0103o09T0c03o0?l0V@3<0?l20?ooo`050<co003oool0oooo0?ooo`3<0?l0
1`3oool20<`0o`<0oooo00<0o`000?ooo`3oool00`3oool00`3o09T0oooo0?ooo`050?ooo`03003o
IP3oool0oooo0180oooo00<0o`2I0?ooo`3oool0403oool20<co00040?ooo`3o09T0oooo0<co00D0
oooo00@0o`000?ooo`3oool0<ol00P3oool01P3<o`00<ol00<co000co`00c?l00?l000D0oooo00P0
c?l00?ooo`3<o`00oooo0<co003oool0c?l00?ooo`80o`004P3oool00`3<o`00oooo0<co00030?oo
o`030<co003oool0oooo01P0oooo00<0c?l00?ooo`3oool06@3oool00`000000oooo0?ooo`010?oo
o`00603oool00`000000oooo0?ooo`040?ooo`060?l00000I_l0oiT0003oo`3<0?l0<ol00P3oool2
0?l000040?nI003o0000o`000?l000@0oooo00d0o`2I0<`0o`3oool0c?l00?ooo`3o0000oooo0?l0
V@3oool0o`2I0<co003oool0c03o00h0oooo00@0o`2I0?ooo`3oool0o`2I1@3oool20<`0o`80oooo
00<0c?l00?ooo`3oool00P3oool00`3<0?l0oooo0?ooo`030?ooo`030<`0o`3oool0c03o00<0oooo
00<0o`000?ooo`3oool00`3oool00`3o09T0oooo0?ooo`050?ooo`03003oIP3oool0oooo0180oooo
00<0o`2I0?ooo`3oool0403oool20<co0003001Vo`3o09T0c?l000P0oooo00X0<ol00?ooo`0co`00
<ol00?ooo`0co`00oooo03?o003oool0c?l01@3oool00`3<o`00oooo0?ooo`020<co00050?ooo`3<
o`00oooo0?ooo`3o00004@3oool0103<o`00oooo0?ooo`3<o`030?ooo`030<co003oool0oooo01P0
oooo00<0c?l00?ooo`3oool06@3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo
0?ooo`040?ooo`070?l0003oool006Ko0?ooo`00ool0<`3o03?o00020?ooo`030?l0003oV@00oooo
00L0oooo0P3<0?l02P3oool0c?l00?ooo`3o0000o`2I0?ooo`3o09T0c?l00?l0003<0?l>0?ooo`80
o`2I00<0oooo0?l0V@3oool0103oool40<`0o`030<co003oool0oooo00<0oooo0`3<0?l20?ooo`03
0<`0o`3oool0c03o00<0oooo00@0o`2I0?ooo`3oool0c?l00P3oool00`3o09T0oooo0?ooo`060?oo
o`03003oIP3oool0oooo0140oooo00<0o`2I0?ooo`3oool0303oool02@3<o`00oooo0?ooo`3<o`00
oooo0<co0000I_l0o`2I0<co00080?ooo`0603?o003oool0oooo03?o003oool0o`000P3oool00`0c
o`00c?l00?ooo`030?ooo`080<co003oool0oooo0?ooo`3<o`00<ol00?ooo`3<o`020?ooo`030?l0
003oool0oooo00X0oooo00<0c?l00?ooo`3oool00P3oool0103<o`00oooo0?ooo`3<o`030?ooo`80
c?l06@3oool00`3<o`00oooo0?ooo`0I0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000
003oool0oooo00D0oooo00H0o`00001Vo`3oool00?oo03<0o`0co`020?ooo`0303?o0000ool0oiT0
00H0oooo00P0c03o0?ooo`3oool0c03o0<co003oool0o`000?ooo`80o`2I00@0c?l00?ooo`3<0?l0
o`003`3oool00`3o09T0oooo0?ooo`040?ooo`050<`0o`3o09T0oooo0<`0o`3<o`00103oool01P3o
0000oooo0?ooo`3<0?l0o`000<`0o`80oooo00D0o`000<`0o`3oool0o`000<`0o`020?ooo`040<co
003oool0oooo0?l0V@P0oooo00<00?mV0?ooo`3oool02`3oool00`00ofH0oooo0?ooo`030?ooo`03
0?l0V@3oool0oooo00L0oooo00<0c?l00?ooo`3oool00P3oool40<co0005001Vo`3oool0c?l00<co
003o09T0203oool00`0co`00oooo0?ooo`050?ooo`0303?o003<o`00oooo0080oooo00<0c?l00?oo
o`3oool00P3oool01`0co`00oooo03?o003oool0c?l00?ooo`3o0000303oool20<co0080oooo00<0
c?l00?ooo`3oool00P3oool00`3<o`00oooo0?ooo`020<co00@0oooo00<0c?l00?ooo`3oool04@3o
ool20<co01/0oooo00<000000?ooo`3oool00@3oool001P0oooo0P0000060?ooo`0<0?l00000I_l0
oooo003oo`3oool0<ol0003oo`0co`000?oo03?o0000ool0oiT0103oool0200co`00c03o0?ooo`3o
ool0c03o0?ooo`3<o`00o`000P3oool01@3<o`00oooo0?ooo`3<0?l0o`0001H0oooo00D0c03o0?oo
o`3o09T0o`000<co00040?ooo`050?l0003oool0o`000?ooo`3<0?l00`3oool01`3o0000c03o0?l0
V@3<o`00c03o0?l0V@3oool00P3<o`000`3o09T0oooo0?ooo`080?ooo`03003oIP3oool0oooo00X0
oooo00@00?mV0?ooo`3oool006Ko0P3oool00`3o09T0oooo0?ooo`070?ooo`080<co003oool0oooo
0?l0V@3<o`00oooo0?l0V@3oool2001Vo`050?ooo`3<o`00c?l00?l0V@00I_l00P3oool01@3o09T0
oooo0?ooo`3oool0<ol000P0oooo00<0<ol00<co003oool00P3oool00`3<o`00oooo0?ooo`020?oo
o`0503?o003oool0oooo03?o003<o`000P3oool00`3o0000oooo0?ooo`070?ooo`80c?l00P3oool0
0`3<o`00oooo0<co00040?ooo`050<co003oool0c?l00?ooo`3<o`00103oool00`3<o`00oooo0?oo
o`0A0?ooo`030<co003oool0c?l001T0oooo0P0000030?ooo`00603oool00`000000oooo0?ooo`05
0?ooo`070?l0003oool006Ko003oo`3<0?l00?oo03?o00020?ooo`0403?o0000ool0oiT00?ooo`80
oiT000<0oooo03?o003<0?l00P3oool00`3<0?l0oooo0<co00030?ooo`050<co003oool0oooo0<`0
o`3o0000603oool0103o0000o`2I0?ooo`3<o`020?ooo`80o`0000H0oooo0?l0003o0000oooo0?l0
003oool20?l0V@80c03o00@0c?l00?ooo`3<0?l0c?l00P3o09T00`3<o`00oooo0?ooo`090?ooo`03
003oIP3oool0oooo00P0oooo0P00ofH20?ooo`05001Vo`3oool0oooo0?ooo`3o09T0203oool20<co
00060?ooo`3o09T0c?l00?l0V@3oool006Ko0P3oool0103o09T0c?l0001Vo`3oool2001Vo`030?oo
o`3o09T0oooo0080oooo00<0<ol00?ooo`3oool01`3oool0100co`00c?l00?ooo`3<o`050?ooo`05
03?o003oool0oooo03?o003<o`000P3oool00`3o0000oooo0?ooo`070?ooo`80c?l00P3oool00`3<
o`00oooo0<co00040?ooo`<0c?l00P3oool0103<o`00oooo0?ooo`3oool20<co0180oooo00<0c?l0
0?ooo`3<o`006P3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`080?oo
o`03001Vo`00ool0<`3o00@0oooo00P0<ol00?ooo`3oV@00oooo0?nI003oool0<ol00<`0o`80oooo
00<0c03o0?ooo`3<o`000`3oool01@3<o`00oooo0?ooo`3<0?l0o`0001P0oooo00@0o`000?l0V@3o
0000c?l00P3oool0103o0000oooo0?l0003o00020?ooo`050?l0003oool0o`2I0?l0V@3oool00P3<
o`000`3oool0c?l00<co00020?ooo`030<co003oool0oooo00T0oooo00<00?mV0?ooo`3oool00`3o
ool01`3<0?l0oooo0?ooo`3oool00?mV0?ooo`00ofH00P3oool2001Vo`80oooo00<0o`2I0?ooo`3o
ool01P3oool20<co0080o`2I00@0c?l00?l0V@00I_l0oooo0`3o09T01@3<o`0006Ko001Vo`3oool0
06Ko0080o`2I0`3oool00`0co`00oooo0?ooo`070?ooo`0403?o003<o`00oooo0<co00@0oooo00H0
<ol00?ooo`3oool0oooo03?o003<o`020?ooo`030?l0003oool0oooo00L0oooo00<0c?l00?ooo`3o
ool00P3oool00`3<o`00oooo0?ooo`030?ooo`<0c?l00P3oool0203<o`00oooo0<co003<o`00oooo
0<co003oool0c?l02@3oool01@3<o`00oooo0<co003oool0c?l00080oooo00<0c?l00?ooo`3<o`00
6P3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`080?ooo`03001Vo`00
ool0<`3o00@0oooo00P0<ol0003oo`3oool0oooo0?nI000co`00oooo0?nI00<0oooo00<0c03o0<co
003oool00P3oool00`3<o`00oooo0<`0o`020?ooo`030?l0003oool0oooo01D0oooo00H0o`000?l0
V@3o0000c?l00?l0000co`020?ooo`0;0?l0003oool0oooo0?ooo`3o0000oooo0?l0V@3<o`00oooo
0<co003oool00P3<o`030?ooo`050<co003oool0oooo0?ooo`3<0?l01`3oool00`00ofH0oooo0?oo
o`030?ooo`80c03o00<0<`3o0?ooo`00ofH00P3oool01000ofH006Ko0?ooo`00I_l20?ooo`030?l0
V@3oool0oooo008006Ko0`3oool0203<o`00oooo0<co003o09T0oooo0<co003oool006Ko103oool0
0`3o09T006Ko0?ooo`020?ooo`03001Vo`0co`00o`2I0080oooo00<0<ol00?l0V@3oool01`3oool0
0`0co`00c?l00<co00050?ooo`0603?o003oool0oooo0?ooo`0co`00c?l00P3oool01@3o0000oooo
0?ooo`3oool0c?l000@0oooo00<0c?l00?ooo`3oool00`3oool00`3<o`00oooo0?ooo`030?ooo`03
0<co003oool0oooo0080oooo00P0c?l00?ooo`3<o`00c?l00?ooo`3<o`00oooo0<co00T0oooo00@0
c?l00?ooo`3<o`00oooo0`3<o`020?ooo`030<co003oool0oooo01P0oooo00<000000?ooo`3oool0
0@3oool001P0oooo00<000000?ooo`3oool0203oool00`00I_l00?oo03<0o`050?ooo`0703?o003o
ool0oooo0?ooo`3oV@00oooo0?nI00030?ooo`0503?o003<o`00oooo0?ooo`3<o`000P3oool0103<
0?l0oooo0?ooo`3o000F0?ooo`060?l0003oool0oooo0?l0V@3<o`00o`000P0co`000`3oool0c?l0
0?ooo`030?ooo`040?l0003<o`00oooo0<co0080oooo00<0c?l00<`0o`3oool00P3oool01@3<o`00
oooo0?ooo`3oool0c03o00P0oooo00H00?mV0?ooo`3oool0oooo0<`0o`3oool203<0o`06003oIP3o
ool0oooo0?ooo`00ofH006Ko0P3oool00`00I_l0oooo0?l0V@02001Vo`80oooo00@006Ko0?ooo`3o
ool0c?l00P3oool20<co0003001Vo`3oool006Ko00@0oooo00<0o`2I0?ooo`3oool00P3oool00`0c
o`0006Ko03?o000203?o00030?ooo`3o09T0oooo00L0oooo00<0<ol00<co003oool0103oool203?o
00@0oooo00P0c?l00?ooo`3oool0o`000?ooo`3<o`00oooo0<co00@0oooo00<0c?l00?ooo`3oool0
1P3oool00`0co`00oooo0?ooo`060?ooo`030<co003oool0c?l00080oooo0P3<o`050?ooo`050<co
003oool0oooo0<co003oool00P3<o`00103oool0c?l00?ooo`3<o`030?ooo`030<co003oool0oooo
01L0oooo00<000000?ooo`3oool00@3oool001P0oooo0P00000:0?ooo`03001Vo`3oool0<`3o00@0
oooo0P0co`020?ooo`040?nI003<0?l0oiT00?nI0080oooo00D0<ol00<co003oool0oooo0<co0002
0?ooo`040<`0o`3oool0oooo0?l001H0oooo00X0o`000?ooo`3oool0o`2I0<co003o0000<ol00?oo
o`0co`00c?l0103oool00`3<o`00oooo0?ooo`030?ooo`030<co003<0?l0oooo0080oooo00<0c?l0
0?ooo`3oool00P3<0?l80?ooo`09003oIP3oool0oooo0?ooo`3<0?l0<`3o0?ooo`3<0?l00?mV00<0
oooo00<00?mV0?ooo`3oool00P3oool2001Vo`80oooo00<0o`2I0?ooo`00I_l00P3oool00`3<o`00
oooo0?ooo`020<co0003001Vo`3oool006Ko00T0oooo00H0<ol00?ooo`00I_l006Ko03?o003oool2
0?l0V@L0oooo00<0<ol00?ooo`3oool0103oool203?o00@0oooo00@0c?l00?ooo`3<o`00oooo0P3<
o`000`3oool0c?l00<co00030?ooo`030<co003oool0oooo00H0oooo00<0<ol00?ooo`3oool02`3o
ool20<co00D0oooo0P3<o`000`3oool0c?l00?ooo`020?ooo`030<co003oool0oooo00@0oooo00<0
c?l00?ooo`3oool05P3oool2000000<0oooo000H0?ooo`030000003oool0oooo00T0oooo00<006Ko
0?ooo`0c0?l0103oool01P00ool0oooo03?o003<0?l0oiT00<`0o`80oiT00P3oool01@3oV@00<ol0
0<co003oool0c?l00080oooo00D0c03o0?ooo`3oool0oooo0?l0000E0?ooo`060?l0003oool0oooo
03?o003<o`00<ol00P3oool0100co`00c?l00<co003oool203<0o`030<co003oool0oooo00D0oooo
00@0c03o0?ooo`3oool0c?l00P3oool20<`0o`P0oooo00X00?mV0?ooo`3oool0oooo0<`0o`0c0?l0
oooo0<`0o`00ofH0<`3o0P3oool00`00ofH0oooo0?ooo`040?ooo`050?l0V@3oool0o`2I0?ooo`00
I_l00P3oool01@3<o`00oooo0?l0V@3oool0c?l0008006Ko2@3oool02@0co`00oooo0?ooo`3o09T0
oooo001Vo`3o09T006Ko0?l0V@070?ooo`030?l0V@0co`00oooo00@0oooo00<0<ol00?ooo`3oool0
0`3oool01`0co`00c?l00<co003<o`00o`000?ooo`3<o`000P3oool30<co00T0oooo0P0co`0=0?oo
o`030<co003oool0oooo00<0oooo0P3<o`000`3oool0c?l00?ooo`020?ooo`030<co003oool0oooo
00D0oooo00<0c?l00?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000
oooo0?ooo`090?ooo`03001Vo`3<0?l0<`3o00D0oooo00/00?oo0?ooo`0co`00oiT00<`0o`3oV@00
oooo0?nI000co`00oiT003?o00020<co00<0oooo00D0c03o0?ooo`3oool0oooo0?l0000E0?ooo`03
0?l0003oool0oooo0080<ol000X0c?l00?ooo`3o09T0c?l003?o003o09T0c?l003<0o`3<o`00<`3o
1`3oool20<`0o`80oooo00D0c?l00?ooo`3<0?l0oooo0<`0o`060?ooo`0603<0o`00ofH0oooo0?oo
o`3<0?l0<`3o0P3oool00`00ofH0c03o03<0o`020?ooo`03003oIP3oool0oooo00@0oooo00P0o`2I
0?ooo`3o09T0o`2I001Vo`3oool0c?l00?ooo`80o`2I00@0oooo001Vo`3oool006Ko2@3oool02P0c
o`00oooo0?ooo`3oool0o`2I001Vo`3o09T006Ko0?ooo`3o09T50?ooo`80o`2I0P0co`030?ooo`03
03?o003oool0oooo00@0oooo00<0<ol00<co003oool00P3oool00`3o0000c?l00?ooo`030?ooo`04
0<co003oool0oooo03?o00D0oooo00<0<ol00?ooo`0co`003P3oool01@3<o`00oooo0?ooo`3oool0
c?l00080oooo00<0c?l00?ooo`3oool02`3oool00`3<o`00oooo0?ooo`0E0?ooo`030000003oool0
oooo0040oooo000H0?ooo`030000003oool0oooo00T0oooo00<006Ko0<`0o`0c0?l00P3oool01P00
I_l0oooo0?ooo`00ool0oooo0<`0o`80oiT000H0oooo03?o003oV@00oiT00?ooo`3oV@020<co00<0
oooo00D0c03o0?ooo`3oool0oooo0?l0000D0?ooo`0@0?l0003oool0oooo0?ooo`0co`00o`000<co
003o09T0oooo0<co000co`00oooo0<co000c0?l0c?l003<0o`80oooo0`0c0?l20?ooo`090<`0o`3o
ool0c03o0?ooo`3<o`00oooo0<`0o`3oool0c03o00H0oooo00H0<`3o003oIP3oool0oooo0<`0o`0c
0?l20?ooo`08003oIP3oool006Ko03<0o`3oool00?mV0?ooo`3<o`040?ooo`80o`2I00H0oooo0?l0
V@00I_l0c?l00?l0V@3oool20?l0V@040?ooo`00I_l0oooo001Vo`P0oooo00<0<ol00?ooo`3oool0
0P3oool01P3o09T0oooo001Vo`00I_l0oooo0?l0V@D0oooo00@0o`2I0?ooo`0co`00oooo100co`07
0?ooo`80<ol00P3oool00`3o0000oooo0?ooo`050?ooo`0303?o003oool0<ol00080<ol00P3oool0
0`0co`00oooo03?o000>0?ooo`80c?l00P3oool00`3<o`00oooo0?ooo`0?0?ooo`<0c?l0503oool0
0`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`090?ooo`06001Vo`3<0?l0oooo
03<0o`3oool006Ko0P3oool01P00ool0c03o0?ooo`3<0?l0oiT00?ooo`80<ol000@0oiT00?ooo`3o
V@00c?l00`3oool00`3<0?l0oooo0?ooo`020?ooo`030?l00000I_l0oooo00d0oooo00<0oiT00?oo
o`0co`000P3oool0403o0000oooo0?ooo`3oool0<ol00?l0V@3<o`00o`2I0?ooo`3<o`00<ol00?oo
o`0c0?l0c?l00?l0V@0c0?l20?ooo`0303<0o`3oool0<`3o00D0oooo00<0<`3o0<co003<0?l00P3o
ool00`3<0?l0oooo0?ooo`030?ooo`80<`3o00D00?mV0?ooo`3oool0c03o03<0o`020?ooo`08003o
IP00I_l006Ko0?ooo`00I_l00?mV03<0o`3<o`050?ooo`080?l0V@3oool0c?l00<co0000I_l0o`2I
0?ooo`3o09T20?ooo`03001Vo`3oool006Ko00P0oooo00<0<ol00?ooo`3oool00`3oool01@3o09T0
oooo0?ooo`00I_l0o`2I00@0oooo00@0o`2I0?ooo`3oool0o`2I303oool203?o0080oooo00<0o`00
0?ooo`3oool0103oool00`0co`00oooo0?ooo`020?ooo`0403?o003oool0oooo03?o0080oooo00<0
<ol00?ooo`3oool02`3oool20<co0080oooo00<0c?l00?ooo`3oool04@3oool00`3<o`00oooo0?oo
o`0B0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo00T0oooo00D006Ko
0<`0o`3oool0<`3o0?ooo`03001Vo`050?ooo`00ool0oooo0?ooo`3oV@001@3oool00`3oV@00oooo
0?ooo`020?ooo`030<`0o`3oool0oooo00<0oooo0P00I_l=0?ooo`80oiT000X0<ol00?ooo`3oool0
o`0003?o003oool0<ol00?ooo`3o09T0c?l00P3oool01@3<o`00oooo03?o000c0?l0o`2I0080oooo
0P0c0?l20?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0<co003<0?l00P3oool00`3<0?l0oooo
0?ooo`030?ooo`0303<0o`3oool00?mV0080oooo00L0<`3o0?ooo`00I_l0oooo003oIP00I_l0c03o
008006Ko00<0oooo003oIP3<o`000P3oool303<0o`050?l0V@3<o`00oooo0?l0V@00I_l00P3oool0
0`3o09T0oooo001Vo`0:0?ooo`0303?o003oool0oooo00L0oooo00<006Ko0?ooo`3o09T00`3oool0
103o09T0oooo0?ooo`3o09T=0?ooo`0403?o003oool0oooo0?l000H0oooo00<0<ol00?ooo`3oool0
0P3oool00`0co`00oooo03?o00030?ooo`80<ol000<0oooo003oo`3oool02@3oool0103<o`00oooo
0<co003<o`0D0?ooo`030<co003oool0oooo0180oooo00<000000?ooo`3oool00@3oool001P0oooo
0P00000:0?ooo`03001Vo`3<0?l006Ko008006Ko00D0c03o0?ooo`3oool006Ko003oo`020?ooo`03
0?nI003oool0oooo00<0oooo00<0oiT003?o000co`000P3oool00`3<0?l0oooo0?ooo`030?ooo`80
06Ko00<0oiT00?ooo`3oool02P3oool00`3oV@00oooo0?nI00020?ooo`090?l0000co`00<ol003?o
003oool0o`2I0<co003oool0c?l00080oooo00<0<ol003<0o`3oool00P3oool00`0c0?l0oooo0?oo
o`020?ooo`0803<0o`3oool0oooo0?ooo`0c0?l0c03o0<co000c0?l20?ooo`030<`0o`3oool0oooo
00<0oooo00`0<`3o0?ooo`0c0?l00?mV0<`0o`0c0?l0oooo001Vo`3oool00?mV001Vo`3<o`02001V
o`090?ooo`3<o`00oooo0<co003oool0<`3o0?ooo`0c0?l0c?l00080oooo00<0o`2I001Vo`3oool0
0`3oool00`00I_l0oooo0?ooo`080?ooo`0303?o003oool0oooo00P0oooo00D006Ko0?l0V@3oool0
oooo0?l0V@030?ooo`030?l0V@3oool0oooo00`0oooo00@0<ol00?ooo`3oool0o`001@3oool00`0c
o`00oooo0?ooo`020?ooo`0303?o003oool0<ol000@0oooo00<0<ol00?ooo`00ool02P3oool00`3<
o`00oooo0<co00060?ooo`030?l0003oool0oooo00d0oooo00<0c?l00?ooo`3oool0403oool20000
00<0oooo000H0?ooo`030000003oool0oooo00X0oooo0P00I_l00`3oool006Ko0<`0o`020?ooo`03
001Vo`3oool00?oo00H0oooo00@0<`3o0?nI000co`00<ol00P3oool00`3<0?l0oooo03?o00020?oo
o`05003oo`3o0000oooo0?nI000co`002P3oool0103oV@00<ol00?ooo`3oV@020?ooo`040?l0000c
o`00oooo03?o00<0oooo0P3<o`030?ooo`80<ol01`3oool01`0c0?l0oooo03<0o`0c0?l0oooo0<`0
o`3oool00P3<o`000`3oool0c03o0?ooo`030?ooo`0403<0o`3oool0oooo03<0o`800?mV00h0oooo
001Vo`3oool00?mV001Vo`3oool0c?l00<`0o`00I_l0oooo0<co003oool0c?l003<0o`<0oooo00D0
c?l00?nI003oV@00oooo001Vo`040?ooo`03001Vo`3oool0oooo00L0oooo00<0<ol00?ooo`3oool0
2P3oool01000I_l0oooo0?ooo`3o09T30?ooo`030?l0V@3oool0oooo0080oooo00<0oiT00?ooo`3o
ool01`3oool303?o00030?l0003oool0oooo0080oooo00<0<ol00?ooo`3oool0103oool203?o00@0
oooo00<00?oo03?o003oool00P00ool80?ooo`030?l0003oool0oooo00D0oooo0P3o000?0?ooo`03
0<co003oool0oooo0140oooo00<000000?ooo`3oool00@3oool000@0oooo0`0000040?ooo`030000
003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo00X0oooo0P00I_l00`3oool0<`3o
0<`0o`020?ooo`030<`0o`00I_l00?oo00H0oooo00T0<`3o0?ooo`3oV@00oooo03?o003oool0c03o
0?ooo`0co`000P3oool01@00ool0oooo0?nI0000I_l0oiT000X0oooo00L0oiT003?o003oool0oooo
0?nI003o0000<ol000H0oooo00<0c?l00?ooo`3oool00P3oool00`0c0?l0<ol00?ooo`060?ooo`03
03<0o`3oool0<`3o00<0oooo00<0c03o03<0o`3<o`000P3oool01@3<0?l0<`3o0<`0o`3oool0<`3o
0080oooo00@0<`3o003oIP00ofH006Ko0P3oool00`00ofH006Ko0?ooo`020<co0080oooo00`0c?l0
03<0o`3<o`00<`3o0?ooo`3oV@00oooo0<co003oV@00oooo0?nI0000I_l30?ooo`03001Vo`3oool0
oooo00D0oooo00@0oiT00?ooo`3oool0<ol00P3oool20?nI00P0oooo00@006Ko0?ooo`3oool0o`2I
0`3oool00`3o09T0oooo0?ooo`020?ooo`030?nI003oool0oooo00T0oooo00@0<ol00?l0003o0000
o`000`0co`060?ooo`0303?o003oool0oooo00<00?oo00<0oooo03?o003oool00P3oool00`00ool0
oooo0?ooo`050?ooo`80o`000`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0oooo00`0
oooo00<0c?l00?ooo`3oool04@3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo
0?ooo`070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0:0?ooo`0<
001Vo`3<0?l0oooo0<`0o`0c0?l0c03o0?ooo`3<0?l0oooo003oo`3oool00?oo103oool203<0o`@0
oiT000@0oooo03?o003oool0<ol00P00ool01@3oool0oiT0001Vo`3oV@00<ol000T0oooo00L0oiT0
03?o003oool0oooo0?nI000co`00oiT000/0oooo00<0<`3o0?ooo`0co`001P3oool00`0c0?l0oooo
03<0o`030?ooo`030<`0o`0c0?l0oooo00<0c?l00`0c0?l20<`0o`80oooo0P00ofH30?ooo`05003o
IP3oool0oooo0<co003oool00P3<o`003`3oool00?mV03<0o`3<o`00oooo0?nI003<o`00oooo0?nI
003oool0oiT00?ooo`3oV@0006Ko0?nI00080?ooo`030?nI003oool0<ol000<0oooo0P3oV@080?oo
o`04001Vo`3oool0oooo0?l0V@<0oooo00<0o`2I0?ooo`3oool00P3oool20?nI00X0oooo00L0<ol0
0?ooo`3oool0<ol00?ooo`3o0000<ol000H0oooo00P0<ol00?ooo`3o00000?oo0?ooo`3o0000oooo
03?o0080oooo0P0co`000`3oool0<ol00?ooo`030?ooo`030?l0003oool006Ko00@0o`0000D0oooo
0?l0003oool0oooo0?l0000>0?ooo`030<co003oool0oooo0140oooo00<000000?ooo`3oool00@3o
ool000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00D006Ko0<`0o`3<0?l0c03o03<0o`020<`0o`80oooo00<006Ko003oo`00ool0103o
ool00`0c0?l0oooo0?nI00020?ooo`040?nI000co`00<ol00?ooo`@0<ol000L0oiT0003oo`0co`00
oiT003?o003oool0oiT000H0oooo00L0oiT00?ooo`3oool0o`000?nI003o0000oiT000X0oooo00@0
<`3o0?ooo`3oool0<ol01P3oool00`0c0?l0oooo03<0o`030?ooo`090<`0o`3oool0<`3o0<co003o
ool0c?l00?ooo`3<0?l0<`3o0080oooo0P3<0?l00`00ofH0oooo003oIP020?ooo`03003oIP3oool0
c?l00080oooo00d0c03o0?ooo`3oool00?mV03<0o`3<o`00oooo0?nI003<o`00oiT00?ooo`0c0?l0
oooo0080oiT000<0oooo0?nI003oV@001`3oool20?nI000703?o003oool0oooo0?ooo`3oV@00oooo
0?nI00070?ooo`03001Vo`3oool0o`2I00D0oooo00@0o`2I0?ooo`3oool0oiT00P3oool00`3oV@00
oooo0?ooo`080?ooo`80<ol000D0oooo0?l0003oool0oooo0?l000060?ooo`040?l00000ool0oooo
0?l00080oooo00L0o`0003?o000co`00oooo03?o0000ool0<ol000@0oooo00<0o`000?ooo`00I_l0
0`3oool00`3o0000oooo001Vo`020?ooo`030?l0003oool0oooo00X0oooo00D00?mV0?ooo`3oool0
c?l0001Vo`0A0?ooo`030000003oool0oooo0040oooo00050?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool2000000/0oooo00L006Ko0?ooo`3oool0c03o03<0o`3oool0c03o
0080oooo00<006Ko003oo`3oool00`00ool01`0c0?l0oooo0?ooo`3oool0<`3o0?ooo`3oV@000P00
ool03P3oool00?oo001Vo`3oool0<ol00?nI000co`0006Ko0?ooo`3oV@00<ol00?nI003oool0oiT0
0P3oool00`3oV@00oooo0?nI00020?ooo`050?l0003oool0oiT00?ooo`3oV@002@3oool0100c0?l0
oooo0?ooo`0co`070?ooo`0303<0o`3oool0oooo00@0oooo00D0<`3o0?ooo`3oool0c?l00<`0o`06
0?ooo`03001Vo`3oool00?mV0080oooo00<00?mV0?ooo`3<o`000P3oool01`3<0?l0oooo0?ooo`00
ofH0oooo0<co003oool00`3oV@020?ooo`<0<`3o00@0oiT003<0o`3oool0oiT01@3oool0103oV@00
oooo0?nI000co`020?ooo`040?nI003oool0oooo0?nI00L0oooo00<006Ko0?l0V@3o09T01@3oool0
103o09T0oooo0?ooo`3oV@030?ooo`030?nI003oool0oooo00L0oooo00<0<ol00?ooo`3oool00`3o
ool30?l000@0oooo00<0o`00003oo`3o0000103oool203?o0080oooo0P0co`040?ooo`040?l00000
I_l0oooo001Vo`80oooo00@0o`000?ooo`00I_l006Ko0P3oool00`3o0000oooo0?ooo`090?ooo`05
003oIP3oool0oooo0<co0000I_l03`3oool3000000<0oooo00050?ooo`030000003oool0oooo00L0
oooo100000050?ooo`030000003oool0oooo00h0oooo00<0<`3o0?ooo`3oool00P3oool01`00I_l0
0?oo0?ooo`00ool0<`3o0?ooo`00ool00`3oool00`0c0?l0oooo0?nI0002003oo`080?ooo`00ool0
oooo0?ooo`0co`00oiT003?o0000I_l20?ooo`060?nI003oool0oiT00?nI003oool0<ol00P3oV@00
100co`00oooo0?ooo`3o00030?ooo`030?nI003oool0oooo00L0oooo00D0<`3o0?ooo`3oool0oooo
03?o00060?ooo`0303<0o`3oool0oooo00D0oooo00@0<`3o001Vo`3oool0c?l01@3oool00`00I_l0
oooo0?ooo`03003oIP80oooo00D0c?l00?ooo`3oool0oooo0<`0o`020?ooo`05003oIP3oool0oiT0
0?ooo`3oV@001@3oool01P0c0?l0oiT003<0o`3oool0oiT003?o00@0oooo00@0oiT003?o003oV@00
<ol00P3oool0103oV@00oooo0?ooo`3oV@080?ooo`03001Vo`3o09T0oooo00@0oooo00@0o`2I0?oo
o`3oool0oiT00`3oool00`3oV@00oooo0?ooo`0?0?ooo`070?l0003oool0oooo0?l0003oool0o`00
003oo`050?ooo`0703?o003oool0oooo0?ooo`00ool0oooo03?o00030?l000040?ooo`00I_l0oooo
001Vo`<0oooo00<006Ko0?ooo`3oool00P00I_l00`3o0000oooo0?ooo`020?ooo`03001Vo`3oool0
oooo00@0oooo00H00?mV0?ooo`3oool0c?l00?ooo`00I_l@0?ooo`030000003oool0oooo0040oooo
00040?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo0`0c
0?l0203oool006Ko0?ooo`3oool006Ko0?ooo`0c0?l00?oo103oool01`0c0?l0oiT0003oo`00ool0
oooo003oo`0c0?l00P3oV@0203?o0004003oo`3oool0oooo03?o00<0oooo00L0oiT003?o003oV@00
oiT003?o003oool0o`0000D0oooo00<0oiT00?ooo`3oool01P3oool01@0c0?l0oooo0?ooo`3oool0
<ol000H0oooo00<0<`3o0?ooo`3oool01@3oool0100c0?l006Ko0?ooo`3<o`050?ooo`03001Vo`3o
ool0oooo0080oooo00@00?mV0?ooo`3oool0c?l00`3oool01`3<0?l0oooo0?ooo`00ofH0oooo0?nI
003<o`001`3oool01`0c0?l0oooo03?o000c0?l0oiT003?o003oool00`3oV@0203?o00040?nI003o
ool0oooo0?nI0080oooo00<0oiT00?ooo`3oool01P3oool00`00I_l0o`2I0?ooo`040?ooo`040?l0
V@3oool0oooo0?nI00<0oooo00<0oiT00?ooo`3oool0403oool40?l000030?ooo`00ool0oooo00@0
oooo0`3o0000103oool00?oo0?ooo`0co`040?ooo`03001Vo`3oool006Ko00<0oooo00<006Ko0?oo
o`3oool00P3oool00`00I_l0oooo0?ooo`020?ooo`03001Vo`3oool0oooo00@0oooo00H00?mV001V
o`3oool006Ko0<co0000I_l@0?ooo`030000003oool0oooo0040oooo00050?ooo`030000003oool0
oooo00L0oooo1@0000040?ooo`030000003oool0oooo00l0oooo0P0c0?l01P3oool0<`3o0?ooo`00
I_l0<`3o001Vo`80oooo00<00?oo0?ooo`3oool00P3oool01`0c0?l00?oo0?nI0000ool0<`3o003o
o`0c0?l00P3oV@0203?o0005003oo`00I_l0oooo0?ooo`0co`000P3oool0103oV@00<ol00?nI003o
V@020?ooo`030?l0003oool0oooo00@0oooo00<0oiT00?ooo`3oool01@3oool00`0c0?l0oooo0?oo
o`020?ooo`0303?o003oool0oooo00`0oooo00<006Ko0?ooo`3<o`001@3oool00`00I_l0c?l00<co
00050?ooo`030<co003oool0oooo0080oooo00H0c03o0?ooo`00ofH0oooo0?nI003<o`070?ooo`08
03?o003oool0<ol003<0o`3oV@00<ol00?ooo`3oV@020?ooo`80<ol000@0oiT00?ooo`3oool0oiT0
0P3oool00`3oV@00oooo0?ooo`060?ooo`03001Vo`3oool0oooo00@0oooo00<0o`2I0?ooo`3oV@00
0`3oool00`3o09T0oiT00?ooo`040?ooo`80o`2I2`3oool01@3o0000oooo0?ooo`3o00000?oo00L0
oooo00H006Ko0?ooo`3o0000oooo003oo`0co`030?ooo`05001Vo`3oool0oooo0?ooo`00I_l00P3o
ool00`00I_l0oooo0?ooo`020?ooo`03001Vo`3oool0o`0000<006Ko1P3oool2003oIP04001Vo`3o
ool0c?l0001Voa00oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool03`3o
ool01@0c0?l0oooo0?ooo`3oool0<`3o00<006Ko0`3oool03`00ool0oooo0?ooo`3oool0<`3o003o
o`3oV@00oooo003oo`3oool0oiT00?ooo`3oV@00<ol00?ooo`02003oo`03001Vo`3oool0<ol00080
<ol00P3oV@00100co`00o`000?ooo`3o00070?ooo`030?nI003oool0oooo00@0oooo00<0<`3o0?oo
o`3oool00`3oool00`0co`00oooo0?ooo`070?ooo`08001Vo`3oool0oooo001Vo`3oool006Ko0?oo
o`3<o`040?ooo`04001Vo`3oool0c?l00<co0080oooo00<0c?l00?ooo`3<o`001@3oool01@3<0?l0
oooo003oIP3oool0oiT000P0oooo0P0co`003@3oool0<`3o0?nI003oool0<ol00?nI003oool0<ol0
0?ooo`0co`00oiT00?ooo`3oV@000`3oool00`3oV@00oooo0?ooo`060?ooo`03001Vo`3oool0oooo
00@0oooo00<0o`2I0?ooo`3oV@000`3oool00`3o09T0oooo0?nI00040?ooo`030?l0V@3oool0o`2I
00d0oooo00<0o`00003oo`3oool01P3oool2001Vo`80oooo00<00?oo03?o003oool00P00ool01@00
I_l0oooo0?ooo`3oool006Ko0080oooo00<006Ko0?ooo`3oool00P3oool00`3o000006Ko001Vo`02
0?ooo`03001Vo`3oool0oooo00<0oooo00<00?mV0?ooo`00ofH00P3oool00`3<o`0006Ko0?ooo`0?
0?ooo`030000003oool0oooo0040oooo000H0?ooo`8000005@3oool2001Vo`050?ooo`00I_l0oooo
0?ooo`00ool00`3oool2003oo`060?nI000c0?l00?oo0?ooo`3oV@00<`3o0`3oool01P3o0000oooo
003oo`3oool006Ko0?l00080oooo00<0oiT003?o003oool00P3o00070?ooo`030?nI003oool0oooo
00<0oooo0P0c0?l50?ooo`0303?o003oool0oooo00L0oooo00P006Ko0?ooo`00I_l006Ko0?ooo`00
I_l0oooo0<co00@0oooo00@006Ko0<co003oool0oooo0`3<o`000`3oool0c?l00?ooo`040?ooo`04
0<`0o`3oool0oooo0?nI00T0oooo00L0<ol00?ooo`3oool0oooo0?nI003oool0oiT000<0<ol000@0
oooo03?o003oool0oiT01@3oool00`3oV@00oooo0?ooo`050?ooo`03001Vo`3oool006Ko0080oooo
0P3oV@000`3oool0o`2I0?nI00030?ooo`80o`2I00<0oiT00?ooo`3oool00P3oool0103o09T0oooo
0?ooo`3o09T=0?ooo`03003oo`3oool0oooo00@0oooo00/006Ko0?ooo`3oool006Ko0?ooo`00ool0
oooo03?o003oool00?oo001Vo`040?ooo`8006Ko1P3oool00`00I_l0o`000?ooo`020?ooo`03001V
o`3oool0oooo008006Ko00<00?mV0?ooo`00ofH00P3oool00`3<o`0006Ko0?ooo`0>0?ooo`800000
0`3oool001P0oooo00<000000?ooo`3oool0503oool01000I_l0oooo0?ooo`00I_l30?ooo`03003o
o`3oool00?oo0080oooo00H0oiT003<0o`00ool0oooo0?nI000c0?l30?ooo`030?l0003oool00?oo
008006Ko00L0o`000?ooo`3oool0oiT003?o003oool0o`0000P0oooo00<0oiT00?ooo`3oool00`3o
ool00`0c0?l006Ko0?ooo`040?ooo`0303?o003oool0oooo00H0oooo0P00I_l0103oool006Ko0?oo
o`00I_l20?ooo`03001Vo`3<o`00oooo0080oooo00D006Ko0<co003oool0oooo0<co00020?ooo`80
c?l01@3oool0103<0?l0oooo0?ooo`3oV@080?ooo`0303?o003oool0oooo0080oooo00<0<`3o0?nI
003oV@00303oool00`3oV@00oooo0?nI00050?ooo`050?nI003oool0oiT0001Vo`3oool00P3oV@00
0`3oool0oiT00?ooo`020?ooo`030?l0V@3oool0o`2I0080oiT00P3oool01@3o09T0oooo0?ooo`3o
ool0o`2I00`0oooo00<00?oo0?ooo`3oool01@3oool01000I_l0oooo0?ooo`00I_l30?ooo`0803?o
003oool00?oo001Vo`00ool0oooo003oo`3oool2001Vo`H0oooo00<0o`000?ooo`3o00000P3oool0
1000I_l0oooo001Vo`3oool2003oIP06001Vo`00ofH0oooo0?ooo`3<o`0006Ko403oool00`000000
oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`0G0?ooo`8006Ko0`3oool01000ool0oooo
0?ooo`3oool20?nI0004003oo`3oV@00oooo03<0o`@0oooo00P0o`00003oo`3oool0o`00001Vo`3o
0000oooo0?l000`0oooo00H0oiT00?ooo`3oool0oooo03<0o`3oool2001Vo`@0oooo00D0<ol00?oo
o`3oool0oooo03?o00040?ooo`8006Ko00@0oooo001Vo`3oool006Ko0`3oool01P3<o`00oooo0?oo
o`00I_l0oooo0<co00D0oooo00<0c?l00?ooo`3oool01@3oool01@3<0?l0oiT0003oIP3oool0c03o
00H0oooo00<0<ol00?ooo`3oool00P3oool00`0c0?l0oiT00?nI000<0?ooo`030?nI003oool0oiT0
00D0oooo00D0oiT0001Vo`3oV@00oooo0?nI00020?ooo`80oiT00`3oool00`3o09T0oooo0?l0V@02
0?ooo`030?nI003oool0oiT000@0oooo00<0o`2I0?ooo`3oool02@3oool00`00ool0oooo0?ooo`05
0?ooo`04001Vo`3oool0oooo001Vo`80oooo00P006Ko03?o000co`000?oo0?ooo`00ool0oooo003o
o`80oooo00<006Ko0?ooo`3oool01P3oool01`3o0000oooo0?ooo`00I_l0oooo001Vo`3oool00P00
ofH01P00I_l00?mV0?ooo`3oool0c?l0001Voa00oooo00<000000?ooo`3oool00@3oool001P0oooo
00<000000?ooo`3oool06@3oool00`00I_l0oooo0?ooo`050?ooo`050?nI003oool0oiT00?ooo`0c
0?l0103oool01@3o0000oooo003oo`3o000006Ko00<0o`00303oool01P3oV@00oooo0?ooo`3oool0
<`3o0?ooo`8006Ko1@3oool0100co`0006Ko0?ooo`0co`040?ooo`8006Ko00<0oooo001Vo`3oool0
103oool01@3<o`00oooo001Vo`3oool0c?l000h0oooo00P0c03o0?nI0000ofH0oooo0<`0o`3oool0
c03o0?ooo`80c03o00<0oooo03?o003oool00P3oool01@3<0?l0<`3o0?nI003oool0c03o00X0oooo
00@0<`3o0?nI003oV@00oiT01@3oool20?nI00080?ooo`3oV@00oooo001Vo`3oool0oiT00?ooo`3o
09T20?ooo`030?l0V@3oool0oooo0080o`2I00<0oiT00?ooo`3oV@00103oool00`3o09T0oooo0?oo
o`030?ooo`03003oo`3oool00?oo00<0oooo00<00?oo0?ooo`3oool01@3oool01000I_l0oooo0?oo
o`00I_l20?ooo`03001Vo`3oool006Ko00@0<ol000<0oooo003oo`0co`002@3oool0203o0000oooo
0?ooo`00I_l00?mV001Vo`00ofH0oooo0P00I_l0203oool00?mV0?ooo`3o0000c?l0001Vo`3oool0
06Ko3@3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`0I0?ooo`03001V
o`3oool0oooo00D0oooo00D0oiT00?ooo`3oV@00oooo03<0o`040?ooo`0:0?l0003oool00?oo0?oo
o`00I_l00?oo0?ooo`3o0000oooo03<0o`X0oooo00H0oiT00?ooo`3oool0oooo03<0o`3oool2001V
o`D0oooo00H0<ol0001Vo`0co`00<ol0001Vo`3oool2001Vo`80oooo0P00I_l50?ooo`050<co003o
ool006Ko0?ooo`3<o`003P3oool0103oV@00oooo003oIP3oool40<`0o`030?ooo`3<0?l0<ol000@0
oooo00<0c03o0?ooo`0c0?l00P3<0?l30?ooo`0303<0o`3oool0oooo00@0oooo00H0<`3o0?nI003o
ool0oiT00?ooo`3oV@020?ooo`030?nI003oool0oiT000<0oooo00D006Ko0?ooo`3oool0oooo0?l0
V@020?ooo`080?l0V@3oool0oooo0?l0V@3oool0oiT00?l0V@3oV@050?ooo`030?l0V@3oool0oooo
0080oooo0`00ool30?ooo`03003oo`3oool0oooo00@0oooo00D006Ko0?ooo`3oool0oooo001Vo`02
0?ooo`0:001Vo`3oool0oooo001Vo`00ool0oooo03?o003oool00?oo03?o00T0oooo00T0o`000?oo
o`3oool0oooo003oIP3oool00?mV0?ooo`3o00000P3oool01P00ofH0o`000?l0003<o`0006Ko0?oo
o`8006Ko303oool00`000000oooo0?ooo`010?ooo`00603oool2000001X0oooo00<006Ko0?ooo`00
I_l01@3oool00`00I_l0oiT00?nI00020?ooo`0703<0o`3oool0oooo0?ooo`3o0000oooo003oo`02
0?ooo`03003oo`3oool0oooo0080<`3o2@3oool2003oo`070?nI003oool0<`3o0?ooo`00I_l0oooo
001Vo`050?ooo`0803?o0000I_l0<ol003?o0000I_l0oooo03?o0000I_l20?ooo`03001Vo`3oool0
oooo00D0oooo103<o`0>0?ooo`060?nI003oool0oooo003oIP3oool0c03o103oool02@0co`00oooo
0<`0o`3oool0c03o0?ooo`3<0?l0<`3o0<`0o`0203<0o`80oooo00<0<`3o0?ooo`3oool00`3oool0
1@0c0?l0oooo0?ooo`0c0?l0oooo0080oiT00P3oool00`3oV@00oooo0?ooo`030?ooo`04001Vo`3o
ool0oooo0?ooo`<0o`2I1P3oool20?nI00D0oooo00<0o`2I0?ooo`00ool00P3oool00`00ool0oooo
003oo`030?ooo`03003oo`3oool0oooo00@0oooo00<006Ko0?ooo`3oool00P3oool2001Vo`@0oooo
00<00?oo0?ooo`3oool00P0co`000`00ool0<ol00?ooo`080?ooo`030?l0003oool0oooo00800?mV
0P3oool20?l000040?ooo`00ofH0o`000?ooo`80c?l000@0o`00001Vo`3oool006Ko2P3oool20000
00<0oooo000H0?ooo`030000003oool0oooo01X0oooo0`00I_l30?ooo`03001Vo`3oool0oiT000<0
oooo00<0<`3o0?ooo`3oool00P3oool0103o00000?oo0?ooo`3oool2003oo`030?ooo`0c0?l0<`3o
00H0oooo00<00?oo0?ooo`3oool00P00ool0203oV@00oooo03<0o`3oool006Ko0?ooo`3oV@0006Ko
0`3oool01@3oV@00<ol0001Vo`0co`00oooo00<0<ol00`3oool00`00I_l0oooo0?ooo`050?ooo`03
0<co003oool0oooo00l0oooo00@0oiT00<`0o`3<0?l00?mV1P3oool0100co`00oooo0<`0o`3<0?l2
0?ooo`060<`0o`3oool0<`3o03<0o`3<0?l00?mV0P0c0?l40?ooo`0603<0o`3oool0oooo0?ooo`0c
0?l0oooo0P3oV@020?ooo`030?nI003oool0oooo00<0oooo00<006Ko0?ooo`3oool00`3oool00`3o
09T0oooo0?ooo`040?ooo`040?nI003oool0oiT00<`0o`<0oooo00<0o`2I0?ooo`00ool00P00ool3
0?ooo`04003oo`3oool0oooo003oo`H0oooo00<006Ko0?ooo`3oool00P3oool2001Vo`L0oooo00@0
<ol00?ooo`00ool0<ol02@3oool20?l00003003oIP3oool0oooo0080oooo0P3o0000103oool0o`00
003oIP3oool20<co0004001Vo`3o0000oooo001Vo`/0oooo00<000000?ooo`3oool00@3oool001P0
oooo00<000000?ooo`3oool06P3oool00`00I_l0oooo0?ooo`02001Vo`040?ooo`00I_l0oooo0?nI
00<0oooo00<0<`3o0?ooo`3oool00P3oool02P0c0?l0oooo003oo`00ool006Ko0?ooo`00ool0<`3o
0?ooo`0c0?l50?ooo`07003oo`3oool00?oo0?ooo`00ool006Ko0?nI0002001Vo`80oiT000<0oooo
0?nI003oool00`3oV@00103oool0<ol00?ooo`3oool203?o00050?ooo`0co`00<ol00?ooo`00I_l0
6@3oool01@3oV@00oooo0?ooo`3oool00?mV00<0oooo0P0co`000`3oool0c03o0?ooo`030?ooo`80
c03o00@0<`3o0?ooo`3<0?l00?mV0P3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00@0<`3o
0?ooo`3oV@00oooo0P3oV@070?ooo`03001Vo`3oool0oooo00/0oooo00@0oiT00<`0o`3oool0oooo
0`00ool20?ooo`07003oo`3oool0oooo0?ooo`00ool0oooo003oo`060?ooo`03001Vo`3oool0oooo
00<0oooo0P00I_l30?ooo`030<`0o`3oool0oooo00<0oooo00<00?oo03?o003oool02@3oool00`3o
00000?mV0?ooo`020?ooo`070?l0003oool0o`000?ooo`3o09T0oooo003oIP020<co0005001Vo`3o
ool0o`000?ooo`00I_l02P3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?oo
o`0O0?ooo`03001Vo`3oool0oooo00@0oooo00<0<`3o0?ooo`0c0?l00P3oool02P0c0?l0oooo003o
o`00ool0oooo001Vo`3oool00?oo0?ooo`0c0?l40?ooo`0;003oo`3oool00?oo03<0o`00I_l00?oo
001Vo`3oV@0006Ko0?ooo`3oV@000P3oool01P00I_l0oiT00?ooo`3oool0oiT0001Vo`<0oooo00<0
<ol00?ooo`3oool00P3oool00`0co`0006Ko0?ooo`0A0?ooo`03003oo`3oool0oooo00@0oooo00<0
oiT00?ooo`3oool00P3oool2003oIP0303?o003oool0oooo00H0oooo00@00?mV0<`0o`3oool0oooo
0P00ofH00`3<0?l0oooo03<0o`030?ooo`0303<0o`3oool0oooo0080oooo00@0<`3o0?ooo`3oool0
oiT0203oool00`00I_l0oooo0?ooo`080?ooo`03003oo`3oool0oooo0080oiT000D0c03o0?ooo`00
ool0oooo0?l0V@060?ooo`03003oo`3oool00?oo00H0oooo00<006Ko0?ooo`3oool00`3oool00`00
I_l0oooo0?ooo`020?ooo`030<`0o`3oool0oooo00@0oooo00<0<ol00?ooo`3oool02@3oool04P00
ofH0oooo0?ooo`3oool0o`000?ooo`3o0000oooo0?nI003o09T0oooo0?l0003oV@00o`000?ooo`3o
0000oooo001Vo`X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool09P3o
ool0100c0?l0oooo03<0o`3oool203<0o`090?ooo`0c0?l0oooo0?ooo`00I_l0<`3o003oo`3oool0
<`3o00@0oooo00P00?oo0?ooo`0c0?l0oooo001Vo`00ool0<`3o001Vo`80oiT00`3oool01P00I_l0
oooo0?ooo`3oool0oiT0001Vo`P0oooo00@0<ol00?ooo`3oool0<ol0403oool00`00ool0oooo0?oo
o`040?ooo`030?nI003oool0oooo00<0oooo00<00?mV03?o003oool01`3oool01`00ofH0c03o0?oo
o`00ofH0oooo003oIP3<0?l00P3oool0100c0?l0oooo0?ooo`0c0?l40?ooo`0303<0o`3<0?l0oooo
0080oooo00<0c03o0?ooo`3oool0103oool00`00I_l0oooo0?ooo`080?ooo`03003oo`3oool0oooo
0080oiT000D0c03o0?ooo`00ool0oooo0?l0V@070?ooo`800?oo0P3oool01@3<0?l0oooo0?ooo`3o
ool006Ko00D0oooo00<006Ko0?ooo`3oool00P3oool00`3<0?l0oooo0?ooo`040?ooo`03003oo`0c
o`00oooo00T0oooo00D00?mV0?ooo`3oool0oooo003oo`020?ooo`040?l0003oV@00oooo0?l0V@80
oiT00P3oool0103o0000oooo0?ooo`00I_l90?ooo`030000003oool0oooo0040oooo000H0?ooo`03
0000003oool0oooo02L0oooo0P0c0?l00`3oool0<`3o0?ooo`0203<0o`070?ooo`0c0?l006Ko03<0
o`00ool0oooo03<0o`030?ooo`0:003oo`3oool0<`3o0?ooo`00I_l0oooo001Vo`00ool006Ko0?nI
00@0oooo00L006Ko0?ooo`3oool0oooo0?nI0000I_l00?oo00L0oooo00@0<ol00?ooo`0co`00<ol0
403oool00`00ool0oooo0?ooo`030?ooo`030?nI003oool0oooo00D0oooo00<0<ol00?ooo`3oool0
1P3oool00`00ofH0oooo003oIP020?ooo`07003oIP3<0?l0oooo0?ooo`0c0?l0oooo03<0o`060?oo
o`0303<0o`3<0?l0oooo0080c03o1`3oool00`00I_l0oooo0?ooo`060?ooo`800?oo0P3oool01`00
ool0oiT00?ooo`3<0?l00?oo0?ooo`3o09T0203oool01000ool0c03o0<`0o`3<0?l30?ooo`03001V
o`3oool0oooo00L0oooo00<0c03o0?ooo`3<0?l01@3oool01@00ool0<ol003?o003oool00?mV00L0
oooo00D00?mV003oo`3oool0o`00003oo`020?ooo`070?l0V@3oV@00oiT00?l0V@3oV@000?mV0?nI
00020?ooo`80o`0000<006Ko0?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`00603oool2
000002P0oooo00L0<`3o0?ooo`0c0?l0<`3o0?ooo`0c0?l0oooo0080<`3o00D0oooo001Vo`3oool0
0?oo03<0o`020?ooo`06003oo`0c0?l0oooo001Vo`3oool006Ko0P3oool00`00ool006Ko0?ooo`05
0?ooo`06001Vo`3oool0oooo0?nI0000I_l00?oo203oool303?o00`0oooo1000ool01`3oool00?oo
0?ooo`3oool00?oo0?ooo`3oV@001P3oool0100co`000?mV003oIP00ofH50?ooo`04003oIP3oool0
0?mV003oIP<0oooo00@00?mV0?ooo`3oool0c03o0P0c0?l60?ooo`0503<0o`3oool0c03o0?ooo`3<
0?l0203oool00`00I_l0oooo0?ooo`050?ooo`08003oo`3oool00?oo0?ooo`00ool0oiT00?ooo`00
ool20?ooo`030?l0V@3oool0oooo00L0oooo00<0c03o0?ooo`3<0?l00P3oool00`3<0?l006Ko0?oo
o`060?ooo`050<`0o`3oool0c03o0?ooo`3<0?l01@3oool01@00ool0<ol003?o003oool00?mV0080
oooo00<0<`3o0?ooo`3oool00P00ofH00`3o00000?oo0?l00002003oo`80oooo00L0o`2I0?nI003o
V@00oooo0?nI0000ofH0oiT000<0oooo00<0o`00001Vo`3oool00P3oool00`00ool0oooo0?ooo`02
0?ooo`8000000`3oool001P0oooo00<000000?ooo`3oool0:@3oool00`0c0?l0oooo0?ooo`020?oo
o`0:03<0o`3oool0oooo001Vo`3oool00?oo03<0o`3oool00?oo0?ooo`80<`3o0P00I_l30?ooo`03
003oo`3oool0oooo00D0oooo00T006Ko0?ooo`3oool0oooo0?nI003oool00?oo0?ooo`00ool01@3o
ool00`0co`00oooo03?o000<0?ooo`06003oo`3oool0oooo003oo`3oool00?oo0P3oool00`00ool0
oiT00?nI00060?ooo`0403?o003oool0oooo003oIPD0oooo00<00?mV0?ooo`00ofH0103oool01000
ofH0c03o0?ooo`3<0?l203<0o`D0oooo00<0c03o03<0o`3oool00P3oool00`3<0?l0oooo03<0o`07
0?ooo`03001Vo`3oool0oooo0080oooo00@0c03o003oo`3<0?l0oooo0P00ool0103<0?l00?oo0?nI
0000ool30?ooo`070?l0V@3oool006Ko0?ooo`00I_l0oooo001Vo`020?ooo`070<`0o`3oool0oooo
0<`0o`3oool0c03o001Vo`070?ooo`050<`0o`3oool0c03o0?ooo`3<0?l01@3oool00`00ool0oooo
03?o0002003oIP80oooo00<0<`3o0?ooo`3oool00P00ofH01@3oool00?oo003oo`3oool00?oo0080
oooo00L0o`2I0?nI003oV@00oiT00?ooo`3o09T0oiT00080oooo00@0o`2I0?l0003oool006Ko0P3o
ool00`00ool0oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000H0?ooo`030000003oool0
oooo0340oooo00<006Ko0?ooo`3oool00P00ool01@3oool0<`3o0?ooo`3oool006Ko00@0oooo00<0
0?oo0?ooo`3oool01@3oool2001Vo`030?ooo`00I_l0oiT00080oooo0P00ool60?ooo`03003oo`3o
ool0<ol000X0oooo00<00?oo0?ooo`3oool00`3oool01000ool0oooo003oo`3oool20?nI000303?o
003oool0oooo00<0oooo00@0<ol00?ooo`3oool00?mV1@3oool00`00ofH0oooo0?ooo`040?ooo`06
003oIP3<0?l0c03o0?ooo`3<0?l0<`3o1@3oool00`3<0?l0oooo03<0o`030?ooo`040<`0o`0c0?l0
oooo03<0o`D0oooo00<006Ko0?ooo`3oool00P3oool02`3<0?l00?oo0<`0o`3oool0c03o0?ooo`3<
0?l0oooo0?nI0000ool0c03o0080oooo00T0o`2I001Vo`00I_l0oooo001Vo`3oool006Ko0?ooo`3<
0?l00`3oool20<`0o`03001Vo`3<0?l0oooo0080<`3o103oool01@3<0?l0oooo0<`0o`3oool0c03o
00<0oooo00<0<`3o0?nI003oV@000P3oool00`0co`00oooo003oIP0203<0o`030?ooo`00ofH0c03o
0080oooo00L00?oo0?ooo`3oool0oooo003oo`3oool0oiT00080oooo00D0oiT00?ooo`3o09T0c?l0
0?nI00020?l0V@030?ooo`3o000006Ko0080oooo00<00?oo0?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00603oool00`000000oooo0?ooo`0a0?ooo`07001Vo`3oool0oooo0?ooo`00I_l0
oooo03<0o`020?ooo`03001Vo`3oool0oooo0080oooo00<00?oo0?ooo`3oool01`3oool00`00I_l0
oooo0?nI00040?ooo`03003oo`3oool0oooo00<0oooo00<00?oo0?ooo`0co`002P3oool00`00ool0
oooo0?ooo`040?ooo`800?oo00@0oiT0003oo`00ool0<ol01@3oool01@0co`00oooo0?ooo`3oool0
0?mV00<0oooo00<00?mV0?ooo`00ool01@3oool01@00ofH0c03o0<`0o`3oool0c03o00D0oooo00@0
c03o0?ooo`3oool0<`3o0`3oool0103<0?l0<`3o0?ooo`0c0?l60?ooo`06001Vo`3oool0oooo0<`0
o`3oool00?oo0P3oool20<`0o`80oooo00<0oiT00?ooo`3<0?l00P3oool01@00I_l0oooo0?ooo`00
I_l0oooo008006Ko00<0oooo0<`0o`3oool00P3oool01@3<0?l0oooo001Vo`3<0?l0oooo0080<`3o
0`3oool00`3<0?l0oooo0<`0o`030?ooo`0C0<`0o`3oool0<`3o0?nI000c0?l0oiT00?ooo`00ofH0
<ol00?ooo`00ofH0<`3o0?ooo`00ofH0oooo0<`0o`3oool00?oo0?l000030?ooo`03003oo`3o09T0
oiT000D0oooo00<0c?l00?nI0000ofH00P00ofH0100c0?l0o`2I001Vo`00ool60?ooo`030000003o
ool0oooo0040oooo000H0?ooo`030000003oool0oooo0380oooo00P006Ko0?ooo`00I_l0<`3o001V
o`0c0?l0oooo001Vo`H0oooo00<00?oo0?ooo`3oool01`3oool00`00ool0oiT00?ooo`030?ooo`03
003oo`3oool0oooo0080oooo0P00ool00`3oool0<ol00?ooo`090?ooo`03003oo`3oool0oooo00@0
oooo00@00?oo0?ooo`3oV@00oooo0P0co`030?ooo`80<ol0103oool01`00ofH0oooo003oo`3oool0
0?mV0?ooo`00ool01@3oool00`00ofH0oooo0<`0o`020?ooo`050<`0o`3oool0oooo0?ooo`3<0?l0
0`3oool0100c0?l0oooo0?ooo`3oool203<0o`030?ooo`0c0?l0oooo00D0oooo00H006Ko0?ooo`3o
ool0c03o0?ooo`00ool30?ooo`060<`0o`3oool0oooo0?nI003oool0c03o0P3oool01000I_l0oooo
0?ooo`00I_l30?ooo`03001Vo`3<0?l0oooo00@0oooo00/006Ko0?ooo`0c0?l0oooo0<`0o`0c0?l0
c03o0?ooo`3<0?l0oooo0<`0o`030?ooo`0B0<`0o`3oool0oiT00?ooo`0c0?l0oiT003<0o`00ofH0
<ol00?ooo`00ofH0<`3o003oIP0c0?l0oooo0<`0o`0c0?l00?oo103oool00`00ool0o`2I0?nI0005
0?ooo`090<co0000ofH0oiT00?ooo`00ofH0<`3o0?l0V@00I_l00?oo00H0oooo00<000000?ooo`3o
ool00@3oool001P0oooo0P00000c0?ooo`03001Vo`3oool006Ko0080<`3o00<006Ko0?ooo`00I_l0
1P3oool00`00ool0oooo0?ooo`070?ooo`03003oo`3oV@00oooo00<0oooo00<00?oo0?ooo`3oool0
0P3oool2003oo`030?ooo`0co`00oooo00L0oooo00<00?oo0?ooo`00ool0203oool01@3oV@00oooo
03?o003oool0<ol00080oooo0P0co`040?ooo`05003oIP3oool00?oo003oIP3oool00P00ool50?oo
o`03003oIP3oool0oooo0080oooo00D0c03o0?ooo`3oool0oooo0<`0o`040?ooo`0803<0o`3oool0
oooo03<0o`3oool0<`3o0?ooo`0c0?l50?ooo`03001Vo`3oool0c03o0080oooo00D00?oo0?ooo`3o
ool0oooo0<`0o`020?ooo`090?nI003oool0c03o0?ooo`00I_l0oooo0?l0V@3oool0o`2I00<0oooo
00@006Ko0<`0o`00I_l0<`3o0`3oool00`00I_l0oooo03<0o`030?ooo`0303<0o`3<0?l0oooo00D0
oooo00<0c03o03<0o`3oV@000P3oool0200c0?l0oiT00?nI003oool0<ol0003oIP0c0?l00?mV0`0c
0?l2003oo`@0oooo00@00?oo0?l0V@3oV@00<ol0103oool02P3<o`00oooo0?ooo`3oV@00c?l0003o
IP00ool0c03o003oo`00ofH40?ooo`8000000`3oool001P0oooo00<000000?ooo`3oool0<P3oool0
2000I_l0oooo001Vo`0c0?l0oooo001Vo`3oool006Ko1`3oool00`00ool0oooo0?ooo`050?ooo`03
003oo`3oool0oiT000@0oooo00<00?oo0?ooo`3oool00P00ool20?ooo`03003oo`0co`00oooo00<0
oooo00@00?oo0?ooo`3oool0oooo0P00ool80?ooo`050?nI003oool0oooo03?o0000ool00`0co`00
0`3oool0<ol0003oo`040?ooo`04003oIP00ool00?mV003oo`80oooo0P00ool40?ooo`09003oIP3o
ool0oooo0?ooo`3<0?l0oooo0<`0o`3oool0c03o00@0oooo00P0<`3o0?ooo`3oool0<`3o0<`0o`0c
0?l0oooo03<0o`H0oooo00@006Ko0<`0o`3oool00?oo103oool0303<0?l0oooo0?ooo`3oool0oiT0
0?ooo`3<0?l006Ko0?ooo`3o09T0oooo0?l0V@<0oooo00D006Ko0?ooo`00I_l0<`3o0?ooo`03001V
o`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool01@3oool00`00ofH0<`3o0?nI00020?oo
o`0403<0o`3oV@00oiT00?ooo`<0<ol000@00?mV0?ooo`3<0?l0oooo0P00ool40?ooo`04003oo`3o
ool0oiT003?o00D0oooo00D0c?l00?ooo`3oV@00<`3o0<co0002003oo`030?ooo`00ofH0oooo00@0
oooo00<000000?ooo`3oool00@3oool000l0oooo1@0000040?ooo`030000003oool0oooo03<0oooo
00L006Ko0?ooo`3oool0oooo001Vo`3oool006Ko00L0oooo00<00?oo0?ooo`3oool01@3oool00`00
ool0oooo0?nI00050?ooo`800?oo103oool00`00ool0oooo03?o00020?ooo`800?oo0P3oool00`00
ool0oooo003oo`080?ooo`040?nI003oool0<ol00?ooo`800?oo0`3oool2003oo`@0oooo00<00?oo
003oIP00ool00`3oool2003oo`@0oooo00<00?mV0?ooo`3oool00P3oool30<`0o`H0oooo00P0<`3o
0?ooo`0c0?l0c03o03<0o`3oool0<`3o0<`0o`<0oooo0`3<0?l00`00I_l0oooo003oo`080?ooo`08
0?nI003oool0c03o001Vo`3oool0o`2I0?ooo`3o09T30?ooo`060<`0o`00I_l0oooo001Vo`3oool0
06Ko0P3oool00`0c0?l0oooo0?ooo`020?ooo`0403<0o`3oool0oooo0?nI00@0oooo00<00?mV03<0
o`3oV@000P3oool01`0c0?l0oiT003<0o`3oV@00oooo03<0o`0co`000P3oool00`3<0?l00?oo03<0
o`050?ooo`03003oo`3oool0oiT00080<ol000@0c03o003oo`3oool0oooo0P3<o`001`3oV@00<`3o
0<co0000ofH00?oo003oIP0c0?l01@3oool00`000000oooo0?ooo`010?ooo`00403oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03P0oooo0P00I_l70?ooo`03003oo`3oool0oooo
00D0oooo00<00?oo0?ooo`3oV@001@3oool2003oo`@0oooo00<00?oo0?ooo`0co`000P3oool00`00
ool0oooo003oo`02003oo`030?ooo`00ool0oooo00L0oooo00<0oiT00?ooo`0co`000`3oool00`00
ool0oooo0?ooo`02003oo`80oooo0`00ool60?ooo`03003oo`3oool0oooo0080oooo00<00?mV0?oo
o`3oool00P3oool00`3<0?l0oooo0<`0o`060?ooo`0403<0o`3oool0<`3o0?ooo`80c03o00<0<`3o
0<`0o`3oool00P3oool01P3<0?l0oooo0?ooo`00I_l0oooo003oo`P0oooo00@0oiT00?ooo`3<0?l0
06Ko0P3oool0203o09T0oooo0?l0V@3oool0o`2I0<`0o`00I_l0<`3o0P00I_l30?ooo`0303<0o`3o
09T0oooo0080oooo00@0<`3o0?ooo`3oool0oiT00`3oool2003oIP0303<0o`3oV@00oooo0080oooo
00<00?mV03<0o`3oV@000P0c0?l01`0co`000?oo0?ooo`3<0?l0<ol00<`0o`0c0?l0103oool00`00
ool0oooo0?nI000203?o00800?oo00/0oooo03<0o`3<o`00c?l00?ooo`3oV@00c?l00?nI003<o`00
0?mV0?nI00050?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0>03oool00`00I_l0oooo0?ooo`070?ooo`07003oo`3oool0oooo0?ooo`00
ool0oooo003oo`020?ooo`030?nI003oool0oooo00<0oooo00<00?oo0?ooo`3oool00`3oool01@00
ool0oooo03?o003oool00?oo00h0oooo00<0oiT003?o000co`001@3oool2003oo`050?ooo`00ool0
oooo0?ooo`00ool02@3oool01@00ool0oooo0?ooo`3oool00?mV00d0oooo0P0c0?l40?ooo`0303<0
o`3oool0c03o0080oooo00H0c03o0?ooo`3oool006Ko0?ooo`00ool80?ooo`030?nI003oool006Ko
00<0oooo00X0o`2I0?ooo`3o09T0oooo0?l0V@3<0?l0oooo03<0o`3oool006Ko0P3oool00`0c0?l0
o`2I0?l0V@040?ooo`0303<0o`3oool0oiT000<0oooo00<00?mV03<0o`3oV@000`3oool01@00ofH0
0?oo0?ooo`3oV@00c03o0080oooo00H0<ol00<`0o`0co`00<ol00<`0o`0c0?l40?ooo`0:0?l0V@3o
V@00<ol00?ooo`0co`000?oo0<`0o`00ool0oooo0<co0080oooo00H0oiT00<co003oV@00c?l00?nI
003o09T50?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003oool0oooo00<0oooo0P00
000i0?ooo`03001Vo`3oool0oooo00L0oooo00L00?oo0?ooo`3oool0oooo003oo`3oool00?oo00<0
oooo00<0oiT00?ooo`3oool02@3oool2003oo`0503?o003oool0oooo03?o003oool00`0co`060?oo
o`0303?o003oool0oiT000P0oooo00<00?oo0?ooo`3oool00P00ool:0?ooo`03003oo`3oool0oooo
0080oooo00<00?mV0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`030?ooo`0503<0o`3<0?l0oooo
0?ooo`3<0?l00P3oool00`00I_l0oooo003oo`090?ooo`030?nI0000I_l0c03o00@0oooo00P0o`2I
0?ooo`3o09T0c03o0?ooo`0c0?l0oooo03<0o`80oooo00@0<`3o0?l0V@3oool0o`2I0`3oool01`0c
0?l0oiT00?ooo`3oV@00oooo003oIP3oool00P3oV@030?ooo`07003oIP00ool0c03o0?ooo`3oV@00
c03o003oo`0203?o00040?ooo`0co`00c03o03<0o`<0oooo00/0o`2I0?ooo`3oV@00<ol00?ooo`00
ool0<ol00<`0o`00ool0oooo0<`0o`020?ooo`80oiT000@0c?l00?nI003oool0c03o0`3oool30000
00<0oooo000?0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`120?oo
o`07003oo`3oool0oooo0?ooo`00ool0oooo003oo`030?ooo`030?nI003oool0oooo00/0oooo0`0c
o`001@3oool0<ol00?ooo`3oool0<ol000D0oooo00@0<ol00?ooo`0co`00oiT02`3oool2003oo`X0
oooo00<00?oo0?ooo`3oool00P3oool00`00ofH0oooo0?ooo`0A0?ooo`0403<0o`3oool0c03o0<`0
o`<0oooo00<006Ko0?ooo`00ool02@3oool00`3oV@00oooo0<`0o`050?ooo`060?l0V@3<0?l0oooo
0?l0V@0c0?l0oooo100c0?l00`3o09T0oooo0?l0V@030?ooo`0303<0o`3oV@00oooo00H0oiT00P00
ofH02P3oool00?mV003oo`3<0?l00?oo0?nI003<0?l00?oo03?o003<0?l20?ooo`0303?o000c0?l0
oooo0080oooo00X0o`2I03?o003oV@00<ol0003oo`3<0?l0<ol003<0o`00ool0c03o1000ool01@3o
V@00c?l003?o003<o`00c03o00D0oooo00<000000?ooo`3oool00@3oool000l0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo04<0oooo00D00?oo0?ooo`00ool0oooo003o
o`040?ooo`030?nI003oool0oooo0180oooo00<0<ol00?ooo`3oool00`3oool0100co`00oooo0?oo
o`3oV@0;0?ooo`800?oo2`3oool01@00ool0oooo0?ooo`3oool00?mV01<0oooo00@0<`3o0?ooo`3<
0?l0<`3o103oool00`00I_l00?oo0?ooo`080?ooo`030?nI003oool0c03o00D0oooo00L0o`2I0<`0
o`3oool0o`2I03<0o`3oool0<`3o0080oooo00D0o`2I0?ooo`3oool0oooo0?l0V@020?ooo`0<0?nI
003oool0<`3o0?nI003oool00?mV0?ooo`0c0?l0oiT00<`0o`3o09T00?mV0P3oool03P00ool0oooo
0?nI003<0?l00?oo0?ooo`3<0?l0o`2I0?ooo`0co`00<`3o0?ooo`0c0?l0o`2I0P0co`00403oV@00
<ol0003oo`0c0?l0<ol003<0o`00ool0c03o003oo`3<0?l0oooo003oo`3oool0c?l003?o003<o`06
0?ooo`030000003oool0oooo0040oooo000@0?ooo`<000001@3oool00`000000oooo0?ooo`130?oo
o`05003oo`3oool00?oo0?ooo`00ool0103oool00`3oV@00oooo0?ooo`0C0?ooo`0503?o003oool0
oooo0?ooo`0co`000`3oool00`3oV@00oooo0?ooo`090?ooo`03003oo`3oool0oooo00/0oooo00@0
0?oo0?ooo`3oool00?mV4`3oool0100c0?l0oooo0?ooo`0c0?l40?ooo`03001Vo`00ool0oooo00L0
oooo00D006Ko0?nI003oool0c03o0?nI00050?ooo`040?nI003oool0<`3o0?l0V@@0oooo00<0o`2I
0?ooo`3oool00`3oV@000`3oool0oiT00?ooo`0203<0o`08003oIP3oool0<`3o0?ooo`3oV@00o`2I
0<`0o`3o09T20?ooo`0J0<`0o`3oool00?oo0?nI0000ool0c03o0?l0V@3oool0o`2I03?o003<0?l0
<`3o0?l0V@0co`00oooo03?o003oV@00<ol0003oo`0c0?l0oooo03?o0000ool0oooo003oo`3<0?l2
0?ooo`040<`0o`0co`00oooo0<co00H0oooo00<000000?ooo`3oool00@3oool001P0oooo00<00000
0?ooo`3oool0A03oool2003oo`L0oooo00<0oiT00?ooo`3oool04P3oool00`0co`00oooo0?ooo`02
03?o00<0oooo00<0oiT00?ooo`3oool05`3oool01@00ool0oooo0?ooo`3oool00?mV01<0oooo0`0c
0?l40?ooo`03003oo`3oool0oooo00D0oooo0`00I_l0103oV@00oooo0?nI003oV@040?ooo`050<`0
o`3oV@00oooo03<0o`3o09T0103oool01`3o09T0oooo0?ooo`3oV@00oooo0?l0V@3oV@000P3oool2
003oIP0303<0o`3oool0<`3o0080oooo00<0o`2I0<`0o`3o09T00P3<0?l30?ooo`030?nI003<0?l0
c03o0080oooo00l0o`2I03?o003<0?l0c03o03?o003oool0<`3o0<`0o`3oV@00oooo003oo`0c0?l0
oooo03?o003oool00P00ool01`3oool0c03o0?ooo`3<0?l0<ol00?ooo`3<o`001P3oool00`000000
oooo0?ooo`010?ooo`00603oool2000004D0oooo00<00?oo0?ooo`3oool01`3oool00`3oV@00oooo
0?ooo`0A0?ooo`0303?o003oool0<ol000@0oooo00<0oiT00?ooo`3oool0603oool01@00ool0oooo
0?ooo`3oool00?mV01H0oooo00H0<`3o0?ooo`3oool0oooo003oo`00I_l50?ooo`05001Vo`3oool0
oooo001Vo`3oool00`3oV@040?ooo`080<`0o`3oV@00oiT003<0o`3o09T0oooo0?l0V@3oool20?l0
V@80oooo00<0oiT00?ooo`3o09T00`3oool01000ofH0oooo0?ooo`0c0?l30?ooo`030?l0V@3<0?l0
oooo0080c03o0`3oool00`3oV@00c03o0<`0o`020?ooo`0;0?l0V@3oool0<ol003?o003o09T0oooo
03<0o`3oool0oiT0003oo`0c0?l00`3oool02`0co`000?oo0?ooo`3oool0c03o0?ooo`3<0?l0<ol0
0?ooo`3<o`00<ol000@0oooo0P0000030?ooo`00603oool00`000000oooo0?ooo`1>0?ooo`030?nI
003oool0oooo00`0oooo00<0oiT00?ooo`3oool00`3oool203?o0080oooo00<0oiT00?ooo`3oV@00
6P3oool00`00ool0oooo0?ooo`020?ooo`03003oIP3oool0oooo00P0oooo0P00ofH30?ooo`03003o
o`3oool0oooo00<0oooo00H0<`3o0?ooo`3oool0oooo003oo`00I_l50?ooo`03001Vo`3oool0oooo
0080oooo00P0oiT00?ooo`3oV@00oooo0<`0o`3oool0c03o0?ooo`80oiT00P3oool30?l0V@<0oooo
00L0oiT00?ooo`3oool0oooo0?l0V@3oool00?mV00L0oooo00H0o`2I0?ooo`3<0?l0o`2I0<`0o`3o
09T20?ooo`03003oo`3oV@00oiT000<0oooo00<0o`2I0?ooo`3o09T00P3oool01@0c0?l0oiT00?oo
o`00ool0<`3o00<0oooo00P0<ol0003oo`3oool0oooo0<`0o`3oool0c03o03?o0080oooo00<0c?l0
0?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`1>0?oo
o`030?nI003oool0oooo00`0oooo0P3oV@040?ooo`070?nI003oool0oooo0?ooo`3oV@00oooo0?nI
000J0?ooo`03003oo`3oool0oooo00<0oooo00<00?mV0?ooo`3oool01@3oool2003oIP80oooo00@0
0?mV0?ooo`3oool00?oo1@3oool01P0c0?l0oooo0?ooo`0c0?l00?oo001Vo`@0oooo00<006Ko0?oo
o`3oool00`3oool03@3oV@00oooo0<`0o`3oV@00c03o0?ooo`3<0?l0oiT003<0o`3oool0oiT00?oo
o`3o09T01@3oool01`3oV@00oooo0?ooo`3oool0o`2I0?ooo`00ofH01P3oool01`3o09T0oooo0?oo
o`3<0?l0o`2I0?ooo`3o09T00P3oool00`3o09T0oiT00?nI00030?ooo`<0o`2I0P3oool20?nI0003
03<0o`00ool0oooo00@0oooo0`0co`000`3oool0c03o03?o00030?ooo`030<co003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0C`3oool00`3oV@00oooo
0?ooo`0:0?ooo`030?nI003oool0oiT000<0oooo0P3oV@030?ooo`030?nI003oool0oiT001/0oooo
00<00?oo0?ooo`3oool00P3oool00`00ofH0oooo0?ooo`050?ooo`05003oIP3oool0oooo0?ooo`00
ofH00P3oool2003oo`D0oooo00H0<`3o0?ooo`00ool0oooo03<0o`00I_l30?ooo`03001Vo`3oool0
oooo00D0oooo00/0c03o0?nI003<0?l0oooo0<`0o`3oV@00<`3o0?ooo`3oV@00oooo0?nI00030?oo
o`030?nI003oool0oiT000@0oooo00<0o`2I003oIP3o09T01@3oool00`3o09T0oooo0?ooo`040?oo
o`030?l0V@3oool0o`2I0080oiT01@3oool00`3o09T0oooo0?ooo`020?nI000303<0o`00ool0oooo
00L0oooo00<0<ol00<`0o`0co`000`3oool00`3<o`00oooo0?ooo`030?ooo`030000003oool0oooo
0040oooo000H0?ooo`030000003oool0oooo04l0oooo00<0oiT00?ooo`3oool02P3oool0103oV@00
oooo0?ooo`3oV@020?ooo`80oiT00P3oool0103oV@00oooo0?nI003oV@0K0?ooo`03003oo`3oool0
oooo00<0oooo0P00ofH00`3oool00?mV0?ooo`020?ooo`03003oIP3oool0oooo0080oooo00D00?mV
003oo`3oool0oooo003oo`040?ooo`0603<0o`3oool00?oo0?ooo`0c0?l006Ko0`3oool00`00I_l0
oooo0?ooo`030?ooo`08003oIP3oool0oooo0?nI003<0?l0oooo0<`0o`3oV@030?ooo`80oiT00`3o
ool20?nI00D0oooo00@0o`2I003oIP3o09T0o`2I103oool00`3o09T0oooo0?ooo`040?ooo`030?l0
V@3oool0o`2I0080oooo00<0oiT00?ooo`3oool01@3oool20?nI00X0oooo00<0<ol00?ooo`0co`00
2@3oool00`000000oooo0?ooo`010?ooo`00603oool200000500oooo00<0oiT00?ooo`3oool02P3o
ool0103oV@00oooo0?ooo`3oool20?nI00070?ooo`3oV@00oooo0?ooo`3oV@00oooo0?nI000L0?oo
o`800?oo103oool2003oIP030?ooo`00ofH0oooo0080oooo00<00?mV0?ooo`3oool00P3oool01@00
ofH00?oo0?ooo`3oool00?oo00D0oooo00D00?oo0?ooo`3oool00?mV001Vo`020?ooo`03001Vo`3o
ool0oooo00@0oooo00D00?mV0?ooo`3oool0oiT00?ooo`020<`0o`030?nI003oool0oooo0080oooo
00D0oiT00?ooo`3oool0oooo0?nI00060?ooo`040?l0V@00ofH0o`2I0?l0V@@0oooo00<0o`2I0?oo
o`3oool0103oool20?l0V@<0oooo00@0oiT00?ooo`3oool0oiT00`3oool00`3oV@00oooo0?ooo`0;
0?ooo`0303?o003oool0oooo00L0oooo0P0000030?ooo`00603oool00`000000oooo0?ooo`1?0?oo
o`030?nI003oool0oooo00T0oooo00<0oiT00?ooo`3oool01@3oool01P3oV@00oooo0?ooo`3oV@00
oooo0?nI01`0oooo0P00ool50?ooo`06003oIP3oool00?mV003oIP3oool00?mV103oool00`00ool0
0?mV0?ooo`030?ooo`03003oo`3oool00?oo0080oooo00D00?oo0?ooo`3oool00?mV001Vo`020?oo
o`03001Vo`3oool0oooo0080oooo0`00ofH20?ooo`050?nI003oool0c03o03<0o`3oV@00103oool0
103oV@00oooo0?ooo`3oV@070?ooo`05003oIP3oool0o`2I0?ooo`3o09T00`3oool00`3o09T0oooo
0?ooo`050?ooo`040?l0V@3oool0oooo0?ooo`@0oiT00`3oool00`3oV@00oooo0?ooo`0;0?ooo`03
03?o003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0
D03oool00`3oV@00oooo0?ooo`040?ooo`050?nI003oool0oooo0?ooo`3oV@00203oool00`3oV@00
oooo0?nI000O0?ooo`03003oo`3oool0oooo00@0oooo00D00?mV0?ooo`00ofH0oooo003oIP040?oo
o`03003oo`3oool00?mV00<0oooo00D00?oo0?ooo`00ool0oooo003oo`020?ooo`800?mV00@0oooo
001Vo`3oool006Ko103oool2003oIP0703<0o`00ofH00?mV0?ooo`3oV@00c03o0?nI00060?ooo`03
0?nI003oool0oiT000L0oooo00H00?mV0?l0V@3oool0oooo0?l0V@3oool20?l0VA00oooo00@0oiT0
0?ooo`3oool0oiT0603oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`1@
0?ooo`030?nI003oool0oooo00@0oooo00D0oiT00?ooo`3oool0oooo0?nI00080?ooo`80oiT0803o
ool00`00ool0oooo0?ooo`040?ooo`03003oIP3oool0oooo00800?mV103oool00`00ool0oooo003o
IP02003oIP80oooo00@00?oo0?ooo`00ool00?oo0P3oool01P00ofH0oooo003oIP00I_l0<`3o001V
o`@0oooo00<00?mV0?ooo`0c0?l00P00ofH0103oool0oiT003<0o`3oV@060?ooo`030?nI003oool0
oiT000L0oooo00H00?mV0?l0V@3oool0oooo0?l0V@3oool20?l0VA00oooo00<0oiT00?ooo`3oV@00
6@3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`1@0?ooo`030?nI003o
ool0oooo00<0oooo00<0oiT00?ooo`3oV@000P3oool00`3oV@00oooo0?ooo`060?ooo`80oiT08@3o
ool00`00ool0oooo0?ooo`030?ooo`03003oIP3oool0oooo00H0oooo00<00?oo0?ooo`3oool00P3o
ool01@00ofH0oooo0?ooo`3oool00?oo00<0oooo00<00?mV0?ooo`00ofH00P00I_l03P0c0?l0oooo
0?ooo`3oool00?mV0?ooo`0c0?l0oooo03<0o`3oool00?mV0?nI003oool0oiT01P3oool20?nI00P0
oooo00<00?mV0?l0V@3oool00P3oool00`3o09T0oooo0?ooo`0@0?ooo`030?nI003oool0oiT001T0
oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0D03oool00`3oV@00oooo
0?ooo`030?ooo`030?nI003oool0oiT00080oooo00<0oiT00?ooo`3oool01P3oool00`3oV@00oooo
0?ooo`0P0?ooo`03003oo`3oool0oooo00/0oooo00<00?oo0?ooo`3oool00`3oool00`00ofH0oooo
0?ooo`040?ooo`07003oIP3oool0oooo003oIP3oool006Ko03<0o`030?ooo`0:003oIP3oool0<`3o
0?ooo`0c0?l0oooo003oIP3oV@00oooo0?nI00<0oooo0P00ofH00`3oool0oiT00?nI00050?ooo`<0
0?mV00<0oooo0?l0V@3oool05P3oool00`3oV@00oooo0?ooo`0H0?ooo`030000003oool0oooo0040
oooo000H0?ooo`800000DP3oool20?nI0080oooo00H0oiT00?ooo`3oool0oiT00?ooo`3oV@0/0?oo
o`03003oo`3oool0oooo00@0oooo0P00ool50?ooo`03003oo`3oool0oooo00<0oooo00<00?mV0?oo
o`3oool0103oool01`00ofH0oooo0?ooo`3oool00?mV001Vo`00ofH00`3oool00`00ofH0oooo03<0
o`020?ooo`0403<0o`00ofH0oooo0?nI00@0oooo0`00ofH00`3oool00?mV0?ooo`020?ooo`05003o
IP3oool00?mV0?ooo`00ofH0<`3oool2000000<0oooo000H0?ooo`030000003oool0oooo0540oooo
0P3oV@020?ooo`040?nI003oool0oooo0?ooo`80oiT0;03oool00`00ool0oooo0?ooo`020?ooo`80
0?oo0P3oool00`00ool0oooo003oo`020?ooo`03003oo`3oool0oooo00<0oooo00<00?mV0?ooo`3o
ool0103oool02P00ofH0oooo0?ooo`3oool00?mV0?ooo`00ofH0<`3o0?ooo`00ofH20?ooo`0303<0
o`3oool0oooo0080oooo00<00?mV0?nI003oool00P3oool01P00ofH0oooo0?ooo`00ofH0oooo003o
IP80oooo00<00?mV0?ooo`00ofH0=`3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000
oooo0?ooo`1A0?ooo`050?nI003oool0oiT00?ooo`3oV@000`3oool20?nI02d0oooo0`00ool00`3o
ool00?oo0?ooo`020?ooo`05003oo`3oool00?oo0?ooo`00ool01P3oool00`00ofH0oooo0?ooo`04
0?ooo`03003oIP3oool0oooo0080oooo00L00?mV0?ooo`00ofH0oooo003oIP3oool0<`3o00H0oooo
00@00?mV0?ooo`3oool00?mV1@3oool01000ofH0oooo0?ooo`00ofHi0?ooo`030000003oool0oooo
0040oooo000H0?ooo`030000003oool0oooo05<0oooo0P3oV@040?ooo`80oiT0;`3oool2003oo`D0
oooo00<00?oo0?ooo`00ool0203oool00`00ofH0oooo0?ooo`030?ooo`03003oIP3oool0oooo00@0
oooo0P00ofH00`3oool0<`3o03<0o`070?ooo`03003oIP3oool00?mV00H0oooo0P00ofHj0?ooo`03
0000003oool0oooo0040oooo000H0?ooo`030000003oool0oooo05@0oooo00<0oiT00?ooo`3oool0
0`3oool00`3oV@00oooo0?ooo`0^0?ooo`03003oo`3oool0oooo00h0oooo00<00?mV0?ooo`3oool0
0P3oool00`00ofH0oooo0?ooo`050?ooo`0303<0o`3oool0<`3o00T0oooo00<00?mV0?ooo`00ofH0
1`3oool00`00ofH0oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000H0?ooo`800000W@3o
ool3003oIP80oooo00<00?mV0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`080?ooo`800?mV@P3o
ool2000000<0oooo000H0?ooo`030000003oool0oooo09`0oooo00<00?mV0?ooo`3oool00`00ofHD
0?ooo`03003oIP3oool0oooo0440oooo00<000000?ooo`3oool00@3oool000<0oooo1@0000030?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0;H0oooo00<00?mV0?oo
o`3oool0@@3oool00`000000oooo0?ooo`010?ooo`00103oool010000000oooo0?ooo`0000070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3j0?ooo`030000003oool0
oooo0040oooo00050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo00060?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool200000?T0oooo0`0000030?ooo`000`3oool01@000000oooo
0?ooo`3oool0000000L0oooo100000050?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`010?ooo`00103oool3000000P0oooo
1@0000040?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<0
00000?ooo`3oool0nP3oool00`000000oooo0?ooo`010?ooo`00603oool200000?X0oooo0P000003
0?ooo`00603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`03
0000003oool0oooo0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0
nP3oool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`3j0?ooo`030000003o
ool0oooo0040oooo000H0?ooo`800000nP3oool2000000<0oooo000H0?ooo`030000003oool0oooo
0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0nP3oool00`000000
oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo
000H0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<00000
0?ooo`3oool0nP3oool00`000000oooo0?ooo`010?ooo`00603oool200000?X0oooo0P0000030?oo
o`00603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo0040oooo000H0?ooo`030000
003oool0oooo0?X0oooo00<000000?ooo`3oool00@3oool001P0oooo00<000000?ooo`3oool0nP3o
ool00`000000oooo0?ooo`010?ooo`00603oool00`000000oooo0?ooo`3j0?ooo`030000003oool0
oooo0040oooo000H0?ooo`800000nP3oool2000000<0oooo000H0?ooo`030000003oool0oooo0?X0
oooo00<000000?ooo`3oool00@3oool00100oooo0`0000050?ooo`030000003oool0oooo0?X0oooo
00<000000?ooo`3oool00@3oool000l0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000A0?ooo`8000001@3oooon
000000<0oooo000C0?ooo`030000003oool0oooo0?l0oooo103oool000l0oooo00D000000?ooo`3o
ool0oooo0000003o0?ooo`H0oooo000@0?ooo`<00000o`3oool70?ooo`00o`3ooolJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-0.126176, -0.233531, \
0.00415412, 0.0192043}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["B//Dimensions", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 201, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["sample data at tau = {0,10,20,30,50,100,T}+1; First \
panel unit  B[[1]]",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell["\<\
miss = -9;
ZM = Shape[miss,{T+1,p}];
tau = {0,10,20,30,50,100,T}+1;
Do[ ZM[[tau[[i]] ]] = B[[1,tau[[i]] ]],{i,Length[tau]}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ZM//Dimensions", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({201, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ZM", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\
\)}, {\(-9\)}, {\(-9\)}, {1.1370279965762853`}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{1.093963633246508`}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\
\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {1.4674635023438412`}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {1.3503111345686094`}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {0.43149245648856194`}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, {\(-9\)}, \
{\(-9\)}, {1.9840043577897457`}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["filtering and smoothing", "Subsection",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\({YG, PG, YF, PF, lik} = \ \[IndentingNewLine]EKG[{ZM, X}, 
          Theta, {fBrownianBridge, Jacobif, gBrownianBridge, h, Jacobih, R, 
            mue, sigma, 
            dt}, \ \ \[IndentingNewLine]\ \ \ \ \ \ \ {miss = \(-9\), 
            option = 2, Nonlin = 1}];\)\)], "Input",
  PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{\(s = Map[VecDiag, PF] // Sqrt;\), "\n", 
    RowBox[{\(HPD = \ YF~ii~\((YF + s)\)~ii~\((YF - s)\);\), 
      StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox[\( (*\ 67  %\ HPD\ confidence\ intervals\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\n", \(filter1 = 
        plot1[B[\([1]\)]~ii~HPD // AddTimeAxis[#, dt] &, 
          color -> {1, 2, 5, 5}, 
          dicke ->  .006 {1, 
                1,  .5,  .5}, \[IndentingNewLine]\t\t\t\t\tPlotLabel -> \
"\<filtered\>"];\), "\n", "Null"}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{201, 5}\),
      SequenceForm[ "Dimension der Daten  ", {201, 5}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.1081 0.342532 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06317 -18 -4.5 ]
[-0.0125 .06317 0 4.5 ]
[-0.0125 .1488 -24 -4.5 ]
[-0.0125 .1488 0 4.5 ]
[-0.0125 .23443 -6 -4.5 ]
[-0.0125 .23443 0 4.5 ]
[-0.0125 .32007 -24 -4.5 ]
[-0.0125 .32007 0 4.5 ]
[-0.0125 .4057 -18 -4.5 ]
[-0.0125 .4057 0 4.5 ]
[-0.0125 .49133 -24 -4.5 ]
[-0.0125 .49133 0 4.5 ]
[-0.0125 .57696 -6 -4.5 ]
[-0.0125 .57696 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[.97619 .57149 -5 -6 ]
[.97619 .57149 5 6 ]
[.97619 .57208 -5 -6 ]
[.97619 .57208 5 6 ]
[.97619 .58153 -5 -6 ]
[.97619 .58153 5 6 ]
[.97619 .56262 -5 -6 ]
[.97619 .56262 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06317 m
.00625 .06317 L
s
[(0.5)] -0.0125 .06317 1 0 Mshowa
0 .1488 m
.00625 .1488 L
s
[(0.75)] -0.0125 .1488 1 0 Mshowa
0 .23443 m
.00625 .23443 L
s
[(1)] -0.0125 .23443 1 0 Mshowa
0 .32007 m
.00625 .32007 L
s
[(1.25)] -0.0125 .32007 1 0 Mshowa
0 .4057 m
.00625 .4057 L
s
[(1.5)] -0.0125 .4057 1 0 Mshowa
0 .49133 m
.00625 .49133 L
s
[(1.75)] -0.0125 .49133 1 0 Mshowa
0 .57696 m
.00625 .57696 L
s
[(2)] -0.0125 .57696 1 0 Mshowa
.125 Mabswid
0 .08029 m
.00375 .08029 L
s
0 .09742 m
.00375 .09742 L
s
0 .11455 m
.00375 .11455 L
s
0 .13167 m
.00375 .13167 L
s
0 .16593 m
.00375 .16593 L
s
0 .18305 m
.00375 .18305 L
s
0 .20018 m
.00375 .20018 L
s
0 .21731 m
.00375 .21731 L
s
0 .25156 m
.00375 .25156 L
s
0 .26869 m
.00375 .26869 L
s
0 .28581 m
.00375 .28581 L
s
0 .30294 m
.00375 .30294 L
s
0 .33719 m
.00375 .33719 L
s
0 .35432 m
.00375 .35432 L
s
0 .37145 m
.00375 .37145 L
s
0 .38857 m
.00375 .38857 L
s
0 .42283 m
.00375 .42283 L
s
0 .43995 m
.00375 .43995 L
s
0 .45708 m
.00375 .45708 L
s
0 .47421 m
.00375 .47421 L
s
0 .50846 m
.00375 .50846 L
s
0 .52558 m
.00375 .52558 L
s
0 .54271 m
.00375 .54271 L
s
0 .55984 m
.00375 .55984 L
s
0 .04604 m
.00375 .04604 L
s
0 .02891 m
.00375 .02891 L
s
0 .01179 m
.00375 .01179 L
s
0 .59409 m
.00375 .59409 L
s
0 .61122 m
.00375 .61122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06317 m
1 .06317 L
s
.99375 .1488 m
1 .1488 L
s
.99375 .23443 m
1 .23443 L
s
.99375 .32007 m
1 .32007 L
s
.99375 .4057 m
1 .4057 L
s
.99375 .49133 m
1 .49133 L
s
.99375 .57696 m
1 .57696 L
s
.125 Mabswid
.99625 .08029 m
1 .08029 L
s
.99625 .09742 m
1 .09742 L
s
.99625 .11455 m
1 .11455 L
s
.99625 .13167 m
1 .13167 L
s
.99625 .16593 m
1 .16593 L
s
.99625 .18305 m
1 .18305 L
s
.99625 .20018 m
1 .20018 L
s
.99625 .21731 m
1 .21731 L
s
.99625 .25156 m
1 .25156 L
s
.99625 .26869 m
1 .26869 L
s
.99625 .28581 m
1 .28581 L
s
.99625 .30294 m
1 .30294 L
s
.99625 .33719 m
1 .33719 L
s
.99625 .35432 m
1 .35432 L
s
.99625 .37145 m
1 .37145 L
s
.99625 .38857 m
1 .38857 L
s
.99625 .42283 m
1 .42283 L
s
.99625 .43995 m
1 .43995 L
s
.99625 .45708 m
1 .45708 L
s
.99625 .47421 m
1 .47421 L
s
.99625 .50846 m
1 .50846 L
s
.99625 .52558 m
1 .52558 L
s
.99625 .54271 m
1 .54271 L
s
.99625 .55984 m
1 .55984 L
s
.99625 .04604 m
1 .04604 L
s
.99625 .02891 m
1 .02891 L
s
.99625 .01179 m
1 .01179 L
s
.99625 .59409 m
1 .59409 L
s
.99625 .61122 m
1 .61122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filtered) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .57149 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.006 w
.02381 .23443 m
.02857 .27685 L
.03333 .30767 L
.0381 .28323 L
.04286 .27821 L
.04762 .27208 L
.05238 .27684 L
.05714 .26856 L
.0619 .28942 L
.06667 .26733 L
.07143 .28137 L
.07619 .28216 L
.08095 .28158 L
.08571 .26702 L
.09048 .27511 L
.09524 .26054 L
.1 .245 L
.10476 .25463 L
.10952 .25036 L
.11429 .26316 L
.11905 .26662 L
.12381 .30245 L
.12857 .27136 L
.13333 .26684 L
.1381 .28841 L
.14286 .28792 L
.14762 .2757 L
.15238 .30299 L
.15714 .34494 L
.1619 .37102 L
.16667 .39455 L
.17143 .41453 L
.17619 .42973 L
.18095 .48215 L
.18571 .48107 L
.19048 .4377 L
.19524 .43137 L
.2 .45606 L
.20476 .46862 L
.20952 .41731 L
.21429 .42673 L
.21905 .44343 L
.22381 .43071 L
.22857 .40603 L
.23333 .38509 L
.2381 .39736 L
.24286 .36258 L
.24762 .33174 L
.25238 .29482 L
.25714 .3231 L
Mistroke
.2619 .35443 L
.26667 .31928 L
.27143 .32274 L
.27619 .29215 L
.28095 .32727 L
.28571 .30035 L
.29048 .30879 L
.29524 .29442 L
.3 .32884 L
.30476 .31194 L
.30952 .29039 L
.31429 .30539 L
.31905 .31093 L
.32381 .27709 L
.32857 .22216 L
.33333 .20628 L
.3381 .20505 L
.34286 .20831 L
.34762 .22176 L
.35238 .20378 L
.35714 .19878 L
.3619 .20021 L
.36667 .19715 L
.37143 .16321 L
.37619 .16036 L
.38095 .14808 L
.38571 .10734 L
.39048 .10486 L
.39524 .11387 L
.4 .08004 L
.40476 .07269 L
.40952 .06742 L
.41429 .07677 L
.41905 .08836 L
.42381 .08962 L
.42857 .0865 L
.43333 .11263 L
.4381 .14799 L
.44286 .09691 L
.44762 .13662 L
.45238 .13264 L
.45714 .12968 L
.4619 .12387 L
.46667 .12268 L
.47143 .08469 L
.47619 .04883 L
.48095 .03241 L
.48571 .03978 L
.49048 .05429 L
.49524 .04392 L
Mistroke
.5 .0397 L
.50476 .06775 L
.50952 .06917 L
.51429 .07117 L
.51905 .07935 L
.52381 .11716 L
.52857 .16642 L
.53333 .15262 L
.5381 .17015 L
.54286 .14731 L
.54762 .16765 L
.55238 .19459 L
.55714 .2122 L
.5619 .21401 L
.56667 .26138 L
.57143 .22693 L
.57619 .24994 L
.58095 .27486 L
.58571 .24522 L
.59048 .24543 L
.59524 .26983 L
.6 .23211 L
.60476 .23915 L
.60952 .28866 L
.61429 .25349 L
.61905 .26024 L
.62381 .28271 L
.62857 .22768 L
.63333 .23278 L
.6381 .21691 L
.64286 .18456 L
.64762 .17123 L
.65238 .20281 L
.65714 .21801 L
.6619 .24369 L
.66667 .269 L
.67143 .24178 L
.67619 .26524 L
.68095 .27338 L
.68571 .27743 L
.69048 .32324 L
.69524 .34441 L
.7 .38609 L
.70476 .38481 L
.70952 .38675 L
.71429 .40086 L
.71905 .3861 L
.72381 .40895 L
.72857 .40346 L
.73333 .40949 L
Mistroke
.7381 .42411 L
.74286 .4102 L
.74762 .43079 L
.75238 .40186 L
.75714 .39356 L
.7619 .40858 L
.76667 .3965 L
.77143 .36773 L
.77619 .38184 L
.78095 .42057 L
.78571 .41756 L
.79048 .42426 L
.79524 .41524 L
.8 .42591 L
.80476 .41381 L
.80952 .41332 L
.81429 .41031 L
.81905 .40058 L
.82381 .379 L
.82857 .38654 L
.83333 .39298 L
.8381 .39579 L
.84286 .38942 L
.84762 .42825 L
.85238 .38446 L
.85714 .37589 L
.8619 .38386 L
.86667 .41935 L
.87143 .44483 L
.87619 .42713 L
.88095 .47687 L
.88571 .48078 L
.89048 .49491 L
.89524 .53126 L
.9 .51321 L
.90476 .50073 L
.90952 .45754 L
.91429 .46979 L
.91905 .51017 L
.92381 .48165 L
.92857 .45273 L
.93333 .48668 L
.9381 .51022 L
.94286 .46912 L
.94762 .4752 L
.95238 .50375 L
.95714 .50661 L
.9619 .53176 L
.96667 .58 L
.97143 .57941 L
Mistroke
.97619 .57149 L
Mfstroke
0 .98 .604 r
gsave
.97619 .57208 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .23443 m
.02857 .23614 L
.03333 .23785 L
.0381 .23956 L
.04286 .24127 L
.04762 .24297 L
.05238 .24468 L
.05714 .24639 L
.0619 .2481 L
.06667 .24981 L
.07143 .28076 L
.07619 .28232 L
.08095 .28387 L
.08571 .28543 L
.09048 .28698 L
.09524 .28854 L
.1 .29009 L
.10476 .29165 L
.10952 .2932 L
.11429 .29476 L
.11905 .26722 L
.12381 .26894 L
.12857 .27065 L
.13333 .27237 L
.1381 .27409 L
.14286 .2758 L
.14762 .27752 L
.15238 .27923 L
.15714 .28095 L
.1619 .28267 L
.16667 .39231 L
.17143 .39339 L
.17619 .39448 L
.18095 .39556 L
.18571 .39664 L
.19048 .39773 L
.19524 .39881 L
.2 .39989 L
.20476 .40097 L
.20952 .40206 L
.21429 .40314 L
.21905 .40422 L
.22381 .40531 L
.22857 .40639 L
.23333 .40747 L
.2381 .40856 L
.24286 .40964 L
.24762 .41072 L
.25238 .4118 L
.25714 .41289 L
Mistroke
.2619 .35509 L
.26667 .35656 L
.27143 .35804 L
.27619 .35951 L
.28095 .36098 L
.28571 .36246 L
.29048 .36393 L
.29524 .36541 L
.3 .36688 L
.30476 .36836 L
.30952 .36983 L
.31429 .3713 L
.31905 .37278 L
.32381 .37425 L
.32857 .37573 L
.33333 .3772 L
.3381 .37867 L
.34286 .38015 L
.34762 .38162 L
.35238 .3831 L
.35714 .38457 L
.3619 .38605 L
.36667 .38752 L
.37143 .38899 L
.37619 .39047 L
.38095 .39194 L
.38571 .39342 L
.39048 .39489 L
.39524 .39637 L
.4 .39784 L
.40476 .39931 L
.40952 .40079 L
.41429 .40226 L
.41905 .40374 L
.42381 .40521 L
.42857 .40669 L
.43333 .40816 L
.4381 .40963 L
.44286 .41111 L
.44762 .41258 L
.45238 .41406 L
.45714 .41553 L
.4619 .41701 L
.46667 .41848 L
.47143 .41995 L
.47619 .42143 L
.48095 .4229 L
.48571 .42438 L
.49048 .42585 L
.49524 .42733 L
Mistroke
.5 .04201 L
.50476 .04733 L
.50952 .05266 L
.51429 .05798 L
.51905 .0633 L
.52381 .06863 L
.52857 .07395 L
.53333 .07927 L
.5381 .08459 L
.54286 .08992 L
.54762 .09524 L
.55238 .10056 L
.55714 .10589 L
.5619 .11121 L
.56667 .11653 L
.57143 .12185 L
.57619 .12718 L
.58095 .1325 L
.58571 .13782 L
.59048 .14315 L
.59524 .14847 L
.6 .15379 L
.60476 .15911 L
.60952 .16444 L
.61429 .16976 L
.61905 .17508 L
.62381 .18041 L
.62857 .18573 L
.63333 .19105 L
.6381 .19637 L
.64286 .2017 L
.64762 .20702 L
.65238 .21234 L
.65714 .21767 L
.6619 .22299 L
.66667 .22831 L
.67143 .23363 L
.67619 .23896 L
.68095 .24428 L
.68571 .2496 L
.69048 .25493 L
.69524 .26025 L
.7 .26557 L
.70476 .27089 L
.70952 .27622 L
.71429 .28154 L
.71905 .28686 L
.72381 .29219 L
.72857 .29751 L
.73333 .30283 L
Mistroke
.7381 .30815 L
.74286 .31348 L
.74762 .3188 L
.75238 .32412 L
.75714 .32945 L
.7619 .33477 L
.76667 .34009 L
.77143 .34541 L
.77619 .35074 L
.78095 .35606 L
.78571 .36138 L
.79048 .3667 L
.79524 .37203 L
.8 .37735 L
.80476 .38267 L
.80952 .388 L
.81429 .39332 L
.81905 .39864 L
.82381 .40396 L
.82857 .40929 L
.83333 .41461 L
.8381 .41993 L
.84286 .42525 L
.84762 .43058 L
.85238 .4359 L
.85714 .44122 L
.8619 .44654 L
.86667 .45187 L
.87143 .45719 L
.87619 .46251 L
.88095 .46783 L
.88571 .47316 L
.89048 .47848 L
.89524 .4838 L
.9 .48912 L
.90476 .49445 L
.90952 .49977 L
.91429 .50509 L
.91905 .51041 L
.92381 .51573 L
.92857 .52105 L
.93333 .52637 L
.9381 .53169 L
.94286 .53701 L
.94762 .54233 L
.95238 .54765 L
.95714 .55296 L
.9619 .55827 L
.96667 .56357 L
.97143 .56884 L
Mistroke
.97619 .57208 L
Mfstroke
.541 .169 .886 r
gsave
.97619 .58153 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.02381 .24526 m
.02857 .2626 L
.03333 .27358 L
.0381 .28254 L
.04286 .29038 L
.04762 .29749 L
.05238 .30405 L
.05714 .31021 L
.0619 .31603 L
.06667 .32157 L
.07143 .29149 L
.07619 .30873 L
.08095 .31956 L
.08571 .32837 L
.09048 .33605 L
.09524 .34299 L
.1 .3494 L
.10476 .35538 L
.10952 .36104 L
.11429 .36642 L
.11905 .27794 L
.12381 .29534 L
.12857 .30633 L
.13333 .31529 L
.1381 .32312 L
.14286 .33021 L
.14762 .33676 L
.15238 .3429 L
.15714 .3487 L
.1619 .35422 L
.16667 .40303 L
.17143 .41979 L
.17619 .43014 L
.18095 .43845 L
.18571 .44564 L
.19048 .45209 L
.19524 .45799 L
.2 .46348 L
.20476 .46863 L
.20952 .4735 L
.21429 .47814 L
.21905 .48256 L
.22381 .48681 L
.22857 .49091 L
.23333 .49485 L
.2381 .49867 L
.24286 .50237 L
.24762 .50597 L
.25238 .50946 L
.25714 .51286 L
Mistroke
.2619 .36586 L
.26667 .38297 L
.27143 .39368 L
.27619 .40236 L
.28095 .40991 L
.28571 .41672 L
.29048 .42298 L
.29524 .42882 L
.3 .43432 L
.30476 .43954 L
.30952 .44451 L
.31429 .44929 L
.31905 .45387 L
.32381 .4583 L
.32857 .46259 L
.33333 .46674 L
.3381 .47077 L
.34286 .47469 L
.34762 .47851 L
.35238 .48223 L
.35714 .48587 L
.3619 .48942 L
.36667 .4929 L
.37143 .4963 L
.37619 .49963 L
.38095 .5029 L
.38571 .5061 L
.39048 .50924 L
.39524 .51233 L
.4 .51536 L
.40476 .51833 L
.40952 .52126 L
.41429 .52414 L
.41905 .52697 L
.42381 .52975 L
.42857 .53249 L
.43333 .53518 L
.4381 .53784 L
.44286 .54045 L
.44762 .54302 L
.45238 .54556 L
.45714 .54805 L
.4619 .55051 L
.46667 .55293 L
.47143 .55532 L
.47619 .55767 L
.48095 .55999 L
.48571 .56228 L
.49048 .56453 L
.49524 .56675 L
Mistroke
.5 .05281 L
.50476 .0737 L
.50952 .08818 L
.51429 .10061 L
.51905 .11189 L
.52381 .12241 L
.52857 .13237 L
.53333 .14189 L
.5381 .15107 L
.54286 .15994 L
.54762 .16857 L
.55238 .17698 L
.55714 .18519 L
.5619 .19324 L
.56667 .20112 L
.57143 .20886 L
.57619 .21648 L
.58095 .22397 L
.58571 .23135 L
.59048 .23862 L
.59524 .2458 L
.6 .25288 L
.60476 .25987 L
.60952 .26678 L
.61429 .27361 L
.61905 .28036 L
.62381 .28704 L
.62857 .29365 L
.63333 .30019 L
.6381 .30666 L
.64286 .31307 L
.64762 .31941 L
.65238 .3257 L
.65714 .33193 L
.6619 .33809 L
.66667 .34421 L
.67143 .35026 L
.67619 .35627 L
.68095 .36222 L
.68571 .36811 L
.69048 .37396 L
.69524 .37975 L
.7 .3855 L
.70476 .39119 L
.70952 .39684 L
.71429 .40243 L
.71905 .40798 L
.72381 .41348 L
.72857 .41893 L
.73333 .42433 L
Mistroke
.7381 .42968 L
.74286 .43499 L
.74762 .44025 L
.75238 .44546 L
.75714 .45062 L
.7619 .45573 L
.76667 .4608 L
.77143 .46581 L
.77619 .47078 L
.78095 .4757 L
.78571 .48056 L
.79048 .48538 L
.79524 .49014 L
.8 .49486 L
.80476 .49952 L
.80952 .50412 L
.81429 .50867 L
.81905 .51317 L
.82381 .5176 L
.82857 .52198 L
.83333 .5263 L
.8381 .53056 L
.84286 .53475 L
.84762 .53888 L
.85238 .54294 L
.85714 .54693 L
.8619 .55084 L
.86667 .55468 L
.87143 .55844 L
.87619 .56212 L
.88095 .56571 L
.88571 .56921 L
.89048 .57262 L
.89524 .57592 L
.9 .57911 L
.90476 .58218 L
.90952 .58512 L
.91429 .58793 L
.91905 .59058 L
.92381 .59307 L
.92857 .59537 L
.93333 .59746 L
.9381 .59932 L
.94286 .60089 L
.94762 .60214 L
.95238 .60298 L
.95714 .60332 L
.9619 .60299 L
.96667 .60171 L
.97143 .59894 L
Mistroke
.97619 .58153 L
Mfstroke
gsave
.97619 .56262 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .2236 m
.02857 .20969 L
.03333 .20212 L
.0381 .19658 L
.04286 .19215 L
.04762 .18846 L
.05238 .18531 L
.05714 .18258 L
.0619 .18017 L
.06667 .17805 L
.07143 .27004 L
.07619 .25591 L
.08095 .24819 L
.08571 .24249 L
.09048 .23792 L
.09524 .23409 L
.1 .23079 L
.10476 .22791 L
.10952 .22537 L
.11429 .2231 L
.11905 .2565 L
.12381 .24253 L
.12857 .23498 L
.13333 .22945 L
.1381 .22505 L
.14286 .22139 L
.14762 .21827 L
.15238 .21557 L
.15714 .2132 L
.1619 .21111 L
.16667 .38159 L
.17143 .367 L
.17619 .35881 L
.18095 .35267 L
.18571 .34764 L
.19048 .34336 L
.19524 .33962 L
.2 .3363 L
.20476 .33332 L
.20952 .33061 L
.21429 .32815 L
.21905 .32588 L
.22381 .3238 L
.22857 .32187 L
.23333 .32009 L
.2381 .31844 L
.24286 .3169 L
.24762 .31548 L
.25238 .31415 L
.25714 .31291 L
Mistroke
.2619 .34432 L
.26667 .33016 L
.27143 .32239 L
.27619 .31666 L
.28095 .31205 L
.28571 .3082 L
.29048 .30489 L
.29524 .302 L
.3 .29944 L
.30476 .29717 L
.30952 .29514 L
.31429 .29332 L
.31905 .29168 L
.32381 .2902 L
.32857 .28887 L
.33333 .28766 L
.3381 .28658 L
.34286 .28561 L
.34762 .28474 L
.35238 .28396 L
.35714 .28328 L
.3619 .28267 L
.36667 .28214 L
.37143 .28169 L
.37619 .28131 L
.38095 .28099 L
.38571 .28074 L
.39048 .28054 L
.39524 .28041 L
.4 .28032 L
.40476 .2803 L
.40952 .28032 L
.41429 .28039 L
.41905 .28051 L
.42381 .28067 L
.42857 .28088 L
.43333 .28114 L
.4381 .28143 L
.44286 .28177 L
.44762 .28214 L
.45238 .28256 L
.45714 .28301 L
.4619 .2835 L
.46667 .28403 L
.47143 .28459 L
.47619 .28518 L
.48095 .28581 L
.48571 .28648 L
.49048 .28717 L
.49524 .2879 L
Mistroke
.5 .03121 L
.50476 .02097 L
.50952 .01713 L
.51429 .01535 L
.51905 .01472 L
.52381 .01484 L
.52857 .01553 L
.53333 .01665 L
.5381 .01812 L
.54286 .01989 L
.54762 .02191 L
.55238 .02415 L
.55714 .02658 L
.5619 .02918 L
.56667 .03194 L
.57143 .03484 L
.57619 .03788 L
.58095 .04103 L
.58571 .0443 L
.59048 .04767 L
.59524 .05114 L
.6 .0547 L
.60476 .05836 L
.60952 .06209 L
.61429 .06591 L
.61905 .0698 L
.62381 .07377 L
.62857 .07781 L
.63333 .08192 L
.6381 .08609 L
.64286 .09033 L
.64762 .09463 L
.65238 .09899 L
.65714 .10341 L
.6619 .10788 L
.66667 .11242 L
.67143 .117 L
.67619 .12165 L
.68095 .12634 L
.68571 .13109 L
.69048 .13589 L
.69524 .14074 L
.7 .14565 L
.70476 .1506 L
.70952 .1556 L
.71429 .16065 L
.71905 .16575 L
.72381 .17089 L
.72857 .17609 L
.73333 .18133 L
Mistroke
.7381 .18663 L
.74286 .19196 L
.74762 .19735 L
.75238 .20279 L
.75714 .20827 L
.7619 .2138 L
.76667 .21938 L
.77143 .22501 L
.77619 .23069 L
.78095 .23642 L
.78571 .2422 L
.79048 .24803 L
.79524 .25391 L
.8 .25984 L
.80476 .26583 L
.80952 .27187 L
.81429 .27796 L
.81905 .28412 L
.82381 .29032 L
.82857 .29659 L
.83333 .30292 L
.8381 .30931 L
.84286 .31576 L
.84762 .32228 L
.85238 .32886 L
.85714 .33552 L
.8619 .34225 L
.86667 .34905 L
.87143 .35593 L
.87619 .3629 L
.88095 .36995 L
.88571 .3771 L
.89048 .38434 L
.89524 .39169 L
.9 .39914 L
.90476 .40671 L
.90952 .41441 L
.91429 .42225 L
.91905 .43024 L
.92381 .43839 L
.92857 .44674 L
.93333 .45528 L
.9381 .46407 L
.94286 .47314 L
.94762 .48253 L
.95238 .49232 L
.95714 .50261 L
.9619 .51355 L
.96667 .52543 L
.97143 .53874 L
Mistroke
.97619 .56262 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00:03oool2000002D0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000007P3oool2
000000@0oooo00<000000?ooo`3oool00`3oool3000001h0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000O0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000903oool3
000000h0oooo000W0?ooo`040000003oool0oooo000002<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000M0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000007@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000903oool00`000000oooo
0?ooo`0=0?ooo`009`3oool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool07@3oool010000000oooo0?ooo`0000070?ooo`D000007@3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000007@3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000903oool00`000000oooo0?ooo`0=0?ooo`00
9`3oool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0703oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000001h0oooo00@0
00000?ooo`3oool000001`3oool4000001h0oooo00@000000?ooo`3oool00000203oool3000002D0
oooo00<000000?ooo`3oool03@3oool002L0oooo00@000000?ooo`3oool000008`3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000007@3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0000001h0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0O0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000T0?oo
o`030000003oool0oooo00d0oooo000W0?ooo`040000003oool0oooo000002<0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000001d0oooo00@000000?ooo`3oool00000
2@3oool2000001h0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0N0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`8000003`3oool0
02P0oooo0P00000U0?ooo`8000002@3oool3000001l0oooo0P00000;0?ooo`030000003oool0oooo
01d0oooo0P00000:0?ooo`8000007`3oool2000000T0oooo0`00000U0?ooo`030000003oool0oooo
00d0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo000S0?oo
ond000002@3oool002<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`00
8`3oool200000>T0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`1f0?ooo`D0RR_RKP3o
ool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1e0?ooo`0308X[hP3oool0
oooo00<0oooo0`2::n9[0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo
07@0oooo00<0RR_R0?ooo`3oool01`3oool308X[hVP0oooo00<000000?ooo`3oool01`3oool002<0
oooo0P00001e0?ooo`0308X[hP3oool0oooo00X0oooo0P2::n9U0?ooo`8000002@3oool002<0oooo
00<000000?ooo`3oool0K`3oool01@000?l0oooo0?ooo`3oool0RR_R00l0oooo00<0RR_R0?ooo`3o
ool0H`3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1_0?ooo`050000
o`3oool0oooo0?ooo`2::n80403oool00`2::n80oooo0?ooo`1R0?ooo`030000003oool0oooo00L0
oooo000S0?ooo`030000003oool0oooo06l0oooo0P000?l20?ooo`0308X[hP3oool0oooo00l0oooo
0P2::n9R0?ooo`030000003oool0oooo00L0oooo000S0?ooo`800000K`3oool01P000?l0oooo0000
o`3oool0003o08X[hQ<0oooo0P2::n9O0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0
KP3oool00`000?l0oooo0?ooo`020000o`0308X[hP00nYX0oooo01<0oooo00<0RR_R0?ooo`3oool0
G@3oool00`000000oooo0?ooo`070?ooo`00403oool2000000@0oooo00<000000?ooo`3oool00P3o
ool3000000D0oooo00<000000?ooo`3oool0KP3oool01`000?l0oooo0?ooo`000?l0oooo08X[hP3o
ool00P00nYXC0?ooo`80RR_RG@3oool00`000000oooo0?ooo`070?ooo`003`3oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1^0?oo
o`030000o`3oool0oooo0080oooo00D0RR_R0000o`3oool0oooo003jVP0D0?ooo`0308X[hP3oool0
oooo05X0oooo00<000000?ooo`3oool01`3oool000l0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`020?ooo`<00000K@3oool00`000?l0oooo0?ooo`030?ooo`0508X[hP000?l0
oooo0?ooo`00nYX05@3oool00`2::n80oooo0?ooo`1H0?ooo`8000002@3oool000l0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`80RR_R0`3oool00`00nYX0oooo0?oo
o`0C0?ooo`0308X[hP3oool0oooo05P0oooo00<000000?ooo`3oool01`3oool000l0oooo00@00000
0?ooo`3oool000001`3oool4000000D0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00<0oooo0P2::n830000o`030?ooo`00nYX0oooo01@0oooo00<0
RR_R0?ooo`3oool0E`3oool00`000000oooo0?ooo`070?ooo`003`3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0000
o`0=0?ooo`030000o`3oool0oooo00<0oooo0P2::n820?ooo`040000o`3oool0oooo003jVQD0oooo
0P2::n9G0?ooo`030000003oool0oooo00L0oooo000@0?ooo`800000203oool5000000@0oooo00<0
00000?ooo`3oool0G03oool010000?l0oooo0?ooo`000?l=0?ooo`030000o`3oool0oooo00<0oooo
0P2::n830?ooo`040000o`3oool0oooo003jVQH0oooo00<0RR_R0?ooo`3oool0E03oool00`000000
oooo0?ooo`070?ooo`008`3oool2000005d0oooo00@0003o0?ooo`3oool0003o303oool00`000?l0
oooo0?ooo`040?ooo`0308X[hP3oool0RR_R0080oooo00@0003o0?ooo`3oool00?ZJ5`3oool00`2:
:n80oooo0?ooo`1B0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0G03oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`000?l02@3oool00`000?l0oooo0?ooo`040?ooo`0308X[hP3oool0
RR_R0080oooo00D0003o0?ooo`3oool0oooo003jVP0G0?ooo`0308X[hP3oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`03
0?ooo`80003o2@3oool00`000?l0oooo0?ooo`040?ooo`0308X[hP3oool0RR_R0080oooo00<0003o
0?ooo`3oool00P3oool00`00nYX0oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo0540oooo00<00000
0?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`040?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`040?ooo`0608X[hP3oool0
oooo08X[hP3oool0003o1@3oool2003jVQH0oooo00<0RR_R0?ooo`3oool0D03oool00`000000oooo
0?ooo`070?ooo`008`3oool2000005`0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?oo
o`3oool0003o00D0oooo00<0003o0?ooo`3oool0103oool01`2::n80oooo0?ooo`3oool0RR_R0?oo
o`000?l01P3oool00`00nYX0oooo0?ooo`0D0?ooo`0308X[hP3oool0oooo04h0oooo0P0000090?oo
o`008`3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oool0003o00L0oooo00@0003o0?ooo`3o
ool0003o1@3oool00`000?l0oooo0?ooo`040?ooo`0708X[hP3oool0oooo0?ooo`2::n80oooo0000
o`060?ooo`03003jVP3oool0oooo01D0oooo00<0RR_R0?ooo`3oool0CP3oool00`000000oooo0?oo
o`070?ooo`008`3oool00`000000oooo0?ooo`1H0?ooo`<0003o203oool010000?l0oooo0?ooo`00
0?l40?ooo`030000o`3oool0oooo00D0oooo00<0RR_R0?ooo`3oool00P3oool00`2::n80003o0?oo
o`060?ooo`03003jVP3oool0oooo01D0oooo00<0RR_R0?ooo`3oool0C@3oool00`000000oooo0?oo
o`070?ooo`008`3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0003o00P0oooo00@0003o
0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`050?ooo`0308X[hP3oool0oooo0080oooo00<0
RR_R0000o`3oool01`3oool00`00nYX0oooo0?ooo`0E0?ooo`80RR_RC@3oool00`000000oooo0?oo
o`070?ooo`008`3oool2000005T0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?ooo`00
0?l40?ooo`030000o`3oool0oooo00D0oooo00<0RR_R0?ooo`3oool00P3oool00`2::n80003o0?oo
o`080?ooo`03003jVP3oool0oooo01H0oooo00<0RR_R0?ooo`3oool0B@3oool2000000T0oooo000S
0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`02
0000o`<0oooo00<0003o0?ooo`3oool01@3oool00`2::n80oooo0?ooo`030?ooo`0308X[hP3oool0
oooo00P0oooo00<00?ZJ0?ooo`3oool05P3oool00`2::n80oooo0?ooo`190?ooo`030000003oool0
oooo00L0oooo000S0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool02@3oool20000
o`040?ooo`000?l0oooo0?ooo`80003o1`3oool00`2::n80oooo0?ooo`030?ooo`0308X[hP3oool0
oooo00P0oooo00<00?ZJ0?ooo`3oool05`3oool00`2::n80oooo0?ooo`180?ooo`030000003oool0
oooo00L0oooo000S0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool02@3oool20000
o`040?ooo`000?l0oooo0000o`T0oooo00<0RR_R0?ooo`3oool00`3oool00`000?l0RR_R0?ooo`09
0?ooo`03003jVP3oool0oooo01H0oooo00<0RR_R0?ooo`3oool0B03oool00`000000oooo0?ooo`07
0?ooo`008`3oool2000005P0oooo00<0003o0?ooo`3oool02P3oool20000o`030?ooo`000?l0003o
00X0oooo00<0RR_R0?ooo`3oool00`3oool00`000?l0RR_R0?ooo`0:0?ooo`03003jVP3oool0oooo
01H0oooo00<0RR_R0?ooo`3oool0AP3oool2000000T0oooo000:0?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo05L0
oooo00<0003o0?ooo`3oool02P3oool20000o`030?ooo`000?l0oooo00X0oooo00<0RR_R0?ooo`3o
ool00`3oool00`000?l0RR_R0?ooo`0;0?ooo`800?ZJ5`3oool00`2::n80oooo0?ooo`160?ooo`03
0000003oool0oooo00L0oooo00090?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E`3oool00`00
0?l0oooo0?ooo`0:0?ooo`80003o3@3oool00`2::n80oooo0?ooo`030?ooo`030000o`3oool0RR_R
00d0oooo00<00?ZJ0?ooo`3oool05@3oool00`2::n80oooo0?ooo`150?ooo`030000003oool0oooo
00L0oooo00090?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0;0?ooo`0308X[hP3oool0oooo00@0oooo00@0003o08X[hP3oool0003o2`3oool0
0`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3oool0oooo04@0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo0`00001G0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0
0`2::n80oooo0?ooo`040?ooo`040000o`3oool0RR_R0000o``0oooo00<00?ZJ0?ooo`3oool05P3o
ool208X[hT<0oooo0P0000090?ooo`002@3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0000000<000001@3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo01T0oooo00<0
RR_R0?ooo`3oool0103oool20000o`0308X[hP000?l0oooo00`0oooo00<00?ZJ0?ooo`3oool05`3o
ool00`2::n80oooo0?ooo`110?ooo`030000003oool0oooo00L0oooo00090?ooo`040000003oool0
oooo000000L0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool0EP3oool00`000?l0oooo0?ooo`0J0?ooo`0308X[hP3oool0oooo00@0oooo0P000?l00`3oool0
RR_R0000o`0=0?ooo`03003jVP3oool0oooo01H0oooo00<0RR_R0?ooo`3oool0@@3oool00`000000
oooo0?ooo`070?ooo`002P3oool2000000P0oooo1@0000000`3oool0000000000003000000@0oooo
00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0J0?ooo`80RR_R1P3oool30000o`0308X[
hP000?l0oooo00d0oooo00<00?ZJ0?ooo`3oool05P3oool00`2::n80oooo0?ooo`100?ooo`030000
003oool0oooo00L0oooo000S0?ooo`800000EP3oool00`000?l0oooo0?ooo`0J0?ooo`80RR_R1P3o
ool01@000?l0oooo0000o`3oool0RR_R00h0oooo00<00?ZJ0?ooo`3oool05`3oool00`2::n80oooo
0?ooo`0n0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?oo
o`0J0?ooo`80RR_R203oool010000?l0oooo0000o`2::n8>0?ooo`03003jVP3oool0oooo00D0oooo
00<0003o0?ooo`3oool03`3oool00`2::n80oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo
000S0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool06P3oool208X[hPX0oooo00<0
003o0?ooo`2::n803P3oool00`00nYX0oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo00<0
RR_R0?ooo`3oool0?@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0<
0?ooo`80RR_RA`3oool00`000?l0oooo0?ooo`0J0?ooo`80RR_R2`3oool00`000?l0RR_R0?ooo`0>
0?ooo`800?ZJ0`3oool20000oa<0oooo00<0RR_R0?ooo`3oool0?03oool00`000000oooo0?ooo`07
0?ooo`008`3oool2000000X0oooo0`2::n800`3oool0RR_R0?ooo`150?ooo`030000o`3oool0oooo
01/0oooo0P2::n8;0?ooo`030000o`3oool0RR_R0100oooo00<00?ZJ0?ooo`3oool00P000?lC0?oo
o`0308X[hP3oool0oooo03/0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`080?ooo`03
08X[hP3oool0oooo0080oooo00<0RR_R0?ooo`3oool0A03oool00`000?l0oooo0?ooo`0K0?ooo`80
RR_R2`3oool00`000?l0oooo08X[hP0@0?ooo`06003jVP3oool0oooo0000o`3oool0003o4`3oool0
0`2::n80oooo0?ooo`0k0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo
00L0oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`140?ooo`030000o`3oool0oooo
01/0oooo0P2::n8<0?ooo`030000o`3oool0RR_R0100oooo00D00?ZJ0?ooo`000?l0oooo0000o`0D
0?ooo`80RR_R>`3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`060?oo
o`0308X[hP3oool0oooo00@0oooo00<0RR_R0?ooo`3oool0A03oool00`000?l0oooo0?ooo`0K0?oo
o`80RR_R303oool00`000?l0oooo08X[hP0A0?ooo`04003jVP000?l0oooo0000oaH0oooo00<0RR_R
0?ooo`3oool0>03oool00`000000oooo0?ooo`070?ooo`008`3oool2000000H0oooo00<0RR_R0?oo
o`3oool01@3oool00`2::n80oooo0?ooo`110?ooo`<0003o7P3oool208X[hP`0oooo00@0003o0?oo
o`3oool0RR_R4@3oool00`00nYX0oooo0000o`0G0?ooo`0308X[hP3oool0oooo03H0oooo0P000009
0?ooo`008`3oool00`000000oooo0?ooo`050?ooo`0308X[hP3oool0oooo00D0oooo00<0RR_R0?oo
o`3oool0?03oool20000o`80oooo00<0003o0?ooo`3oool07`3oool208X[hP`0oooo00@0003o0?oo
o`3oool0RR_R403oool010000?l0oooo003jVP000?lG0?ooo`0308X[hP3oool0oooo03L0oooo00<0
00000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0103oool00`2::n80oooo0?ooo`06
0?ooo`0308X[hP3oool0oooo01<0oooo00<0RR_R0?ooo`3oool09P3oool01@000?l0oooo0000o`3o
ool0003o0240oooo0P2::n8=0?ooo`040000o`3oool0oooo08X[hPl0oooo00@0003o0?ooo`00nYX0
003o603oool00`2::n80oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000
003oool0oooo00@0oooo00<0RR_R0?ooo`3oool01P3oool00`2::n80oooo0?ooo`0A0?ooo`<0RR_R
:03oool01@000?l0oooo0000o`3oool0003o0240oooo0P2::n8=0?ooo`80003o00<0oooo08X[hP3o
ool03P3oool01@000?l0oooo0?ooo`00nYX0003o01P0oooo00<0RR_R0?ooo`3oool0=@3oool00`00
0000oooo0?ooo`070?ooo`008`3oool2000000@0oooo00<0RR_R0?ooo`3oool01`3oool00`2::n80
oooo0?ooo`0@0?ooo`0408X[hP3oool0oooo08X[hRL0oooo00D0003o0?ooo`3oool0oooo0000o`0R
0?ooo`80RR_R3P3oool010000?l0oooo0?ooo`2::n8>0?ooo`050000o`3oool0oooo0?ooo`00nYX0
6@3oool00`2::n80oooo0?ooo`0c0?ooo`8000002@3oool001/0oooo0`0000050?ooo`030000003o
ool0oooo00<0oooo00<0RR_R0?ooo`3oool01`3oool00`2::n80oooo0?ooo`080?ooo`0308X[hP3o
ool0oooo00@0oooo00D0RR_R0?ooo`3oool0oooo08X[hP0W0?ooo`050000o`3oool0oooo0?ooo`00
0?l08P3oool208X[hPh0oooo00D0003o0?ooo`3oool0oooo08X[hP0=0?ooo`060000o`3oool0oooo
0?ooo`000?l00?ZJ603oool00`2::n80oooo0?ooo`0d0?ooo`030000003oool0oooo00L0oooo000L
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`2::n80oooo0?ooo`05
0?ooo`<0RR_R1@3oool00`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0oooo02D0oooo00<0003o
0?ooo`3oool0903oool208X[hPh0oooo00D0003o0?ooo`000?l0oooo08X[hP0;0?ooo`030000o`3o
ool0003o00<0oooo00<0003o0?ooo`00nYX0603oool00`2::n80oooo0?ooo`0c0?ooo`030000003o
ool0oooo00L0oooo000L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool0
0`2::n80oooo0?ooo`040?ooo`0408X[hP3oool0oooo08X[hP<0oooo0P2::n850?ooo`0308X[hP3o
ool0oooo02D0oooo00<0003o0?ooo`3oool0903oool208X[hPh0oooo00<0003o0?ooo`000?l00P3o
ool01@2::n80oooo0?ooo`3oool0003o00H0oooo0P000?l40?ooo`040000o`3oool0oooo003jVQP0
oooo00<0RR_R0?ooo`3oool0<P3oool00`000000oooo0?ooo`070?ooo`00703oool00`000000oooo
0?ooo`040?ooo`<000000`3oool2003jVPT0oooo00<0RR_R0?ooo`3oool00P3oool208X[hP<0oooo
00@0RR_R0?ooo`3oool0RR_R1`3oool00`2::n80oooo0?ooo`0U0?ooo`030000o`3oool0oooo02@0
oooo0P2::n8>0?ooo`030000o`3oool0003o00<0oooo00@0RR_R0?ooo`3oool0003o1P3oool20000
o`D0oooo00@0003o0?ooo`3oool00?ZJ603oool00`2::n80oooo0?ooo`0`0?ooo`8000002@3oool0
01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`040000o`3oool00?ZJ
003jVPL0oooo00D0RR_R0?ooo`3oool0oooo08X[hP050?ooo`0408X[hP3oool0oooo08X[hPL0oooo
00<0RR_R0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0T0?ooo`80RR_R3`3oool20000o`@0oooo
00@0RR_R0?ooo`000?l0003o1@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?oo
o`00nYX0603oool00`2::n80oooo0?ooo`0`0?ooo`030000003oool0oooo00L0oooo000K0?ooo`80
00001P3oool00`000000oooo0?ooo`030?ooo`040000o`3oool0oooo0?ooo`@00?ZJ0`3oool0102:
:n80oooo0?ooo`2::n830?ooo`040000o`3oool0oooo0?ooo`80RR_R203oool00`2::n80oooo0?oo
o`0U0?ooo`030000o`3oool0oooo02@0oooo0P2::n8?0?ooo`<0003o00D0oooo0000o`000?l0RR_R
0?ooo`020000o`@0oooo00<0003o0?ooo`3oool01@3oool01P000?l0oooo0?ooo`000?l0oooo003j
VQP0oooo00<0RR_R0?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`00703oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0RR_R0?ooo`3oool01@3oool2003jVP04
0?ooo`2::n80oooo08X[hP@0oooo00@0003o0?ooo`3oool0oooo0P2::n880?ooo`0308X[hP3oool0
oooo02D0oooo00<0003o0?ooo`3oool0903oool208X[hPl0oooo00P0003o0?ooo`000?l0oooo0000
o`3oool0003o08X[hP80003o103oool00`000?l0oooo0?ooo`050?ooo`060000o`3oool0oooo0000
o`3oool00?ZJ6@3oool00`2::n80oooo0?ooo`0^0?ooo`030000003oool0oooo00L0oooo000S0?oo
o`800000103oool00`2::n80oooo0?ooo`070?ooo`04003jVP2::n80oooo08X[hP@0oooo0`000?l0
0`3oool0RR_R0?ooo`080?ooo`0308X[hP3oool0oooo02@0oooo00<0003o0?ooo`3oool09@3oool2
08X[hPl0oooo00H0003o0?ooo`000?l0oooo0000o`3oool20000o`0408X[hP000?l0oooo0000o`80
oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0000o`000?l20?ooo`03003jVP3oool0oooo
01H0oooo00<0RR_R0?ooo`3oool0;@3oool2000000T0oooo000S0?ooo`030000003oool0oooo00<0
oooo00<0RR_R0?ooo`3oool01`3oool00`00nYX0RR_R08X[hP040?ooo`060000o`3oool0003o0000
o`3oool0RR_R2@3oool00`2::n80oooo0?ooo`0T0?ooo`030000o`3oool0oooo02D0oooo0P2::n8?
0?ooo`060000o`3oool0003o0?ooo`000?l0oooo0P000?l0102::n80003o0?ooo`000?l20?ooo`03
0000o`3oool0oooo00D0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`03003jVP3oool0oooo
01H0oooo00<0RR_R0?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000
oooo0?ooo`040?ooo`0308X[hP3oool0oooo00H0oooo00<00?ZJ08X[hP2::n80103oool01@000?l0
oooo0?ooo`3oool0003o00X0oooo00<0RR_R0?ooo`3oool0903oool00`000?l0oooo0?ooo`0U0?oo
o`80RR_R3`3oool010000?l0oooo0000o`000?l30?ooo`040000o`3oool0RR_R0?ooo`80003o00<0
oooo0000o`3oool01`3oool20000o`030?ooo`000?l0oooo0080oooo00<00?ZJ0?ooo`3oool05P3o
ool00`2::n80oooo0?ooo`0/0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0
oooo00@0oooo00<0RR_R0?ooo`3oool01P3oool00`00nYX0RR_R0?ooo`040?ooo`050000o`3oool0
oooo0?ooo`000?l02P3oool00`2::n80oooo0?ooo`0T0?ooo`030000o`3oool0oooo02D0oooo0P2:
:n8B0?ooo`080000o`3oool0oooo0?ooo`000?l0oooo08X[hP3oool20000o`030?ooo`000?l0oooo
00L0oooo00@0003o0?ooo`3oool0003o103oool00`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3oool0
oooo02/0oooo00<000000?ooo`3oool01`3oool002<0oooo0P0000050?ooo`0308X[hP3oool0oooo
00@0oooo00@0003o0?ooo`000?l0RR_R0P3oool00`000?l0oooo0000o`050?ooo`@00?ZJ00<0003o
0?ooo`3oool00`3oool00`2::n80oooo0?ooo`0T0?ooo`030000o`3oool0oooo02D0oooo0P2::n8B
0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool01@2::n80003o0000o`3oool0003o00P0oooo
00@0003o0?ooo`3oool0003o103oool00`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3oool0oooo02X0
oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`040?ooo`060000o`2::n80oooo0?ooo`00
0?l0oooo0P000?l00`3oool0003o003jVP020?ooo`030000o`3oool0003o00D0oooo00@00?ZJ0?oo
o`000?l0oooo0P00nYX40?ooo`0308X[hP3oool0oooo02@0oooo00<0003o0?ooo`3oool09@3oool2
08X[hQ80oooo00<0003o0?ooo`3oool0103oool010000?l0RR_R0?ooo`000?l=0?ooo`030000o`3o
ool0oooo0080oooo0P00nYXG0?ooo`0308X[hP3oool0oooo02X0oooo00<000000?ooo`3oool01`3o
ool002<0oooo00<000000?ooo`3oool0103oool03`000?l0RR_R0?ooo`000?l0oooo0000o`3oool0
003o0?ooo`000?l00?ZJ0?ooo`000?l0oooo0000o`060?ooo`0608X[hP3oool0003o0?ooo`000?l0
oooo0P00nYX20?ooo`0308X[hP3oool0oooo02@0oooo00<0003o0?ooo`3oool09@3oool208X[hQT0
oooo00@0003o08X[hP3oool0003o3P3oool00`000?l0oooo0?ooo`030?ooo`03003jVP3oool0oooo
01D0oooo00<0RR_R0?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000
oooo0?ooo`040?ooo`030000o`3oool0RR_R00D0oooo00D0003o0?ooo`00nYX00?ZJ0000o`080?oo
o`0308X[hP3oool0003o0080oooo00<0003o0?ooo`000?l00P00nYX00`2::n80oooo0?ooo`0T0?oo
o`030000o`3oool0oooo00@0oooo6@2::n880?ooo`80RR_R6@3oool010000?l0oooo08X[hP000?l>
0?ooo`030000o`3oool0oooo00@0oooo00<00?ZJ0?ooo`3oool0503oool00`2::n80oooo0?ooo`0Y
0?ooo`030000003oool0oooo00L0oooo000S0?ooo`8000001@3oool00`000?l0oooo08X[hP050?oo
o`040000o`3oool0oooo0?ooo`@00?ZJ103oool01000nYX0RR_R0?ooo`000?l20?ooo`<0003o0P3o
ool00`2::n80oooo0?ooo`0T0?ooo`030000o`3oool0oooo00@0RR_R6@3oool:08X[hQT0oooo00@0
003o0?ooo`3oool0RR_R3P3oool00`000?l0oooo0?ooo`050?ooo`03003jVP3oool0oooo01@0oooo
0P2::n8X0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0103oool010000?l0oooo0000
o`2::n840?ooo`030000o`3oool0RR_R00D0oooo0`00nYX0103oool00?ZJ08X[hP2::n830?ooo`<0
003o0P3oool00`2::n80oooo0?ooo`0P0?ooo`030000o`3oool0RR_R00@0RR_R9@3oool208X[hQT0
oooo00D0003o0?ooo`3oool0oooo08X[hP0=0?ooo`030000o`3oool0oooo00D0oooo00<00?ZJ0?oo
o`3oool05P3oool00`2::n80oooo0?ooo`0V0?ooo`030000003oool0oooo00L0oooo000S0?ooo`03
0000003oool0oooo00D0oooo0P000?l00`2::n80oooo0?ooo`040?ooo`0308X[hP3oool0oooo00H0
oooo0P00nYX208X[hPH0oooo00<0003o0?ooo`2::n805@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P2::n800`3oool0003o0?ooo`0W0?ooo`03
003jVP2::n80oooo01d0oooo00<0RR_R0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03
003jVP3oool0oooo01D0oooo00<0RR_R0?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`00
8`3oool00`000000oooo0?ooo`050?ooo`040000o`3oool0oooo08X[hPD0oooo00<0RR_R0?ooo`3o
ool0203oool208X[hPH0oooo00@0003o0?ooo`00nYX0RR_R503oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00@0003o08X[hP2::n80003o0P3oool00`000?l0oooo0?ooo`0V
0?ooo`03003jVP2::n80oooo01h0oooo00<0RR_R0?ooo`3oool02@3oool00`000?l0oooo0?ooo`07
0?ooo`03003jVP3oool0oooo01D0oooo00<0RR_R0?ooo`3oool09@3oool00`000000oooo0?ooo`07
0?ooo`008`3oool2000000H0oooo00D0003o0?ooo`3oool0oooo08X[hP040?ooo`80RR_R2@3oool0
0`2::n80003o08X[hP050?ooo`040000o`3oool00?ZJ08X[hQ@0oooo00<0003o0?ooo`3oool00P3o
ool030000?l0oooo0?ooo`000?l0oooo08X[hP3oool0003o0?ooo`000?l0oooo0000obP0oooo00<0
0?ZJ08X[hP3oool07P3oool00`2::n80oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo00<0
0?ZJ0?ooo`3oool05@3oool00`2::n80oooo0?ooo`0S0?ooo`8000002@3oool002<0oooo00<00000
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`0408X[hP3oool0oooo0?ooo`80RR_R2@3o
ool00`2::n80oooo08X[hP050?ooo`040000o`3oool00?ZJ08X[hQ@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo08X[hP0208X[hP040000o`3oool0003o0?ooo`80003o:@3oool00`00nYX0
RR_R0?ooo`0O0?ooo`0308X[hP3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`00nYX0
oooo0?ooo`0D0?ooo`0308X[hP3oool0oooo02@0oooo00<000000?ooo`3oool01`3oool000T0oooo
0`0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3o
ool02`3oool01@2::n80oooo08X[hP3oool0RR_R00T0oooo00@0RR_R0?ooo`3oool0RR_R103oool0
10000?l0oooo003jVP2::n8D0?ooo`040000o`2::n80oooo0?ooo`80003o00<0RR_R0000o`3oool0
0P000?l01@3oool0003o0?ooo`3oool0003o02T0oooo00<0RR_R0?ooo`3oool07`3oool00`2::n80
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<00?ZJ0?ooo`3oool05@3oool00`2::n80
oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo00P0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool208X[hP80oooo00<0RR_R0?ooo`3oool01P3oool01@2::n80oooo0?ooo`3oool0
RR_R00<0oooo00@0003o0?ooo`00nYX0RR_R4@3oool508X[hP80oooo00@0003o08X[hP000?l0003o
0`3oool20000ob`0oooo00<0RR_R0?ooo`3oool0803oool00`2::n80oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo0P00nYXF0?ooo`0308X[hP3oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo0`00000<0?ooo`80RR_R0P3oool00`2::n80oooo0?ooo`060?ooo`0508X[hP3o
ool0oooo0?ooo`2::n800`3oool010000?l0oooo003jVP2::n8?0?ooo`80RR_R0P3oool010000?l0
oooo08X[hP3oool20000o`0308X[hP000?l0003o00<0oooo0P000?l/0?ooo`0308X[hP3oool0oooo
0240oooo00<0RR_R0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`03003jVP3oool0oooo
01<0oooo00<0RR_R0?ooo`3oool08@3oool2000000T0oooo000:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00@0RR_R0?ooo`3oool0RR_R1`3oool00`2::n80oooo0?ooo`030?ooo`0708X[hP3oool0oooo
0000o`3oool00?ZJ08X[hP0=0?ooo`80RR_R103oool020000?l0oooo08X[hP3oool0003o08X[hP3o
ool0003o103oool00`000?l0oooo0?ooo`0[0?ooo`0308X[hP3oool0oooo0240oooo00<0RR_R0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0<0?ooo`03003jVP3oool0oooo01<0oooo00<0RR_R0?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`070?ooo`06
0000003oool0oooo0?ooo`000000oooo100000050?ooo`030000003oool0oooo0140oooo00<0RR_R
0?ooo`3oool0103oool00`2::n80oooo0?ooo`030?ooo`0708X[hP3oool0oooo0?ooo`000?l00?ZJ
08X[hP0;0?ooo`80RR_R1P3oool020000?l0oooo08X[hP3oool0003o08X[hP3oool0003o103oool0
0`000?l0oooo0?ooo`0[0?ooo`0308X[hP3oool0oooo0280oooo00<0RR_R0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0=0?ooo`03003jVP3oool0oooo01<0oooo00<0RR_R0?ooo`3oool0803oool0
0`000000oooo0?ooo`070?ooo`002@3oool2000000T0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool04@3oool00`2::n80oooo0?ooo`040?ooo`0308X[hP3o
ool0oooo00@0oooo00H0RR_R0?ooo`3oool0003o003jVP2::n880?ooo`<0RR_R203oool00`000?l0
oooo0000o`0208X[hSD0oooo00<0RR_R0?ooo`3oool08`3oool00`2::n80oooo0?ooo`050?ooo`03
0000o`3oool0oooo00d0oooo00<00?ZJ0?ooo`3oool04`3oool00`2::n80oooo0?ooo`0P0?ooo`03
0000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`D00000
103oool2000001<0oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`050?ooo`0508X[
hP3oool0003o003jVP2::n801`3oool00`2::n80oooo0?ooo`090?ooo`030000o`3oool0003o0080
RR_R=@3oool00`2::n80oooo0?ooo`0T0?ooo`0308X[hP3oool0oooo00D0oooo00<0003o0?ooo`3o
ool03@3oool00`00nYX0oooo0?ooo`0C0?ooo`80RR_R7`3oool2000000T0oooo000S0?ooo`030000
003oool0oooo01<0oooo00<0RR_R0?ooo`3oool00P3oool00`2::n80oooo0?ooo`050?ooo`0508X[
hP3oool0003o0?ooo`2::n801P3oool00`2::n80oooo0?ooo`0:0?ooo`040000o`3oool0oooo08X[
hSH0oooo00<0RR_R0?ooo`3oool0903oool00`2::n80oooo0?ooo`050?ooo`030000o`3oool0oooo
00h0oooo00<00?ZJ0?ooo`3oool0503oool00`2::n80oooo0?ooo`0M0?ooo`030000003oool0oooo
00L0oooo000S0?ooo`030000003oool0oooo01@0oooo00D0RR_R0?ooo`3oool0oooo08X[hP080?oo
o`0408X[hP000?l0oooo08X[hPD0oooo00<0RR_R0?ooo`3oool02P3oool01@000?l0oooo0?ooo`3o
ool0RR_R03H0oooo00<0RR_R0?ooo`3oool09@3oool208X[hPD0oooo00<0003o0?ooo`3oool03`3o
ool00`00nYX0oooo0?ooo`0C0?ooo`0308X[hP3oool0oooo01d0oooo00<000000?ooo`3oool01`3o
ool002<0oooo00<000000?ooo`3oool05@3oool0102::n80oooo0?ooo`2::n890?ooo`0308X[hP3o
ool0RR_R00@0oooo00<0RR_R0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o03H0oooo
00<0RR_R0?ooo`3oool09`3oool00`2::n80oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo
00<00?ZJ0?ooo`3oool04`3oool00`2::n80oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo
000S0?ooo`8000005P3oool0102::n80oooo0?ooo`2::n890?ooo`030000o`2::n80RR_R00<0oooo
00<0RR_R0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool00?ZJ03H0oooo00<0RR_R0?ooo`3o
ool09`3oool00`2::n80oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo00<00?ZJ0?ooo`3o
ool04`3oool00`2::n80oooo0?ooo`0K0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0
5P3oool00`2::n80oooo08X[hP090?ooo`030000o`2::n80RR_R0080oooo00<0RR_R0?ooo`3oool0
303oool00`000?l0oooo0?ooo`020?ooo`@00?ZJ<`3oool00`2::n80oooo0?ooo`0X0?ooo`0508X[
hP3oool0oooo0?ooo`000?l04`3oool2003jVQ@0oooo00<0RR_R0?ooo`3oool06`3oool00`000000
oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0G0?ooo`80RR_R2P3oool208X[hP80oooo
00<0RR_R0?ooo`3oool0303oool00`000?l0oooo0?ooo`020?ooo`04003jVP3oool0oooo0?ooo`<0
0?ZJ<03oool00`2::n80oooo0?ooo`0Y0?ooo`0408X[hP3oool0oooo0000oaD0oooo00<00?ZJ0?oo
o`3oool04P3oool00`2::n80oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo000S0?ooo`03
0000003oool0oooo01P0oooo00<0RR_R0?ooo`3oool0203oool208X[hP030?ooo`2::n80oooo00h0
oooo00<0003o0?ooo`3oool00P3oool00`2::n80oooo0?ooo`040?ooo`<00?ZJ;@3oool00`2::n80
oooo0?ooo`0Y0?ooo`0408X[hP3oool0oooo0000oa40oooo00<0003o0?ooo`3oool00P3oool00`00
nYX0oooo0?ooo`0A0?ooo`0308X[hP3oool0oooo01X0oooo00<000000?ooo`3oool01`3oool002<0
oooo0P00000T0?ooo`80RR_R00<0oooo08X[hP3oool03P3oool00`000?l0oooo0?ooo`020?ooo`03
08X[hP3oool0oooo00L0oooo0`00nYXZ0?ooo`0308X[hP3oool0oooo02X0oooo00@0RR_R0?ooo`3o
ool0003o403oool00`000?l0oooo0?ooo`030?ooo`03003jVP3oool0oooo0140oooo00<0RR_R0?oo
o`3oool0603oool2000000T0oooo000S0?ooo`030000003oool0oooo02<0oooo0`2::n8@0?ooo`03
0000o`3oool0oooo0080oooo00<0RR_R0?ooo`3oool02P3oool4003jVRH0oooo00<0RR_R0?ooo`3o
ool0:`3oool00`2::n80oooo0000o`0@0?ooo`030000o`3oool0oooo00<0oooo00<00?ZJ0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`030?ooo`0308X[hP3oool0oooo01T0oooo00<000000?ooo`3o
ool01`3oool002<0oooo00<000000?ooo`3oool08`3oool308X[hQ00oooo00<0003o0?ooo`3oool0
0P3oool208X[hPl0oooo0`00nYXS0?ooo`0308X[hP3oool0oooo02`0oooo00<0RR_R0000o`3oool0
3`3oool20000o`D0oooo00<00?ZJ0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80003o
1@3oool00`2::n80oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003o
ool0oooo02<0oooo00<0003o08X[hP3oool03`3oool00`000?l0oooo0?ooo`030?ooo`80RR_R4P3o
ool4003jVQl0oooo00<0RR_R0?ooo`3oool0;03oool0102::n80003o0000o`000?l=0?ooo`030000
o`3oool0003o00H0oooo00<00?ZJ0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`040000
o`3oool0oooo0000o`D0oooo00<0RR_R0?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`00
8`3oool2000002D0oooo00<0RR_R0?ooo`3oool03@3oool20000o`@0oooo00<00?ZJ08X[hP2::n80
5P3oool3003jVQ`0oooo00<0RR_R0?ooo`3oool0;@3oool01P2::n80oooo0?ooo`000?l0oooo0000
o`X0oooo00<0003o0?ooo`000?l01`3oool01P00nYX0oooo0?ooo`000?l0oooo0000o`@0oooo00@0
003o0?ooo`3oool0003o1@3oool00`2::n80oooo0?ooo`0F0?ooo`8000002@3oool002<0oooo00<0
00000?ooo`3oool0903oool00`2::n800?ZJ003jVP0=0?ooo`80003o103oool01000nYX0RR_R0?oo
o`2::n8H0?ooo`<00?ZJ6@3oool00`2::n80oooo0?ooo`0^0?ooo`80RR_R00<0003o0?ooo`000?l0
2P3oool00`000?l0oooo0000o`080?ooo`03003jVP3oool0003o0080oooo00D0003o0?ooo`000?l0
oooo0000o`020?ooo`030000o`3oool0oooo00@0oooo00<0RR_R0?ooo`3oool05P3oool00`000000
oooo0?ooo`070?ooo`003`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool0903oool00`2::n80oooo0?ooo`03003jVPX0oooo0P000?l40?ooo`04003j
VP2::n80oooo08X[hQ/0oooo0`00nYXF0?ooo`0308X[hP3oool0oooo0300oooo00<0RR_R0000o`00
0?l0203oool01@000?l0oooo0000o`3oool0003o00P0oooo00<00?ZJ0?ooo`000?l00`3oool20000
o`050?ooo`000?l0oooo0?ooo`000?l01`3oool00`2::n80oooo0?ooo`0E0?ooo`030000003oool0
oooo00L0oooo000@0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo02@0oooo00<0RR_R0?ooo`3oool00`3oool5003jVP@0oooo00<0003o
0?ooo`3oool0103oool01000nYX0RR_R0?ooo`2::n8N0?ooo`<00?ZJ4`3oool00`2::n80oooo0?oo
o`0`0?ooo`0408X[hP000?l0oooo0000o`H0oooo0P000?l0103oool0003o0?ooo`000?l90?ooo`80
0?ZJ103oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00H0oooo00<0RR_R0?ooo`3o
ool0503oool00`000000oooo0?ooo`070?ooo`00403oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo0`00000T0?ooo`0308X[hP000?l0oooo00P0oooo1000nYX00`000?l0oooo
0?ooo`040?ooo`05003jVP2::n80oooo0?ooo`2::n80803oool3003jVQ00oooo00<0RR_R0?ooo`3o
ool0<@3oool0102::n80oooo0000o`000?l50?ooo`030000o`3oool0003o00<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo003jVP030?ooo`030000o`3oool0003o00<0oooo00<0003o0?oo
o`3oool01@3oool00`2::n80oooo0?ooo`0C0?ooo`8000002@3oool00100oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0RR_R0000o`3o
ool0303oool5003jVP80oooo00<00?ZJ08X[hP3oool00P3oool00`2::n80oooo0?ooo`0P0?ooo`@0
0?ZJ303oool00`2::n80oooo0?ooo`0b0?ooo`0608X[hP000?l0oooo0000o`3oool0003o0P3oool0
0`000?l0oooo0000o`030?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo003j
VP020?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`0308X[hP3oool0oooo01<0oooo00<0
00000?ooo`3oool01`3oool00100oooo00<000000?ooo`3oool01`3oool4000000D0oooo00<00000
0?ooo`3oool09@3oool00`2::n80003o0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo0`00nYX0
0`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0oooo02<0oooo0`00nYX90?ooo`0308X[hP3oool0
oooo03<0oooo00D0RR_R0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool20000o`@0oooo00D00?ZJ0?ooo`3oool0oooo0000o`040?ooo`030000
o`3oool0oooo00L0oooo00<0RR_R0?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`003`3o
ool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`0308X[hP00
0?l0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`0308X[hP3oool0oooo00<0oooo
00<0RR_R0?ooo`3oool09@3oool3003jVPH0oooo00<0RR_R0?ooo`3oool0<`3oool0102::n80oooo
0000o`3oool30000o`H0oooo0`000?l0103oool0003o0?ooo`000?l60?ooo`04003jVP3oool0oooo
0000o`@0oooo00<0003o0?ooo`3oool01`3oool00`2::n80oooo0?ooo`0B0?ooo`030000003oool0
oooo00L0oooo000@0?ooo`030000003oool0oooo00L0oooo1@0000040?ooo`8000009`3oool00`2:
:n80oooo0?ooo`060?ooo`040000o`3oool0oooo0000o`P0oooo00<0RR_R0?ooo`3oool0103oool0
0`2::n80oooo0?ooo`0W0?ooo`@00?ZJ0P3oool00`2::n80oooo0?ooo`0d0?ooo`0408X[hP3oool0
003o0?ooo`80003o1P3oool010000?l0oooo0000o`3oool20000o`P0oooo00<00?ZJ0?ooo`000?l0
103oool00`000?l0oooo0?ooo`080?ooo`0308X[hP3oool0oooo0100oooo0P0000090?ooo`008`3o
ool00`000000oooo0?ooo`0V0?ooo`0308X[hP000?l0oooo00H0oooo0P000?l00`3oool0003o0?oo
o`070?ooo`0308X[hP3oool0oooo00@0oooo00<0RR_R0?ooo`3oool0:`3oool2003jVP0308X[hP3o
ool0oooo03D0oooo00<0RR_R0000o`3oool00P000?l90?ooo`030000o`3oool0003o00T0oooo00<0
0?ZJ0000o`3oool00`3oool00`000?l0oooo0000o`080?ooo`0308X[hP3oool0oooo0140oooo00<0
00000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool09`3oool01@2::n80oooo0?ooo`3o
ool0003o00<0oooo0P000?l00`3oool0003o0?ooo`070?ooo`0308X[hP3oool0oooo00D0oooo00<0
RR_R0?ooo`3oool0;03oool00`2::n80oooo0?ooo`0f0?ooo`0408X[hP3oool0oooo0000oaH0oooo
00<00?ZJ0?ooo`3oool00P3oool00`000?l0oooo0000o`090?ooo`0308X[hP3oool0oooo0100oooo
00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool09`3oool01@2::n80oooo0?oo
o`3oool0003o0080oooo00D0003o0?ooo`000?l0oooo0000o`080?ooo`0308X[hP3oool0oooo00H0
oooo00<0RR_R0?ooo`3oool0:`3oool00`2::n80oooo0?ooo`0g0?ooo`0308X[hP3oool0oooo01H0
oooo00<00?ZJ0?ooo`3oool00P3oool00`000?l0oooo0000o`090?ooo`0308X[hP3oool0oooo0100
oooo00<000000?ooo`3oool01`3oool002<0oooo0P00000X0?ooo`030000o`2::n80oooo0080003o
0P3oool010000?l0oooo0?ooo`000?l90?ooo`0308X[hP3oool0oooo00L0oooo00<0RR_R0?ooo`3o
ool0:P3oool00`2::n80oooo0?ooo`0h0?ooo`0308X[hP3oool0oooo01H0oooo00<00?ZJ0?ooo`3o
ool00P3oool20000o`X0oooo00<0RR_R0?ooo`3oool03P3oool2000000T0oooo000S0?ooo`030000
003oool0oooo02L0oooo00<0003o08X[hP3oool00P000?l20?ooo`040000o`3oool0oooo0000o`P0
oooo00<0RR_R0?ooo`3oool0203oool00`2::n80oooo0?ooo`0Z0?ooo`0308X[hP3oool0oooo03T0
oooo00<0RR_R0?ooo`3oool05P3oool2003jVP80oooo0P000?l:0?ooo`0308X[hP3oool0oooo00l0
oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool09`3oool020000?l0oooo
08X[hP000?l0oooo0000o`3oool0003o2`3oool00`2::n80oooo0?ooo`090?ooo`0308X[hP3oool0
oooo02T0oooo00<0RR_R0?ooo`3oool0>P3oool00`2::n80oooo0?ooo`0G0?ooo`04003jVP3oool0
003o0000o`/0oooo00<0RR_R0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`008`3oool0
0`000000oooo0?ooo`0W0?ooo`080000o`3oool0oooo08X[hP3oool0003o0?ooo`000?l;0?ooo`03
08X[hP3oool0oooo00X0oooo00<0RR_R0?ooo`3oool0:03oool00`2::n80oooo0?ooo`0k0?ooo`03
08X[hP3oool0oooo01L0oooo00<00?ZJ0?ooo`000?l02`3oool00`2::n80oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo02L0oooo00P0003o0?ooo`3oool0
RR_R0?ooo`000?l0oooo0000o`/0oooo00<0RR_R0?ooo`3oool02`3oool208X[hRP0oooo00<0RR_R
0?ooo`3oool0?03oool00`2::n80oooo0?ooo`0F0?ooo`04003jVP3oool0oooo0000o`X0oooo00<0
003o08X[hP3oool03P3oool00`000000oooo0?ooo`070?ooo`008`3oool2000002T0oooo00@0003o
0?ooo`000?l0RR_R0P000?l<0?ooo`0308X[hP3oool0oooo00d0oooo00<0RR_R0?ooo`3oool09@3o
ool00`2::n80oooo0?ooo`0m0?ooo`0308X[hP3oool0oooo01H0oooo00<00?ZJ0?ooo`000?l01P3o
ool01`000?l0oooo0?ooo`3oool0003o0?ooo`2::n803@3oool2000000T0oooo000S0?ooo`030000
003oool0oooo02P0oooo0P000?l20?ooo`0308X[hP000?l0oooo00/0oooo00<0RR_R0?ooo`3oool0
3P3oool00`2::n80oooo0?ooo`0T0?ooo`0308X[hP3oool0oooo03d0oooo00<0RR_R0?ooo`3oool0
5`3oool00`00nYX0003o0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`2::n80
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo02P0oooo
0P000?l30?ooo`80RR_R2`3oool00`2::n80oooo0?ooo`0?0?ooo`0308X[hP3oool0oooo02<0oooo
00<0RR_R0?ooo`3oool0?P3oool00`2::n80oooo0?ooo`0G0?ooo`03003jVP3oool0oooo00@0oooo
0P000?l20?ooo`050000o`3oool0oooo08X[hP000?l0303oool00`000000oooo0?ooo`070?ooo`00
8`3oool00`000000oooo0?ooo`0X0?ooo`80003o1@3oool00`2::n80oooo0?ooo`080?ooo`0308X[
hP3oool0oooo0100oooo00<0RR_R0?ooo`3oool08P3oool00`2::n80oooo0?ooo`0o0?ooo`0308X[
hP3oool0oooo01H0oooo00<0003o003jVP3oool0103oool20000o`030?ooo`000?l0003o00<0oooo
00<0RR_R0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`008`3oool2000002T0oooo0P00
0?l50?ooo`0308X[hP3oool0oooo00P0oooo00<0RR_R0?ooo`3oool04@3oool00`2::n80oooo0?oo
o`0Q0?ooo`0308X[hP3oool0oooo0400oooo0P2::n8F0?ooo`030000o`00nYX0oooo00@0oooo0P00
0?l0103oool0003o0?ooo`000?l20?ooo`0308X[hP000?l0oooo00T0oooo0P0000090?ooo`002@3o
ool3000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3o
ool00`000000oooo0?ooo`0X0?ooo`80003o1P3oool00`2::n80oooo0?ooo`070?ooo`0308X[hP3o
ool0oooo0180oooo0P2::n8Q0?ooo`0308X[hP3oool0oooo0480oooo00<0RR_R0?ooo`3oool0503o
ool00`000?l00?ZJ0?ooo`030?ooo`80003o00@0oooo0000o`3oool0003o0P3oool00`000?l0RR_R
0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
<@3oool00`2::n80oooo0?ooo`060?ooo`0308X[hP3oool0oooo01@0oooo0P2::n8O0?ooo`0308X[
hP3oool0oooo04<0oooo00<0RR_R0?ooo`3oool04`3oool030000?l0oooo003jVP00nYX0oooo0000
o`3oool0003o0?ooo`000?l0oooo0000o`80oooo00<0003o08X[hP3oool02P3oool00`000000oooo
0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`0308X[hP3oool0oooo00D0oooo00<0
RR_R0?ooo`3oool05P3oool00`2::n80oooo0?ooo`0L0?ooo`0308X[hP3oool0oooo04@0oooo00<0
RR_R0?ooo`3oool04`3oool02`000?l0oooo0?ooo`00nYX0003o0?ooo`000?l0oooo0000o`3oool0
003o0080oooo00<0003o08X[hP3oool02P3oool00`000000oooo0?ooo`070?ooo`002P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool30000
03<0oooo0P2::n850?ooo`0308X[hP3oool0oooo01L0oooo00<0RR_R0?ooo`3oool06`3oool00`2:
:n80oooo0?ooo`150?ooo`0308X[hP3oool0oooo0180oooo00D0003o0?ooo`3oool0oooo003jVP02
0?ooo`80003o00@0oooo0000o`3oool0003o0P3oool00`2::n80oooo0?ooo`070?ooo`8000002@3o
ool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo00000003000000D0oooo00<00000
0?ooo`3oool0=@3oool00`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0oooo01P0oooo00<0RR_R
0?ooo`3oool06P3oool00`2::n80oooo0?ooo`150?ooo`0308X[hP3oool0oooo0180oooo00D0003o
0?ooo`3oool0oooo003jVP020?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool00`2::n80oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00090?ooo`8000002@3oool01`000000oooo0?oo
o`3oool000000?ooo`000000203oool00`000000oooo0?ooo`0f0?ooo`80RR_R0P3oool00`2::n80
oooo0?ooo`0I0?ooo`80RR_R6P3oool00`2::n80oooo0?ooo`160?ooo`0308X[hP3oool0oooo0140
oooo00P0003o0?ooo`3oool0oooo0000o`00nYX0oooo0000o`<0oooo0P000?l20?ooo`030000o`2:
:n80oooo00P0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool01`3oool5
000000030?ooo`000000000000<00000103oool00`000000oooo0?ooo`0h0?ooo`0308X[hP3oool0
RR_R01d0oooo00<0RR_R0?ooo`3oool05`3oool00`2::n80oooo0?ooo`170?ooo`0308X[hP3oool0
oooo0100oooo00P0003o0?ooo`3oool0oooo0000o`3oool00?ZJ0000o`<0oooo0P000?l20?ooo`03
0000o`2::n80oooo00P0oooo00<000000?ooo`3oool01`3oool002<0oooo0P00000j0?ooo`80RR_R
7P3oool00`2::n80oooo0?ooo`0F0?ooo`0308X[hP3oool0oooo04P0oooo00<0RR_R0?ooo`3oool0
3`3oool010000?l0oooo0?ooo`000?l30?ooo`03003jVP3oool0oooo0080oooo00H0003o0?ooo`3o
ool0oooo0000o`2::n870?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0>P3oool00`2:
:n80oooo0?ooo`0M0?ooo`<0RR_R5@3oool00`2::n80oooo0?ooo`190?ooo`80RR_R403oool00`00
0?l0oooo0000o`040?ooo`03003jVP3oool0oooo00D0oooo00<0003o08X[hP3oool01`3oool00`00
0000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1M0?ooo`0308X[hP3oool0oooo0180
oooo00<0RR_R0?ooo`3oool0B`3oool00`2::n80oooo0?ooo`0=0?ooo`030000o`3oool0003o00@0
oooo00<00?ZJ0?ooo`3oool01@3oool00`000?l0RR_R0?ooo`070?ooo`030000003oool0oooo00L0
oooo000S0?ooo`030000003oool0oooo05h0oooo0P2::n8B0?ooo`0308X[hP3oool0oooo04`0oooo
00<0RR_R0?ooo`3oool0303oool20000o`H0oooo00<00?ZJ0?ooo`3oool01@3oool00`000?l0RR_R
0?ooo`060?ooo`030000003oool0oooo00L0oooo000S0?ooo`800000H@3oool00`2::n80oooo0?oo
o`0?0?ooo`0308X[hP3oool0oooo04d0oooo00<0RR_R0?ooo`3oool02`3oool20000o`L0oooo0P00
nYX50?ooo`030000o`2::n80oooo00D0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`1Q
0?ooo`80RR_R3`3oool00`2::n80oooo0?ooo`1>0?ooo`0308X[hP3oool0oooo00X0oooo00<0003o
0?ooo`3oool0203oool00`00nYX0oooo0?ooo`020?ooo`030000o`2::n80oooo00H0oooo00<00000
0?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0H`3oool208X[hPd0oooo00<0RR_R0?oo
o`3oool0C`3oool00`2::n80oooo0?ooo`0E0?ooo`07003jVP3oool0oooo0?ooo`000?l0oooo08X[
hP060?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo06D0oooo0P2::n8;
0?ooo`0308X[hP3oool0oooo0500oooo00<0RR_R0?ooo`3oool0503oool01`00nYX0oooo0?ooo`3o
ool0003o0?ooo`2::n801P3oool00`000000oooo0?ooo`070?ooo`008`3oool2000006P0oooo0P2:
:n890?ooo`0308X[hP3oool0oooo0540oooo00<0RR_R0?ooo`3oool0503oool01P00nYX0oooo0?oo
o`000?l0oooo08X[hPD0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`1Y0?ooo`0308X[
hP3oool0oooo00H0oooo00<0RR_R0?ooo`3oool0DP3oool208X[hQD0oooo00<00?ZJ0?ooo`000?l0
0P3oool00`2::n80oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003o
ool0oooo06X0oooo0P2::n860?ooo`0308X[hP3oool0oooo05@0oooo00<0RR_R0?ooo`3oool04`3o
ool01@00nYX0003o0?ooo`3oool0RR_R00D0oooo00<000000?ooo`3oool01`3oool002<0oooo00<0
00000?ooo`3oool0K03oool308X[hP<0oooo00<0RR_R0?ooo`3oool0E@3oool208X[hQ@0oooo00@0
0?ZJ0?ooo`3oool0RR_R1@3oool00`000000oooo0?ooo`070?ooo`008`3oool200000700oooo0P2:
:n800`3oool0RR_R0?ooo`1H0?ooo`0308X[hP3oool0oooo0140oooo00D00?ZJ0000o`3oool0oooo
08X[hP030?ooo`8000002@3oool001X0oooo1@0000040?ooo`030000003oool0oooo0740oooo0P2:
:n9J0?ooo`0308X[hP3oool0oooo0140oooo00<00?ZJ0?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`006`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0<h0oooo00<0
RR_R0?ooo`3oool0403oool00`000?l00?ZJ003jVP050?ooo`030000003oool0oooo00L0oooo000L
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0c`3oool00`2::n80oooo0?ooo`0?
0?ooo`040000o`3oool0003o003jVP@0oooo00<000000?ooo`3oool01`3oool001d0oooo00<00000
0?ooo`3oool00`3oool300000=00oooo0`2::n8>0?ooo`80003o1@3oool2000000T0oooo000J0?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`3C0?ooo`0308X[hP3oool0
oooo00/0oooo00@0003o0?ooo`3oool0RR_R103oool00`000000oooo0?ooo`070?ooo`006P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0e03oool208X[hPh0oooo00<0
RR_R0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`006`3oool3000000D0oooo00<00000
0?ooo`3oool0eP3oool00`2::n80oooo0?ooo`0:0?ooo`0308X[hP3oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool002<0oooo0P00003H0?ooo`80RR_R2P3oool00`2::n80oooo0?ooo`020?oo
o`8000002@3oool002<0oooo00<000000?ooo`3oool0f@3oool408X[hPD0oooo00<0RR_R0?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`3M0?ooo`D0RR_R
1`3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`3Y0?ooo`030000003o
ool0oooo00L0oooo000S0?ooo`800000103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo02X0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo000S0?ooond000002@3oool00?l0oooo6P3oool00?l0oooo
6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00840oooo1@0000000`3oool0
000000000003000000030?ooo`000000000000<000000`3oool2000000<0oooo0`0000020?ooo`<0
0000103oool3000000<0oooo1000001Y0?ooo`00P`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo0000
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000006X0oooo00230?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`030000003oool0oooo
0080oooo1@0000001@3oool000000?ooo`3oool0000006X0oooo00230?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`1X0?ooo`00PP3oool4000000040?ooo`00
00000000000000D0oooo00@000000?ooo`3oool0oooo100000030?ooo`<000000P3oool200000003
0?ooo`00000000000080oooo0`0000030?ooo`<00000JP3oool008<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
J03oool008@0oooo0P0000030?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo
0?ooo`0F0?ooo`800000JP3oool00?l0oooo6P3oool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-0.183001, 0.167841, \
0.00444568, 0.0123608}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s = Map[VecDiag, PG] // Sqrt;\)\), "\n", 
    \(\(HPD = \ YG~ii~\((YG + s)\)~ii~\((YG - s)\);\)\), "\n", 
    \(\(glatt1 = 
        plot1[B[\([1]\)]~ii~HPD // AddTimeAxis[#, dt] &, 
          color -> {1, 2, 5, 5}, 
          dicke ->  .007 {1, 
                1,  .5,  .5}, \[IndentingNewLine]\t\t\t\tPlotLabel -> \
"\<smoothed\>"];\)\), "\n", 
    \(\)}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{201, 5}\),
      SequenceForm[ "Dimension der Daten  ", {201, 5}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.108784 0.344625 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06353 -18 -4.5 ]
[-0.0125 .06353 0 4.5 ]
[-0.0125 .14968 -24 -4.5 ]
[-0.0125 .14968 0 4.5 ]
[-0.0125 .23584 -6 -4.5 ]
[-0.0125 .23584 0 4.5 ]
[-0.0125 .322 -24 -4.5 ]
[-0.0125 .322 0 4.5 ]
[-0.0125 .40815 -18 -4.5 ]
[-0.0125 .40815 0 4.5 ]
[-0.0125 .49431 -24 -4.5 ]
[-0.0125 .49431 0 4.5 ]
[-0.0125 .58047 -6 -4.5 ]
[-0.0125 .58047 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[.97619 .57495 -5 -6 ]
[.97619 .57495 5 6 ]
[.97619 .57555 -5 -6 ]
[.97619 .57555 5 6 ]
[.97619 .58506 -5 -6 ]
[.97619 .58506 5 6 ]
[.97619 .56603 -5 -6 ]
[.97619 .56603 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06353 m
.00625 .06353 L
s
[(0.5)] -0.0125 .06353 1 0 Mshowa
0 .14968 m
.00625 .14968 L
s
[(0.75)] -0.0125 .14968 1 0 Mshowa
0 .23584 m
.00625 .23584 L
s
[(1)] -0.0125 .23584 1 0 Mshowa
0 .322 m
.00625 .322 L
s
[(1.25)] -0.0125 .322 1 0 Mshowa
0 .40815 m
.00625 .40815 L
s
[(1.5)] -0.0125 .40815 1 0 Mshowa
0 .49431 m
.00625 .49431 L
s
[(1.75)] -0.0125 .49431 1 0 Mshowa
0 .58047 m
.00625 .58047 L
s
[(2)] -0.0125 .58047 1 0 Mshowa
.125 Mabswid
0 .08076 m
.00375 .08076 L
s
0 .09799 m
.00375 .09799 L
s
0 .11522 m
.00375 .11522 L
s
0 .13245 m
.00375 .13245 L
s
0 .16692 m
.00375 .16692 L
s
0 .18415 m
.00375 .18415 L
s
0 .20138 m
.00375 .20138 L
s
0 .21861 m
.00375 .21861 L
s
0 .25307 m
.00375 .25307 L
s
0 .2703 m
.00375 .2703 L
s
0 .28753 m
.00375 .28753 L
s
0 .30477 m
.00375 .30477 L
s
0 .33923 m
.00375 .33923 L
s
0 .35646 m
.00375 .35646 L
s
0 .37369 m
.00375 .37369 L
s
0 .39092 m
.00375 .39092 L
s
0 .42538 m
.00375 .42538 L
s
0 .44262 m
.00375 .44262 L
s
0 .45985 m
.00375 .45985 L
s
0 .47708 m
.00375 .47708 L
s
0 .51154 m
.00375 .51154 L
s
0 .52877 m
.00375 .52877 L
s
0 .546 m
.00375 .546 L
s
0 .56323 m
.00375 .56323 L
s
0 .0463 m
.00375 .0463 L
s
0 .02907 m
.00375 .02907 L
s
0 .01183 m
.00375 .01183 L
s
0 .5977 m
.00375 .5977 L
s
0 .61493 m
.00375 .61493 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06353 m
1 .06353 L
s
.99375 .14968 m
1 .14968 L
s
.99375 .23584 m
1 .23584 L
s
.99375 .322 m
1 .322 L
s
.99375 .40815 m
1 .40815 L
s
.99375 .49431 m
1 .49431 L
s
.99375 .58047 m
1 .58047 L
s
.125 Mabswid
.99625 .08076 m
1 .08076 L
s
.99625 .09799 m
1 .09799 L
s
.99625 .11522 m
1 .11522 L
s
.99625 .13245 m
1 .13245 L
s
.99625 .16692 m
1 .16692 L
s
.99625 .18415 m
1 .18415 L
s
.99625 .20138 m
1 .20138 L
s
.99625 .21861 m
1 .21861 L
s
.99625 .25307 m
1 .25307 L
s
.99625 .2703 m
1 .2703 L
s
.99625 .28753 m
1 .28753 L
s
.99625 .30477 m
1 .30477 L
s
.99625 .33923 m
1 .33923 L
s
.99625 .35646 m
1 .35646 L
s
.99625 .37369 m
1 .37369 L
s
.99625 .39092 m
1 .39092 L
s
.99625 .42538 m
1 .42538 L
s
.99625 .44262 m
1 .44262 L
s
.99625 .45985 m
1 .45985 L
s
.99625 .47708 m
1 .47708 L
s
.99625 .51154 m
1 .51154 L
s
.99625 .52877 m
1 .52877 L
s
.99625 .546 m
1 .546 L
s
.99625 .56323 m
1 .56323 L
s
.99625 .0463 m
1 .0463 L
s
.99625 .02907 m
1 .02907 L
s
.99625 .01183 m
1 .01183 L
s
.99625 .5977 m
1 .5977 L
s
.99625 .61493 m
1 .61493 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(smoothed) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .57495 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.007 w
.02381 .23584 m
.02857 .27852 L
.03333 .30952 L
.0381 .28494 L
.04286 .27989 L
.04762 .27372 L
.05238 .2785 L
.05714 .27017 L
.0619 .29117 L
.06667 .26894 L
.07143 .28306 L
.07619 .28386 L
.08095 .28328 L
.08571 .26863 L
.09048 .27676 L
.09524 .2621 L
.1 .24648 L
.10476 .25616 L
.10952 .25187 L
.11429 .26474 L
.11905 .26822 L
.12381 .30428 L
.12857 .273 L
.13333 .26844 L
.1381 .29014 L
.14286 .28965 L
.14762 .27736 L
.15238 .30482 L
.15714 .34702 L
.1619 .37326 L
.16667 .39694 L
.17143 .41704 L
.17619 .43233 L
.18095 .48507 L
.18571 .48398 L
.19048 .44035 L
.19524 .43398 L
.2 .45883 L
.20476 .47146 L
.20952 .41984 L
.21429 .42931 L
.21905 .44611 L
.22381 .43332 L
.22857 .40849 L
.23333 .38742 L
.2381 .39977 L
.24286 .36477 L
.24762 .33374 L
.25238 .29659 L
.25714 .32505 L
Mistroke
.2619 .35657 L
.26667 .32121 L
.27143 .32469 L
.27619 .29391 L
.28095 .32924 L
.28571 .30216 L
.29048 .31065 L
.29524 .29619 L
.3 .33082 L
.30476 .31382 L
.30952 .29214 L
.31429 .30723 L
.31905 .31281 L
.32381 .27876 L
.32857 .22349 L
.33333 .20752 L
.3381 .20628 L
.34286 .20956 L
.34762 .22309 L
.35238 .205 L
.35714 .19997 L
.3619 .20141 L
.36667 .19833 L
.37143 .16418 L
.37619 .16132 L
.38095 .14896 L
.38571 .10798 L
.39048 .10547 L
.39524 .11455 L
.4 .08051 L
.40476 .07311 L
.40952 .06781 L
.41429 .07722 L
.41905 .08887 L
.42381 .09014 L
.42857 .087 L
.43333 .1133 L
.4381 .14887 L
.44286 .09747 L
.44762 .13743 L
.45238 .13342 L
.45714 .13045 L
.4619 .1246 L
.46667 .1234 L
.47143 .08519 L
.47619 .0491 L
.48095 .03259 L
.48571 .04 L
.49048 .0546 L
.49524 .04416 L
Mistroke
.5 .03992 L
.50476 .06814 L
.50952 .06957 L
.51429 .07158 L
.51905 .07981 L
.52381 .11785 L
.52857 .16741 L
.53333 .15353 L
.5381 .17116 L
.54286 .14818 L
.54762 .16865 L
.55238 .19575 L
.55714 .21347 L
.5619 .21529 L
.56667 .26296 L
.57143 .22829 L
.57619 .25145 L
.58095 .27651 L
.58571 .2467 L
.59048 .24691 L
.59524 .27145 L
.6 .2335 L
.60476 .24058 L
.60952 .2904 L
.61429 .25502 L
.61905 .26181 L
.62381 .28441 L
.62857 .22905 L
.63333 .23418 L
.6381 .21821 L
.64286 .18566 L
.64762 .17225 L
.65238 .20403 L
.65714 .21931 L
.6619 .24516 L
.66667 .27062 L
.67143 .24323 L
.67619 .26684 L
.68095 .27503 L
.68571 .27911 L
.69048 .32519 L
.69524 .34649 L
.7 .38842 L
.70476 .38714 L
.70952 .38908 L
.71429 .40328 L
.71905 .38843 L
.72381 .41142 L
.72857 .4059 L
.73333 .41196 L
Mistroke
.7381 .42668 L
.74286 .41269 L
.74762 .4334 L
.75238 .40429 L
.75714 .39594 L
.7619 .41105 L
.76667 .3989 L
.77143 .36996 L
.77619 .38415 L
.78095 .42312 L
.78571 .42009 L
.79048 .42683 L
.79524 .41775 L
.8 .42849 L
.80476 .41631 L
.80952 .41582 L
.81429 .41279 L
.81905 .40301 L
.82381 .3813 L
.82857 .38888 L
.83333 .39536 L
.8381 .39819 L
.84286 .39178 L
.84762 .43084 L
.85238 .38679 L
.85714 .37816 L
.8619 .38618 L
.86667 .42189 L
.87143 .44752 L
.87619 .42972 L
.88095 .47976 L
.88571 .48369 L
.89048 .49791 L
.89524 .53448 L
.9 .51632 L
.90476 .50377 L
.90952 .46032 L
.91429 .47263 L
.91905 .51326 L
.92381 .48457 L
.92857 .45547 L
.93333 .48963 L
.9381 .51332 L
.94286 .47197 L
.94762 .47808 L
.95238 .50681 L
.95714 .50969 L
.9619 .53499 L
.96667 .58352 L
.97143 .58293 L
Mistroke
.97619 .57495 L
Mfstroke
0 .98 .604 r
gsave
.97619 .57555 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .23641 m
.02857 .24096 L
.03333 .24551 L
.0381 .25007 L
.04286 .25462 L
.04762 .25917 L
.05238 .26372 L
.05714 .26828 L
.0619 .27283 L
.06667 .27738 L
.07143 .28193 L
.07619 .28083 L
.08095 .27973 L
.08571 .27863 L
.09048 .27752 L
.09524 .27642 L
.1 .27532 L
.10476 .27422 L
.10952 .27311 L
.11429 .27201 L
.11905 .27091 L
.12381 .28323 L
.12857 .29554 L
.13333 .30786 L
.1381 .32018 L
.14286 .3325 L
.14762 .34482 L
.15238 .35714 L
.15714 .36946 L
.1619 .38177 L
.16667 .39409 L
.17143 .39217 L
.17619 .39025 L
.18095 .38833 L
.18571 .38641 L
.19048 .38449 L
.19524 .38257 L
.2 .38065 L
.20476 .37873 L
.20952 .37681 L
.21429 .3749 L
.21905 .37298 L
.22381 .37106 L
.22857 .36914 L
.23333 .36722 L
.2381 .3653 L
.24286 .36338 L
.24762 .36146 L
.25238 .35954 L
.25714 .35762 L
Mistroke
.2619 .3557 L
.26667 .34943 L
.27143 .34316 L
.27619 .33689 L
.28095 .33062 L
.28571 .32435 L
.29048 .31808 L
.29524 .31181 L
.3 .30554 L
.30476 .29928 L
.30952 .29301 L
.31429 .28674 L
.31905 .28047 L
.32381 .2742 L
.32857 .26793 L
.33333 .26166 L
.3381 .25539 L
.34286 .24912 L
.34762 .24285 L
.35238 .23658 L
.35714 .23031 L
.3619 .22405 L
.36667 .21778 L
.37143 .21151 L
.37619 .20524 L
.38095 .19897 L
.38571 .1927 L
.39048 .18643 L
.39524 .18016 L
.4 .17389 L
.40476 .16762 L
.40952 .16135 L
.41429 .15509 L
.41905 .14882 L
.42381 .14255 L
.42857 .13628 L
.43333 .13001 L
.4381 .12374 L
.44286 .11747 L
.44762 .1112 L
.45238 .10493 L
.45714 .09866 L
.4619 .09239 L
.46667 .08612 L
.47143 .07986 L
.47619 .07359 L
.48095 .06732 L
.48571 .06105 L
.49048 .05478 L
.49524 .04851 L
Mistroke
.5 .04224 L
.50476 .04758 L
.50952 .05292 L
.51429 .05826 L
.51905 .0636 L
.52381 .06893 L
.52857 .07427 L
.53333 .07961 L
.5381 .08495 L
.54286 .09029 L
.54762 .09563 L
.55238 .10097 L
.55714 .10631 L
.5619 .11164 L
.56667 .11698 L
.57143 .12232 L
.57619 .12766 L
.58095 .133 L
.58571 .13834 L
.59048 .14368 L
.59524 .14902 L
.6 .15435 L
.60476 .15969 L
.60952 .16503 L
.61429 .17037 L
.61905 .17571 L
.62381 .18105 L
.62857 .18639 L
.63333 .19173 L
.6381 .19707 L
.64286 .2024 L
.64762 .20774 L
.65238 .21308 L
.65714 .21842 L
.6619 .22376 L
.66667 .2291 L
.67143 .23444 L
.67619 .23978 L
.68095 .24511 L
.68571 .25045 L
.69048 .25579 L
.69524 .26113 L
.7 .26647 L
.70476 .27181 L
.70952 .27715 L
.71429 .28249 L
.71905 .28782 L
.72381 .29316 L
.72857 .2985 L
.73333 .30384 L
Mistroke
.7381 .30918 L
.74286 .31452 L
.74762 .31986 L
.75238 .3252 L
.75714 .33053 L
.7619 .33587 L
.76667 .34121 L
.77143 .34655 L
.77619 .35189 L
.78095 .35723 L
.78571 .36257 L
.79048 .3679 L
.79524 .37324 L
.8 .37858 L
.80476 .38392 L
.80952 .38926 L
.81429 .3946 L
.81905 .39994 L
.82381 .40528 L
.82857 .41061 L
.83333 .41595 L
.8381 .42129 L
.84286 .42663 L
.84762 .43197 L
.85238 .43731 L
.85714 .44265 L
.8619 .44798 L
.86667 .45332 L
.87143 .45866 L
.87619 .464 L
.88095 .46934 L
.88571 .47468 L
.89048 .48001 L
.89524 .48535 L
.9 .49069 L
.90476 .49603 L
.90952 .50137 L
.91429 .5067 L
.91905 .51204 L
.92381 .51738 L
.92857 .52271 L
.93333 .52805 L
.9381 .53339 L
.94286 .53872 L
.94762 .54405 L
.95238 .54939 L
.95714 .55471 L
.9619 .56004 L
.96667 .56534 L
.97143 .5706 L
Mistroke
.97619 .57555 L
Mfstroke
.541 .169 .886 r
gsave
.97619 .58506 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0035 w
.02381 .24721 m
.02857 .26607 L
.03333 .27761 L
.0381 .28633 L
.04286 .29317 L
.04762 .29846 L
.05238 .30227 L
.05714 .30453 L
.0619 .3049 L
.06667 .30245 L
.07143 .29262 L
.07619 .3059 L
.08095 .3118 L
.08571 .31488 L
.09048 .31607 L
.09524 .3157 L
.1 .31386 L
.10476 .31047 L
.10952 .30518 L
.11429 .29708 L
.11905 .2816 L
.12381 .3083 L
.12857 .32762 L
.13333 .34412 L
.1381 .35873 L
.14286 .37178 L
.14762 .38337 L
.15238 .3934 L
.15714 .40154 L
.1619 .40686 L
.16667 .40483 L
.17143 .41803 L
.17619 .42437 L
.18095 .42834 L
.18571 .4309 L
.19048 .43245 L
.19524 .43319 L
.2 .43324 L
.20476 .43269 L
.20952 .43157 L
.21429 .42992 L
.21905 .42774 L
.22381 .42501 L
.22857 .42173 L
.23333 .41784 L
.2381 .41326 L
.24286 .40788 L
.24762 .40148 L
.25238 .39367 L
.25714 .38351 L
Mistroke
.2619 .36652 L
.26667 .37578 L
.27143 .37849 L
.27619 .37906 L
.28095 .37843 L
.28571 .37697 L
.29048 .3749 L
.29524 .37234 L
.3 .36939 L
.30476 .3661 L
.30952 .36251 L
.31429 .35866 L
.31905 .35457 L
.32381 .35026 L
.32857 .34575 L
.33333 .34106 L
.3381 .33618 L
.34286 .33115 L
.34762 .32595 L
.35238 .32059 L
.35714 .31509 L
.3619 .30945 L
.36667 .30366 L
.37143 .29773 L
.37619 .29167 L
.38095 .28547 L
.38571 .27913 L
.39048 .27266 L
.39524 .26605 L
.4 .2593 L
.40476 .2524 L
.40952 .24537 L
.41429 .23818 L
.41905 .23084 L
.42381 .22334 L
.42857 .21568 L
.43333 .20783 L
.4381 .1998 L
.44286 .19157 L
.44762 .18312 L
.45238 .17444 L
.45714 .16549 L
.4619 .15625 L
.46667 .14666 L
.47143 .13668 L
.47619 .12621 L
.48095 .11513 L
.48571 .10323 L
.49048 .09012 L
.49524 .07488 L
Mistroke
.5 .05311 L
.50476 .07411 L
.50952 .08866 L
.51429 .10114 L
.51905 .11248 L
.52381 .12304 L
.52857 .13304 L
.53333 .14261 L
.5381 .15182 L
.54286 .16073 L
.54762 .16939 L
.55238 .17783 L
.55714 .18608 L
.5619 .19415 L
.56667 .20206 L
.57143 .20984 L
.57619 .21748 L
.58095 .22499 L
.58571 .2324 L
.59048 .2397 L
.59524 .24689 L
.6 .254 L
.60476 .26101 L
.60952 .26795 L
.61429 .2748 L
.61905 .28157 L
.62381 .28827 L
.62857 .29489 L
.63333 .30145 L
.6381 .30794 L
.64286 .31437 L
.64762 .32073 L
.65238 .32703 L
.65714 .33327 L
.6619 .33946 L
.66667 .34559 L
.67143 .35166 L
.67619 .35767 L
.68095 .36364 L
.68571 .36955 L
.69048 .3754 L
.69524 .38121 L
.7 .38697 L
.70476 .39267 L
.70952 .39833 L
.71429 .40393 L
.71905 .40949 L
.72381 .41499 L
.72857 .42045 L
.73333 .42586 L
Mistroke
.7381 .43122 L
.74286 .43654 L
.74762 .4418 L
.75238 .44702 L
.75714 .45218 L
.7619 .4573 L
.76667 .46237 L
.77143 .46739 L
.77619 .47236 L
.78095 .47728 L
.78571 .48215 L
.79048 .48696 L
.79524 .49173 L
.8 .49644 L
.80476 .50109 L
.80952 .5057 L
.81429 .51024 L
.81905 .51473 L
.82381 .51916 L
.82857 .52353 L
.83333 .52784 L
.8381 .53209 L
.84286 .53627 L
.84762 .54039 L
.85238 .54444 L
.85714 .54841 L
.8619 .55231 L
.86667 .55613 L
.87143 .55987 L
.87619 .56353 L
.88095 .5671 L
.88571 .57057 L
.89048 .57394 L
.89524 .57721 L
.9 .58036 L
.90476 .58339 L
.90952 .58629 L
.91429 .58904 L
.91905 .59164 L
.92381 .59406 L
.92857 .59628 L
.93333 .59828 L
.9381 .60003 L
.94286 .60148 L
.94762 .60258 L
.95238 .60323 L
.95714 .60332 L
.9619 .60263 L
.96667 .60079 L
.97143 .59685 L
Mistroke
.97619 .58506 L
Mfstroke
gsave
.97619 .56603 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .22561 m
.02857 .21585 L
.03333 .21342 L
.0381 .2138 L
.04286 .21606 L
.04762 .21988 L
.05238 .22517 L
.05714 .23202 L
.0619 .24076 L
.06667 .25231 L
.07143 .27124 L
.07619 .25576 L
.08095 .24766 L
.08571 .24237 L
.09048 .23898 L
.09524 .23714 L
.1 .23677 L
.10476 .23796 L
.10952 .24104 L
.11429 .24694 L
.11905 .26022 L
.12381 .25815 L
.12857 .26347 L
.13333 .27161 L
.1381 .28163 L
.14286 .29322 L
.14762 .30627 L
.15238 .32088 L
.15714 .33737 L
.1619 .35669 L
.16667 .38335 L
.17143 .36631 L
.17619 .35614 L
.18095 .34833 L
.18571 .34193 L
.19048 .33654 L
.19524 .33196 L
.2 .32807 L
.20476 .32478 L
.20952 .32205 L
.21429 .31987 L
.21905 .31821 L
.22381 .3171 L
.22857 .31654 L
.23333 .3166 L
.2381 .31733 L
.24286 .31888 L
.24762 .32143 L
.25238 .3254 L
.25714 .33173 L
Mistroke
.2619 .34487 L
.26667 .32307 L
.27143 .30783 L
.27619 .29472 L
.28095 .28282 L
.28571 .27174 L
.29048 .26127 L
.29524 .25128 L
.3 .2417 L
.30476 .23245 L
.30952 .2235 L
.31429 .21482 L
.31905 .20637 L
.32381 .19814 L
.32857 .19011 L
.33333 .18227 L
.3381 .1746 L
.34286 .1671 L
.34762 .15976 L
.35238 .15257 L
.35714 .14554 L
.3619 .13864 L
.36667 .13189 L
.37143 .12528 L
.37619 .11881 L
.38095 .11247 L
.38571 .10627 L
.39048 .1002 L
.39524 .09428 L
.4 .08849 L
.40476 .08284 L
.40952 .07734 L
.41429 .07199 L
.41905 .06679 L
.42381 .06175 L
.42857 .05688 L
.43333 .05219 L
.4381 .04768 L
.44286 .04337 L
.44762 .03928 L
.45238 .03543 L
.45714 .03184 L
.4619 .02854 L
.46667 .02559 L
.47143 .02303 L
.47619 .02096 L
.48095 .0195 L
.48571 .01886 L
.49048 .01943 L
.49524 .02214 L
Mistroke
.5 .03137 L
.50476 .02105 L
.50952 .01718 L
.51429 .01537 L
.51905 .01472 L
.52381 .01483 L
.52857 .0155 L
.53333 .01662 L
.5381 .01808 L
.54286 .01985 L
.54762 .02187 L
.55238 .0241 L
.55714 .02653 L
.5619 .02914 L
.56667 .0319 L
.57143 .03481 L
.57619 .03785 L
.58095 .04101 L
.58571 .04428 L
.59048 .04766 L
.59524 .05114 L
.6 .05471 L
.60476 .05837 L
.60952 .06212 L
.61429 .06595 L
.61905 .06985 L
.62381 .07383 L
.62857 .07788 L
.63333 .082 L
.6381 .08619 L
.64286 .09044 L
.64762 .09476 L
.65238 .09913 L
.65714 .10357 L
.6619 .10806 L
.66667 .11261 L
.67143 .11722 L
.67619 .12188 L
.68095 .12659 L
.68571 .13136 L
.69048 .13618 L
.69524 .14105 L
.7 .14597 L
.70476 .15095 L
.70952 .15597 L
.71429 .16104 L
.71905 .16616 L
.72381 .17133 L
.72857 .17655 L
.73333 .18182 L
Mistroke
.7381 .18713 L
.74286 .1925 L
.74762 .19791 L
.75238 .20337 L
.75714 .20888 L
.7619 .21444 L
.76667 .22005 L
.77143 .22571 L
.77619 .23142 L
.78095 .23718 L
.78571 .24299 L
.79048 .24885 L
.79524 .25476 L
.8 .26073 L
.80476 .26675 L
.80952 .27282 L
.81429 .27895 L
.81905 .28514 L
.82381 .29139 L
.82857 .29769 L
.83333 .30406 L
.8381 .31049 L
.84286 .31699 L
.84762 .32355 L
.85238 .33018 L
.85714 .33688 L
.8619 .34366 L
.86667 .35051 L
.87143 .35745 L
.87619 .36447 L
.88095 .37158 L
.88571 .37878 L
.89048 .38609 L
.89524 .3935 L
.9 .40102 L
.90476 .40867 L
.90952 .41644 L
.91429 .42437 L
.91905 .43244 L
.92381 .4407 L
.92857 .44915 L
.93333 .45782 L
.9381 .46674 L
.94286 .47596 L
.94762 .48553 L
.95238 .49554 L
.95714 .50611 L
.9619 .51744 L
.96667 .52989 L
.97143 .54435 L
Mistroke
.97619 .56603 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00:03oool2000002D0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000007P3oool2
000000@0oooo00<000000?ooo`3oool00`3oool3000001h0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000O0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000903oool3
000000h0oooo000W0?ooo`040000003oool0oooo000002<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000M0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000007@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000903oool00`000000oooo
0?ooo`0=0?ooo`009`3oool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool07@3oool010000000oooo0?ooo`0000070?ooo`D000007@3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000007@3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000903oool00`000000oooo0?ooo`0=0?ooo`00
9`3oool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0703oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000001h0oooo00@0
00000?ooo`3oool000001`3oool4000001h0oooo00@000000?ooo`3oool00000203oool3000002D0
oooo00<000000?ooo`3oool03@3oool002L0oooo00@000000?ooo`3oool000008`3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000007@3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0000001h0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0O0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000T0?oo
o`030000003oool0oooo00d0oooo000W0?ooo`040000003oool0oooo000002<0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000001d0oooo00@000000?ooo`3oool00000
2@3oool2000001h0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0N0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`8000003`3oool0
02P0oooo0P00000U0?ooo`8000002@3oool3000001l0oooo0P00000;0?ooo`030000003oool0oooo
01d0oooo0P00000:0?ooo`8000007`3oool2000000T0oooo0`00000U0?ooo`030000003oool0oooo
00d0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo000S0?oo
ond000002@3oool002<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`00
8`3oool200000>T0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`1f0?ooo`D0RR_RKP3o
ool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1_0?ooo`<0RR_R0`3oool0
0`2::n80oooo0?ooo`030?ooo`<0RR_RJ`3oool00`000000oooo0?ooo`070?ooo`008`3oool00`00
0000oooo0?ooo`1/0?ooo`<0RR_R0`3oool00`2::n80oooo08X[hP090?ooo`<0RR_RJ03oool00`00
0000oooo0?ooo`070?ooo`008`3oool2000006/0oooo0P2::n860?ooo`0308X[hP3oool0RR_R00`0
oooo0P2::n9U0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0J@3oool00`2::n80oooo
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`2::n803`3oool00`2::n80oooo0?ooo`1S0?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo06P0oooo00<0RR_R0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0B0?ooo`0308X[hP3oool0oooo0680oooo00<000000?ooo`3oool0
1`3oool002<0oooo00<000000?ooo`3oool0I`3oool00`2::n80oooo0?ooo`050?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`0?0?ooo`80RR_RHP3oool00`000000oooo0?ooo`070?ooo`008`3oool0
0`000000oooo0?ooo`1V0?ooo`0308X[hP3oool0oooo00D0oooo00H0003o0?ooo`000?l0oooo0000
o`00nYXC0?ooo`80RR_RH03oool00`000000oooo0?ooo`070?ooo`008`3oool2000006D0oooo0P2:
:n880?ooo`070000o`3oool0oooo0000o`00nYX0003o003jVP0D0?ooo`0308X[hP3oool0oooo05`0
oooo0P0000090?ooo`00403oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool0H`3oool00`2::n80oooo0?ooo`080?ooo`070000o`3oool0oooo0000o`00
nYX0RR_R0?ooo`02003jVQ<0oooo0P2::n9M0?ooo`030000003oool0oooo00L0oooo000?0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0680oooo00<0RR_R0?ooo`3oool02@3oool01`000?l0oooo0?ooo`00nYX0oooo08X[hP000?l0
0P3oool00`00nYX0oooo0?ooo`0B0?ooo`0308X[hP3oool0oooo05X0oooo00<000000?ooo`3oool0
1`3oool000l0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0640oooo00<0RR_R0?ooo`3oool02@3oool010000?l0oooo0?ooo`00nYX20?ooo`05
08X[hP000?l0oooo0?ooo`00nYX05@3oool00`2::n80oooo0?ooo`1I0?ooo`030000003oool0oooo
00L0oooo000?0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool30000
0600oooo00<0RR_R0?ooo`3oool02P3oool00`000?l0oooo003jVP020?ooo`0308X[hP3oool0RR_R
00<0oooo00<00?ZJ0?ooo`3oool04`3oool00`2::n80oooo0?ooo`1G0?ooo`8000002@3oool000l0
oooo00@000000?ooo`3oool000001`3oool4000000D0oooo00<000000?ooo`3oool0GP3oool00`00
0?l0oooo08X[hP0<0?ooo`030000o`3oool00?ZJ0080oooo00<0RR_R0?ooo`2::n800`000?l00`3o
ool00?ZJ0?ooo`0D0?ooo`0308X[hP3oool0oooo05L0oooo00<000000?ooo`3oool01`3oool000l0
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
05d0oooo0P000?l00`2::n80oooo0?ooo`0;0?ooo`800?ZJ0`3oool00`2::n80oooo08X[hP020?oo
o`040000o`3oool0oooo003jVQD0oooo0P2::n9G0?ooo`030000003oool0oooo00L0oooo000@0?oo
o`800000203oool5000000@0oooo00<000000?ooo`3oool0G@3oool00`000?l0RR_R0000o`0<0?oo
o`03003jVP000?l0oooo00<0oooo00<0RR_R0?ooo`2::n800`3oool010000?l0oooo0?ooo`00nYXF
0?ooo`0308X[hP3oool0oooo05@0oooo00<000000?ooo`3oool01`3oool002<0oooo0P00001M0?oo
o`040000o`2::n80oooo0000o``0oooo00<00?ZJ0?ooo`3oool00`3oool00`2::n80oooo08X[hP03
0?ooo`040000o`3oool0oooo003jVQL0oooo00<0RR_R0?ooo`3oool0DP3oool2000000T0oooo000S
0?ooo`030000003oool0oooo05`0oooo00L0RR_R0?ooo`3oool0oooo0000o`3oool0003o00P0oooo
00<00?ZJ0000o`3oool00`3oool01@2::n80oooo0?ooo`3oool0RR_R0080oooo00D0003o0?ooo`3o
ool0oooo003jVP0G0?ooo`0308X[hP3oool0oooo0580oooo00<000000?ooo`3oool01`3oool002<0
oooo00<000000?ooo`3oool0F`3oool00`2::n80003o0?ooo`020?ooo`<0003o1`3oool00`00nYX0
oooo0000o`040?ooo`0508X[hP3oool0oooo0?ooo`2::n800P3oool00`000?l0oooo0?ooo`020?oo
o`03003jVP3oool0oooo01D0oooo00<0RR_R0?ooo`3oool0D@3oool00`000000oooo0?ooo`070?oo
o`008`3oool00`000000oooo0?ooo`1J0?ooo`0308X[hP000?l0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`00nYX0oooo0000o`040?ooo`0308X[hP3oool0oooo0080oooo00<0RR_R0?ooo`00
0?l01@3oool2003jVQH0oooo00<0RR_R0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00
8`3oool2000005X0oooo00<0RR_R0?ooo`000?l01P3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00@00?ZJ0?ooo`3oool0003o0`3oool00`2::n80oooo0?ooo`040?ooo`0308X[hP3oool0003o
00H0oooo00<00?ZJ0?ooo`3oool0503oool00`2::n80oooo0?ooo`1>0?ooo`8000002@3oool002<0
oooo00<000000?ooo`3oool0F@3oool00`2::n80oooo0000o`070?ooo`060000o`3oool0oooo0000
o`3oool00?ZJ0`3oool01@000?l0oooo0?ooo`3oool0RR_R00H0oooo00<0RR_R0?ooo`000?l01P3o
ool00`00nYX0oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo04h0oooo00<000000?ooo`3oool01`3o
ool002<0oooo00<000000?ooo`3oool0F03oool0102::n80003o0?ooo`000?l70?ooo`060000o`3o
ool0oooo0000o`3oool00?ZJ0P3oool00`000?l0oooo0?ooo`020?ooo`0308X[hP3oool0oooo00D0
oooo00<0RR_R0000o`3oool01P3oool00`00nYX0oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo04d0
oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0E`3oool0102::n80003o
0?ooo`000?l80?ooo`050000o`3oool0oooo0000o`00nYX00`3oool01@000?l0oooo0?ooo`3oool0
RR_R00P0oooo00<0RR_R0000o`3oool01`3oool00`00nYX0oooo0?ooo`0E0?ooo`80RR_RC@3oool0
0`000000oooo0?ooo`070?ooo`008`3oool2000005P0oooo00@0RR_R0000o`3oool0003o203oool0
10000?l0oooo0?ooo`00nYX40?ooo`050000o`3oool0oooo0?ooo`2::n80203oool00`2::n80003o
0?ooo`080?ooo`03003jVP3oool0oooo01H0oooo00<0RR_R0?ooo`3oool0B@3oool2000000T0oooo
000S0?ooo`030000003oool0oooo05H0oooo00<0RR_R0?ooo`000?l02P3oool01@000?l0oooo0?oo
o`00nYX0003o00<0oooo00D0003o0?ooo`3oool0oooo08X[hP090?ooo`0308X[hP3oool0oooo00P0
oooo00<00?ZJ0?ooo`3oool05P3oool00`2::n80oooo0?ooo`190?ooo`030000003oool0oooo00L0
oooo000S0?ooo`030000003oool0oooo05D0oooo00@0RR_R0?ooo`3oool0003o2`3oool2003jVP80
003o0P3oool20000o`80oooo00<0RR_R0?ooo`3oool0203oool00`2::n80oooo0?ooo`080?ooo`03
003jVP3oool0oooo01L0oooo00<0RR_R0?ooo`3oool0B03oool00`000000oooo0?ooo`070?ooo`00
8`3oool00`000000oooo0?ooo`1E0?ooo`0408X[hP3oool0oooo0000o`X0oooo00L00?ZJ0000o`00
0?l0oooo0000o`3oool0003o00@0oooo00<0RR_R0?ooo`3oool0203oool00`2::n80oooo0?ooo`09
0?ooo`03003jVP3oool0oooo01H0oooo00<0RR_R0?ooo`3oool0B03oool00`000000oooo0?ooo`07
0?ooo`008`3oool2000005D0oooo00@0RR_R0?ooo`3oool0003o2`3oool01000nYX0003o0000o`3o
ool20000o`@0oooo00<0RR_R0?ooo`3oool02@3oool00`000?l0RR_R0?ooo`0:0?ooo`03003jVP3o
ool0oooo01H0oooo00<0RR_R0?ooo`3oool0AP3oool2000000T0oooo000:0?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo05<0oooo00D0RR_R0?ooo`3oool0oooo0000o`0:0?ooo`06003jVP3oool0003o0000o`3oool0
003o103oool00`2::n80oooo0?ooo`0:0?ooo`030000o`2::n80oooo00/0oooo00<00?ZJ0?ooo`3o
ool05P3oool00`2::n80oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo00090?ooo`040000
003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0DP3oool00`2::n80oooo0?ooo`020?ooo`030000o`3oool0oooo
00L0oooo00<00?ZJ0?ooo`3oool00P000?l60?ooo`0308X[hP3oool0oooo00X0oooo00<0003o0?oo
o`2::n80303oool00`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3oool0oooo04D0oooo00<000000?oo
o`3oool01`3oool000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0D@3oool00`2::n80oooo0?ooo`030?oo
o`030000o`3oool0oooo00L0oooo00D00?ZJ0?ooo`3oool0oooo0000o`050?ooo`0308X[hP3oool0
oooo00`0oooo00<0003o08X[hP3oool0303oool00`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3oool0
oooo04@0oooo00<000000?ooo`3oool01`3oool000T0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00001A0?ooo`0308X[hP3oool0
oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`00nYX0oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0RR_R0?ooo`3oool0303oool010000?l0oooo08X[hP000?l<0?ooo`03003jVP3o
ool0oooo01H0oooo0P2::n930?ooo`8000002@3oool000T0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo00000003000000D0oooo00<000000?ooo`3oool0D03oool00`2::n80oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<00?ZJ0?ooo`3oool0203oool00`2::n80oooo0?oo
o`0=0?ooo`80003o00<0RR_R0000o`3oool0303oool00`00nYX0oooo0?ooo`0G0?ooo`0308X[hP3o
ool0oooo0440oooo00<000000?ooo`3oool01`3oool000T0oooo00@000000?ooo`3oool000001`3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo0?ooo`1?0?ooo`03
08X[hP3oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`00nYX0oooo0?ooo`080?ooo`03
08X[hP3oool0oooo00d0oooo0P000?l00`3oool0RR_R0?ooo`0=0?ooo`03003jVP3oool0oooo01H0
oooo00<0RR_R0?ooo`3oool0@@3oool00`000000oooo0?ooo`070?ooo`002P3oool2000000P0oooo
1@0000000`3oool0000000000003000000@0oooo00<000000?ooo`3oool0C`3oool00`2::n80oooo
0?ooo`030?ooo`80003o1`3oool00`00nYX0oooo0?ooo`080?ooo`0308X[hP3oool0oooo00h0oooo
0`000?l00`2::n80003o0?ooo`0<0?ooo`03003jVP3oool0oooo01L0oooo00<0RR_R0?ooo`3oool0
@03oool00`000000oooo0?ooo`070?ooo`008`3oool2000004l0oooo00<0RR_R0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`03003jVP3oool0oooo00T0oooo00<0RR_R0?ooo`3oool03P3o
ool01@000?l0oooo0000o`2::n80003o00h0oooo00<00?ZJ0?ooo`3oool05`3oool00`2::n80oooo
0?ooo`0n0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0CP3oool00`2::n80oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<00?ZJ0?ooo`3oool02@3oool00`2::n80oooo0?oo
o`0@0?ooo`030000o`3oool0RR_R00l0oooo00<00?ZJ0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0?0?ooo`0308X[hP3oool0oooo03h0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool0C@3oool00`2::n80oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0P00nYX;
0?ooo`0308X[hP3oool0oooo01<0oooo00<0003o08X[hP3oool03P3oool00`00nYX0oooo0?ooo`04
0?ooo`030000o`3oool0oooo0100oooo00<0RR_R0?ooo`3oool0?@3oool00`000000oooo0?ooo`07
0?ooo`008`3oool00`000000oooo0?ooo`1=0?ooo`0308X[hP3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool00`00nYX0oooo0?ooo`0;0?ooo`0308X[hP3oool0oooo01@0oooo00<0003o08X[
hP3oool03P3oool00`00nYX0oooo0?ooo`020?ooo`80003o4P3oool00`2::n80oooo0?ooo`0m0?oo
o`030000003oool0oooo00L0oooo000S0?ooo`800000C@3oool00`2::n80oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<00?ZJ0?ooo`3oool02P3oool00`2::n80oooo0?ooo`0E0?ooo`03
0000o`2::n80oooo00l0oooo00@00?ZJ0?ooo`3oool0oooo0P000?lC0?ooo`0308X[hP3oool0oooo
03/0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`1;0?ooo`0308X[hP3oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool00`00nYX0oooo0?ooo`0;0?ooo`0308X[hP3oool0oooo01D0
oooo00<0003o0?ooo`2::n80403oool00`00nYX0oooo0?ooo`020000oa@0oooo00<0RR_R0?ooo`3o
ool0>`3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1;0?ooo`0308X[
hP3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo003jVP0=0?ooo`0308X[hP3oool0oooo01L0
oooo00<0003o0?ooo`2::n80403oool01@00nYX0oooo0000o`3oool0003o01@0oooo0P2::n8k0?oo
o`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo04X0oooo00<0RR_R0?ooo`3o
ool01`3oool01@000?l0oooo0?ooo`3oool00?ZJ00d0oooo00<0RR_R0?ooo`3oool05`3oool00`00
0?l0oooo08X[hP0A0?ooo`04003jVP000?l0oooo0000oaH0oooo00<0RR_R0?ooo`3oool0>03oool0
0`000000oooo0?ooo`070?ooo`008`3oool2000004X0oooo00<0RR_R0?ooo`3oool01@3oool30000
o`<0oooo00<00?ZJ0?ooo`3oool02`3oool00`2::n80oooo0?ooo`0H0?ooo`040000o`3oool0oooo
08X[hQ40oooo00<00?ZJ0?ooo`000?l05P3oool00`2::n80oooo0?ooo`0g0?ooo`8000002@3oool0
02<0oooo00<000000?ooo`3oool0B03oool00`2::n80oooo0?ooo`020?ooo`040000o`3oool0oooo
0000o`D0oooo00<00?ZJ0?ooo`3oool02`3oool00`2::n80oooo0?ooo`0I0?ooo`040000o`3oool0
oooo08X[hQ00oooo00@0003o003jVP3oool0003o5`3oool00`2::n80oooo0?ooo`0g0?ooo`030000
003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo04P0oooo00T0RR_R0?ooo`3oool0oooo
0000o`3oool0003o0?ooo`000?l01@3oool00`00nYX0oooo0?ooo`0:0?ooo`0308X[hP3oool0oooo
01/0oooo00@0003o0?ooo`3oool0RR_R3`3oool010000?l0oooo003jVP000?lH0?ooo`0308X[hP3o
ool0oooo03H0oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool01@3oool2
08X[hT00oooo00<0RR_R0?ooo`3oool00P3oool01@000?l0oooo0000o`3oool0003o00@0oooo00<0
0?ZJ0?ooo`3oool02`3oool00`2::n80oooo0?ooo`0K0?ooo`80003o00<0oooo08X[hP3oool03P3o
ool01@000?l0oooo0?ooo`00nYX0003o01P0oooo00<0RR_R0?ooo`3oool0=@3oool00`000000oooo
0?ooo`070?ooo`008`3oool2000000D0oooo00@0RR_R0?ooo`3oool0RR_R?`3oool01@2::n80oooo
0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool00`00nYX0oooo0?ooo`0;0?ooo`03
08X[hP3oool0oooo01d0oooo00@0003o0?ooo`3oool0RR_R3P3oool01@000?l0oooo0?ooo`3oool0
0?ZJ01P0oooo00<0RR_R0?ooo`3oool0=03oool2000000T0oooo000S0?ooo`030000003oool0oooo
00@0oooo00D0RR_R0?ooo`3oool0oooo08X[hP0m0?ooo`0308X[hP3oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0000o`030?ooo`03003jVP3oool0oooo00/0oooo00<0RR_R0?ooo`3oool07P3o
ool010000?l0oooo0?ooo`2::n8>0?ooo`060000o`3oool0oooo0?ooo`000?l00?ZJ603oool00`2:
:n80oooo0?ooo`0d0?ooo`030000003oool0oooo00L0oooo000K0?ooo`<000001@3oool00`000000
oooo0?ooo`030?ooo`0308X[hP3oool0oooo00<0oooo0P2::n8k0?ooo`0308X[hP3oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool00`00nYX0oooo0?ooo`0<0?ooo`0308X[hP3oool0oooo01h0
oooo00D0003o0?ooo`000?l0oooo08X[hP0=0?ooo`060000o`3oool0oooo0?ooo`000?l00?ZJ6@3o
ool00`2::n80oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo000L0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool00`2::n80oooo0?ooo`0g0?ooo`0308X[hP3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`00nYX0oooo0?ooo`0<0?ooo`0308X[hP3oool0
oooo01l0oooo00<0003o0?ooo`000?l00P3oool00`2::n80oooo0?ooo`080?ooo`80003o103oool0
10000?l0oooo003jVP00nYXH0?ooo`0308X[hP3oool0oooo0380oooo00<000000?ooo`3oool01`3o
ool001`0oooo00<000000?ooo`3oool0103oool3000000<0oooo00<00?ZJ0?ooo`3oool01@3oool0
0`2::n80oooo0?ooo`070?ooo`0308X[hP3oool0oooo02d0oooo00<0RR_R0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`03003jVP3oool0oooo00d0oooo00<0RR_R0?ooo`3oool07`3oool0
0`000?l0oooo0000o`030?ooo`0408X[hP3oool0oooo0000o`H0oooo0P000?l50?ooo`040000o`3o
ool0oooo003jVQL0oooo00<0RR_R0?ooo`3oool0<@3oool2000000T0oooo000L0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000?l00?ZJ0?ooo`060?ooo`0308X[hP3o
ool0oooo00<0oooo0`2::n800`3oool0RR_R0?ooo`0/0?ooo`0308X[hP3oool0oooo00@0oooo00<0
003o0?ooo`3oool00P3oool00`00nYX0oooo0?ooo`0<0?ooo`0308X[hP3oool0oooo0200oooo00<0
003o0?ooo`000?l0103oool0102::n80oooo0000o`000?l50?ooo`030000o`3oool0oooo00@0oooo
00D0003o0?ooo`3oool0oooo003jVP0G0?ooo`80RR_R<P3oool00`000000oooo0?ooo`070?ooo`00
703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0003o003jVP3oool0
1P3oool00`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0oooo00<0oooo00<0RR_R0?ooo`3oool0
:P3oool00`2::n80oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`00nYX03`3oool00`2::n80
oooo0?ooo`0Q0?ooo`<0003o0`3oool0102::n80oooo0000o`000?l50?ooo`030000o`3oool0oooo
00@0oooo00H0003o0?ooo`3oool0003o0?ooo`00nYXH0?ooo`0308X[hP3oool0oooo02l0oooo00<0
00000?ooo`3oool01`3oool001/0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<0RR_R
0?ooo`00nYX01`3oool0102::n80oooo0?ooo`2::n840?ooo`040000o`3oool0oooo08X[hR/0oooo
00<0RR_R0?ooo`3oool0103oool010000?l0oooo0?ooo`00nYX?0?ooo`0308X[hP3oool0oooo0280
oooo00@0003o0?ooo`000?l0oooo0`000?l00`2::n80003o0000o`040?ooo`030000o`3oool0oooo
00D0oooo00H0003o0?ooo`3oool0003o0?ooo`00nYXI0?ooo`0308X[hP3oool0oooo02h0oooo00<0
00000?ooo`3oool01`3oool001`0oooo00<000000?ooo`3oool0103oool2000000@0oooo00@0RR_R
0?ooo`3oool00?ZJ1P3oool0102::n80oooo0?ooo`2::n840?ooo`040000o`3oool0003o08X[hRX0
oooo00<0RR_R0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool00?ZJ00h0oooo00<0RR_R0?oo
o`3oool08`3oool020000?l0oooo0000o`3oool0003o0?ooo`000?l0RR_R0P000?l40?ooo`030000
o`3oool0oooo00D0oooo00@0003o0?ooo`000?l0003o0P3oool00`00nYX0oooo0?ooo`0F0?ooo`03
08X[hP3oool0oooo02d0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`030?ooo`0508X[
hP3oool0oooo0?ooo`00nYX01@3oool00`2::n80oooo08X[hP040?ooo`060000o`3oool0003o0000
o`3oool0RR_R:@3oool00`2::n80oooo0?ooo`040?ooo`040000o`3oool0oooo003jVPl0oooo00<0
RR_R0?ooo`3oool08`3oool01P000?l0oooo0000o`3oool0003o0?ooo`80003o00@0RR_R0000o`3o
ool0003o0P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0003o0000o`<0oooo00<00?ZJ
0?ooo`3oool05P3oool00`2::n80oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo000S0?oo
o`030000003oool0oooo00@0oooo00D0RR_R0?ooo`3oool0oooo003jVP040?ooo`0308X[hP3oool0
RR_R00@0oooo00D0003o0?ooo`3oool0oooo0000o`0208X[hRL0oooo00<0RR_R0?ooo`3oool01@3o
ool00`000?l0oooo003jVP0>0?ooo`80RR_R9P3oool01P000?l0oooo0000o`3oool0003o0?ooo`80
003o00<0oooo08X[hP3oool00P000?l00`3oool0003o0?ooo`070?ooo`80003o00<0oooo0000o`3o
ool00P3oool00`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3oool0oooo02`0oooo00<000000?ooo`3o
ool01`3oool002<0oooo00<000000?ooo`3oool0103oool00`2::n80oooo0?ooo`020?ooo`800?ZJ
0`3oool208X[hP@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`0308X[hP3oool0oooo02@0
oooo00<0RR_R0?ooo`3oool01@3oool00`000?l0oooo003jVP0=0?ooo`0308X[hP3oool0oooo02H0
oooo00@0003o0?ooo`000?l0003o0`3oool010000?l0oooo08X[hP3oool20000o`030?ooo`000?l0
oooo00L0oooo00@0003o0?ooo`3oool0003o0`3oool00`00nYX0oooo0?ooo`0F0?ooo`0308X[hP3o
ool0oooo02`0oooo00<000000?ooo`3oool01`3oool002<0oooo0P0000050?ooo`0308X[hP3oool0
oooo00@0oooo00@00?ZJ0?ooo`000?l0RR_R0P3oool00`000?l0oooo0000o`050?ooo`050000o`3o
ool0oooo08X[hP000?l08`3oool00`2::n80oooo0?ooo`060?ooo`030000o`00nYX0oooo00d0oooo
00<0RR_R0?ooo`3oool0:@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00D0RR_R0000o`00
0?l0oooo0000o`080?ooo`040000o`3oool0oooo0000o`@0oooo00<00?ZJ0?ooo`3oool05P3oool0
0`2::n80oooo0?ooo`0Z0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0103oool01P00
0?l0RR_R0?ooo`3oool0003o0?ooo`80003o00<00?ZJ0000o`2::n800P3oool00`000?l0oooo0000
o`020?ooo`@00?ZJ00@0oooo0000o`3oool0RR_R8`3oool00`2::n80oooo0?ooo`060?ooo`03003j
VP3oool0oooo00`0oooo00<0RR_R0?ooo`3oool0:P3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00D0003o08X[hP000?l0oooo0000o`0;0?ooo`030000o`3oool0oooo00<0oooo0P00nYXG0?oo
o`0308X[hP3oool0oooo02X0oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3o
ool0103oool010000?l0RR_R0?ooo`3oool20000o`070?ooo`000?l0oooo003jVP000?l0oooo0000
o`05003jVP<0oooo00D00?ZJ0?ooo`000?l0oooo08X[hP020?ooo`030000o`3oool0oooo01d0oooo
00<0RR_R0?ooo`3oool01P3oool00`00nYX0003o0?ooo`0=0?ooo`0308X[hP3oool0oooo02X0oooo
00<0003o0?ooo`3oool0103oool010000?l0RR_R0?ooo`000?l=0?ooo`80003o1@3oool00`00nYX0
oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo02T0oooo00<000000?ooo`3oool01`3oool002<0oooo
00<000000?ooo`3oool0103oool010000?l0RR_R0?ooo`000?l40?ooo`030000o`3oool00?ZJ0080
0?ZJ203oool00`2::n800?ZJ0000o`020?ooo`0308X[hP3oool0003o01h0oooo00<0RR_R0?ooo`3o
ool01P3oool00`00nYX0oooo0000o`0=0?ooo`0308X[hP3oool0oooo0380oooo00@0003o0?ooo`2:
:n80003o3P3oool00`000?l0oooo0?ooo`040?ooo`03003jVP3oool0oooo01@0oooo00<0RR_R0?oo
o`3oool0:@3oool00`000000oooo0?ooo`070?ooo`008`3oool2000000D0oooo00<0003o0?ooo`2:
:n801@3oool010000?l0oooo0?ooo`000?l90?ooo`0308X[hP00nYX0003o0080oooo00<0RR_R0000
o`000?l07P3oool00`2::n80oooo0?ooo`050?ooo`04003jVP3oool0oooo0000o``0oooo00<0RR_R
0?ooo`3oool0<`3oool010000?l0oooo08X[hP000?l>0?ooo`030000o`3oool0oooo00@0oooo00<0
0?ZJ0?ooo`3oool05@3oool208X[hRP0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`04
0?ooo`030000o`3oool0RR_R00D0oooo00<0003o0?ooo`3oool02P3oool00`2::n80003o003jVP02
0?ooo`030000o`2::n80003o01d0oooo00<0RR_R0?ooo`3oool01P3oool00`00nYX0oooo0000o`0<
0?ooo`0308X[hP3oool0oooo03@0oooo00<0003o0?ooo`3oool00P2::n8=0?ooo`030000o`3oool0
oooo00D0oooo00<00?ZJ0?ooo`3oool05P3oool00`2::n80oooo0?ooo`0V0?ooo`030000003oool0
oooo00L0oooo000S0?ooo`030000003oool0oooo00@0oooo00@0003o0?ooo`000?l0RR_R1P3oool0
0`2::n80oooo0?ooo`070?ooo`80RR_R00<0003o003jVP3oool00P3oool00`2::n80oooo0000o`0L
0?ooo`0308X[hP3oool0oooo00D0oooo00@00?ZJ0?ooo`3oool0003o303oool00`2::n80oooo0?oo
o`0i0?ooo`0308X[hP3oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`00nYX0oooo0?oo
o`0E0?ooo`0308X[hP3oool0oooo02H0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool01@3oool20000o`030?ooo`2::n80oooo00@0oooo00<0RR_R0?ooo`3oool01`3oool0
102::n80oooo08X[hP00nYX30?ooo`0308X[hP3oool0003o01L0oooo00<0003o0?ooo`3oool00P3o
ool00`2::n80oooo0?ooo`020?ooo`040000o`3oool00?ZJ0000o`80oooo00<0003o0?ooo`3oool0
2@3oool00`2::n80oooo0?ooo`0j0?ooo`0308X[hP3oool0oooo00X0oooo00<0003o0?ooo`3oool0
1`3oool00`00nYX0oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo02D0oooo00<000000?ooo`3oool0
1`3oool002<0oooo00<000000?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool208X[hP80oooo
00<0RR_R0?ooo`2::n80203oool01@2::n80oooo08X[hP3oool00?ZJ00<0oooo00<0RR_R0000o`3o
ool05P3oool01P000?l0oooo0?ooo`3oool0RR_R0000o`80oooo00D0003o0?ooo`000?l0oooo003j
VP020000o`030?ooo`000?l0oooo00T0oooo00<0RR_R0?ooo`3oool0?03oool00`2::n80oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00L0oooo00<00?ZJ0?ooo`3oool05@3oool00`2::n80oooo0?oo
o`0T0?ooo`030000003oool0oooo00L0oooo000S0?ooo`8000001P3oool00`000?l0oooo0?ooo`03
0?ooo`80RR_R0P3oool00`2::n80oooo0?ooo`050?ooo`0408X[hP3oool0oooo08X[hP80oooo00D0
0?ZJ0?ooo`3oool0RR_R0000o`0G0?ooo`060000o`3oool0oooo0?ooo`2::n80003o0P3oool30000
o`03003jVP000?l0oooo0080003o2`3oool00`2::n80oooo0?ooo`0m0?ooo`0308X[hP3oool0oooo
00T0oooo00<0003o0?ooo`3oool01`3oool00`00nYX0oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo
02<0oooo0P0000090?ooo`002@3oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?oo
o`<000001@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0RR_R0?oo
o`3oool00`3oool01@2::n80oooo0?ooo`3oool0RR_R0080oooo00D00?ZJ0?ooo`3oool0RR_R0000
o`0G0?ooo`0=0000o`3oool0oooo0?ooo`2::n80003o0?ooo`000?l0oooo0000o`00nYX0oooo0000
o`020?ooo`030000o`3oool0oooo00L0oooo0P2::n900?ooo`0308X[hP3oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`00nYX0oooo0?ooo`0E0?ooo`0308X[hP3oool0oooo02<0oooo00<0
00000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`D0RR_R
103oool01@2::n80oooo0?ooo`3oool00?ZJ0080oooo00<0RR_R0?ooo`3oool03P3oool308X[hP@0
oooo0P000?l20?ooo`0408X[hP3oool0003o0000o`80oooo00<00?ZJ0?ooo`000?l02`3oool00`2:
:n80oooo0?ooo`110?ooo`0308X[hP3oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool2003j
VQH0oooo00<0RR_R0?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0K0?ooo`0408X[hP3oool0oooo003jVP80oooo00<0RR_R0?ooo`3oool0303oool208X[
hP<0oooo102::n801P3oool0003o0?ooo`2::n80003o0?ooo`80003o00<0oooo003jVP3oool00P00
0?l:0?ooo`0308X[hP3oool0oooo04<0oooo00<0RR_R0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0;0?ooo`03003jVP3oool0oooo01<0oooo00<0RR_R0?ooo`3oool08P3oool00`000000oooo0?oo
o`070?ooo`002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool3000001/0oooo00@0RR_R0?ooo`3oool00?ZJ0P3oool00`2::n80oooo0?oo
o`090?ooo`<0RR_R203oool02P000?l0RR_R0000o`3oool0RR_R0000o`3oool0003o0?ooo`00nYX2
0?ooo`80003o2P3oool00`2::n80oooo0?ooo`130?ooo`0308X[hP3oool0oooo00L0oooo00<0003o
0?ooo`3oool0303oool00`00nYX0oooo0?ooo`0C0?ooo`0308X[hP3oool0oooo0200oooo0P000009
0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0?ooo`000000oooo1000
00050?ooo`030000003oool0oooo01/0oooo00L0RR_R0?ooo`3oool0oooo003jVP3oool0RR_R00X0
oooo00<0RR_R0?ooo`3oool02@3oool01@000?l0RR_R0000o`3oool0RR_R0080oooo00<0003o003j
VP3oool00P3oool00`000?l0oooo0?ooo`080?ooo`0308X[hP3oool0oooo04D0oooo00<0RR_R0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`03003jVP3oool0oooo01<0oooo00<0RR_R0?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool2000000T0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000P0oooo00<000000?ooo`3oool06`3oool01@2::n80oooo0?ooo`3o
ool00?ZJ0080oooo00<0RR_R0?ooo`3oool01P3oool00`2::n80oooo0?ooo`0:0?ooo`050000o`3o
ool0RR_R0?ooo`2::n800P3oool00`00nYX0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo
00<0RR_R0?ooo`3oool0A`3oool00`2::n80oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo
00<00?ZJ0?ooo`3oool04`3oool00`2::n80oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
000:0?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`D00000103oool00`000000oooo0?oo
o`0L0?ooo`0408X[hP3oool0oooo003jVP80oooo00<0RR_R0?ooo`3oool01@3oool00`2::n80oooo
0?ooo`0;0?ooo`070000o`3oool0RR_R08X[hP000?l0oooo003jVP0>0?ooo`0308X[hP3oool0oooo
04P0oooo00<0RR_R0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?ooo`03003jVP3oool0oooo
01<0oooo00<0RR_R0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`008`3oool2000001d0
oooo00L0RR_R0?ooo`3oool0oooo003jVP3oool0RR_R00H0oooo00<0RR_R0?ooo`3oool0303oool0
10000?l0oooo0000o`2::n820?ooo`03003jVP3oool0oooo00/0oooo00<0RR_R0?ooo`3oool0BP3o
ool00`2::n80oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo00<00?ZJ0?ooo`3oool04`3o
ool00`2::n80oooo0?ooo`0M0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool07@3oool0
1P2::n80oooo0?ooo`00nYX0oooo08X[hPH0oooo00<0RR_R0?ooo`3oool02`3oool01`000?l0oooo
0?ooo`3oool0RR_R0?ooo`00nYX03@3oool00`2::n80oooo0?ooo`1<0?ooo`0308X[hP3oool0oooo
00@0oooo00<0003o0?ooo`3oool03`3oool00`00nYX0oooo0?ooo`0C0?ooo`0308X[hP3oool0oooo
01d0oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool07@3oool01`2::n80
oooo0?ooo`00nYX0oooo0000o`2::n80103oool00`2::n80oooo0?ooo`0<0?ooo`060000o`3oool0
oooo0?ooo`000?l00?ZJ303oool208X[hU00oooo00<0RR_R0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0?0?ooo`03003jVP3oool0oooo01@0oooo00<0RR_R0?ooo`3oool0703oool00`000000oooo
0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0N0?ooo`0608X[hP3oool0oooo003jVP000?l0
RR_R103oool00`2::n80oooo0?ooo`0<0?ooo`060000o`3oool0oooo0?ooo`000?l00?ZJ2`3oool0
0`2::n80oooo0?ooo`1A0?ooo`0308X[hP3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool0
0`00nYX0oooo0?ooo`0C0?ooo`0308X[hP3oool0oooo01`0oooo00<000000?ooo`3oool01`3oool0
02<0oooo0P00000O0?ooo`0608X[hP3oool0oooo003jVP000?l0RR_R0`3oool00`2::n80oooo0?oo
o`0=0?ooo`030000o`3oool00?ZJ00800?ZJ2`3oool00`2::n80oooo0?ooo`1C0?ooo`0508X[hP3o
ool0oooo0?ooo`000?l04`3oool2003jVQ@0oooo00<0RR_R0?ooo`3oool06P3oool2000000T0oooo
000S0?ooo`030000003oool0oooo01h0oooo00H0RR_R0?ooo`3oool00?ZJ0000o`2::n830?ooo`03
08X[hP3oool0oooo00`0oooo0`00nYX=0?ooo`0308X[hP3oool0oooo05D0oooo00@0RR_R0?ooo`3o
ool0003o5@3oool00`00nYX0oooo0?ooo`0A0?ooo`0308X[hP3oool0oooo01/0oooo00<000000?oo
o`3oool01`3oool002<0oooo00<000000?ooo`3oool07`3oool01@2::n80oooo0?ooo`00nYX0RR_R
0080oooo00<0RR_R0?ooo`3oool02`3oool2003jVP030000o`3oool0oooo0080oooo00<0RR_R0?oo
o`3oool01`3oool00`2::n80oooo0?ooo`1F0?ooo`0408X[hP3oool0oooo0000oaH0oooo00<00?ZJ
0?ooo`3oool04@3oool00`2::n80oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo000S0?oo
o`030000003oool0oooo01l0oooo00D0RR_R0?ooo`3oool00?ZJ08X[hP020?ooo`0308X[hP3oool0
oooo00T0oooo0P00nYX20?ooo`030000o`3oool0oooo0080oooo00<0RR_R0?ooo`3oool01P3oool0
0`2::n80oooo0?ooo`1H0?ooo`0408X[hP3oool0oooo0000oa00oooo00<0003o0?ooo`3oool00P3o
ool00`00nYX0oooo0?ooo`0B0?ooo`0308X[hP3oool0oooo01T0oooo00<000000?ooo`3oool01`3o
ool002<0oooo0P00000P0?ooo`0508X[hP3oool0oooo003jVP000?l00P2::n8:0?ooo`800?ZJ103o
ool00`000?l0oooo0?ooo`020?ooo`80RR_R1@3oool208X[hU`0oooo00<0RR_R0?ooo`000?l0403o
ool00`000?l0oooo0?ooo`030?ooo`03003jVP3oool0oooo0140oooo00<0RR_R0?ooo`3oool0603o
ool2000000T0oooo000S0?ooo`030000003oool0oooo0200oooo00@0RR_R0?ooo`3oool00?ZJ0P2:
:n860?ooo`@00?ZJ1P3oool01@000?l0oooo0?ooo`3oool0RR_R0080oooo1@2::n9N0?ooo`0308X[
hP3oool0003o0100oooo0P000?l50?ooo`03003jVP3oool0oooo00X0oooo00<0003o0?ooo`3oool0
103oool00`2::n80oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003o
ool0oooo0200oooo00D0RR_R0?ooo`3oool00?ZJ08X[hP050?ooo`800?ZJ2P3oool01@000?l0oooo
0?ooo`3oool0RR_R06H0oooo00<0RR_R0000o`3oool03`3oool20000o`H0oooo00<00?ZJ0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`2::n80oooo0?ooo`0H0?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo0200oooo00D0RR_R0?ooo`3oool0
0?ZJ0000o`030?ooo`800?ZJ2P3oool20000o`@0oooo00<0RR_R0?ooo`3oool0I@3oool01P2::n80
003o0000o`000?l0oooo0000o`X0oooo00<0003o0?ooo`000?l01P3oool00`00nYX0oooo0?ooo`02
0?ooo`80003o103oool010000?l0oooo0?ooo`000?l50?ooo`0308X[hP3oool0oooo01L0oooo00<0
00000?ooo`3oool01`3oool002<0oooo0P00000R0?ooo`0308X[hP3oool0oooo00@00?ZJ303oool2
0000o`<0oooo00<0RR_R0?ooo`3oool0I`3oool01@2::n80oooo0000o`3oool0003o00X0oooo00<0
003o0?ooo`000?l01`3oool01P00nYX0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`030?ooo`0308X[hP3oool0oooo01H0oooo0P0000090?ooo`00
3`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0
8@3oool0102::n80oooo0?ooo`00nYX?0?ooo`80003o0`3oool00`2::n80oooo0?ooo`1X0?ooo`04
08X[hP000?l0oooo0000o`P0oooo00D0003o0?ooo`000?l0oooo0000o`080?ooo`03003jVP3oool0
003o0080oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00@0oooo0P2:
:n8G0?ooo`030000003oool0oooo00L0oooo000@0?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0280oooo00<0RR_R0?ooo`000?l03P3o
ool00`000?l0oooo0000o`020?ooo`0308X[hP3oool0oooo06X0oooo00<0RR_R0000o`000?l0203o
ool01@000?l0oooo0000o`3oool0003o00T0oooo0P00nYX30?ooo`80003o00D0oooo0000o`3oool0
oooo0000o`080?ooo`0308X[hP3oool0oooo01@0oooo00<000000?ooo`3oool01`3oool00100oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo
00@0RR_R0?ooo`2::n80003o3@3oool01@000?l0oooo0?ooo`3oool0RR_R06h0oooo00@0RR_R0?oo
o`000?l0003o1@3oool20000o`040?ooo`000?l0oooo0000o`T0oooo00<0003o0?ooo`00nYX00`3o
ool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00H0oooo00<0RR_R0?ooo`3oool0503o
ool00`000000oooo0?ooo`070?ooo`00403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0080oooo0`00000S0?ooo`80RR_R00<0003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`2:
:n9`0?ooo`0308X[hP000?l0003o00D0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool00?ZJ00<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`060?ooo`0308X[hP3oool0oooo0180oooo0P0000090?ooo`00403oool00`000000oooo0?ooo`07
0?ooo`@000001@3oool00`000000oooo0?ooo`0U0?ooo`0308X[hP3oool0oooo00/0oooo00<0003o
0?ooo`2::n80L@3oool01P2::n80003o0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00nYX00`3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0RR_R0?ooo`3oool04`3oool00`000000
oooo0?ooo`070?ooo`003`3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0V0?ooo`0308X[hP3oool0oooo00X0oooo00<0003o08X[hP3oool0LP3oool01@2::n80oooo
0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00`3oool01P000?l0oooo0?ooo`3oool0003o
0?ooo`80003o1@3oool01000nYX0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo00L0oooo00<0
RR_R0?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`00403oool00`000000oooo0?ooo`07
0?ooo`D00000103oool00`000000oooo0?ooo`0V0?ooo`0308X[hP3oool0oooo00H0oooo00D0003o
0?ooo`3oool0oooo08X[hP1e0?ooo`0408X[hP3oool0003o0?ooo`80003o1P3oool30000o`040?oo
o`000?l0oooo0000o`L0oooo00<00?ZJ0?ooo`000?l0103oool00`000?l0oooo0?ooo`070?ooo`03
08X[hP3oool0oooo0180oooo00<000000?ooo`3oool01`3oool002<0oooo0P00000W0?ooo`030000
o`2::n80oooo00H0oooo00@0003o0?ooo`3oool0RR_RM`3oool00`2::n80003o0?ooo`020000o`H0
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l90?ooo`03003jVP000?l0oooo00<0oooo00<0003o
0?ooo`3oool0203oool00`2::n80oooo0?ooo`0@0?ooo`8000002@3oool002<0oooo00<000000?oo
o`3oool09`3oool00`000?l0RR_R08X[hP050?ooo`040000o`2::n80RR_R0000ogP0oooo00@0RR_R
0?ooo`000?l0003o2`3oool00`000?l0oooo0?ooo`070?ooo`03003jVP000?l0oooo00<0oooo00<0
003o0?ooo`000?l0203oool00`2::n80oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo000S
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool01P2::n800`000?l0oooo0000o`1h
0?ooo`0408X[hP3oool0oooo0000oaH0oooo00<00?ZJ0?ooo`3oool00P3oool00`000?l0oooo0000
o`090?ooo`0308X[hP3oool0oooo0100oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool09`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00D0003o0?ooo`000?l0oooo
0000o`1i0?ooo`80RR_R603oool00`00nYX0oooo0?ooo`020?ooo`80003o2@3oool00`2::n80oooo
0?ooo`0@0?ooo`030000003oool0oooo00L0oooo000S0?ooo`800000:03oool00`000?l0oooo0?oo
o`020000o`80oooo00@0003o0?ooo`3oool0003oO03oool00`2::n80oooo0?ooo`0F0?ooo`800?ZJ
0P3oool20000o`X0oooo00<0RR_R0?ooo`3oool03P3oool2000000T0oooo000S0?ooo`030000003o
ool0oooo02L0oooo00<0003o0?ooo`3oool00P000?l20?ooo`040000o`3oool0oooo0000ogd0oooo
00<0RR_R0?ooo`3oool05`3oool01000nYX0oooo0000o`000?l:0?ooo`0308X[hP3oool0oooo00l0
oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool09`3oool020000?l0oooo
0?ooo`000?l0oooo0000o`3oool0003oP@3oool00`2::n80oooo0?ooo`0F0?ooo`04003jVP3oool0
oooo0000o`/0oooo00<0RR_R0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`008`3oool0
0`000000oooo0?ooo`0W0?ooo`080000o`3oool0oooo0000o`3oool0003o0?ooo`000?n10?ooo`03
08X[hP3oool0oooo01L0oooo00<00?ZJ0?ooo`000?l02`3oool00`2::n80oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`800000:03oool020000?l0oooo0?ooo`000?l0oooo0000
o`3oool0003oPP3oool00`2::n80oooo0?ooo`0G0?ooo`03003jVP3oool0003o00H0oooo00H0003o
0?ooo`3oool0oooo0000o`2::n8>0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0:03o
ool010000?l0oooo0000o`3oool20000oh@0oooo00<0RR_R0?ooo`3oool05`3oool00`00nYX0003o
0?ooo`050?ooo`070000o`3oool0oooo0?ooo`000?l0oooo08X[hP0>0?ooo`030000003oool0oooo
00L0oooo000S0?ooo`030000003oool0oooo02P0oooo0P000?l30?ooo`030000o`3oool0oooo08<0
oooo00<0RR_R0?ooo`3oool05`3oool00`00nYX0oooo0?ooo`040?ooo`80003o0P3oool010000?l0
oooo0?ooo`2::n8=0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo02P0
oooo0P000?l30?ooo`030000o`3oool0oooo08@0oooo00<0RR_R0?ooo`3oool05P3oool00`00nYX0
oooo0?ooo`040?ooo`80003o00<0oooo0000o`000?l00P3oool00`2::n80003o0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`800000:@3oool20000oh/0oooo0P2::n8F0?ooo`030000
o`00nYX0oooo00@0oooo0P000?l0103oool0003o0?ooo`000?l20?ooo`0308X[hP000?l0oooo00T0
oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`0X0?ooo`80003oS@3oool00`2::n80oooo
0?ooo`0C0?ooo`030000o`3oool00?ZJ00@0oooo0P000?l0103oool0003o0?ooo`000?l20?ooo`03
08X[hP000?l0oooo00X0oooo00<000000?ooo`3oool01`3oool000T0oooo0`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0
:03oool20000ohd0oooo00<0RR_R0?ooo`3oool0503oool030000?l0oooo003jVP00nYX0oooo0000
o`3oool0003o0?ooo`000?l0oooo0000o`80oooo00<0003o08X[hP3oool02P3oool00`000000oooo
0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;P0oooo00<0RR_R0?ooo`3oool0
4`3oool030000?l0oooo0?ooo`3oool00?ZJ0000o`3oool0003o0?ooo`000?l0oooo0000o`80oooo
00<0003o08X[hP3oool02P3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool300000;T0oooo00<0
RR_R0?ooo`3oool04`3oool02`000?l0oooo0?ooo`00nYX0003o0?ooo`000?l0oooo0000o`3oool0
003o0080oooo00<0003o0?ooo`2::n802@3oool2000000T0oooo000:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0;X0oooo00<0RR_R0?ooo`3oool04P3oool01@000?l0oooo0?ooo`3oool00?ZJ0080oooo0P000?l2
0?ooo`80003o0P3oool00`2::n80oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo000:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo
0;/0oooo00<0RR_R0?ooo`3oool04@3oool020000?l0oooo0?ooo`3oool0003o003jVP3oool0003o
0`3oool20000o`80oooo00<0RR_R0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`002@3o
ool2000000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool0_03oool00`2::n80oooo0?ooo`0@0?ooo`080000o`3oool0oooo0?ooo`000?l0oooo003jVP00
0?l30?ooo`80003o0P3oool00`000?l0RR_R0?ooo`080?ooo`030000003oool0oooo00L0oooo000:
0?ooo`030000003oool0oooo00L0oooo1@0000000`3oool0000000000003000000@0oooo0P00002n
0?ooo`0308X[hP3oool0oooo00l0oooo00P0003o0?ooo`3oool0oooo0000o`3oool00?ZJ0000o`@0
oooo00D0003o0?ooo`3oool0oooo08X[hP080?ooo`8000002@3oool002<0oooo00<000000?ooo`3o
ool0_P3oool208X[hPl0oooo00@0003o0?ooo`3oool0003o0`3oool00`00nYX0oooo0?ooo`020?oo
o`060000o`3oool0oooo0?ooo`000?l0RR_R203oool00`000000oooo0?ooo`070?ooo`008`3oool0
0`000000oooo0?ooo`300?ooo`0308X[hP3oool0oooo00d0oooo00<0003o0?ooo`000?l0103oool0
0`00nYX0oooo0?ooo`050?ooo`030000o`2::n80oooo00L0oooo00<000000?ooo`3oool01`3oool0
02<0oooo00<000000?ooo`3oool0`@3oool00`2::n80oooo0?ooo`0<0?ooo`030000o`3oool0003o
00D0oooo00<00?ZJ0?ooo`3oool0103oool00`000?l0RR_R0?ooo`070?ooo`030000003oool0oooo
00L0oooo000S0?ooo`800000``3oool00`2::n80oooo0?ooo`0;0?ooo`80003o1`3oool00`00nYX0
oooo0?ooo`040?ooo`030000o`2::n80oooo00D0oooo0P0000090?ooo`008`3oool00`000000oooo
0?ooo`330?ooo`0308X[hP3oool0oooo00X0oooo0P000?l80?ooo`03003jVP3oool0oooo00<0oooo
00<0003o08X[hP3oool01P3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?oo
o`340?ooo`0308X[hP3oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`00nYX0oooo0?oo
o`020?ooo`030000o`2::n80oooo00H0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool0a@3oool00`2::n80oooo0?ooo`0D0?ooo`07003jVP3oool0oooo0?ooo`000?l0oooo
08X[hP060?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo0<H0oooo00<0
RR_R0?ooo`3oool0503oool01P00nYX0oooo0?ooo`000?l0oooo08X[hPH0oooo00<000000?ooo`3o
ool01`3oool002<0oooo0P0000380?ooo`80RR_R5@3oool01@00nYX0oooo0000o`3oool0RR_R00D0
oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`390?ooo`0308X[hP3oool0oooo0180oooo
00<00?ZJ0?ooo`000?l00P3oool00`2::n80oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
000S0?ooo`030000003oool0oooo0<X0oooo00<0RR_R0?ooo`3oool04P3oool01@00nYX0003o0?oo
o`3oool0RR_R00D0oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0b`3o
ool00`2::n80oooo0?ooo`0B0?ooo`04003jVP000?l0oooo08X[hPD0oooo00<000000?ooo`3oool0
1`3oool002<0oooo0P00003=0?ooo`0308X[hP3oool0oooo0180oooo00@00?ZJ0?ooo`3oool0RR_R
0`3oool2000000T0oooo000J0?ooo`D00000103oool00`000000oooo0?ooo`3=0?ooo`80RR_R4P3o
ool00`000?l00?ZJ0?ooo`050?ooo`030000003oool0oooo00L0oooo000K0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0c`3oool00`2::n80oooo0?ooo`0?0?ooo`040000o`3o
ool00?ZJ0000o`@0oooo00<000000?ooo`3oool01`3oool001`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3@0?ooo`80RR_R3`3oool010000?l0oooo0000o`00nYX40?ooo`030000
003oool0oooo00L0oooo000M0?ooo`030000003oool0oooo00<0oooo0`00003B0?ooo`80RR_R3@3o
ool20000o`D0oooo0P0000090?ooo`006P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0e03oool00`2::n80oooo0?ooo`0=0?ooo`0308X[hP3oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool001X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0=D0oooo0P2::n8=0?ooo`0308X[hP3oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool001/0oooo0`0000050?ooo`030000003oool0oooo0=L0oooo0P2::n8:0?ooo`0308X[hP3oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool002<0oooo0P00003J0?ooo`<0RR_R1@3oool208X[
hPD0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`3L0?ooo`D0RR_R203oool00`000000
oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo00L0oooo
000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002<0oooo0P000004
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3o
ool2000000T0oooo000S0?ooond000002@3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo
6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00840oooo100000020?ooo`050000003oool00000
0?ooo`0000000P3oool3000000<0oooo0`0000040?ooo`8000000P3oool6000000040?ooo`000000
0000000000<0oooo1000001Y0?ooo`00Q@3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000JP3o
ool00880oooo0`0000020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`000000oooo
00D0000000D0oooo0000003oool0oooo0000001Z0?ooo`00P@3oool00`000000oooo0?ooo`030?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`1X0?ooo`00PP3oool4000000050?ooo`00000000000?oo
o`0000000`3oool3000000<0oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`0000030?oo
o`<00000JP3oool009X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo06P0oooo002J0?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`800000
JP3oool00?l0oooo6P3oool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-0.183001, 0.168806, \
0.00444568, 0.0122858}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{{filter1,glatt1}},DisplayFunction->$\
DisplayFunction]]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .30902 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00735755 0.47619 [
[ 0 0 0 0 ]
[ 1 .30902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .30902 L
0 .30902 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00735755 0.5 0.301659 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.1081 0.342532 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06317 -18 -4.5 ]
[-0.0125 .06317 0 4.5 ]
[-0.0125 .1488 -24 -4.5 ]
[-0.0125 .1488 0 4.5 ]
[-0.0125 .23443 -6 -4.5 ]
[-0.0125 .23443 0 4.5 ]
[-0.0125 .32007 -24 -4.5 ]
[-0.0125 .32007 0 4.5 ]
[-0.0125 .4057 -18 -4.5 ]
[-0.0125 .4057 0 4.5 ]
[-0.0125 .49133 -24 -4.5 ]
[-0.0125 .49133 0 4.5 ]
[-0.0125 .57696 -6 -4.5 ]
[-0.0125 .57696 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[.97619 .57149 -5 -6 ]
[.97619 .57149 5 6 ]
[.97619 .57208 -5 -6 ]
[.97619 .57208 5 6 ]
[.97619 .58153 -5 -6 ]
[.97619 .58153 5 6 ]
[.97619 .56262 -5 -6 ]
[.97619 .56262 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06317 m
.00625 .06317 L
s
[(0.5)] -0.0125 .06317 1 0 Mshowa
0 .1488 m
.00625 .1488 L
s
[(0.75)] -0.0125 .1488 1 0 Mshowa
0 .23443 m
.00625 .23443 L
s
[(1)] -0.0125 .23443 1 0 Mshowa
0 .32007 m
.00625 .32007 L
s
[(1.25)] -0.0125 .32007 1 0 Mshowa
0 .4057 m
.00625 .4057 L
s
[(1.5)] -0.0125 .4057 1 0 Mshowa
0 .49133 m
.00625 .49133 L
s
[(1.75)] -0.0125 .49133 1 0 Mshowa
0 .57696 m
.00625 .57696 L
s
[(2)] -0.0125 .57696 1 0 Mshowa
.125 Mabswid
0 .08029 m
.00375 .08029 L
s
0 .09742 m
.00375 .09742 L
s
0 .11455 m
.00375 .11455 L
s
0 .13167 m
.00375 .13167 L
s
0 .16593 m
.00375 .16593 L
s
0 .18305 m
.00375 .18305 L
s
0 .20018 m
.00375 .20018 L
s
0 .21731 m
.00375 .21731 L
s
0 .25156 m
.00375 .25156 L
s
0 .26869 m
.00375 .26869 L
s
0 .28581 m
.00375 .28581 L
s
0 .30294 m
.00375 .30294 L
s
0 .33719 m
.00375 .33719 L
s
0 .35432 m
.00375 .35432 L
s
0 .37145 m
.00375 .37145 L
s
0 .38857 m
.00375 .38857 L
s
0 .42283 m
.00375 .42283 L
s
0 .43995 m
.00375 .43995 L
s
0 .45708 m
.00375 .45708 L
s
0 .47421 m
.00375 .47421 L
s
0 .50846 m
.00375 .50846 L
s
0 .52558 m
.00375 .52558 L
s
0 .54271 m
.00375 .54271 L
s
0 .55984 m
.00375 .55984 L
s
0 .04604 m
.00375 .04604 L
s
0 .02891 m
.00375 .02891 L
s
0 .01179 m
.00375 .01179 L
s
0 .59409 m
.00375 .59409 L
s
0 .61122 m
.00375 .61122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06317 m
1 .06317 L
s
.99375 .1488 m
1 .1488 L
s
.99375 .23443 m
1 .23443 L
s
.99375 .32007 m
1 .32007 L
s
.99375 .4057 m
1 .4057 L
s
.99375 .49133 m
1 .49133 L
s
.99375 .57696 m
1 .57696 L
s
.125 Mabswid
.99625 .08029 m
1 .08029 L
s
.99625 .09742 m
1 .09742 L
s
.99625 .11455 m
1 .11455 L
s
.99625 .13167 m
1 .13167 L
s
.99625 .16593 m
1 .16593 L
s
.99625 .18305 m
1 .18305 L
s
.99625 .20018 m
1 .20018 L
s
.99625 .21731 m
1 .21731 L
s
.99625 .25156 m
1 .25156 L
s
.99625 .26869 m
1 .26869 L
s
.99625 .28581 m
1 .28581 L
s
.99625 .30294 m
1 .30294 L
s
.99625 .33719 m
1 .33719 L
s
.99625 .35432 m
1 .35432 L
s
.99625 .37145 m
1 .37145 L
s
.99625 .38857 m
1 .38857 L
s
.99625 .42283 m
1 .42283 L
s
.99625 .43995 m
1 .43995 L
s
.99625 .45708 m
1 .45708 L
s
.99625 .47421 m
1 .47421 L
s
.99625 .50846 m
1 .50846 L
s
.99625 .52558 m
1 .52558 L
s
.99625 .54271 m
1 .54271 L
s
.99625 .55984 m
1 .55984 L
s
.99625 .04604 m
1 .04604 L
s
.99625 .02891 m
1 .02891 L
s
.99625 .01179 m
1 .01179 L
s
.99625 .59409 m
1 .59409 L
s
.99625 .61122 m
1 .61122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filtered) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .57149 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.006 w
.02381 .23443 m
.02857 .27685 L
.03333 .30767 L
.0381 .28323 L
.04286 .27821 L
.04762 .27208 L
.05238 .27684 L
.05714 .26856 L
.0619 .28942 L
.06667 .26733 L
.07143 .28137 L
.07619 .28216 L
.08095 .28158 L
.08571 .26702 L
.09048 .27511 L
.09524 .26054 L
.1 .245 L
.10476 .25463 L
.10952 .25036 L
.11429 .26316 L
.11905 .26662 L
.12381 .30245 L
.12857 .27136 L
.13333 .26684 L
.1381 .28841 L
.14286 .28792 L
.14762 .2757 L
.15238 .30299 L
.15714 .34494 L
.1619 .37102 L
.16667 .39455 L
.17143 .41453 L
.17619 .42973 L
.18095 .48215 L
.18571 .48107 L
.19048 .4377 L
.19524 .43137 L
.2 .45606 L
.20476 .46862 L
.20952 .41731 L
.21429 .42673 L
.21905 .44343 L
.22381 .43071 L
.22857 .40603 L
.23333 .38509 L
.2381 .39736 L
.24286 .36258 L
.24762 .33174 L
.25238 .29482 L
.25714 .3231 L
Mistroke
.2619 .35443 L
.26667 .31928 L
.27143 .32274 L
.27619 .29215 L
.28095 .32727 L
.28571 .30035 L
.29048 .30879 L
.29524 .29442 L
.3 .32884 L
.30476 .31194 L
.30952 .29039 L
.31429 .30539 L
.31905 .31093 L
.32381 .27709 L
.32857 .22216 L
.33333 .20628 L
.3381 .20505 L
.34286 .20831 L
.34762 .22176 L
.35238 .20378 L
.35714 .19878 L
.3619 .20021 L
.36667 .19715 L
.37143 .16321 L
.37619 .16036 L
.38095 .14808 L
.38571 .10734 L
.39048 .10486 L
.39524 .11387 L
.4 .08004 L
.40476 .07269 L
.40952 .06742 L
.41429 .07677 L
.41905 .08836 L
.42381 .08962 L
.42857 .0865 L
.43333 .11263 L
.4381 .14799 L
.44286 .09691 L
.44762 .13662 L
.45238 .13264 L
.45714 .12968 L
.4619 .12387 L
.46667 .12268 L
.47143 .08469 L
.47619 .04883 L
.48095 .03241 L
.48571 .03978 L
.49048 .05429 L
.49524 .04392 L
Mistroke
.5 .0397 L
.50476 .06775 L
.50952 .06917 L
.51429 .07117 L
.51905 .07935 L
.52381 .11716 L
.52857 .16642 L
.53333 .15262 L
.5381 .17015 L
.54286 .14731 L
.54762 .16765 L
.55238 .19459 L
.55714 .2122 L
.5619 .21401 L
.56667 .26138 L
.57143 .22693 L
.57619 .24994 L
.58095 .27486 L
.58571 .24522 L
.59048 .24543 L
.59524 .26983 L
.6 .23211 L
.60476 .23915 L
.60952 .28866 L
.61429 .25349 L
.61905 .26024 L
.62381 .28271 L
.62857 .22768 L
.63333 .23278 L
.6381 .21691 L
.64286 .18456 L
.64762 .17123 L
.65238 .20281 L
.65714 .21801 L
.6619 .24369 L
.66667 .269 L
.67143 .24178 L
.67619 .26524 L
.68095 .27338 L
.68571 .27743 L
.69048 .32324 L
.69524 .34441 L
.7 .38609 L
.70476 .38481 L
.70952 .38675 L
.71429 .40086 L
.71905 .3861 L
.72381 .40895 L
.72857 .40346 L
.73333 .40949 L
Mistroke
.7381 .42411 L
.74286 .4102 L
.74762 .43079 L
.75238 .40186 L
.75714 .39356 L
.7619 .40858 L
.76667 .3965 L
.77143 .36773 L
.77619 .38184 L
.78095 .42057 L
.78571 .41756 L
.79048 .42426 L
.79524 .41524 L
.8 .42591 L
.80476 .41381 L
.80952 .41332 L
.81429 .41031 L
.81905 .40058 L
.82381 .379 L
.82857 .38654 L
.83333 .39298 L
.8381 .39579 L
.84286 .38942 L
.84762 .42825 L
.85238 .38446 L
.85714 .37589 L
.8619 .38386 L
.86667 .41935 L
.87143 .44483 L
.87619 .42713 L
.88095 .47687 L
.88571 .48078 L
.89048 .49491 L
.89524 .53126 L
.9 .51321 L
.90476 .50073 L
.90952 .45754 L
.91429 .46979 L
.91905 .51017 L
.92381 .48165 L
.92857 .45273 L
.93333 .48668 L
.9381 .51022 L
.94286 .46912 L
.94762 .4752 L
.95238 .50375 L
.95714 .50661 L
.9619 .53176 L
.96667 .58 L
.97143 .57941 L
Mistroke
.97619 .57149 L
Mfstroke
0 .98 .604 r
gsave
.97619 .57208 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .23443 m
.02857 .23614 L
.03333 .23785 L
.0381 .23956 L
.04286 .24127 L
.04762 .24297 L
.05238 .24468 L
.05714 .24639 L
.0619 .2481 L
.06667 .24981 L
.07143 .28076 L
.07619 .28232 L
.08095 .28387 L
.08571 .28543 L
.09048 .28698 L
.09524 .28854 L
.1 .29009 L
.10476 .29165 L
.10952 .2932 L
.11429 .29476 L
.11905 .26722 L
.12381 .26894 L
.12857 .27065 L
.13333 .27237 L
.1381 .27409 L
.14286 .2758 L
.14762 .27752 L
.15238 .27923 L
.15714 .28095 L
.1619 .28267 L
.16667 .39231 L
.17143 .39339 L
.17619 .39448 L
.18095 .39556 L
.18571 .39664 L
.19048 .39773 L
.19524 .39881 L
.2 .39989 L
.20476 .40097 L
.20952 .40206 L
.21429 .40314 L
.21905 .40422 L
.22381 .40531 L
.22857 .40639 L
.23333 .40747 L
.2381 .40856 L
.24286 .40964 L
.24762 .41072 L
.25238 .4118 L
.25714 .41289 L
Mistroke
.2619 .35509 L
.26667 .35656 L
.27143 .35804 L
.27619 .35951 L
.28095 .36098 L
.28571 .36246 L
.29048 .36393 L
.29524 .36541 L
.3 .36688 L
.30476 .36836 L
.30952 .36983 L
.31429 .3713 L
.31905 .37278 L
.32381 .37425 L
.32857 .37573 L
.33333 .3772 L
.3381 .37867 L
.34286 .38015 L
.34762 .38162 L
.35238 .3831 L
.35714 .38457 L
.3619 .38605 L
.36667 .38752 L
.37143 .38899 L
.37619 .39047 L
.38095 .39194 L
.38571 .39342 L
.39048 .39489 L
.39524 .39637 L
.4 .39784 L
.40476 .39931 L
.40952 .40079 L
.41429 .40226 L
.41905 .40374 L
.42381 .40521 L
.42857 .40669 L
.43333 .40816 L
.4381 .40963 L
.44286 .41111 L
.44762 .41258 L
.45238 .41406 L
.45714 .41553 L
.4619 .41701 L
.46667 .41848 L
.47143 .41995 L
.47619 .42143 L
.48095 .4229 L
.48571 .42438 L
.49048 .42585 L
.49524 .42733 L
Mistroke
.5 .04201 L
.50476 .04733 L
.50952 .05266 L
.51429 .05798 L
.51905 .0633 L
.52381 .06863 L
.52857 .07395 L
.53333 .07927 L
.5381 .08459 L
.54286 .08992 L
.54762 .09524 L
.55238 .10056 L
.55714 .10589 L
.5619 .11121 L
.56667 .11653 L
.57143 .12185 L
.57619 .12718 L
.58095 .1325 L
.58571 .13782 L
.59048 .14315 L
.59524 .14847 L
.6 .15379 L
.60476 .15911 L
.60952 .16444 L
.61429 .16976 L
.61905 .17508 L
.62381 .18041 L
.62857 .18573 L
.63333 .19105 L
.6381 .19637 L
.64286 .2017 L
.64762 .20702 L
.65238 .21234 L
.65714 .21767 L
.6619 .22299 L
.66667 .22831 L
.67143 .23363 L
.67619 .23896 L
.68095 .24428 L
.68571 .2496 L
.69048 .25493 L
.69524 .26025 L
.7 .26557 L
.70476 .27089 L
.70952 .27622 L
.71429 .28154 L
.71905 .28686 L
.72381 .29219 L
.72857 .29751 L
.73333 .30283 L
Mistroke
.7381 .30815 L
.74286 .31348 L
.74762 .3188 L
.75238 .32412 L
.75714 .32945 L
.7619 .33477 L
.76667 .34009 L
.77143 .34541 L
.77619 .35074 L
.78095 .35606 L
.78571 .36138 L
.79048 .3667 L
.79524 .37203 L
.8 .37735 L
.80476 .38267 L
.80952 .388 L
.81429 .39332 L
.81905 .39864 L
.82381 .40396 L
.82857 .40929 L
.83333 .41461 L
.8381 .41993 L
.84286 .42525 L
.84762 .43058 L
.85238 .4359 L
.85714 .44122 L
.8619 .44654 L
.86667 .45187 L
.87143 .45719 L
.87619 .46251 L
.88095 .46783 L
.88571 .47316 L
.89048 .47848 L
.89524 .4838 L
.9 .48912 L
.90476 .49445 L
.90952 .49977 L
.91429 .50509 L
.91905 .51041 L
.92381 .51573 L
.92857 .52105 L
.93333 .52637 L
.9381 .53169 L
.94286 .53701 L
.94762 .54233 L
.95238 .54765 L
.95714 .55296 L
.9619 .55827 L
.96667 .56357 L
.97143 .56884 L
Mistroke
.97619 .57208 L
Mfstroke
.541 .169 .886 r
gsave
.97619 .58153 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.02381 .24526 m
.02857 .2626 L
.03333 .27358 L
.0381 .28254 L
.04286 .29038 L
.04762 .29749 L
.05238 .30405 L
.05714 .31021 L
.0619 .31603 L
.06667 .32157 L
.07143 .29149 L
.07619 .30873 L
.08095 .31956 L
.08571 .32837 L
.09048 .33605 L
.09524 .34299 L
.1 .3494 L
.10476 .35538 L
.10952 .36104 L
.11429 .36642 L
.11905 .27794 L
.12381 .29534 L
.12857 .30633 L
.13333 .31529 L
.1381 .32312 L
.14286 .33021 L
.14762 .33676 L
.15238 .3429 L
.15714 .3487 L
.1619 .35422 L
.16667 .40303 L
.17143 .41979 L
.17619 .43014 L
.18095 .43845 L
.18571 .44564 L
.19048 .45209 L
.19524 .45799 L
.2 .46348 L
.20476 .46863 L
.20952 .4735 L
.21429 .47814 L
.21905 .48256 L
.22381 .48681 L
.22857 .49091 L
.23333 .49485 L
.2381 .49867 L
.24286 .50237 L
.24762 .50597 L
.25238 .50946 L
.25714 .51286 L
Mistroke
.2619 .36586 L
.26667 .38297 L
.27143 .39368 L
.27619 .40236 L
.28095 .40991 L
.28571 .41672 L
.29048 .42298 L
.29524 .42882 L
.3 .43432 L
.30476 .43954 L
.30952 .44451 L
.31429 .44929 L
.31905 .45387 L
.32381 .4583 L
.32857 .46259 L
.33333 .46674 L
.3381 .47077 L
.34286 .47469 L
.34762 .47851 L
.35238 .48223 L
.35714 .48587 L
.3619 .48942 L
.36667 .4929 L
.37143 .4963 L
.37619 .49963 L
.38095 .5029 L
.38571 .5061 L
.39048 .50924 L
.39524 .51233 L
.4 .51536 L
.40476 .51833 L
.40952 .52126 L
.41429 .52414 L
.41905 .52697 L
.42381 .52975 L
.42857 .53249 L
.43333 .53518 L
.4381 .53784 L
.44286 .54045 L
.44762 .54302 L
.45238 .54556 L
.45714 .54805 L
.4619 .55051 L
.46667 .55293 L
.47143 .55532 L
.47619 .55767 L
.48095 .55999 L
.48571 .56228 L
.49048 .56453 L
.49524 .56675 L
Mistroke
.5 .05281 L
.50476 .0737 L
.50952 .08818 L
.51429 .10061 L
.51905 .11189 L
.52381 .12241 L
.52857 .13237 L
.53333 .14189 L
.5381 .15107 L
.54286 .15994 L
.54762 .16857 L
.55238 .17698 L
.55714 .18519 L
.5619 .19324 L
.56667 .20112 L
.57143 .20886 L
.57619 .21648 L
.58095 .22397 L
.58571 .23135 L
.59048 .23862 L
.59524 .2458 L
.6 .25288 L
.60476 .25987 L
.60952 .26678 L
.61429 .27361 L
.61905 .28036 L
.62381 .28704 L
.62857 .29365 L
.63333 .30019 L
.6381 .30666 L
.64286 .31307 L
.64762 .31941 L
.65238 .3257 L
.65714 .33193 L
.6619 .33809 L
.66667 .34421 L
.67143 .35026 L
.67619 .35627 L
.68095 .36222 L
.68571 .36811 L
.69048 .37396 L
.69524 .37975 L
.7 .3855 L
.70476 .39119 L
.70952 .39684 L
.71429 .40243 L
.71905 .40798 L
.72381 .41348 L
.72857 .41893 L
.73333 .42433 L
Mistroke
.7381 .42968 L
.74286 .43499 L
.74762 .44025 L
.75238 .44546 L
.75714 .45062 L
.7619 .45573 L
.76667 .4608 L
.77143 .46581 L
.77619 .47078 L
.78095 .4757 L
.78571 .48056 L
.79048 .48538 L
.79524 .49014 L
.8 .49486 L
.80476 .49952 L
.80952 .50412 L
.81429 .50867 L
.81905 .51317 L
.82381 .5176 L
.82857 .52198 L
.83333 .5263 L
.8381 .53056 L
.84286 .53475 L
.84762 .53888 L
.85238 .54294 L
.85714 .54693 L
.8619 .55084 L
.86667 .55468 L
.87143 .55844 L
.87619 .56212 L
.88095 .56571 L
.88571 .56921 L
.89048 .57262 L
.89524 .57592 L
.9 .57911 L
.90476 .58218 L
.90952 .58512 L
.91429 .58793 L
.91905 .59058 L
.92381 .59307 L
.92857 .59537 L
.93333 .59746 L
.9381 .59932 L
.94286 .60089 L
.94762 .60214 L
.95238 .60298 L
.95714 .60332 L
.9619 .60299 L
.96667 .60171 L
.97143 .59894 L
Mistroke
.97619 .58153 L
Mfstroke
gsave
.97619 .56262 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .2236 m
.02857 .20969 L
.03333 .20212 L
.0381 .19658 L
.04286 .19215 L
.04762 .18846 L
.05238 .18531 L
.05714 .18258 L
.0619 .18017 L
.06667 .17805 L
.07143 .27004 L
.07619 .25591 L
.08095 .24819 L
.08571 .24249 L
.09048 .23792 L
.09524 .23409 L
.1 .23079 L
.10476 .22791 L
.10952 .22537 L
.11429 .2231 L
.11905 .2565 L
.12381 .24253 L
.12857 .23498 L
.13333 .22945 L
.1381 .22505 L
.14286 .22139 L
.14762 .21827 L
.15238 .21557 L
.15714 .2132 L
.1619 .21111 L
.16667 .38159 L
.17143 .367 L
.17619 .35881 L
.18095 .35267 L
.18571 .34764 L
.19048 .34336 L
.19524 .33962 L
.2 .3363 L
.20476 .33332 L
.20952 .33061 L
.21429 .32815 L
.21905 .32588 L
.22381 .3238 L
.22857 .32187 L
.23333 .32009 L
.2381 .31844 L
.24286 .3169 L
.24762 .31548 L
.25238 .31415 L
.25714 .31291 L
Mistroke
.2619 .34432 L
.26667 .33016 L
.27143 .32239 L
.27619 .31666 L
.28095 .31205 L
.28571 .3082 L
.29048 .30489 L
.29524 .302 L
.3 .29944 L
.30476 .29717 L
.30952 .29514 L
.31429 .29332 L
.31905 .29168 L
.32381 .2902 L
.32857 .28887 L
.33333 .28766 L
.3381 .28658 L
.34286 .28561 L
.34762 .28474 L
.35238 .28396 L
.35714 .28328 L
.3619 .28267 L
.36667 .28214 L
.37143 .28169 L
.37619 .28131 L
.38095 .28099 L
.38571 .28074 L
.39048 .28054 L
.39524 .28041 L
.4 .28032 L
.40476 .2803 L
.40952 .28032 L
.41429 .28039 L
.41905 .28051 L
.42381 .28067 L
.42857 .28088 L
.43333 .28114 L
.4381 .28143 L
.44286 .28177 L
.44762 .28214 L
.45238 .28256 L
.45714 .28301 L
.4619 .2835 L
.46667 .28403 L
.47143 .28459 L
.47619 .28518 L
.48095 .28581 L
.48571 .28648 L
.49048 .28717 L
.49524 .2879 L
Mistroke
.5 .03121 L
.50476 .02097 L
.50952 .01713 L
.51429 .01535 L
.51905 .01472 L
.52381 .01484 L
.52857 .01553 L
.53333 .01665 L
.5381 .01812 L
.54286 .01989 L
.54762 .02191 L
.55238 .02415 L
.55714 .02658 L
.5619 .02918 L
.56667 .03194 L
.57143 .03484 L
.57619 .03788 L
.58095 .04103 L
.58571 .0443 L
.59048 .04767 L
.59524 .05114 L
.6 .0547 L
.60476 .05836 L
.60952 .06209 L
.61429 .06591 L
.61905 .0698 L
.62381 .07377 L
.62857 .07781 L
.63333 .08192 L
.6381 .08609 L
.64286 .09033 L
.64762 .09463 L
.65238 .09899 L
.65714 .10341 L
.6619 .10788 L
.66667 .11242 L
.67143 .117 L
.67619 .12165 L
.68095 .12634 L
.68571 .13109 L
.69048 .13589 L
.69524 .14074 L
.7 .14565 L
.70476 .1506 L
.70952 .1556 L
.71429 .16065 L
.71905 .16575 L
.72381 .17089 L
.72857 .17609 L
.73333 .18133 L
Mistroke
.7381 .18663 L
.74286 .19196 L
.74762 .19735 L
.75238 .20279 L
.75714 .20827 L
.7619 .2138 L
.76667 .21938 L
.77143 .22501 L
.77619 .23069 L
.78095 .23642 L
.78571 .2422 L
.79048 .24803 L
.79524 .25391 L
.8 .25984 L
.80476 .26583 L
.80952 .27187 L
.81429 .27796 L
.81905 .28412 L
.82381 .29032 L
.82857 .29659 L
.83333 .30292 L
.8381 .30931 L
.84286 .31576 L
.84762 .32228 L
.85238 .32886 L
.85714 .33552 L
.8619 .34225 L
.86667 .34905 L
.87143 .35593 L
.87619 .3629 L
.88095 .36995 L
.88571 .3771 L
.89048 .38434 L
.89524 .39169 L
.9 .39914 L
.90476 .40671 L
.90952 .41441 L
.91429 .42225 L
.91905 .43024 L
.92381 .43839 L
.92857 .44674 L
.93333 .45528 L
.9381 .46407 L
.94286 .47314 L
.94762 .48253 L
.95238 .49232 L
.95714 .50261 L
.9619 .51355 L
.96667 .52543 L
.97143 .53874 L
Mistroke
.97619 .56262 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00735755 0.97619 0.301659 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.108784 0.344625 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06353 -18 -4.5 ]
[-0.0125 .06353 0 4.5 ]
[-0.0125 .14968 -24 -4.5 ]
[-0.0125 .14968 0 4.5 ]
[-0.0125 .23584 -6 -4.5 ]
[-0.0125 .23584 0 4.5 ]
[-0.0125 .322 -24 -4.5 ]
[-0.0125 .322 0 4.5 ]
[-0.0125 .40815 -18 -4.5 ]
[-0.0125 .40815 0 4.5 ]
[-0.0125 .49431 -24 -4.5 ]
[-0.0125 .49431 0 4.5 ]
[-0.0125 .58047 -6 -4.5 ]
[-0.0125 .58047 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[.97619 .57495 -5 -6 ]
[.97619 .57495 5 6 ]
[.97619 .57555 -5 -6 ]
[.97619 .57555 5 6 ]
[.97619 .58506 -5 -6 ]
[.97619 .58506 5 6 ]
[.97619 .56603 -5 -6 ]
[.97619 .56603 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06353 m
.00625 .06353 L
s
[(0.5)] -0.0125 .06353 1 0 Mshowa
0 .14968 m
.00625 .14968 L
s
[(0.75)] -0.0125 .14968 1 0 Mshowa
0 .23584 m
.00625 .23584 L
s
[(1)] -0.0125 .23584 1 0 Mshowa
0 .322 m
.00625 .322 L
s
[(1.25)] -0.0125 .322 1 0 Mshowa
0 .40815 m
.00625 .40815 L
s
[(1.5)] -0.0125 .40815 1 0 Mshowa
0 .49431 m
.00625 .49431 L
s
[(1.75)] -0.0125 .49431 1 0 Mshowa
0 .58047 m
.00625 .58047 L
s
[(2)] -0.0125 .58047 1 0 Mshowa
.125 Mabswid
0 .08076 m
.00375 .08076 L
s
0 .09799 m
.00375 .09799 L
s
0 .11522 m
.00375 .11522 L
s
0 .13245 m
.00375 .13245 L
s
0 .16692 m
.00375 .16692 L
s
0 .18415 m
.00375 .18415 L
s
0 .20138 m
.00375 .20138 L
s
0 .21861 m
.00375 .21861 L
s
0 .25307 m
.00375 .25307 L
s
0 .2703 m
.00375 .2703 L
s
0 .28753 m
.00375 .28753 L
s
0 .30477 m
.00375 .30477 L
s
0 .33923 m
.00375 .33923 L
s
0 .35646 m
.00375 .35646 L
s
0 .37369 m
.00375 .37369 L
s
0 .39092 m
.00375 .39092 L
s
0 .42538 m
.00375 .42538 L
s
0 .44262 m
.00375 .44262 L
s
0 .45985 m
.00375 .45985 L
s
0 .47708 m
.00375 .47708 L
s
0 .51154 m
.00375 .51154 L
s
0 .52877 m
.00375 .52877 L
s
0 .546 m
.00375 .546 L
s
0 .56323 m
.00375 .56323 L
s
0 .0463 m
.00375 .0463 L
s
0 .02907 m
.00375 .02907 L
s
0 .01183 m
.00375 .01183 L
s
0 .5977 m
.00375 .5977 L
s
0 .61493 m
.00375 .61493 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06353 m
1 .06353 L
s
.99375 .14968 m
1 .14968 L
s
.99375 .23584 m
1 .23584 L
s
.99375 .322 m
1 .322 L
s
.99375 .40815 m
1 .40815 L
s
.99375 .49431 m
1 .49431 L
s
.99375 .58047 m
1 .58047 L
s
.125 Mabswid
.99625 .08076 m
1 .08076 L
s
.99625 .09799 m
1 .09799 L
s
.99625 .11522 m
1 .11522 L
s
.99625 .13245 m
1 .13245 L
s
.99625 .16692 m
1 .16692 L
s
.99625 .18415 m
1 .18415 L
s
.99625 .20138 m
1 .20138 L
s
.99625 .21861 m
1 .21861 L
s
.99625 .25307 m
1 .25307 L
s
.99625 .2703 m
1 .2703 L
s
.99625 .28753 m
1 .28753 L
s
.99625 .30477 m
1 .30477 L
s
.99625 .33923 m
1 .33923 L
s
.99625 .35646 m
1 .35646 L
s
.99625 .37369 m
1 .37369 L
s
.99625 .39092 m
1 .39092 L
s
.99625 .42538 m
1 .42538 L
s
.99625 .44262 m
1 .44262 L
s
.99625 .45985 m
1 .45985 L
s
.99625 .47708 m
1 .47708 L
s
.99625 .51154 m
1 .51154 L
s
.99625 .52877 m
1 .52877 L
s
.99625 .546 m
1 .546 L
s
.99625 .56323 m
1 .56323 L
s
.99625 .0463 m
1 .0463 L
s
.99625 .02907 m
1 .02907 L
s
.99625 .01183 m
1 .01183 L
s
.99625 .5977 m
1 .5977 L
s
.99625 .61493 m
1 .61493 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(smoothed) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .57495 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.007 w
.02381 .23584 m
.02857 .27852 L
.03333 .30952 L
.0381 .28494 L
.04286 .27989 L
.04762 .27372 L
.05238 .2785 L
.05714 .27017 L
.0619 .29117 L
.06667 .26894 L
.07143 .28306 L
.07619 .28386 L
.08095 .28328 L
.08571 .26863 L
.09048 .27676 L
.09524 .2621 L
.1 .24648 L
.10476 .25616 L
.10952 .25187 L
.11429 .26474 L
.11905 .26822 L
.12381 .30428 L
.12857 .273 L
.13333 .26844 L
.1381 .29014 L
.14286 .28965 L
.14762 .27736 L
.15238 .30482 L
.15714 .34702 L
.1619 .37326 L
.16667 .39694 L
.17143 .41704 L
.17619 .43233 L
.18095 .48507 L
.18571 .48398 L
.19048 .44035 L
.19524 .43398 L
.2 .45883 L
.20476 .47146 L
.20952 .41984 L
.21429 .42931 L
.21905 .44611 L
.22381 .43332 L
.22857 .40849 L
.23333 .38742 L
.2381 .39977 L
.24286 .36477 L
.24762 .33374 L
.25238 .29659 L
.25714 .32505 L
Mistroke
.2619 .35657 L
.26667 .32121 L
.27143 .32469 L
.27619 .29391 L
.28095 .32924 L
.28571 .30216 L
.29048 .31065 L
.29524 .29619 L
.3 .33082 L
.30476 .31382 L
.30952 .29214 L
.31429 .30723 L
.31905 .31281 L
.32381 .27876 L
.32857 .22349 L
.33333 .20752 L
.3381 .20628 L
.34286 .20956 L
.34762 .22309 L
.35238 .205 L
.35714 .19997 L
.3619 .20141 L
.36667 .19833 L
.37143 .16418 L
.37619 .16132 L
.38095 .14896 L
.38571 .10798 L
.39048 .10547 L
.39524 .11455 L
.4 .08051 L
.40476 .07311 L
.40952 .06781 L
.41429 .07722 L
.41905 .08887 L
.42381 .09014 L
.42857 .087 L
.43333 .1133 L
.4381 .14887 L
.44286 .09747 L
.44762 .13743 L
.45238 .13342 L
.45714 .13045 L
.4619 .1246 L
.46667 .1234 L
.47143 .08519 L
.47619 .0491 L
.48095 .03259 L
.48571 .04 L
.49048 .0546 L
.49524 .04416 L
Mistroke
.5 .03992 L
.50476 .06814 L
.50952 .06957 L
.51429 .07158 L
.51905 .07981 L
.52381 .11785 L
.52857 .16741 L
.53333 .15353 L
.5381 .17116 L
.54286 .14818 L
.54762 .16865 L
.55238 .19575 L
.55714 .21347 L
.5619 .21529 L
.56667 .26296 L
.57143 .22829 L
.57619 .25145 L
.58095 .27651 L
.58571 .2467 L
.59048 .24691 L
.59524 .27145 L
.6 .2335 L
.60476 .24058 L
.60952 .2904 L
.61429 .25502 L
.61905 .26181 L
.62381 .28441 L
.62857 .22905 L
.63333 .23418 L
.6381 .21821 L
.64286 .18566 L
.64762 .17225 L
.65238 .20403 L
.65714 .21931 L
.6619 .24516 L
.66667 .27062 L
.67143 .24323 L
.67619 .26684 L
.68095 .27503 L
.68571 .27911 L
.69048 .32519 L
.69524 .34649 L
.7 .38842 L
.70476 .38714 L
.70952 .38908 L
.71429 .40328 L
.71905 .38843 L
.72381 .41142 L
.72857 .4059 L
.73333 .41196 L
Mistroke
.7381 .42668 L
.74286 .41269 L
.74762 .4334 L
.75238 .40429 L
.75714 .39594 L
.7619 .41105 L
.76667 .3989 L
.77143 .36996 L
.77619 .38415 L
.78095 .42312 L
.78571 .42009 L
.79048 .42683 L
.79524 .41775 L
.8 .42849 L
.80476 .41631 L
.80952 .41582 L
.81429 .41279 L
.81905 .40301 L
.82381 .3813 L
.82857 .38888 L
.83333 .39536 L
.8381 .39819 L
.84286 .39178 L
.84762 .43084 L
.85238 .38679 L
.85714 .37816 L
.8619 .38618 L
.86667 .42189 L
.87143 .44752 L
.87619 .42972 L
.88095 .47976 L
.88571 .48369 L
.89048 .49791 L
.89524 .53448 L
.9 .51632 L
.90476 .50377 L
.90952 .46032 L
.91429 .47263 L
.91905 .51326 L
.92381 .48457 L
.92857 .45547 L
.93333 .48963 L
.9381 .51332 L
.94286 .47197 L
.94762 .47808 L
.95238 .50681 L
.95714 .50969 L
.9619 .53499 L
.96667 .58352 L
.97143 .58293 L
Mistroke
.97619 .57495 L
Mfstroke
0 .98 .604 r
gsave
.97619 .57555 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .23641 m
.02857 .24096 L
.03333 .24551 L
.0381 .25007 L
.04286 .25462 L
.04762 .25917 L
.05238 .26372 L
.05714 .26828 L
.0619 .27283 L
.06667 .27738 L
.07143 .28193 L
.07619 .28083 L
.08095 .27973 L
.08571 .27863 L
.09048 .27752 L
.09524 .27642 L
.1 .27532 L
.10476 .27422 L
.10952 .27311 L
.11429 .27201 L
.11905 .27091 L
.12381 .28323 L
.12857 .29554 L
.13333 .30786 L
.1381 .32018 L
.14286 .3325 L
.14762 .34482 L
.15238 .35714 L
.15714 .36946 L
.1619 .38177 L
.16667 .39409 L
.17143 .39217 L
.17619 .39025 L
.18095 .38833 L
.18571 .38641 L
.19048 .38449 L
.19524 .38257 L
.2 .38065 L
.20476 .37873 L
.20952 .37681 L
.21429 .3749 L
.21905 .37298 L
.22381 .37106 L
.22857 .36914 L
.23333 .36722 L
.2381 .3653 L
.24286 .36338 L
.24762 .36146 L
.25238 .35954 L
.25714 .35762 L
Mistroke
.2619 .3557 L
.26667 .34943 L
.27143 .34316 L
.27619 .33689 L
.28095 .33062 L
.28571 .32435 L
.29048 .31808 L
.29524 .31181 L
.3 .30554 L
.30476 .29928 L
.30952 .29301 L
.31429 .28674 L
.31905 .28047 L
.32381 .2742 L
.32857 .26793 L
.33333 .26166 L
.3381 .25539 L
.34286 .24912 L
.34762 .24285 L
.35238 .23658 L
.35714 .23031 L
.3619 .22405 L
.36667 .21778 L
.37143 .21151 L
.37619 .20524 L
.38095 .19897 L
.38571 .1927 L
.39048 .18643 L
.39524 .18016 L
.4 .17389 L
.40476 .16762 L
.40952 .16135 L
.41429 .15509 L
.41905 .14882 L
.42381 .14255 L
.42857 .13628 L
.43333 .13001 L
.4381 .12374 L
.44286 .11747 L
.44762 .1112 L
.45238 .10493 L
.45714 .09866 L
.4619 .09239 L
.46667 .08612 L
.47143 .07986 L
.47619 .07359 L
.48095 .06732 L
.48571 .06105 L
.49048 .05478 L
.49524 .04851 L
Mistroke
.5 .04224 L
.50476 .04758 L
.50952 .05292 L
.51429 .05826 L
.51905 .0636 L
.52381 .06893 L
.52857 .07427 L
.53333 .07961 L
.5381 .08495 L
.54286 .09029 L
.54762 .09563 L
.55238 .10097 L
.55714 .10631 L
.5619 .11164 L
.56667 .11698 L
.57143 .12232 L
.57619 .12766 L
.58095 .133 L
.58571 .13834 L
.59048 .14368 L
.59524 .14902 L
.6 .15435 L
.60476 .15969 L
.60952 .16503 L
.61429 .17037 L
.61905 .17571 L
.62381 .18105 L
.62857 .18639 L
.63333 .19173 L
.6381 .19707 L
.64286 .2024 L
.64762 .20774 L
.65238 .21308 L
.65714 .21842 L
.6619 .22376 L
.66667 .2291 L
.67143 .23444 L
.67619 .23978 L
.68095 .24511 L
.68571 .25045 L
.69048 .25579 L
.69524 .26113 L
.7 .26647 L
.70476 .27181 L
.70952 .27715 L
.71429 .28249 L
.71905 .28782 L
.72381 .29316 L
.72857 .2985 L
.73333 .30384 L
Mistroke
.7381 .30918 L
.74286 .31452 L
.74762 .31986 L
.75238 .3252 L
.75714 .33053 L
.7619 .33587 L
.76667 .34121 L
.77143 .34655 L
.77619 .35189 L
.78095 .35723 L
.78571 .36257 L
.79048 .3679 L
.79524 .37324 L
.8 .37858 L
.80476 .38392 L
.80952 .38926 L
.81429 .3946 L
.81905 .39994 L
.82381 .40528 L
.82857 .41061 L
.83333 .41595 L
.8381 .42129 L
.84286 .42663 L
.84762 .43197 L
.85238 .43731 L
.85714 .44265 L
.8619 .44798 L
.86667 .45332 L
.87143 .45866 L
.87619 .464 L
.88095 .46934 L
.88571 .47468 L
.89048 .48001 L
.89524 .48535 L
.9 .49069 L
.90476 .49603 L
.90952 .50137 L
.91429 .5067 L
.91905 .51204 L
.92381 .51738 L
.92857 .52271 L
.93333 .52805 L
.9381 .53339 L
.94286 .53872 L
.94762 .54405 L
.95238 .54939 L
.95714 .55471 L
.9619 .56004 L
.96667 .56534 L
.97143 .5706 L
Mistroke
.97619 .57555 L
Mfstroke
.541 .169 .886 r
gsave
.97619 .58506 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0035 w
.02381 .24721 m
.02857 .26607 L
.03333 .27761 L
.0381 .28633 L
.04286 .29317 L
.04762 .29846 L
.05238 .30227 L
.05714 .30453 L
.0619 .3049 L
.06667 .30245 L
.07143 .29262 L
.07619 .3059 L
.08095 .3118 L
.08571 .31488 L
.09048 .31607 L
.09524 .3157 L
.1 .31386 L
.10476 .31047 L
.10952 .30518 L
.11429 .29708 L
.11905 .2816 L
.12381 .3083 L
.12857 .32762 L
.13333 .34412 L
.1381 .35873 L
.14286 .37178 L
.14762 .38337 L
.15238 .3934 L
.15714 .40154 L
.1619 .40686 L
.16667 .40483 L
.17143 .41803 L
.17619 .42437 L
.18095 .42834 L
.18571 .4309 L
.19048 .43245 L
.19524 .43319 L
.2 .43324 L
.20476 .43269 L
.20952 .43157 L
.21429 .42992 L
.21905 .42774 L
.22381 .42501 L
.22857 .42173 L
.23333 .41784 L
.2381 .41326 L
.24286 .40788 L
.24762 .40148 L
.25238 .39367 L
.25714 .38351 L
Mistroke
.2619 .36652 L
.26667 .37578 L
.27143 .37849 L
.27619 .37906 L
.28095 .37843 L
.28571 .37697 L
.29048 .3749 L
.29524 .37234 L
.3 .36939 L
.30476 .3661 L
.30952 .36251 L
.31429 .35866 L
.31905 .35457 L
.32381 .35026 L
.32857 .34575 L
.33333 .34106 L
.3381 .33618 L
.34286 .33115 L
.34762 .32595 L
.35238 .32059 L
.35714 .31509 L
.3619 .30945 L
.36667 .30366 L
.37143 .29773 L
.37619 .29167 L
.38095 .28547 L
.38571 .27913 L
.39048 .27266 L
.39524 .26605 L
.4 .2593 L
.40476 .2524 L
.40952 .24537 L
.41429 .23818 L
.41905 .23084 L
.42381 .22334 L
.42857 .21568 L
.43333 .20783 L
.4381 .1998 L
.44286 .19157 L
.44762 .18312 L
.45238 .17444 L
.45714 .16549 L
.4619 .15625 L
.46667 .14666 L
.47143 .13668 L
.47619 .12621 L
.48095 .11513 L
.48571 .10323 L
.49048 .09012 L
.49524 .07488 L
Mistroke
.5 .05311 L
.50476 .07411 L
.50952 .08866 L
.51429 .10114 L
.51905 .11248 L
.52381 .12304 L
.52857 .13304 L
.53333 .14261 L
.5381 .15182 L
.54286 .16073 L
.54762 .16939 L
.55238 .17783 L
.55714 .18608 L
.5619 .19415 L
.56667 .20206 L
.57143 .20984 L
.57619 .21748 L
.58095 .22499 L
.58571 .2324 L
.59048 .2397 L
.59524 .24689 L
.6 .254 L
.60476 .26101 L
.60952 .26795 L
.61429 .2748 L
.61905 .28157 L
.62381 .28827 L
.62857 .29489 L
.63333 .30145 L
.6381 .30794 L
.64286 .31437 L
.64762 .32073 L
.65238 .32703 L
.65714 .33327 L
.6619 .33946 L
.66667 .34559 L
.67143 .35166 L
.67619 .35767 L
.68095 .36364 L
.68571 .36955 L
.69048 .3754 L
.69524 .38121 L
.7 .38697 L
.70476 .39267 L
.70952 .39833 L
.71429 .40393 L
.71905 .40949 L
.72381 .41499 L
.72857 .42045 L
.73333 .42586 L
Mistroke
.7381 .43122 L
.74286 .43654 L
.74762 .4418 L
.75238 .44702 L
.75714 .45218 L
.7619 .4573 L
.76667 .46237 L
.77143 .46739 L
.77619 .47236 L
.78095 .47728 L
.78571 .48215 L
.79048 .48696 L
.79524 .49173 L
.8 .49644 L
.80476 .50109 L
.80952 .5057 L
.81429 .51024 L
.81905 .51473 L
.82381 .51916 L
.82857 .52353 L
.83333 .52784 L
.8381 .53209 L
.84286 .53627 L
.84762 .54039 L
.85238 .54444 L
.85714 .54841 L
.8619 .55231 L
.86667 .55613 L
.87143 .55987 L
.87619 .56353 L
.88095 .5671 L
.88571 .57057 L
.89048 .57394 L
.89524 .57721 L
.9 .58036 L
.90476 .58339 L
.90952 .58629 L
.91429 .58904 L
.91905 .59164 L
.92381 .59406 L
.92857 .59628 L
.93333 .59828 L
.9381 .60003 L
.94286 .60148 L
.94762 .60258 L
.95238 .60323 L
.95714 .60332 L
.9619 .60263 L
.96667 .60079 L
.97143 .59685 L
Mistroke
.97619 .58506 L
Mfstroke
gsave
.97619 .56603 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.541 0.169 0.886 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .22561 m
.02857 .21585 L
.03333 .21342 L
.0381 .2138 L
.04286 .21606 L
.04762 .21988 L
.05238 .22517 L
.05714 .23202 L
.0619 .24076 L
.06667 .25231 L
.07143 .27124 L
.07619 .25576 L
.08095 .24766 L
.08571 .24237 L
.09048 .23898 L
.09524 .23714 L
.1 .23677 L
.10476 .23796 L
.10952 .24104 L
.11429 .24694 L
.11905 .26022 L
.12381 .25815 L
.12857 .26347 L
.13333 .27161 L
.1381 .28163 L
.14286 .29322 L
.14762 .30627 L
.15238 .32088 L
.15714 .33737 L
.1619 .35669 L
.16667 .38335 L
.17143 .36631 L
.17619 .35614 L
.18095 .34833 L
.18571 .34193 L
.19048 .33654 L
.19524 .33196 L
.2 .32807 L
.20476 .32478 L
.20952 .32205 L
.21429 .31987 L
.21905 .31821 L
.22381 .3171 L
.22857 .31654 L
.23333 .3166 L
.2381 .31733 L
.24286 .31888 L
.24762 .32143 L
.25238 .3254 L
.25714 .33173 L
Mistroke
.2619 .34487 L
.26667 .32307 L
.27143 .30783 L
.27619 .29472 L
.28095 .28282 L
.28571 .27174 L
.29048 .26127 L
.29524 .25128 L
.3 .2417 L
.30476 .23245 L
.30952 .2235 L
.31429 .21482 L
.31905 .20637 L
.32381 .19814 L
.32857 .19011 L
.33333 .18227 L
.3381 .1746 L
.34286 .1671 L
.34762 .15976 L
.35238 .15257 L
.35714 .14554 L
.3619 .13864 L
.36667 .13189 L
.37143 .12528 L
.37619 .11881 L
.38095 .11247 L
.38571 .10627 L
.39048 .1002 L
.39524 .09428 L
.4 .08849 L
.40476 .08284 L
.40952 .07734 L
.41429 .07199 L
.41905 .06679 L
.42381 .06175 L
.42857 .05688 L
.43333 .05219 L
.4381 .04768 L
.44286 .04337 L
.44762 .03928 L
.45238 .03543 L
.45714 .03184 L
.4619 .02854 L
.46667 .02559 L
.47143 .02303 L
.47619 .02096 L
.48095 .0195 L
.48571 .01886 L
.49048 .01943 L
.49524 .02214 L
Mistroke
.5 .03137 L
.50476 .02105 L
.50952 .01718 L
.51429 .01537 L
.51905 .01472 L
.52381 .01483 L
.52857 .0155 L
.53333 .01662 L
.5381 .01808 L
.54286 .01985 L
.54762 .02187 L
.55238 .0241 L
.55714 .02653 L
.5619 .02914 L
.56667 .0319 L
.57143 .03481 L
.57619 .03785 L
.58095 .04101 L
.58571 .04428 L
.59048 .04766 L
.59524 .05114 L
.6 .05471 L
.60476 .05837 L
.60952 .06212 L
.61429 .06595 L
.61905 .06985 L
.62381 .07383 L
.62857 .07788 L
.63333 .082 L
.6381 .08619 L
.64286 .09044 L
.64762 .09476 L
.65238 .09913 L
.65714 .10357 L
.6619 .10806 L
.66667 .11261 L
.67143 .11722 L
.67619 .12188 L
.68095 .12659 L
.68571 .13136 L
.69048 .13618 L
.69524 .14105 L
.7 .14597 L
.70476 .15095 L
.70952 .15597 L
.71429 .16104 L
.71905 .16616 L
.72381 .17133 L
.72857 .17655 L
.73333 .18182 L
Mistroke
.7381 .18713 L
.74286 .1925 L
.74762 .19791 L
.75238 .20337 L
.75714 .20888 L
.7619 .21444 L
.76667 .22005 L
.77143 .22571 L
.77619 .23142 L
.78095 .23718 L
.78571 .24299 L
.79048 .24885 L
.79524 .25476 L
.8 .26073 L
.80476 .26675 L
.80952 .27282 L
.81429 .27895 L
.81905 .28514 L
.82381 .29139 L
.82857 .29769 L
.83333 .30406 L
.8381 .31049 L
.84286 .31699 L
.84762 .32355 L
.85238 .33018 L
.85714 .33688 L
.8619 .34366 L
.86667 .35051 L
.87143 .35745 L
.87619 .36447 L
.88095 .37158 L
.88571 .37878 L
.89048 .38609 L
.89524 .3935 L
.9 .40102 L
.90476 .40867 L
.90952 .41644 L
.91429 .42437 L
.91905 .43244 L
.92381 .4407 L
.92857 .44915 L
.93333 .45782 L
.9381 .46674 L
.94286 .47596 L
.94762 .48553 L
.95238 .49554 L
.95714 .50611 L
.9619 .51744 L
.96667 .52989 L
.97143 .54435 L
Mistroke
.97619 .56603 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{836.312, 258.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=400010R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooA`3oool00?l0ooooo`3ooooo0?ooodL0oooo003o0?ooool0ooooo`3ooom70?ooo`00
o`3ooooo0?ooool0ooooA`3oool00?l0ooooo`3ooooo0?ooodL0oooo003o0?ooool0ooooo`3ooom7
0?ooo`00o`3ooooo0?ooool0ooooA`3oool00480oooo0P00000j0?ooo`800000103oool010000000
oooo0?ooo`3oool5000003@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`00000c0?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<00000=03oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000003X0oooo0`00000o0?ooo`800000>P3oool2000000@0oooo00@000000?oo
o`3oool0oooo1@00000c0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<00000=03oool2
000000@0oooo00<000000?ooo`3oool00P3oool3000003@0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000j0?ooo`<000009`3oool00440oooo00@000000?ooo`3oool00000>03oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`3oool0oooo0000000b0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo
0000000j0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000>03oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000380oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo0000000b0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000j
0?ooo`030000003oool0oooo02H0oooo00110?ooo`040000003oool0oooo000003P0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`0c0?ooo`040000003oool0oooo000000L0oooo
1@00000b0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000b0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`030000003o
ool0oooo03d0oooo00@000000?ooo`3oool00000>03oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo0380oooo00@000000?ooo`3oool000001`3oool5000003<0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool000000380oooo00@000000?ooo`3oool00000
1`3oool01@000000oooo0?ooo`3oool0000003X0oooo00<000000?ooo`3oool09P3oool00440oooo
00@000000?ooo`3oool00000>03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0380oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`00000c0?ooo`040000003o
ool0oooo000000L0oooo1000000c0?ooo`040000003oool0oooo000000P0oooo0`00000k0?ooo`03
0000003oool0oooo03d0oooo00@000000?ooo`3oool00000>03oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool000001`3oool010000000oooo0?oo
o`00000d0?ooo`040000003oool0oooo000000L0oooo1000000c0?ooo`040000003oool0oooo0000
00P0oooo0`00000k0?ooo`030000003oool0oooo02H0oooo00110?ooo`040000003oool0oooo0000
03P0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000003<0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0000000c0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000>P3oool00`000000oooo0?ooo`0m0?ooo`040000003oool0oooo000003P0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool000000380oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0000000d0?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool0=03oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000
>P3oool00`000000oooo0?ooo`0V0?ooo`00@@3oool010000000oooo0?ooo`00000h0?ooo`040000
003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`040000003oool0oooo
000000T0oooo0P00000c0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0<`3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000>@3oool2000003l0
oooo00@000000?ooo`3oool00000>03oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`000000<P3oool010000000oooo0?ooo`0000090?ooo`800000=03oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool0000003T0oooo0P00000X0?ooo`00@P3oool2000003X0oooo0P0000090?oo
o`<00000=@3oool2000000/0oooo00<000000?ooo`3oool0<P3oool2000000X0oooo0P00000d0?oo
o`8000002@3oool3000003/0oooo00<000000?ooo`3oool0?P3oool2000003X0oooo0P0000090?oo
o`<00000=03oool2000000/0oooo00<000000?ooo`3oool0<`3oool2000000X0oooo0P00000d0?oo
o`8000002@3oool3000003/0oooo00<000000?ooo`3oool09P3oool00?l0ooooo`3ooooo0?ooodL0
oooo003o0?ooool0ooooo`3ooom70?ooo`00o`3ooooo0?ooool0ooooA`3oool00?l0ooooo`3ooooo
0?ooodL0oooo003o0?ooool0ooooo`3ooom70?ooo`00o`3ooooo0?ooool0ooooA`3oool003/0oooo
o`00001N000002l0ooooo`00001O000001l0oooo000k0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo000k
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo0?l0ooooFP3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooF`3oool00`000000oooo0?ooo`0M0?oo
o`00>`3oool200000?l0ooooFP3oool2000002l0oooo0`00003o0?oooeX0oooo0P00000O0?ooo`00
>`3oool00`000000oooo0?ooo`2_0?ooo`T0RR_RX@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0;00oooo2@2::n:Q0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003o
ool0oooo0:h0oooo00<0RR_R0?ooo`3oool01`3oool208X[hYl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`2T0?ooo`H0RR_R103oool208X[hPT0oooo0P2::n:O0?ooo`030000003o
ool0oooo01d0oooo000k0?ooo`030000003oool0oooo0:d0oooo00<0RR_R0?ooo`3oool02P3oool3
08X[hY`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2S0?ooo`0308X[hP3oool0
oooo00@0oooo00@0RR_R0?ooo`3oool0RR_R3@3oool308X[hY`0oooo00<000000?ooo`3oool07@3o
ool003/0oooo00<000000?ooo`3oool0[@3oool00`2::n80oooo0?ooo`0=0?ooo`80RR_RVP3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0:40oooo0P2::n870?ooo`0408X[hP3oool0
oooo08X[hQ00oooo0P2::n:J0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0
oooo0:`0oooo00<0RR_R0?ooo`3oool0403oool00`2::n80oooo0?ooo`2G0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0W`3oool208X[hPX0oooo00<0RR_R0?ooo`2::n804P3oool0
0`2::n80oooo0?ooo`2G0?ooo`030000003oool0oooo01d0oooo000k0?ooo`800000[03oool00`2:
:n80oooo0?ooo`0B0?ooo`80RR_RUP3oool2000002l0oooo0`00002N0?ooo`0308X[hP3oool0oooo
00X0oooo0P2::n8D0?ooo`80RR_RUP3oool2000001l0oooo000k0?ooo`030000003oool0oooo0:<0
oooo0P000?l60?ooo`0308X[hP3oool0oooo01@0oooo0P2::n:E0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0W03oool208X[hPH0oooo0P000?l60?ooo`0308X[hP3oool0oooo01@0
oooo00<0RR_R0?ooo`3oool0U03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo
0?ooo`2S0?ooo`<0003o1@3oool00`2::n80oooo0?ooo`0F0?ooo`0308X[hP3oool0oooo0980oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2J0?ooo`80RR_R203oool20000oah0oooo
0P2::n:D0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo0:<0oooo1000
0?l30?ooo`030000o`2::n80oooo01P0oooo0P2::n:B0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0V@3oool00`2::n80oooo0?ooo`070?ooo`@0003o7`3oool208X[hY80oooo00<0
00000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0X`3oool40000o`80oooo00<0003o
003jVP2::n806`3oool208X[hY00oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2I
0?ooo`0308X[hP3oool0oooo00L0oooo1@000?l20?ooo`030000o`00nYX00?ZJ01/0oooo00<0RR_R
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`2R0?oo
o`P0003o00<00?ZJ08X[hP00nYX0703oool00`2::n80oooo0?ooo`2=0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0U`3oool208X[hPX0oooo0P000?l0103oool0003o0000o`3oool2
0000o`800?ZJ703oool208X[hXl0oooo00<000000?ooo`3oool07@3oool003/0oooo0P00002S0?oo
o`80003o0P3oool40000o`04003jVP2::n800?ZJ003jVQ`0oooo0P2::n:<0?ooo`800000;`3oool3
000009H0oooo00<0RR_R0?ooo`3oool02@3oool30000o`050?ooo`000?l0003o0?ooo`000?l01000
nYXM0?ooo`80RR_RS03oool2000001l0oooo000k0?ooo`030000003oool0oooo0:80oooo0P000?l2
0?ooo`@0003o00@00?ZJ08X[hP00nYX00?ZJ7P3oool00`2::n80oooo0?ooo`2:0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0U@3oool00`2::n80oooo0?ooo`0:0?ooo`80003o0P3o
ool30000o`H00?ZJ7P3oool00`2::n80oooo0?ooo`2:0?ooo`030000003oool0oooo01d0oooo000k
0?ooo`030000003oool0oooo0:80oooo0P000?l20?ooo`@0003o00<00?ZJ08X[hP00nYX00P00nYXN
0?ooo`0308X[hP3oool0oooo08T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2D
0?ooo`0308X[hP3oool0oooo00/0oooo0P000?l30?ooo`060000o`00nYX00?ZJ003jVP000?l0RR_R
0`00nYXM0?ooo`0308X[hP3oool0oooo08X0oooo00<000000?ooo`3oool07@3oool002H0oooo0P00
00040?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo0:80oooo0P00
0?l30?ooo`80003o00@0oooo003jVP2::n80003o0`00nYXN0?ooo`0308X[hP3oool0oooo08P0oooo
00<000000?ooo`3oool06@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000H0oooo
00<000000?ooo`3oool0T`3oool00`2::n80oooo0?ooo`0<0?ooo`80003o0`3oool3003jVP040?oo
o`000?l0RR_R0000o`<00?ZJ7@3oool208X[hXX0oooo00<000000?ooo`3oool07@3oool002D0oooo
00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0XP3oool20000o`<0oooo0P000?l01@3oool00?ZJ08X[hP000?l0oooo00<00?ZJ7P3oool2
08X[hXP0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2B0?ooo`0308X[hP3oool0oooo00d0oooo
0P000?l30?ooo`800?ZJ0`3oool00`2::n80003o0?ooo`03003jVQh0oooo0P2::n:80?ooo`030000
003oool0oooo01d0oooo000U0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2Q0?ooo`<0003o1P3oool01@00nYX0RR_R08X[hP000?l0oooo00<0
0?ZJ7`3oool00`2::n80oooo0?ooo`250?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0940oooo00<0RR_R0?oo
o`3oool03P3oool20000o`80oooo0`00nYX20?ooo`80RR_R00<0003o0?ooo`3oool00P00nYXP0?oo
o`0308X[hP3oool0oooo08D0oooo00<000000?ooo`3oool07@3oool002D0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`040?ooo`<00000X@3oool20000o`L0oooo00@00?ZJ08X[
hP2::n80003o0P3oool3003jVQl0oooo00<0RR_R0?ooo`3oool0PP3oool3000001X0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`030?ooo`<00000T03oool00`2::n80oooo0?oo
o`0?0?ooo`80003o00@0oooo003jVP00nYX00?ZJ0`3oool00`2::n80003o08X[hP020?ooo`<00?ZJ
7`3oool00`2::n80oooo0?ooo`230?ooo`<000007`3oool002D0oooo00@000000?ooo`3oool00000
1`3oool4000000L0oooo00<000000?ooo`3oool0RP3oool20000oaD0oooo0P000?l70?ooo`04003j
VP2::n80RR_R0000o`<0oooo0P00nYXP0?ooo`0308X[hP3oool0oooo08<0oooo00<000000?ooo`3o
ool0603oool010000000oooo0?ooo`0000070?ooo`@000001P3oool00`000000oooo0?ooo`2;0?oo
o`80003o0P3oool00`2::n80oooo0?ooo`0@0?ooo`80003o0`00nYX40?ooo`0408X[hP000?l0RR_R
0000o`80oooo0`00nYXO0?ooo`80RR_RQ@3oool00`000000oooo0?ooo`0M0?ooo`009@3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0RP3oool2
0000oaD0oooo0P000?l70?ooo`04003jVP2::n80003o08X[hP<0003o1000nYXO0?ooo`80RR_RP`3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2:0?ooo`<0003o0P3oool00`2::n80oooo0?ooo`0?0?ooo`80003o
0`00nYX50?ooo`0308X[hP000?l0RR_R00<0003o00<0oooo003jVP00nYX00P00nYXO0?ooo`80RR_R
P`3oool00`000000oooo0?ooo`0M0?ooo`009P3oool2000000P0oooo1@0000060?ooo`030000003o
ool0oooo08T0oooo10000?lD0?ooo`80003o1`3oool01000nYX0RR_R0?ooo`2::n830000o`030?oo
o`00nYX00?ZJ00800?ZJ803oool00`2::n80oooo0?ooo`200?ooo`030000003oool0oooo01T0oooo
0P0000080?ooo`D000001@3oool00`000000oooo0?ooo`290?ooo`D0003o00<0RR_R0?ooo`3oool0
403oool010000?l00?ZJ003jVP00nYX50?ooo`0408X[hP3oool0oooo08X[hP@0003o00<0oooo003j
VP00nYX00P00nYXP0?ooo`0308X[hP3oool0oooo0800oooo00<000000?ooo`3oool07@3oool003/0
oooo00<000000?ooo`3oool0R@3oool50000oa<0oooo0P000?l70?ooo`05003jVP2::n80oooo08X[
hP3oool00`000?l20?ooo`<00?ZJ803oool00`2::n80oooo0?ooo`1o0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0R@3oool20000o`030?ooo`000?l0RR_R01<0oooo00<0003o003j
VP00nYX01P3oool0102::n80oooo0?ooo`2::n820?ooo`80003o0`3oool2003jVR00oooo00<0RR_R
0?ooo`3oool0P03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`280?oo
o`<0003o00<0oooo0000o`000?l04P3oool30000o`L0oooo00@00?ZJ08X[hP3oool0RR_R0P3oool3
0000o`80oooo0`00nYXP0?ooo`0308X[hP3oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`280?ooo`<0003o0P2::n820000oa80oooo0`00nYX60?ooo`0608X[hP3oool0
oooo0?ooo`2::n80oooo0`000?l20?ooo`<00?ZJ803oool208X[hX00oooo00<000000?ooo`3oool0
7@3oool003/0oooo0P0000280?ooo`<0003o0P3oool30000oa40oooo0P000?l80?ooo`05003jVP2:
:n80oooo0?ooo`2::n800P3oool20000o`<0oooo0P00nYXQ0?ooo`0308X[hP3oool0oooo07`0oooo
0P00000_0?ooo`<00000R03oool20000o`0308X[hP3oool0oooo0080003o4P3oool2003jVPH0oooo
00<0RR_R0?ooo`3oool00P3oool00`2::n80oooo0?ooo`020000o`<0oooo0`00nYXQ0?ooo`0308X[
hP3oool0oooo07`0oooo0P00000O0?ooo`00>`3oool00`000000oooo0?ooo`270?ooo`80003o103o
ool20000oa40oooo0P000?l80?ooo`05003jVP2::n80oooo0?ooo`2::n800P3oool20000o`<0oooo
0`00nYXQ0?ooo`0308X[hP3oool0oooo07`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`280?ooo`80003o00<0RR_R0?ooo`3oool00P000?lA0?ooo`<00?ZJ1P3oool00`2::n80oooo
0?ooo`020?ooo`0308X[hP3oool0oooo0080003o103oool3003jVR40oooo00<0RR_R0?ooo`3oool0
O03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`270?ooo`80003o103o
ool60000o`d0oooo0P000?l80?ooo`05003jVP2::n80oooo0?ooo`2::n800P3oool20000o`@0oooo
0`00nYXQ0?ooo`80RR_RO03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo08P0oooo
00<0003o08X[hP3oool00P3oool30000o`040?ooo`000?l0003o0000o`/0oooo0`00nYX00`000?l0
oooo0?ooo`040?ooo`0308X[hP3oool0oooo00<0oooo00@0RR_R0?ooo`000?l0003o1@3oool3003j
VR40oooo00<0RR_R0?ooo`3oool0N`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000
oooo0?ooo`270?ooo`80003o1@3oool50000o`d0oooo0P000?l80?ooo`05003jVP2::n80oooo0?oo
o`2::n800P3oool20000o`D0oooo0`00nYXR0?ooo`0308X[hP3oool0oooo07T0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`280?ooo`0308X[hP000?l0oooo00<0oooo1P000?l:0?oo
o`<00?ZJ0P000?l50?ooo`0308X[hP3oool0oooo00@0oooo00<0RR_R0?ooo`000?l00P000?l50?oo
o`<00?ZJ8@3oool00`2::n80oooo0?ooo`1j0?ooo`030000003oool0oooo01d0oooo000k0?ooo`03
0000003oool0oooo08H0oooo0`000?l60?ooo`@0003o3@3oool20000o`P0oooo00<00?ZJ08X[hP3o
ool00P3oool0102::n80oooo0000o`000?l60?ooo`800?ZJ8P3oool00`2::n80oooo0?ooo`1i0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0Q`3oool00`2::n80003o0000o`040?oo
o`H0003o2@3oool3003jVP030?ooo`000?l0003o00D0oooo00<0RR_R0?ooo`3oool0103oool00`2:
:n80oooo0?ooo`020000o`H0oooo0P00nYXR0?ooo`0308X[hP3oool0oooo07T0oooo00<000000?oo
o`3oool07@3oool003/0oooo00<000000?ooo`3oool0QP3oool20000o`T0oooo0`000?l20?ooo`80
003o1`3oool30000o`P0oooo0P2::n830?ooo`0408X[hP3oool0003o0000o`H0oooo0`00nYXR0?oo
o`80RR_RN@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo08L0oooo00<0RR_R0000
o`3oool0203oool20000o`T0oooo0P00nYX0103oool0003o0000o`000?l50?ooo`0308X[hP3oool0
oooo00D0oooo00@0RR_R0?ooo`000?l0003o1P3oool3003jVR80oooo0P2::n9i0?ooo`030000003o
ool0oooo01d0oooo000k0?ooo`800000Q`3oool20000o`X0oooo0P000?l20?ooo`80003o1`3oool2
0000o`T0oooo0P2::n830?ooo`0308X[hP3oool0003o0080003o1P3oool3003jVR<0oooo00<0RR_R
0?ooo`3oool0M@3oool2000002l0oooo0`0000260?ooo`0308X[hP000?l0003o00T0oooo0P000?l3
0?ooo`80003o0`3oool3003jVP030?ooo`000?l0003o00D0oooo00<0RR_R0?ooo`3oool01P3oool0
102::n80oooo0000o`000?l70?ooo`<00?ZJ8`3oool00`2::n80oooo0?ooo`1e0?ooo`8000007`3o
ool003/0oooo00<000000?ooo`3oool0QP3oool20000o`X0oooo0P000?l20?ooo`80003o1`3oool2
0000o`T0oooo0P2::n840?ooo`0408X[hP3oool0003o0000o`L0oooo0`00nYXS0?ooo`0308X[hP3o
ool0oooo07D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`250?ooo`0408X[hP3o
ool0003o0000o`T0oooo0`000?l20?ooo`80003o0P3oool3003jVP80oooo0P000?l50?ooo`0308X[
hP3oool0oooo00L0oooo00<0RR_R0000o`000?l0203oool3003jVR80oooo00<0RR_R0?ooo`3oool0
MP3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`230?ooo`D0003o2P3o
ool20000o`80oooo0P000?l70?ooo`80003o2@3oool208X[hP@0oooo00@0RR_R0?ooo`000?l0003o
203oool3003jVR<0oooo00<0RR_R0?ooo`3oool0M03oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo08@0oooo00<0003o08X[hP3oool00P000?l:0?ooo`80003o0P3oool20000o`040?oo
o`00nYX00?ZJ003jVP<0oooo0P000?l50?ooo`0308X[hP3oool0oooo00L0oooo00<0RR_R0000o`00
0?l02@3oool3003jVR80oooo0P2::n9f0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000
003oool0oooo0880oooo1P000?l:0?ooo`80003o0P3oool30000o`H0oooo0P000?l90?ooo`80RR_R
1@3oool00`2::n80003o0000o`090?ooo`<00?ZJ8`3oool00`2::n80oooo0?ooo`1c0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0P`3oool010000?l0RR_R0000o`3oool20000o`X0
oooo0P000?l20?ooo`80003o0`00nYX40?ooo`80003o1@3oool00`2::n80oooo0?ooo`070?ooo`03
08X[hP000?l0003o00X0oooo0`00nYXS0?ooo`0308X[hP3oool0oooo07<0oooo00<000000?ooo`3o
ool07@3oool003/0oooo00<000000?ooo`3oool0PP3oool50000o`/0oooo1`000?l60?ooo`80003o
2@3oool208X[hPD0oooo00<0RR_R0000o`000?l02P3oool3003jVR<0oooo00<0RR_R0?ooo`3oool0
LP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo08<0oooo00<0RR_R0000o`000?l0
0`000?l:0?ooo`80003o0P3oool010000?l00?ZJ003jVP00nYX50?ooo`80003o103oool00`2::n80
oooo0?ooo`090?ooo`0308X[hP000?l0003o00X0oooo0P00nYXT0?ooo`0308X[hP3oool0oooo0780
oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0PP3oool20000o`030?oo
o`000?l0003o00`0oooo1P000?l60?ooo`80003o2@3oool208X[hPH0oooo00<0RR_R0000o`3oool0
2P3oool3003jVR<0oooo0P2::n9b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
PP3oool00`2::n80003o0000o`030000o`/0oooo0P000?l00`3oool0003o0000o`02003jVPH0oooo
0P000?l40?ooo`0308X[hP3oool0oooo00T0oooo00<0RR_R0000o`000?l02P3oool4003jVR<0oooo
00<0RR_R0?ooo`3oool0L@3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool2000008<0oooo0P00
0?l00`3oool0003o0000o`0<0?ooo`H0003o1@3oool30000o`T0oooo0P2::n860?ooo`0308X[hP00
0?l0oooo00/0oooo0`00nYXT0?ooo`0308X[hP3oool0oooo06h0oooo0P00000_0?ooo`<00000P@3o
ool00`2::n80oooo0000o`040000o`/0oooo0P000?l00`3oool0003o003jVP02003jVPD0oooo0`00
0?l30?ooo`0308X[hP3oool0oooo00X0oooo00<0RR_R0000o`000?l02`3oool4003jVR<0oooo00<0
RR_R0?ooo`3oool0K`3oool2000001l0oooo000k0?ooo`030000003oool0oooo0840oooo0`000?l?
0?ooo`H0003o1@3oool20000o`X0oooo0P2::n860?ooo`030000o`2::n80oooo00`0oooo0`00nYXS
0?ooo`0308X[hP3oool0oooo06l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`20
0?ooo`0308X[hP3oool0oooo0080003o00<0oooo0000o`000?l02`3oool20000o`040?ooo`000?l0
0?ZJ003jVPH0oooo0P000?l40?ooo`0308X[hP3oool0oooo00/0oooo00<0RR_R0000o`3oool0303o
ool2003jVR@0oooo00<0RR_R0?ooo`3oool0K`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool0
0`000000oooo0?ooo`210?ooo`80003o403oool60000o`D0oooo0P000?l:0?ooo`80RR_R1P3oool0
0`000?l0RR_R0?ooo`0=0?ooo`<00?ZJ8`3oool00`2::n80oooo0?ooo`1^0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0P03oool00`2::n80oooo0000o`020000o`h0oooo0P000?l0
1@3oool00?ZJ003jVP00nYX0003o00D0oooo0P000?l30?ooo`0308X[hP3oool0oooo00`0oooo00<0
003o08X[hP3oool0303oool3003jVR@0oooo00<0RR_R0?ooo`3oool0KP3oool00`000000oooo0?oo
o`0M0?ooo`00>`3oool00`000000oooo0?ooo`210?ooo`80003o403oool60000o`@0oooo0`000?l:
0?ooo`80RR_R1P3oool00`000?l0RR_R0?ooo`0>0?ooo`800?ZJ903oool00`2::n80oooo0?ooo`1]
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0O`3oool00`2::n80oooo0?ooo`02
0000o`l0oooo0P000?l3003jVP80003o0`3oool40000o`<0oooo00<0RR_R0?ooo`3oool0303oool0
0`000?l0RR_R0?ooo`0=0?ooo`<00?ZJ903oool00`2::n80oooo0?ooo`1]0?ooo`030000003oool0
oooo01d0oooo000k0?ooo`030000003oool0oooo0840oooo0P000?l@0?ooo`L0003o0P3oool30000
o`/0oooo0P2::n860?ooo`80003o00<0RR_R0?ooo`3oool0303oool3003jVR@0oooo0P2::n9]0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0O`3oool00`2::n80oooo0?ooo`020000
oa00oooo0`00nYX30000o`<0oooo10000?l20?ooo`0308X[hP3oool0oooo00d0oooo0P000?l00`2:
:n80oooo0?ooo`0<0?ooo`<00?ZJ903oool00`2::n80oooo0?ooo`1/0?ooo`030000003oool0oooo
01d0oooo000k0?ooo`800000PP3oool20000oa00oooo10000?l00`3oool0003o0000o`040000o``0
oooo0P2::n860?ooo`80003o00<0RR_R0?ooo`3oool03@3oool3003jVRD0oooo00<0RR_R0?ooo`3o
ool0J@3oool2000002l0oooo00<000000?ooo`3oool0OP3oool0102::n80oooo0?ooo`3oool20000
o`l0oooo0`00nYX40000o`030?ooo`000?l0003o0080003o103oool00`2::n80oooo0?ooo`0=0?oo
o`80003o00<0RR_R0?ooo`3oool03@3oool3003jVR@0oooo00<0RR_R0?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`210?ooo`80003o403oool40000o`03
0?ooo`000?l0003o00<0003o3@3oool208X[hPL0oooo0P000?l00`2::n80oooo0?ooo`0=0?ooo`<0
0?ZJ903oool00`2::n80oooo0?ooo`1Z0?ooo`030000003oool0oooo02d0oooo0`00001m0?ooo`03
08X[hP3oool0oooo0080oooo0P000?l?0?ooo`800?ZJ2@000?l40?ooo`0308X[hP3oool0oooo00h0
oooo0`000?l00`2::n80oooo0?ooo`0=0?ooo`<00?ZJ903oool00`2::n80oooo0?ooo`1Y0?ooo`80
00007`3oool003/0oooo00<000000?ooo`3oool0P@3oool20000oa40oooo0`000?l0103oool0003o
0000o`000?l?0?ooo`80RR_R1`3oool20000o`0308X[hP3oool0oooo00h0oooo0`00nYXT0?ooo`03
08X[hP3oool0oooo06T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1l0?ooo`03
08X[hP3oool0oooo00<0oooo0P000?l>0?ooo`<00?ZJ1`000?l60?ooo`0308X[hP3oool0oooo00l0
oooo0P000?l00`2::n80oooo0?ooo`0>0?ooo`800?ZJ9@3oool00`2::n80oooo0?ooo`1Y0?ooo`03
0000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo0800oooo0`000?lA0?ooo`80003o
0P3oool20000oa00oooo0P2::n870?ooo`80003o00<0oooo08X[hP3oool03`3oool3003jVR@0oooo
00<0RR_R0?ooo`3oool0J03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07/0oooo
00<0RR_R0?ooo`3oool0103oool20000o`d0oooo0`00nYX70000o`L0oooo00<0RR_R0?ooo`3oool0
3`3oool20000o`030?ooo`2::n80oooo00h0oooo0`00nYXU0?ooo`0308X[hP3oool0oooo06P0oooo
00<000000?ooo`3oool07@3oool00200oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool3000000L0oooo00<000000?ooo`3oool0P03oool20000oa80oooo0P00
0?lC0?ooo`03003jVP2::n80RR_R00L0oooo0P000?l20?ooo`0308X[hP3oool0oooo00h0oooo0`00
nYXT0?ooo`80RR_RJ03oool00`000000oooo0?ooo`0C0?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo07/0oooo00<0
RR_R0?ooo`3oool00`3oool30000o``0oooo0`00nYX01@3oool0003o0000o`000?l0oooo0080003o
1`3oool00`2::n80oooo0?ooo`0@0?ooo`80003o00<0oooo08X[hP3oool03`3oool3003jVRD0oooo
00<0RR_R0?ooo`3oool0I`3oool00`000000oooo0?ooo`0M0?ooo`007`3oool010000000oooo0?oo
o`0000090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0800oooo0P000?lB0?ooo`80003o4`3oool00`00nYX0RR_R08X[hP070?ooo`80
003o0P3oool00`2::n80oooo0?ooo`0?0?ooo`<00?ZJ9@3oool00`2::n80oooo0?ooo`1U0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool000002@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1j0?ooo`0308X[hP3oool0
oooo00@0oooo0P000?l<0?ooo`<00?ZJ0`3oool20000o`X0oooo00<0RR_R0?ooo`3oool0403oool2
0000o`030?ooo`2::n80oooo0100oooo0`00nYXU0?ooo`0308X[hP3oool0oooo06H0oooo00<00000
0?ooo`3oool07@3oool001l0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo0`0000200?ooo`80003o4P3oool20000oa<0oooo00<00?ZJ
08X[hP2::n801`3oool20000o`<0oooo00<0RR_R0000o`000?l03`3oool3003jVR@0oooo00<0RR_R
0?ooo`3oool0H`3oool3000001@0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0NP3oool00`2::n80oooo0?oo
o`040?ooo`80003o2`3oool3003jVP@0oooo0P000?l90?ooo`0308X[hP3oool0oooo0140oooo0P00
0?l20?ooo`0408X[hP3oool0003o0000o`h0oooo0`00nYXU0?ooo`0308X[hP3oool0oooo06D0oooo
00<000000?ooo`3oool07@3oool001l0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0P03oool20000oa80oooo
0P000?lC0?ooo`03003jVP2::n80RR_R00L0oooo0P000?l30?ooo`0308X[hP000?l0003o0100oooo
0`00nYXT0?ooo`0308X[hP3oool0oooo06@0oooo00<000000?ooo`3oool04P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000007T0
oooo00<0RR_R0?ooo`3oool01@3oool20000o`/0oooo0P00nYX50?ooo`80003o2@3oool00`2::n80
oooo0?ooo`0A0?ooo`80003o0P3oool0102::n80oooo0000o`000?l?0?ooo`<00?ZJ9@3oool00`2:
:n80oooo0?ooo`1R0?ooo`<000007`3oool001l0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo00000003000000L0oooo00<000000?ooo`3oool0P03oool20000obL0oooo00<00?ZJ08X[
hP2::n801`3oool20000o`040?ooo`000?l0003o08X[hP80003o4@3oool3003jVR@0oooo00<0RR_R
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`0000000`0000060?ooo`030000003oool0oooo07P0oooo00<0RR_R0?ooo`3oool01P3o
ool20000o`X0oooo0`00nYX?0?ooo`0308X[hP3oool0oooo0180oooo10000?l0103oool0RR_R0000
o`000?l@0?ooo`<00?ZJ9@3oool00`2::n80oooo0?ooo`1S0?ooo`030000003oool0oooo01d0oooo
000O0?ooo`040000003oool0oooo000000L0oooo00L000000?ooo`3oool0oooo0000003oool00000
00X0oooo00<000000?ooo`3oool0O`3oool30000obL0oooo00<00?ZJ08X[hP2::n801`3oool60000
o`0308X[hP000?l0oooo0140oooo0P00nYXU0?ooo`0308X[hP3oool0oooo0680oooo00<000000?oo
o`3oool04P3oool010000000oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000oooo
000000090?ooo`030000003oool0oooo07L0oooo00<0RR_R0?ooo`3oool01P3oool30000o`X0oooo
0P00nYX?0?ooo`0308X[hP3oool0oooo01<0oooo10000?l0103oool0RR_R0000o`000?lA0?ooo`<0
0?ZJ9@3oool00`2::n80oooo0?ooo`1R0?ooo`030000003oool0oooo01d0oooo000P0?ooo`800000
203oool5000000030?ooo`000000000000<000001P3oool00`000000oooo0?ooo`1n0?ooo`<0003o
:03oool00`00nYX0RR_R08X[hP080?ooo`H0003o00<0RR_R0000o`3oool0403oool3003jVRD0oooo
00<0RR_R0?ooo`3oool0H@3oool00`000000oooo0?ooo`0C0?ooo`800000203oool5000000030?oo
o`000000000000<000001@3oool00`000000oooo0?ooo`1f0?ooo`0308X[hP3oool0oooo00L0oooo
0P000?l:0?ooo`<00?ZJ3`3oool00`2::n80oooo0?ooo`0C0?ooo`H0003o00<0RR_R0000o`000?l0
4@3oool3003jVR@0oooo00<0RR_R0?ooo`3oool0HP3oool00`000000oooo0?ooo`0M0?ooo`00>`3o
ool00`000000oooo0?ooo`1m0?ooo`@0003o:03oool00`00nYX0RR_R08X[hP080?ooo`H0003o00<0
RR_R0000o`3oool04@3oool3003jVRD0oooo00<0RR_R0?ooo`3oool0H03oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo07H0oooo00<0RR_R0?ooo`3oool01P3oool30000o`T0oooo0`00
nYX?0?ooo`0308X[hP3oool0oooo01D0oooo1P000?l00`2::n80003o0?ooo`0A0?ooo`<00?ZJ903o
ool00`2::n80oooo0?ooo`1Q0?ooo`030000003oool0oooo01d0oooo000k0?ooo`800000OP3oool2
0000obX0oooo00<00?ZJ08X[hP2::n80203oool70000o`0308X[hP3oool0oooo0140oooo0`00nYXU
0?ooo`0308X[hP3oool0oooo05h0oooo0P00000_0?ooo`030000003oool0oooo07D0oooo00<0RR_R
0?ooo`3oool01P3oool30000o`T0oooo0`00nYX@0?ooo`0308X[hP3oool0oooo01D0oooo1P000?l0
0`2::n80003o0?ooo`0B0?ooo`<00?ZJ903oool00`2::n80oooo0?ooo`1P0?ooo`030000003oool0
oooo01d0oooo000k0?ooo`030000003oool0oooo07d0oooo0P000?lZ0?ooo`03003jVP2::n80RR_R
00P0oooo1`000?l00`2::n80oooo0?ooo`0B0?ooo`<00?ZJ9@3oool00`2::n80oooo0?ooo`1N0?oo
o`030000003oool0oooo02d0oooo0`00001e0?ooo`0308X[hP3oool0oooo00H0oooo0P000?l90?oo
o`<00?ZJ4@3oool00`2::n80oooo0?ooo`0E0?ooo`L0003o00<0RR_R0?ooo`3oool04P3oool2003j
VRD0oooo0P2::n9O0?ooo`8000007`3oool003/0oooo00<000000?ooo`3oool0O@3oool20000obX0
oooo00<00?ZJ08X[hP2::n80203oool20000o`060?ooo`000?l0003o0?ooo`000?l0RR_R5@3oool3
003jVPT0oooo0P000?lJ0?ooo`0308X[hP3oool0oooo05d0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`1d0?ooo`0308X[hP3oool0oooo00L0oooo0P000?l90?ooo`800?ZJ4@3oool0
0`2::n80oooo0?ooo`0F0?ooo`80003o00H0oooo0000o`000?l0oooo0000o`2::n8D0?ooo`<00?ZJ
9P3oool00`2::n80oooo0?ooo`1M0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003o
ool0oooo07`0oooo0`000?lZ0?ooo`03003jVP2::n80RR_R00/0oooo0P000?l0103oool0003o0000
o`2::n8E0?ooo`800?ZJ2@3oool20000oa/0oooo00<0RR_R0?ooo`3oool0G03oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo07<0oooo00<0RR_R0?ooo`3oool0203oool20000o`P0oooo
0`00nYX@0?ooo`0308X[hP3oool0oooo01X0oooo0P000?l00`3oool0003o08X[hP0E0?ooo`<00?ZJ
2@3oool20000oaX0oooo00<0RR_R0?ooo`3oool0G@3oool00`000000oooo0?ooo`0M0?ooo`00>`3o
ool00`000000oooo0?ooo`1l0?ooo`80003o:`3oool00`00nYX0RR_R08X[hP0>0?ooo`<0003o00<0
RR_R0?ooo`3oool04P3oool4003jVPL0oooo0P000?lL0?ooo`0308X[hP3oool0oooo05/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`1c0?ooo`0308X[hP3oool0oooo00L0oooo0`00
0?l70?ooo`<00?ZJ4@3oool00`2::n80oooo0?ooo`0M0?ooo`80003o00<0RR_R0?ooo`3oool04`3o
ool3003jVPP0oooo0P000?lK0?ooo`0308X[hP3oool0oooo05`0oooo00<000000?ooo`3oool07@3o
ool003/0oooo00<000000?ooo`3oool04P3oool308X[hVL0oooo0P000?l[0?ooo`03003jVP2::n80
RR_R00l0oooo0P000?l00`2::n80oooo0?ooo`0C0?ooo`@00?ZJ1@3oool30000oa`0oooo00<0RR_R
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0780oooo00<0RR_R
0?ooo`3oool0203oool20000o`L0oooo0`00nYXA0?ooo`0308X[hP3oool0oooo01l0oooo0P000?l0
0`2::n80oooo0?ooo`0C0?ooo`<00?ZJ1P3oool30000oa`0oooo00<0RR_R0?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0M0?ooo`00>`3oool200000140oooo0P2::n820?ooo`0308X[hP3oool0oooo
06D0oooo0P000?l[0?ooo`03003jVP2::n80RR_R00l0oooo0P000?l00`3oool0RR_R0?ooo`0E0?oo
o`<00?ZJ103oool40000oa`0oooo00<0RR_R0?ooo`3oool0F@3oool2000002l0oooo00<000000?oo
o`3oool0L@3oool00`2::n80oooo0?ooo`090?ooo`80003o1`3oool2003jVQ40oooo00<0RR_R0?oo
o`3oool0803oool20000o`030?ooo`2::n80oooo01@0oooo0`00nYX50?ooo`<0003o7@3oool00`2:
:n80oooo0?ooo`1J0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo00h0
oooo0P2::n840?ooo`0308X[hP3oool0oooo06D0oooo0P000?l[0?ooo`03003jVP2::n80oooo00l0
oooo0P000?l20?ooo`0308X[hP3oool0oooo01@0oooo0`00nYX30?ooo`@0003o7@3oool00`2::n80
oooo0?ooo`1I0?ooo`030000003oool0oooo02d0oooo0`00001a0?ooo`0308X[hP3oool0oooo00T0
oooo0P000?l60?ooo`<00?ZJ4@3oool00`2::n80oooo0?ooo`0P0?ooo`80003o0P3oool00`2::n80
oooo0?ooo`0C0?ooo`800?ZJ103oool50000oad0oooo00<0RR_R0?ooo`3oool0F03oool2000001l0
oooo000k0?ooo`030000003oool0oooo00d0oooo00<0RR_R0?ooo`3oool0103oool00`2::n80oooo
0?ooo`1U0?ooo`80003o:`3oool00`00nYX0RR_R0?ooo`0?0?ooo`80003o0P3oool00`2::n80oooo
0?ooo`0E0?ooo`800?ZJ0`3oool40000oah0oooo00<0RR_R0?ooo`3oool0F03oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0700oooo00<0RR_R0?ooo`3oool02P3oool20000o`D0oooo
0`00nYXA0?ooo`0308X[hP3oool0oooo0240oooo0P000?l20?ooo`0308X[hP3oool0oooo01<0oooo
1000nYX20?ooo`80003o00<0oooo0000o`000?l07P3oool00`2::n80oooo0?ooo`1H0?ooo`030000
003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo00d0oooo00<0RR_R0?ooo`3oool0103o
ool00`2::n80oooo0?ooo`1T0?ooo`<0003o:`3oool00`00nYX0RR_R0?ooo`0?0?ooo`<0003o0P3o
ool00`2::n80oooo0?ooo`0D0?ooo`<00?ZJ0P3oool40000oal0oooo00<0RR_R0?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0700oooo00<0RR_R0?ooo`3oool02P3o
ool20000o`D0oooo0P00nYXB0?ooo`0308X[hP3oool0oooo0240oooo0`000?l20?ooo`0308X[hP3o
ool0oooo01<0oooo1000nYX0103oool0003o0000o`3oool20000oah0oooo00<0RR_R0?ooo`3oool0
F03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`0;0?ooo`80RR_R1`3o
ool00`2::n80oooo0?ooo`1T0?ooo`80003o;03oool00`00nYX0RR_R0?ooo`0@0?ooo`80003o0P3o
ool00`2::n80oooo0?ooo`0E0?ooo`<00?ZJ00<0oooo0000o`000?l00P000?lP0?ooo`0308X[hP3o
ool0oooo05H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1`0?ooo`0308X[hP3o
ool0oooo00T0oooo0`000?l40?ooo`<00?ZJ4P3oool00`2::n80oooo0?ooo`0R0?ooo`80003o0P3o
ool00`2::n80oooo0?ooo`0E0?ooo`<00?ZJ0P000?l00`3oool0003o0000o`0O0?ooo`0308X[hP3o
ool0oooo05L0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool02P3oool0
0`2::n80oooo0?ooo`070?ooo`0308X[hP3oool0oooo06@0oooo0P000?l/0?ooo`03003jVP2::n80
oooo0100oooo0P000?l20?ooo`0308X[hP3oool0oooo01H0oooo0`00nYX50000ob00oooo00<0RR_R
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06l0oooo00<0RR_R
0?ooo`3oool02P3oool20000o`@0oooo0`00nYXB0?ooo`0308X[hP3oool0oooo02<0oooo0P000?l2
0?ooo`0308X[hP3oool0oooo01H0oooo0`00nYX010000?l0oooo0000o`000?lP0?ooo`0308X[hP3o
ool0oooo05H0oooo00<000000?ooo`3oool07@3oool003/0oooo0P00000:0?ooo`0308X[hP3oool0
oooo00P0oooo00<0RR_R0?ooo`3oool0H@3oool50000ob`0oooo00<00?ZJ08X[hP3oool0403oool2
0000o`<0oooo00<0RR_R0?ooo`3oool05P3oool3003jVP80oooo0P000?lQ0?ooo`0308X[hP3oool0
oooo05<0oooo0P00000_0?ooo`030000003oool0oooo06h0oooo00<0RR_R0?ooo`3oool0203oool5
0000o`<0oooo0`00nYXB0?ooo`0308X[hP3oool0oooo02@0oooo0P000?l30?ooo`0308X[hP3oool0
oooo01H0oooo0P00nYX00`000?l0oooo0000o`020000ob00oooo0P2::n9F0?ooo`030000003oool0
oooo01d0oooo000k0?ooo`030000003oool0oooo00P0oooo00<0RR_R0?ooo`3oool02@3oool00`2:
:n80oooo0?ooo`1P0?ooo`D0003o;@3oool00`00nYX0RR_R0?ooo`0@0?ooo`<0003o0`3oool00`2:
:n80oooo0?ooo`0F0?ooo`<00?ZJ00<0oooo0000o`000?l08P3oool00`2::n80oooo0?ooo`1C0?oo
o`030000003oool0oooo02d0oooo0`00001^0?ooo`0308X[hP3oool0oooo00L0oooo1P000?l20?oo
o`<00?ZJ4`3oool00`2::n80oooo0?ooo`0T0?ooo`<0003o0`3oool00`2::n80oooo0?ooo`0E0?oo
o`<00?ZJ0P3oool20000ob80oooo00<0RR_R0?ooo`3oool0DP3oool2000001l0oooo000k0?ooo`03
0000003oool0oooo00P0oooo00<0RR_R0?ooo`3oool02P3oool00`2::n80oooo0?ooo`1I0?ooo`<0
003o0P3oool30000oc00oooo00<00?ZJ08X[hP3oool04@3oool20000o`@0oooo00<0RR_R0?ooo`3o
ool05@3oool010000?l00?ZJ003jVP3oool20000ob<0oooo00<0RR_R0?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo06d0oooo00<0RR_R0?ooo`3oool01`3oool50000
o`<0oooo0`00nYXC0?ooo`0308X[hP3oool0oooo02H0oooo0P000?l30?ooo`0308X[hP3oool0oooo
01D0oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000ob80oooo00<0RR_R0?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`070?ooo`0308X[hP3oool0oooo
00/0oooo00<0RR_R0?ooo`3oool0F03oool50000o`030?ooo`000?l0003o0340oooo00<00?ZJ08X[
hP3oool04@3oool20000o`D0oooo00<0RR_R0?ooo`3oool0503oool010000?l00?ZJ003jVP00nYX3
0000ob<0oooo00<0RR_R0?ooo`3oool0D@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo06d0oooo00<0RR_R0?ooo`3oool01@000?l20?ooo`80003o1P3oool2003jVQ<0oooo00<0RR_R
0?ooo`3oool09`3oool20000o`@0oooo00<0RR_R0?ooo`3oool0503oool20000o`<00?ZJ0P000?lS
0?ooo`0308X[hP3oool0oooo0580oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?oo
o`3oool01`3oool00`2::n80oooo0?ooo`0;0?ooo`0308X[hP3oool0oooo01`0oooo0P2::n8j0?oo
o`80003o00@0oooo0000o`000?l0oooo0P000?la0?ooo`03003jVP2::n80oooo0140oooo0`000?l4
0?ooo`0308X[hP3oool0oooo01<0oooo0`000?l3003jVP80003o8`3oool00`2::n80oooo0?ooo`1A
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0K03oool0102::n80oooo0?ooo`3o
ool90000o`D0oooo0`00nYXC0?ooo`0308X[hP3oool0oooo02L0oooo0`000?l30?ooo`0308X[hP3o
ool0oooo01@0oooo0P000?l01@3oool00?ZJ003jVP00nYX0003o02@0oooo00<0RR_R0?ooo`3oool0
D@3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`070?ooo`0308X[hP3o
ool0oooo00/0oooo00<0RR_R0?ooo`3oool06`3oool00`2::n80oooo08X[hP0i0?ooo`<0003o00<0
oooo0000o`000?l00`000?la0?ooo`03003jVP2::n80oooo0180oooo0`000?l40?ooo`0308X[hP3o
ool0oooo0180oooo0P000?l20?ooo`@00?ZJ903oool00`2::n80oooo0?ooo`1@0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0203oool408X[hUl0oooo00<0RR_R0?ooo`3oool00P3o
ool20000o`80oooo10000?l60?ooo`800?ZJ4`3oool00`2::n80oooo0?ooo`0Y0?ooo`80003o103o
ool00`2::n80oooo0?ooo`0C0?ooo`80003o0P3oool3003jVP030000o`3oool0oooo0280oooo00<0
RR_R0?ooo`3oool0D03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool2000000L0oooo00<0RR_R
0?ooo`3oool0303oool00`2::n80oooo0?ooo`0I0?ooo`80RR_R0P3oool00`2::n80oooo0?ooo`0g
0?ooo`80003o0`3oool40000oc40oooo00<00?ZJ08X[hP3oool04P3oool30000o`@0oooo00<0RR_R
0?ooo`3oool04P3oool20000o`<0oooo1000nYXT0?ooo`0308X[hP3oool0oooo04h0oooo0P00000_
0?ooo`030000003oool0oooo00L0oooo00<0RR_R0?ooo`3oool00P3oool208X[hUd0oooo00<0RR_R
0?ooo`3oool00P3oool20000o`80oooo10000?l50?ooo`<00?ZJ4`3oool00`2::n80oooo0?ooo`0Y
0?ooo`<0003o103oool00`2::n80oooo0?ooo`0B0?ooo`80003o0`3oool2003jVP030000o`3oool0
oooo02<0oooo00<0RR_R0?ooo`3oool0C`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`00
0000oooo0?ooo`060?ooo`0308X[hP3oool0oooo00`0oooo00<0RR_R0?ooo`3oool05`3oool208X[
hP@0oooo00<0RR_R0?ooo`3oool0=`3oool20000o`<0oooo0`000?lb0?ooo`03003jVP2::n80oooo
01<0oooo0P000?l40?ooo`0308X[hP3oool0oooo0180oooo0P000?l50?ooo`800?ZJ9@3oool00`2:
:n80oooo0?ooo`1>0?ooo`030000003oool0oooo02d0oooo0`0000070?ooo`0308X[hP3oool0oooo
00@0oooo00<0RR_R0?ooo`3oool0F@3oool00`2::n80oooo0?ooo`020?ooo`<0003o0P3oool40000
o`@0oooo0`00nYXC0?ooo`0308X[hP3oool0oooo02/0oooo0P000?l40?ooo`0308X[hP3oool0oooo
0180oooo0P000?l30?ooo`<00?ZJ9P3oool00`2::n80oooo0?ooo`1=0?ooo`8000007`3oool003/0
oooo00<000000?ooo`3oool01P3oool00`2::n80oooo0?ooo`0<0?ooo`0308X[hP3oool0oooo00`0
oooo00<0RR_R0?ooo`3oool01`3oool00`2::n80oooo0?ooo`040?ooo`0308X[hP3oool0oooo03H0
oooo0`000?l30?ooo`<0003o<P3oool00`00nYX0RR_R0?ooo`0C0?ooo`80003o1@3oool00`2::n80
oooo0?ooo`0@0?ooo`<0003o1@3oool3003jVRD0oooo00<0RR_R0?ooo`3oool0C@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<0RR_R0?ooo`3oool01P3oool00`2::n80
oooo0?ooo`1H0?ooo`0308X[hP3oool0oooo0080oooo0P000?l40?ooo`80003o103oool3003jVQ<0
oooo00<0RR_R0?ooo`3oool0;03oool20000o`D0oooo00<0RR_R0?ooo`3oool04@3oool20000o`@0
oooo0`00nYXU0?ooo`0308X[hP3oool0oooo04h0oooo00<000000?ooo`3oool07@3oool003/0oooo
00<000000?ooo`3oool01@3oool00`2::n80oooo0?ooo`0=0?ooo`0308X[hP3oool0oooo00X0oooo
0`2::n880?ooo`0308X[hP3oool0oooo00D0oooo00<0RR_R0?ooo`3oool0=P3oool20000o`D0oooo
0P000?lb0?ooo`80RR_R503oool20000o`H0oooo00<0RR_R0?ooo`3oool03`3oool20000o`H0oooo
00@0003o003jVP00nYX00?ZJ9@3oool00`2::n80oooo0?ooo`1<0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool01P3oool00`2::n80oooo0?ooo`070?ooo`0308X[hP3oool0oooo05H0
oooo00<0RR_R0?ooo`3oool00`3oool20000o`@0oooo0P000?l30?ooo`<00?ZJ503oool00`2::n80
oooo0?ooo`0/0?ooo`80003o1P3oool00`2::n80oooo0?ooo`0?0?ooo`<0003o103oool00`000?l0
0?ZJ003jVP02003jVR@0oooo00<0RR_R0?ooo`3oool0C@3oool00`000000oooo0?ooo`0M0?ooo`00
<@3oool3000000L0oooo00<000000?ooo`3oool05@3oool00`2::n80oooo0?ooo`080?ooo`80RR_R
0P3oool00`2::n80oooo0?ooo`050?ooo`0308X[hP3oool0oooo00H0oooo00<0RR_R0?ooo`3oool0
=P3oool20000ocT0oooo0P2::n8D0?ooo`<0003o00<0oooo0000o`000?l00`3oool00`2::n80oooo
0?ooo`0<0?ooo`@0003o1P3oool20000o`<00?ZJ903oool00`2::n80oooo0?ooo`1<0?ooo`030000
003oool0oooo02@0oooo0`0000060?ooo`030000003oool0oooo0100oooo00<0RR_R0?ooo`3oool0
EP3oool00`2::n80oooo0?ooo`030?ooo`80003o2@3oool2003jVQ@0oooo00<0RR_R0?ooo`3oool0
;@3oool20000o`030?ooo`000?l0003o00<0oooo00<0RR_R0?ooo`3oool0303oool20000o`030?oo
o`000?l0003o00D0oooo0P000?l4003jVR@0oooo00<0RR_R0?ooo`3oool0C03oool00`000000oooo
0?ooo`0M0?ooo`00<P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
RR_R0?ooo`3oool01`3oool00`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0oooo00@0oooo00<0
RR_R0?ooo`3oool01`3oool00`2::n80oooo0?ooo`0f0?ooo`80003o>@3oool208X[hQD0oooo0P00
0?l00`3oool0003o0000o`040?ooo`0308X[hP3oool0oooo00/0oooo10000?l60?ooo`80003o00@0
oooo003jVP00nYX00?ZJ903oool00`2::n80oooo0?ooo`1;0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`0308X[hP3oool0oooo05@0oooo
00<0RR_R0?ooo`3oool0103oool20000o`P0oooo0`00nYXC0?ooo`0308X[hP3oool0oooo02h0oooo
1@000?l40?ooo`0308X[hP3oool0oooo00/0oooo1@000?l60?ooo`80003o00<0oooo003jVP00nYX0
9@3oool00`2::n80oooo0?ooo`1;0?ooo`030000003oool0oooo01d0oooo000b0?ooo`030000003o
ool0oooo00H0oooo0`0000040?ooo`<00?ZJ3P3oool00`2::n80oooo0?ooo`060?ooo`0308X[hP3o
ool0oooo00@0oooo00<0RR_R0?ooo`3oool00P3oool00`2::n80oooo0?ooo`080?ooo`0308X[hP3o
ool0oooo03H0oooo0P000?li0?ooo`80RR_R5@3oool20000o`030?ooo`000?l0003o00@0oooo00@0
RR_R0?ooo`3oool0oooo0P000?l80?ooo`<0003o1`3oool30000o`040?ooo`00nYX00?ZJ003jVR@0
oooo00<0RR_R0?ooo`3oool0B03oool3000002L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0A0?ooo`0308X[hP3oool0oooo05@0oooo00<0RR_R0?ooo`3oool0103oool20000o`L0
oooo0`00nYXD0?ooo`0308X[hP3oool0oooo02l0oooo10000?l40?ooo`0408X[hP3oool0oooo0?oo
o`80003o203oool50000o`H0oooo0P000?l0103oool00?ZJ003jVP00nYXU0?ooo`0308X[hP3oool0
oooo04X0oooo00<000000?ooo`3oool07@3oool00380oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`@00?ZJ3@3oool00`2::n80oooo0?ooo`050?ooo`0308X[hP3oool0oooo
00D0oooo00D0RR_R0?ooo`3oool0oooo08X[hP0;0?ooo`0308X[hP3oool0oooo03H0oooo0P000?li
0?ooo`80RR_R5@3oool20000o`030?ooo`000?l0003o00D0oooo00<0RR_R0?ooo`3oool00P000?l8
0?ooo`<0003o203oool20000o`80oooo0P00nYXU0?ooo`0308X[hP3oool0oooo04T0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`<000001@3oool2003jVP/0oooo00<0RR_R
0?ooo`3oool02@3oool408X[hTH0oooo00<0RR_R0?ooo`3oool0103oool20000o`H0oooo0`00nYXD
0?ooo`0308X[hP3oool0oooo0300oooo1@000?l40?ooo`0308X[hP3oool0oooo00<0003o1`3oool4
0000o`L0oooo0P000?l20?ooo`<00?ZJ9@3oool00`2::n80oooo0?ooo`170?ooo`<000007`3oool0
0380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`80003o1P00nYX90?oo
o`0308X[hP3oool0oooo00@0oooo00<0RR_R0?ooo`3oool01P3oool01@2::n80oooo0?ooo`3oool0
RR_R00/0oooo00<0RR_R0?ooo`3oool0=@3oool30000ocT0oooo0P2::n8E0?ooo`D0003o1@3oool0
0`2::n80oooo0?ooo`030000o`L0oooo0P000?l90?ooo`80003o0P3oool3003jVR@0oooo00<0RR_R
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool2003jVP/0oooo00<0RR_R0?ooo`3oool01`3oool208X[hP@0oooo00<0RR_R
0?ooo`3oool0@P3oool00`2::n80oooo0?ooo`050?ooo`80003o1@3oool3003jVQD0oooo00<0RR_R
0?ooo`3oool0<03oool50000o`D0oooo00<0RR_R0?ooo`000?l00`000?l60?ooo`80003o2@3oool2
0000o`<0oooo0`00nYXT0?ooo`0308X[hP3oool0oooo04T0oooo00<000000?ooo`3oool07@3oool0
0340oooo0P0000080?ooo`030000003oool0oooo00@0oooo0P000?l00`3oool00?ZJ003jVP06003j
VPH0oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`070?ooo`0408X[hP3oool0oooo
08X[hP`0oooo00<0RR_R0?ooo`3oool0=@3oool20000ocX0oooo0P2::n8E0?ooo`H0003o1@3oool0
0`2::n80oooo0000o`020000o`L0oooo0P000?l90?ooo`80003o0P3oool010000?l00?ZJ003jVP00
nYXT0?ooo`0308X[hP3oool0oooo04P0oooo00<000000?ooo`3oool0903oool2000000L0oooo00<0
00000?ooo`3oool01@3oool4003jVPX0oooo00<0RR_R0?ooo`3oool01@3oool00`2::n80oooo0?oo
o`050?ooo`0308X[hP3oool0oooo0400oooo00<0RR_R0?ooo`3oool01@3oool30000o`@0oooo0`00
nYXE0?ooo`0308X[hP3oool0oooo0340oooo1@000?l50?ooo`0308X[hP3oool0003o00<0003o1P3o
ool20000o`T0oooo0`000?l00`3oool0003o0000o`03003jVR@0oooo00<0RR_R0?ooo`3oool0B03o
ool00`000000oooo0?ooo`0M0?ooo`00<P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<0003o08X[hP3oool0103oool7003jVP<0oooo00<0RR_R0?ooo`3oool00P3oool0
102::n80oooo0?ooo`3oool20000o`D0oooo00@0RR_R0?ooo`3oool0RR_R303oool00`2::n80oooo
0?ooo`0e0?ooo`80003o>P3oool208X[hQD0oooo1P000?l20?ooo`<0003o00<0oooo08X[hP000?l0
0P000?l60?ooo`<0003o2@3oool20000o`80oooo0P000?l3003jVR@0oooo00<0RR_R0?ooo`3oool0
A`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000?l00?ZJ003jVP02003jVPT0oooo00<0RR_R0?ooo`3oool01@3oool00`2::n80oooo
0?ooo`060?ooo`0308X[hP3oool0oooo03l0oooo00<0RR_R0?ooo`3oool01@3oool20000o`D0oooo
0P00nYXE0?ooo`0308X[hP3oool0oooo0380oooo1@000?l60?ooo`0308X[hP000?l0003o0080003o
1P3oool20000o`X0oooo0P000?l0103oool0003o0000o`3oool3003jVR@0oooo00<0RR_R0?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`040?ooo`030000
o`2::n80003o00L0oooo1P00nYX00`3oool0RR_R0?ooo`020?ooo`0308X[hP3oool0oooo0080oooo
0P000?l50?ooo`0308X[hP3oool0RR_R00d0oooo00<0RR_R0?ooo`3oool0=@3oool20000ocX0oooo
0P2::n8E0?ooo`H0003o0P3oool30000o`030?ooo`2::n80003o0080003o1P3oool20000o`X0oooo
0P000?l20?ooo`80003o00@0oooo003jVP00nYX00?ZJ903oool00`2::n80oooo0?ooo`160?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool01@3oool00`000?l0RR_R0?ooo`03003jVPT0
oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`020?ooo`80003o103oool00`2::n80
oooo0?ooo`0m0?ooo`0308X[hP3oool0oooo00H0oooo0P000?l40?ooo`<00?ZJ5@3oool00`2::n80
oooo0?ooo`0b0?ooo`H0003o00<0oooo0000o`000?l00P000?l00`3oool0RR_R0000o`020000o`H0
oooo0P000?l:0?ooo`80003o00<0oooo0000o`000?l00P3oool2003jVRD0oooo00<0RR_R0?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool2000000H0oooo00<0003o08X[hP3oool0
2@3oool4003jVP050?ooo`2::n80oooo0?ooo`2::n80103oool60000o`80oooo0P2::n8=0?ooo`03
08X[hP3oool0oooo03D0oooo0P000?lj0?ooo`80RR_R5@3oool60000o`80oooo0`000?l00`3oool0
003o08X[hP020000o`H0oooo0P000?l:0?ooo`80003o00@0oooo0000o`000?l0003o0P3oool3003j
VR@0oooo00<0RR_R0?ooo`3oool0A03oool2000002l0oooo00<000000?ooo`3oool01@3oool01000
0?l0RR_R0?ooo`3oool3003jVPP0oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`02
0?ooo`80003o00D0oooo0000o`000?l0oooo08X[hP0n0?ooo`0308X[hP3oool0oooo00L0oooo0P00
0?l40?ooo`800?ZJ5@3oool00`2::n80oooo0?ooo`0c0?ooo`<0003o00@0oooo0000o`000?l0oooo
10000?l00`3oool0RR_R0000o`020000o`H0oooo0P000?l:0?ooo`80003o00D0oooo0000o`000?l0
003o0?ooo`03003jVR@0oooo00<0RR_R0?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`00
>`3oool00`000000oooo0?ooo`050?ooo`030000o`2::n80oooo00/0oooo0P00nYX0103oool0RR_R
0?ooo`2::n840?ooo`L0003o0P3oool208X[hPd0oooo00<0RR_R0?ooo`3oool0=@3oool20000ocX0
oooo0P2::n8E0?ooo`H0003o00<0oooo0000o`000?l01@000?l0102::n80003o0000o`3oool20000
o`80oooo0P000?l:0?ooo`H0003o0`3oool3003jVR@0oooo00<0RR_R0?ooo`3oool0A03oool00`00
0000oooo0?ooo`0]0?ooo`<000001@3oool00`000?l0RR_R0?ooo`020?ooo`<00?ZJ203oool01@2:
:n80oooo0?ooo`3oool0RR_R00D0oooo1@000?l20?ooo`0308X[hP3oool0oooo03/0oooo00<0RR_R
0?ooo`3oool01`3oool20000o`<0oooo0`00nYXD0?ooo`0308X[hP3oool0oooo03@0oooo0`000?l0
103oool0003o0000o`3oool60000o`0308X[hP000?l0003o00<0003o0`3oool20000o`X0oooo1P00
0?l20?ooo`<00?ZJ903oool00`2::n80oooo0?ooo`140?ooo`8000007`3oool003/0oooo00<00000
0?ooo`3oool01@3oool00`000?l0RR_R0?ooo`0;0?ooo`800?ZJ00<0oooo08X[hP2::n801@3oool2
0000o`030?ooo`000?l0003o0080003o0P3oool00`2::n80oooo0?ooo`0=0?ooo`0308X[hP3oool0
oooo03@0oooo0P000?lj0?ooo`80RR_R5P3oool50000o`040?ooo`000?l0003o0?ooo`@0003o00@0
RR_R0000o`000?l0oooo0P000?l20?ooo`80003o2`3oool60000o`<0oooo0`00nYXS0?ooo`0308X[
hP3oool0oooo04@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000
o`2::n80oooo00<0oooo0`00nYX70?ooo`0408X[hP3oool0oooo08X[hPD0oooo1`000?l00`3oool0
RR_R0?ooo`0l0?ooo`0308X[hP3oool0oooo00L0oooo0P000?l20?ooo`<00?ZJ5@3oool00`2::n80
oooo0?ooo`0e0?ooo`80003o00@0oooo0000o`000?l0oooo1P000?l00`2::n80oooo0000o`030000
o`<0oooo0P000?l;0?ooo`D0003o0`3oool3003jVR@0oooo00<0RR_R0?ooo`3oool0A03oool00`00
0000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`050?ooo`80003o00<0RR_R0?ooo`3o
ool02@3oool3003jVP80RR_R1@3oool20000o`<0oooo0`000?lA0?ooo`0308X[hP3oool0oooo03@0
oooo0P000?lj0?ooo`80RR_R5P3oool20000o`030?ooo`000?l0003o00<0003o00<0oooo0000o`00
0?l00P000?l0103oool0RR_R0000o`3oool30000o`030?ooo`000?l0003o00/0oooo1P000?l40?oo
o`<00?ZJ8`3oool00`2::n80oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool01@3oool20000o`0308X[hP3oool0oooo0080oooo0`00nYX60?ooo`0408X[hP3oool0oooo
08X[hPD0oooo0P000?l00`3oool0003o0000o`020000o`80oooo0`2::n8i0?ooo`0308X[hP3oool0
oooo00P0oooo0P000?l0103oool00?ZJ003jVP00nYXE0?ooo`0308X[hP3oool0oooo03H0oooo0P00
0?l00`3oool0003o0000o`030000o`060?ooo`000?l0003o0000o`3oool0RR_R1@000?l0103oool0
003o0000o`000?l;0?ooo`D0003o103oool3003jVR@0oooo00<0RR_R0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`050?ooo`80003o00<0RR_R0?ooo`3o
ool02P3oool2003jVP80RR_R1@3oool20000o`@0oooo0P000?lA0?ooo`0308X[hP3oool0oooo03@0
oooo0P000?lj0?ooo`80RR_R5P3oool20000o`80oooo10000?l00`3oool0003o0000o`020000o`04
0?ooo`2::n80003o0?ooo`<0003o00<0oooo0000o`000?l02`3oool60000o`D0oooo0`00nYXS0?oo
o`0308X[hP3oool0oooo0480oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?oo
o`030000o`2::n80oooo00@0oooo0`00nYX50?ooo`0308X[hP3oool0RR_R00H0oooo0P000?l30?oo
o`80003o1@3oool00`2::n80oooo0?ooo`0f0?ooo`0308X[hP3oool0oooo00P0oooo0P000?l3003j
VQD0oooo00<0RR_R0?ooo`3oool0=`3oool20000o`80oooo10000?l0103oool0003o0000o`000?l2
0?ooo`0308X[hP000?l0003o00D0003o303oool50000o`D0oooo0`00nYXS0?ooo`0308X[hP3oool0
oooo04<0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool01@3oool20000
o`0308X[hP3oool0oooo00X0oooo0P00nYX00`2::n80oooo0?ooo`030?ooo`<0003o103oool30000
oa00oooo00<0RR_R0?ooo`3oool0<`3oool30000ocX0oooo0P2::n8F0?ooo`80003o0P3oool40000
o`030?ooo`000?l0003o0080003o00<0oooo0000o`2::n8010000?l00`3oool0003o0000o`0;0?oo
o`H0003o1P3oool3003jVR<0oooo00<0RR_R0?ooo`3oool0@@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00H0oooo00<0003o08X[hP3oool01@3oool3003jVPD0oooo0P2::n860?oo
o`80003o0`3oool40000o`<0oooo00<0RR_R0?ooo`3oool0=P3oool00`2::n80oooo0?ooo`080?oo
o`80003o0P00nYXE0?ooo`0308X[hP3oool0oooo03P0oooo0P000?l20?ooo`@0003o00@0oooo0000
o`000?l0003o0P3oool00`000?l0RR_R0000o`050000o``0oooo1P000?l50?ooo`<00?ZJ8`3oool0
0`2::n80oooo0?ooo`120?ooo`030000003oool0oooo01d0oooo000k0?ooo`8000001P3oool20000
o`0308X[hP3oool0oooo00H0oooo0P000?l01@3oool0003o003jVP00nYX0RR_R00<0oooo10000?l6
0?ooo`030000o`00nYX00?ZJ00800?ZJ0`000?l:0?ooo`0308X[hP3oool0oooo03<0oooo0P000?lk
0?ooo`80RR_R6P3oool40000o`040?ooo`000?l0003o0000o`80oooo0P000?l00`2::n80003o0000
o`040000o``0oooo0P000?l00`3oool0003o0000o`070?ooo`800?ZJ903oool00`2::n80oooo0?oo
o`0o0?ooo`800000;`3oool00`000000oooo0?ooo`060?ooo`030000o`2::n80oooo00H0oooo0`00
nYX20?ooo`80003o0P2::n820?ooo`80003o00@0oooo0000o`000?l0003o103oool40000o`<0oooo
00<0RR_R0000o`3oool0=03oool00`2::n80oooo0?ooo`080?ooo`80003o0`00nYXE0?ooo`0308X[
hP3oool0oooo03`0oooo0`000?l20?ooo`<0003o0P3oool20000o`0308X[hP000?l0003o00<0003o
303oool30000o`030?ooo`000?l0003o00H0oooo0`00nYXS0?ooo`0308X[hP3oool0oooo0440oooo
00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool01P3oool20000o`0408X[hP3o
ool0oooo0?ooo`80003o0P3oool20000o`050?ooo`000?l00?ZJ003jVP2::n800`3oool40000o`L0
oooo1P00nYX00`000?l0oooo0?ooo`080?ooo`0308X[hP3oool0oooo03<0oooo0P000?lk0?ooo`80
RR_R6P3oool30000o`<0oooo0P000?l20?ooo`<0003o00<0RR_R0?ooo`000?l00`000?l<0?ooo`80
003o00@0oooo0000o`000?l0003o1P3oool3003jVR@0oooo00<0RR_R0?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0]0?ooo`<000001P3oool20000o`0308X[hP3oool0oooo00D0oooo0`00nYX0103o
ool0003o0000o`2::n830?ooo`80003o00<0oooo0000o`000?l0103oool5003jVP80oooo0P000?l0
0`2::n80oooo0?ooo`0b0?ooo`0308X[hP3oool0oooo00T0oooo00@0003o003jVP00nYX00?ZJ5@3o
ool00`2::n80oooo0?ooo`0m0?ooo`<0003o0`3oool20000o`80oooo0P000?l00`2::n80003o0000
o`030000o`d0oooo0P000?l0103oool0003o0000o`000?l60?ooo`<00?ZJ8P3oool00`2::n80oooo
0?ooo`100?ooo`8000007`3oool003/0oooo00<000000?ooo`3oool01P3oool20000o`0408X[hP3o
ool0oooo0?ooo`H0003o00<0oooo0000o`00nYX00P00nYX20?ooo`D0003o1`3oool2003jVP030?oo
o`00nYX00?ZJ00@00?ZJ203oool00`2::n80oooo0?ooo`0c0?ooo`80003o>`3oool208X[hQ/0oooo
0P000?l30?ooo`80003o0P3oool40000o`0408X[hP000?l0003o0000oa40oooo10000?l50?ooo`<0
0?ZJ8`3oool00`2::n80oooo0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01P3oool20000o`0308X[hP3oool0oooo0080oooo0P000?l00`3oool0003o003jVP03003jVP03
0000o`3oool0oooo0080oooo1@000?l00`3oool00?ZJ003jVP06003jVP050?ooo`000?l0003o0000
o`2::n80=03oool00`2::n80oooo0?ooo`090?ooo`<00?ZJ5@3oool00`2::n80oooo0?ooo`0n0?oo
o`<0003o0`3oool20000o`80oooo0`000?l00`2::n80oooo0000o`020000o`d0oooo0P000?l20?oo
o`<0003o1P3oool3003jVR80oooo00<0RR_R0?ooo`3oool0@03oool00`000000oooo0?ooo`0M0?oo
o`00>`3oool00`000000oooo0?ooo`060?ooo`80003o00<0RR_R0?ooo`3oool02P000?l2003jVP80
oooo10000?l70?ooo`800?ZJ00@0RR_R0?ooo`000?l0003o2000nYX40?ooo`0308X[hP3oool0oooo
03<0oooo0P000?lk0?ooo`80RR_R6`3oool20000o`L0oooo10000?l0102::n80003o0000o`000?lB
0?ooo`@0003o1@3oool3003jVR<0oooo00<0RR_R0?ooo`3oool0?P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00H0oooo0P000?l0103oool0RR_R0?ooo`3oool60000o`@00?ZJ00<0
003o0?ooo`3oool00P000?l9003jVP80oooo0P00nYX01@3oool0003o0000o`000?l0RR_R00<0oooo
0P000?l^0?ooo`0308X[hP3oool0oooo00X0oooo0P00nYXF0?ooo`0308X[hP3oool0oooo03l0oooo
0P000?l70?ooo`<0003o00<0RR_R0?ooo`000?l00P000?lB0?ooo`80003o1`3oool3003jVR80oooo
00<0RR_R0?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?oo
o`060?ooo`80003o00<0oooo08X[hP000?l00P000?l00`3oool0003o0000o`050000o`800?ZJ0P3o
ool20000o`T0oooo0P00nYX01@2::n80003o0000o`000?l0oooo0080003o1P00nYX30?ooo`0308X[
hP3oool0oooo03<0oooo0P000?lD0?oooa00RR_R5`3oool208X[hR@0oooo10000?l0103oool0RR_R
0000o`000?lD0?ooo`80003o1P3oool3003jVR80oooo00<0RR_R0?ooo`3oool0?P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo0P000?l00`3oool0RR_R0?ooo`090000o`d0
0?ZJ1@3oool3003jVP@0003o00<0RR_R0?ooo`3oool00P000?l^0?ooo`0308X[hP3oool0oooo00T0
oooo0`00nYXE0?ooo`0308X[hP3oool0oooo0400oooo0P000?l70?ooo`<0003o00<0oooo08X[hP00
0?l00P000?lB0?ooo`<0003o1`3oool2003jVR<0oooo00<0RR_R0?ooo`3oool0?P3oool00`000000
oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`060?ooo`80003o00<0oooo0000o`2::n80
0P000?l40?ooo`@0003o1000nYX20000o`T0oooo0P00nYX01@2::n80003o0000o`000?l0oooo0080
003o00@0oooo0000o`000?l0003o1@00nYX00`2::n80oooo0?ooo`0c0?ooo`80003o2P3oool:08X[
hQ00oooo3@2::n8:0?ooo`80RR_R9@3oool30000o`040?ooo`2::n80003o0000oa@0oooo0P000?l7
0?ooo`<00?ZJ8P3oool00`2::n80oooo0?ooo`0m0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool01P3oool20000o`80oooo00<0RR_R0000o`000?l00P3oool50000o`P00?ZJ2P3oool0
0`000?l0RR_R003jVP040000o`0308X[hP3oool0003o0080003o;@3oool00`2::n80oooo0?ooo`0:
0?ooo`800?ZJ00<0003o0?ooo`3oool04P3oool00`2::n80oooo0?ooo`1;0?ooo`80003o0P3oool0
0`2::n80003o0000o`0C0?ooo`80003o1`3oool3003jVR<0oooo00<0RR_R0?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0M0?ooo`00>`3oool2000000L0oooo0P000?l00`3oool0003o08X[hP060?oo
o`<0003o00<0oooo0000o`00nYX01@00nYX80?ooo`800?ZJ0P2::n820000o`030?ooo`000?l0003o
00D0003o1000nYX00`2::n80oooo0?ooo`0c0?ooo`80003o103oool608X[hRL0oooo2@2::n800`3o
ool0RR_R08X[hP0U0?ooo`80003o0`3oool00`2::n80003o0?ooo`0C0?ooo`80003o203oool2003j
VR<0oooo00<0RR_R0?ooo`3oool0>`3oool2000002l0oooo00<000000?ooo`3oool01P3oool20000
o`80oooo00<0003o08X[hP000?l0103oool40000o`800?ZJ10000?l;0?ooo`030000o`2::n800?ZJ
0080003o00@0oooo0000o`2::n80oooo0`000?l]0?ooo`0308X[hP3oool0oooo00T0oooo0`00nYX0
0`000?l0oooo0?ooo`0A0?ooo`0308X[hP3oool0oooo04`0oooo0P000?l30?ooo`0308X[hP000?l0
oooo0180oooo0P000?l80?ooo`<00?ZJ8`3oool00`2::n80oooo0?ooo`0l0?ooo`030000003oool0
oooo01d0oooo000k0?ooo`030000003oool0oooo00H0oooo0P000?l0103oool0003o0000o`2::n85
0?ooo`80003o1@3oool7003jVPD0oooo0P00nYX208X[hP80003o0P3oool60000o`80oooo0P00nYX0
0`2::n80oooo0?ooo`0c0?ooo`80003o102::n8f0?ooo`<0RR_R9@3oool20000o`@0oooo00<0RR_R
0?ooo`3oool04P3oool20000o`P0oooo1000nYXR0?ooo`0308X[hP3oool0oooo03/0oooo00<00000
0?ooo`3oool0;@3oool3000000H0oooo0`000?l00`3oool0003o08X[hP050?ooo`@0003o0P3oool2
0000o`d0oooo0P2::n82003jVP80oooo0P000?l0102::n80003o0000o`000?l]0?ooo`0308X[hP3o
ool0oooo00P0oooo0`00nYX20000oa80oooo00<0RR_R0?ooo`3oool0C@3oool20000o`<0oooo00<0
003o08X[hP3oool04P3oool20000o`T0oooo0`00nYXR0?ooo`0308X[hP3oool0oooo03/0oooo0P00
000O0?ooo`00>`3oool00`000000oooo0?ooo`060?ooo`D0003o00<0oooo08X[hP3oool00`3oool2
0000o`<0oooo00<0RR_R0?ooo`3oool00P3oool;003jVP80RR_R00@0003o0?ooo`3oool0oooo0`00
0?l00`3oool0003o0000o`020?ooo`800?ZJ00<0RR_R0?ooo`3oool08`3oool20000o`X0oooo0P00
0?l0103oool0RR_R08X[hP2::n8k0?ooo`03003jVP2::n80oooo02@0oooo0P000?l50?ooo`0308X[
hP3oool0oooo0140oooo0P000?l90?ooo`@00?ZJ8P3oool00`2::n80oooo0?ooo`0j0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool20000o`040?ooo`000?l0003o08X[hPD0
oooo0P000?lB0?ooo`80RR_R0P00nYX20?ooo`80003o00@0RR_R0000o`000?l0003o;03oool00`2:
:n80oooo0?ooo`070?ooo`050000o`00nYX00?ZJ003jVP3oool00P000?lA0?ooo`0308X[hP3oool0
oooo04h0oooo0P000?l40?ooo`0308X[hP3oool0oooo0140oooo0P000?l:0?ooo`<00?ZJ8P3oool0
0`2::n80oooo0?ooo`0k0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo
00H0oooo10000?l20?ooo`0308X[hP3oool0oooo00L0oooo00<0RR_R0?ooo`3oool01@3oool7003j
VP040?ooo`2::n80003o08X[hPL0oooo0P000?l20?ooo`800?ZJ00<0RR_R0?ooo`3oool06`3oool2
0000o`H0oooo0P000?l50?ooo`80003o0`3oool308X[hP030?ooo`000?l0003o03/0oooo00<00?ZJ
08X[hP3oool0;03oool00`2::n80oooo0?ooo`0@0?ooo`80003o2`3oool3003jVR40oooo00<0RR_R
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo1@000?l0
0`2::n80oooo0?ooo`030?ooo`80003o0P3oool00`2::n80oooo0?ooo`0=0?ooo`80RR_R0P00nYX2
0?ooo`<0003o00@0RR_R0000o`000?l0003o:P3oool00`000?l0RR_R0?ooo`080?ooo`<00?ZJ0P3o
ool20000oa40oooo00<0RR_R0?ooo`3oool0CP3oool20000o`D0oooo00<0RR_R0?ooo`3oool0403o
ool30000o`X0oooo0`00nYXR0?ooo`0308X[hP3oool0oooo03X0oooo00<000000?ooo`3oool07@3o
ool003/0oooo00<000000?ooo`3oool01`3oool30000o`<0oooo00<0RR_R0?ooo`3oool01P3oool0
0`2::n80oooo0?ooo`090?ooo`<00?ZJ00@0oooo08X[hP000?l0RR_R1`3oool20000o`80oooo0P00
nYX00`2::n80oooo0?ooo`0K0?ooo`80003o1P3oool20000o`D0oooo0P000?l00`3oool0RR_R08X[
hP020000o`040?ooo`000?l0003o0000oc/0oooo00<00?ZJ08X[hP3oool0;03oool00`2::n80oooo
0?ooo`0@0?ooo`80003o303oool3003jVR40oooo00<0RR_R0?ooo`3oool0>@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00L0oooo10000?l20?ooo`0308X[hP3oool0oooo00H0oooo
00<0RR_R0?ooo`3oool0303oool0102::n80oooo0000o`2::n82003jVP@0oooo00@0RR_R0?ooo`00
0?l0003o8@3oool20000o`L0oooo00<0003o08X[hP3oool00`3oool20000o`<0oooo0P00nYX00`00
0?l0oooo0?ooo`020000oa00oooo00<0RR_R0?ooo`3oool0EP3oool00`2::n80oooo0?ooo`0A0?oo
o`80003o2`3oool2003jVR<0oooo00<0RR_R0?ooo`3oool0>@3oool00`000000oooo0?ooo`0M0?oo
o`00>`3oool00`000000oooo0?ooo`070?ooo`<0003o0`3oool00`2::n80oooo0?ooo`060?ooo`03
08X[hP3oool0oooo00d0oooo00<0RR_R0000o`2::n801`3oool30000o`040?ooo`00nYX00?ZJ08X[
hQd0oooo0P000?l60?ooo`80003o00@0oooo0000o`000?l0oooo0`000?l00`2::n80oooo0000o`05
0000oc`0oooo00<00?ZJ08X[hP3oool0;@3oool00`2::n80oooo0?ooo`0?0?ooo`80003o3@3oool2
003jVR80oooo00<0RR_R0?ooo`3oool0>03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00L0oooo10000?l30?ooo`80RR_R1@3oool00`2::n80oooo08X[hP0=0?ooo`0408X[hP3oool0
003o08X[hP800?ZJ1@3oool00`2::n80003o0000o`0Q0?ooo`80003o1`3oool00`2::n80003o0?oo
o`030?ooo`80003o0P3oool3003jVP030000o`3oool0003o0080003o3`3oool00`2::n80oooo0?oo
o`1H0?ooo`0308X[hP3oool0oooo0100oooo0P000?l;0?ooo`<00?ZJ8P3oool00`2::n80oooo0?oo
o`0i0?ooo`030000003oool0oooo01d0oooo000k0?ooo`800000203oool30000o`@0oooo00<0RR_R
0?ooo`3oool0103oool00`2::n80oooo08X[hP0=0?ooo`0508X[hP3oool0003o0000o`2::n801`3o
ool20000o`040?ooo`00nYX00?ZJ08X[hQd0oooo0P000?l50?ooo`H0003o00@0oooo0000o`2::n80
RR_R0P3oool60000oc`0oooo00<00?ZJ08X[hP3oool0;P3oool00`2::n80oooo0?ooo`0>0?ooo`<0
003o303oool3003jVR80oooo00<0RR_R0?ooo`3oool0=P3oool2000002l0oooo00<000000?ooo`3o
ool01`3oool40000o`D0oooo00@0RR_R0?ooo`3oool0oooo0P2::n800`3oool0RR_R0?ooo`0;0?oo
o`0508X[hP3oool0oooo0000o`2::n800`00nYX40?ooo`0308X[hP000?l0003o0240oooo0P000?l7
0?ooo`0308X[hP000?l0oooo0080003o00@0oooo0000o`000?l0oooo0`00nYX20000o`030?ooo`00
0?l0003o00l0oooo00<0RR_R0?ooo`3oool0FP3oool00`2::n80oooo0?ooo`0?0?ooo`80003o303o
ool3003jVR80oooo00<0RR_R0?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool0
0`000000oooo0?ooo`070?ooo`<0003o1@3oool00`2::n80oooo0?ooo`030?ooo`0308X[hP3oool0
RR_R00d0oooo00D0RR_R0?ooo`000?l0003o08X[hP070?ooo`80003o00@0oooo003jVP00nYX0RR_R
703oool30000o`D0oooo1P000?l208X[hP80003o0P3oool60000oc`0oooo00<00?ZJ08X[hP3oool0
;`3oool00`2::n80oooo0?ooo`0>0?ooo`80003o3@3oool3003jVR80oooo00<0RR_R0?ooo`3oool0
=P3oool00`000000oooo0?ooo`0]0?ooo`<00000203oool30000o`H0oooo0`2::n840?ooo`0308X[
hP3oool0oooo00P0oooo00L0RR_R0?ooo`3oool0oooo0000o`2::n80oooo00800?ZJ1@3oool00`2:
:n80003o0?ooo`0P0?ooo`<0003o1@3oool010000?l0RR_R0000o`3oool50000o`<00?ZJ1P000?l>
0?ooo`0308X[hP3oool0oooo05`0oooo00<0RR_R0?ooo`3oool03P3oool20000o`d0oooo1000nYXQ
0?ooo`0308X[hP3oool0oooo03H0oooo0P00000O0?ooo`00>`3oool00`000000oooo0?ooo`070?oo
o`80003o1`3oool00`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0RR_R00d0oooo00D0RR_R0?oo
o`3oool0oooo08X[hP070?ooo`80003o00@0oooo003jVP00nYX0RR_R703oool30000o`D0oooo1@00
0?l00`2::n80003o0000o`020000o`030?ooo`000?l0003o00D0003o?03oool00`00nYX0RR_R0?oo
o`0_0?ooo`0308X[hP3oool0oooo00h0oooo0P000?l>0?ooo`<00?ZJ8P3oool00`2::n80oooo0?oo
o`0e0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203oool20000o`l0oooo00<0
RR_R0?ooo`3oool01`3oool01`2::n80oooo0?ooo`3oool0003o08X[hP3oool00`00nYX40?ooo`03
08X[hP000?l0oooo0200oooo0`000?l50?ooo`0408X[hP000?l0003o0?ooo`@0003o0`00nYX20000
o`030?ooo`000?l0003o0080003o3@3oool00`2::n80oooo0?ooo`1N0?ooo`0308X[hP3oool0oooo
00d0oooo0P000?l>0?ooo`@00?ZJ803oool00`2::n80oooo0?ooo`0g0?ooo`030000003oool0oooo
01d0oooo000k0?ooo`030000003oool0oooo00L0oooo0P000?l80?ooo`0708X[hP3oool0oooo0?oo
o`2::n80oooo08X[hP0=0?ooo`0308X[hP3oool0oooo0080oooo00<0RR_R0?ooo`3oool0103oool2
0000o`040?ooo`00nYX00?ZJ08X[hQ`0oooo10000?l40?ooo`@0003o00<0RR_R0000o`000?l00`00
0?l00`3oool0003o0000o`020?ooo`<0003o?03oool00`00nYX0RR_R0?ooo`0`0?ooo`0308X[hP3o
ool0oooo00d0oooo0P000?l?0?ooo`<00?ZJ8@3oool00`2::n80oooo0?ooo`0e0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0203oool20000oa00oooo00<0RR_R0?ooo`3oool0103o
ool208X[hPD0oooo00<0RR_R0?ooo`3oool00P00nYX40?ooo`0308X[hP000?l0oooo0200oooo0`00
0?l50?ooo`0308X[hP000?l0003o00@0003o0`00nYX0103oool0003o0000o`3oool40000o`d0oooo
00<0RR_R0?ooo`3oool0GP3oool00`2::n80oooo0?ooo`0=0?ooo`80003o403oool2003jVR40oooo
00<0RR_R0?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?ooo`007`3oool3000000@0oooo00@0
00000?ooo`3oool0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`0A0?ooo`0508X[
hP3oool0oooo0?ooo`2::n800P3oool00`2::n80oooo0?ooo`0:0?ooo`0308X[hP3oool0oooo00<0
oooo00<0RR_R0?ooo`3oool00`3oool20000o`80oooo00<00?ZJ08X[hP3oool06`3oool010000?l0
RR_R08X[hP2::n840?ooo`<0003o00<0RR_R0000o`000?l00P3oool50000o`<0oooo0P000?ll0?oo
o`03003jVP2::n80oooo0340oooo00<0RR_R0?ooo`3oool0303oool20000oa00oooo0`00nYXQ0?oo
o`0308X[hP3oool0oooo03@0oooo00<000000?ooo`3oool04P3oool3000000@0oooo00@000000?oo
o`3oool0oooo1@0000020?ooo`<000001P3oool00`000000oooo0?ooo`0K0?ooo`80RR_R0`3oool0
0`2::n80oooo0?ooo`050?ooo`0308X[hP3oool0oooo00800?ZJ103oool00`000?l0RR_R0?ooo`0P
0?ooo`<0003o103oool00`2::n80003o0000o`030000o`060?ooo`000?l00?ZJ003jVP000?l0oooo
0P000?l20?ooo`<0003o303oool00`2::n80oooo0?ooo`1P0?ooo`0308X[hP3oool0oooo00`0oooo
0P000?l@0?ooo`<00?ZJ8@3oool00`2::n80oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo
000P0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`2::n80oooo08X[hP030?ooo`03
08X[hP3oool0oooo00X0oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`030?ooo`80
003o0P3oool00`00nYX0RR_R0?ooo`0I0?ooo`<0RR_R0P000?l0102::n80oooo0?ooo`3oool30000
o`0408X[hP000?l0003o0000o`<0oooo10000?m10?ooo`03003jVP2::n80oooo0340oooo00<0RR_R
0?ooo`3oool0303oool20000oa40oooo0P00nYXQ0?ooo`0308X[hP3oool0oooo03@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo0`2::n890?ooo`0308X[
hP3oool00?ZJ00800?ZJ0`3oool00`000?l0RR_R0?ooo`0G0?ooo`L0RR_R00<0oooo0000o`000?l0
0P000?l40?ooo`0308X[hP000?l0003o00<0003o00H0oooo003jVP00nYX00?ZJ0000o`3oool20000
o`<0oooo0P000?l;0?ooo`0308X[hP3oool0oooo0680oooo00<0RR_R0?ooo`3oool02`3oool30000
oa00oooo0`00nYXQ0?ooo`0308X[hP3oool0oooo03@0oooo00<000000?ooo`3oool07@3oool00200
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo0`00000C0?ooo`80RR_R103oool00`2::n80oooo0?ooo`090?ooo`0308X[hP3oool0oooo00@0
oooo00<0RR_R0?ooo`3oool00P3oool20000o`80oooo00<00?ZJ08X[hP3oool05@3oool408X[hP80
oooo0`000?l00`2::n80oooo0?ooo`030000o`0408X[hP000?l0003o0000o`@0oooo0`000?m20?oo
o`03003jVP2::n80oooo0380oooo00<0RR_R0?ooo`3oool02`3oool20000oa40oooo0`00nYXQ0?oo
o`0308X[hP3oool0oooo0340oooo0`00000E0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<0RR_R0?oo
o`3oool00P00nYX30?ooo`030000o`2::n80003o01<0oooo102::n870?ooo`80RR_R10000?l30?oo
o`0308X[hP000?l0003o00<0003o00<0oooo003jVP00nYX01@000?l?0?ooo`0308X[hP3oool0oooo
06@0oooo00<0RR_R0?ooo`3oool02`3oool20000oa40oooo0`00nYXQ0?ooo`0308X[hP3oool0oooo
03<0oooo00<000000?ooo`3oool07@3oool00200oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`2::n80
oooo0?ooo`020?ooo`0308X[hP3oool0oooo00T0oooo00<0RR_R0?ooo`3oool01@3oool0102::n80
oooo0?ooo`3oool20000o`80oooo00<00?ZJ08X[hP3oool04P3oool308X[hPH0oooo0`000?l00`2:
:n80oooo0?ooo`020000o`0308X[hP3oool0003o0080003o103oool30000od80oooo00<00?ZJ08X[
hP3oool0<`3oool00`2::n80oooo0?ooo`0:0?ooo`80003o4P3oool3003jVR40oooo00<0RR_R0?oo
o`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`<00000:@3oool00`2::n80oooo0?ooo`02003j
VP@0oooo00<0RR_R0000o`3oool04@3oool00`2::n80oooo0?ooo`0:0?ooo`030000o`2::n80oooo
0080003o00<0oooo0000o`2::n800P000?l0103oool0003o0000o`000?l3003jVP@0003o3`3oool0
0`2::n80oooo0?ooo`1U0?ooo`0308X[hP3oool0oooo00/0oooo0P000?lB0?ooo`<00?ZJ8@3oool0
0`2::n80oooo0?ooo`0`0?ooo`<000007`3oool00200oooo00<000000?ooo`3oool01`3oool01P00
0000oooo0?ooo`3oool000000?ooo`@000001`3oool00`000000oooo0?ooo`0J0?ooo`0308X[hP3o
ool0oooo00P0oooo00<0RR_R0?ooo`3oool01@3oool0102::n80oooo0?ooo`3oool30000o`030?oo
o`00nYX0RR_R0140oooo0P2::n880?ooo`D0003o00D0RR_R0?ooo`000?l0003o08X[hP020?ooo`80
003o103oool30000od80oooo00<00?ZJ08X[hP3oool0=03oool00`2::n80oooo0?ooo`090?ooo`80
003o4`3oool4003jVR00oooo00<0RR_R0?ooo`3oool0<@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00L0oooo00H000000?ooo`3oool0oooo0000003oool4000000H0oooo00<00000
0?ooo`3oool0:P3oool00`2::n80oooo003jVP02003jVP<0oooo00<0003o08X[hP3oool03`3oool2
08X[hPd0oooo0P000?l01P2::n80003o0000o`3oool0003o08X[hP80003o00<0oooo0000o`000?l0
0`00nYX00`3oool0003o0000o`020000o`h0oooo00<0RR_R0?ooo`3oool0I`3oool00`2::n80oooo
0?ooo`0:0?ooo`80003o4`3oool3003jVR00oooo00<0RR_R0?ooo`3oool0<P3oool00`000000oooo
0?ooo`0M0?ooo`007`3oool2000000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000X0
oooo00<000000?ooo`3oool06`3oool00`2::n80oooo0?ooo`070?ooo`0308X[hP3oool0oooo00H0
oooo00@0RR_R0?ooo`3oool0oooo0P000?l00`3oool00?ZJ08X[hP0@0?ooo`0308X[hP3oool0oooo
00P0oooo0P000?l01`3oool0003o0000o`2::n80oooo0000o`2::n800`3oool20000o`@0oooo0P00
0?m30?ooo`03003jVP2::n80oooo03D0oooo00<0RR_R0?ooo`3oool0203oool20000oa@0oooo1000
nYXP0?ooo`0308X[hP3oool0oooo0300oooo00<000000?ooo`3oool04P3oool2000000T0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool0:P3oool00`2::n80
oooo0?ooo`02003jVP<0oooo00<0003o08X[hP3oool03@3oool208X[hPl0oooo0P000?l01P3oool0
RR_R0000o`3oool0003o08X[hP80003o00<0oooo0000o`00nYX00P00nYX30?ooo`<0003o3P3oool0
0`2::n80oooo0?ooo`1X0?ooo`0308X[hP3oool0oooo00T0oooo0P000?lD0?ooo`800?ZJ8@3oool0
0`2::n80oooo0?ooo`0a0?ooo`030000003oool0oooo01d0oooo000P0?ooo`030000003oool0oooo
00P0oooo0`0000020?ooo`D000001P3oool00`000000oooo0?ooo`0K0?ooo`0308X[hP3oool0oooo
00L0oooo00<0RR_R0?ooo`3oool01P3oool0102::n80oooo0?ooo`3oool20000o`030?ooo`00nYX0
RR_R00h0oooo0P2::n8;0?ooo`80003o00@0oooo0000o`000?l0RR_R0P000?l0102::n80oooo0?oo
o`3oool20000o`@0oooo0P000?m30?ooo`03003jVP2::n80oooo03H0oooo00<0RR_R0?ooo`3oool0
1`3oool30000oaD0oooo0P00nYXP0?ooo`0308X[hP3oool0oooo0300oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`080?ooo`<000000P3oool5000000D0oooo00<000000?ooo`3oool0
:P3oool00`2::n80oooo0?ooo`03003jVP80oooo00<0003o08X[hP3oool0303oool00`2::n80oooo
0?ooo`0?0?ooo`80003o00H0oooo0000o`2::n80oooo0000o`2::n830?ooo`<00?ZJ103oool20000
o`h0oooo00<0RR_R0?ooo`3oool0J@3oool00`2::n80oooo0?ooo`090?ooo`80003o503oool3003j
VR00oooo00<0RR_R0?ooo`3oool0<@3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000
oooo0?ooo`0L0?ooo`0308X[hP3oool0oooo00H0oooo00<0RR_R0?ooo`3oool01`3oool00`2::n80
oooo0?ooo`020000o`030?ooo`00nYX0RR_R00`0oooo0P2::n8=0?ooo`80003o00@0oooo0000o`00
0?l0RR_R0P000?l00`2::n80oooo0?ooo`1;0?ooo`800?ZJ00<0RR_R0?ooo`3oool0=@3oool00`2:
:n80oooo0?ooo`080?ooo`80003o5@3oool3003jVR00oooo00<0RR_R0?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02/0oooo00<0RR_R0?ooo`3oool00P00nYX20?oo
o`80003o00<0RR_R0?ooo`3oool02P3oool00`2::n80oooo0?ooo`0?0?ooo`80003o00H0oooo0000
o`2::n80oooo0000o`2::n830?ooo`800?ZJ1@3oool20000o`d0oooo00<0RR_R0?ooo`3oool0J`3o
ool00`2::n80oooo0?ooo`080?ooo`<0003o503oool3003jVR00oooo00<0RR_R0?ooo`3oool0<03o
ool00`000000oooo0?ooo`0M0?ooo`00>`3oool2000001d0oooo00<0RR_R0?ooo`3oool01P3oool0
0`2::n80oooo0?ooo`080?ooo`0708X[hP3oool0003o0000o`3oool00?ZJ08X[hP0;0?ooo`0308X[
hP3oool0oooo00d0oooo0P000?l20?ooo`040000o`2::n80003o08X[hTh0oooo0P00nYX00`2::n80
oooo0?ooo`0f0?ooo`0308X[hP3oool0oooo00L0oooo0P000?lF0?ooo`<00?ZJ7`3oool00`2::n80
oooo0?ooo`0^0?ooo`800000;`3oool00`000000oooo0?ooo`0[0?ooo`0308X[hP3oool0oooo00<0
0?ZJ00@0oooo0000o`000?l0RR_R2`3oool00`2::n80oooo0?ooo`0@0?ooo`80003o00<0oooo0000
o`000?l00P2::n800`000?l0oooo0?ooo`03003jVQ80oooo0P2::n9_0?ooo`0308X[hP3oool0oooo
00P0oooo0P000?lE0?ooo`<00?ZJ803oool00`2::n80oooo0?ooo`0_0?ooo`030000003oool0oooo
01d0oooo000k0?ooo`030000003oool0oooo01d0oooo00<0RR_R0?ooo`3oool01@3oool00`2::n80
oooo0?ooo`090?ooo`0608X[hP000?l0003o0?ooo`00nYX0RR_R2@3oool208X[hQ00oooo0P000?l2
0?ooo`80003o0P2::n9>0?ooo`800?ZJ00<0RR_R0?ooo`3oool0=P3oool00`2::n80oooo0?ooo`07
0?ooo`80003o5`3oool3003jVQl0oooo00<0RR_R0?ooo`3oool0;P3oool00`000000oooo0?ooo`0]
0?ooo`<00000:`3oool0102::n80oooo0?ooo`3oool2003jVP040?ooo`000?l0003o08X[hPX0oooo
00<0RR_R0?ooo`3oool04@3oool20000o`80oooo00D0003o08X[hP2::n80003o0?ooo`03003jVQ80
oooo00<0RR_R0?ooo`3oool0L03oool00`2::n80oooo0?ooo`070?ooo`80003o5P3oool3003jVR00
oooo00<0RR_R0?ooo`3oool0;@3oool2000001l0oooo000k0?ooo`030000003oool0oooo01h0oooo
00<0RR_R0?ooo`3oool0103oool00`2::n80oooo0?ooo`0:0?ooo`0308X[hP000?l0oooo00800?ZJ
00<0RR_R0?ooo`3oool01@3oool00`2::n80oooo0?ooo`0?0?ooo`<0003o0P3oool20000o`80RR_R
CP3oool2003jVP0308X[hP3oool0oooo03L0oooo00<0RR_R0?ooo`3oool01P3oool30000oaL0oooo
0`00nYXO0?ooo`0308X[hP3oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0/0?ooo`0308X[hP3oool0oooo00800?ZJ0P3oool00`000?l0RR_R0?ooo`080?ooo`0308X[
hP3oool0oooo0180oooo0P000?l20?ooo`040000o`2::n80RR_R0000o`<00?ZJ4`3oool00`2::n80
oooo0?ooo`1a0?ooo`0308X[hP3oool0oooo00H0oooo0`000?lF0?ooo`<00?ZJ803oool00`2::n80
oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo01h0oooo
00<0RR_R0?ooo`3oool00`3oool00`2::n80oooo0?ooo`0;0?ooo`0308X[hP000?l0oooo00800?ZJ
00<0RR_R0?ooo`3oool0103oool00`2::n80oooo0?ooo`0@0?ooo`80003o0`3oool20000o`0308X[
hP000?l0oooo04d0oooo0P00nYX00`2::n80oooo0?ooo`0h0?ooo`0308X[hP3oool0oooo00H0oooo
0P000?lH0?ooo`<00?ZJ7`3oool00`2::n80oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;03oool00`2::n80oooo0?ooo`03003jVP040?ooo`000?l0003o08X[hPL0
oooo00<0RR_R0?ooo`3oool04P3oool30000o`80oooo0P000?l0102::n800?ZJ003jVP00nYXC0?oo
o`0308X[hP3oool0oooo07<0oooo00<0RR_R0?ooo`3oool01P3oool20000oaL0oooo0`00nYXO0?oo
o`0308X[hP3oool0oooo02d0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3o
ool07`3oool00`2::n80oooo0?ooo`020?ooo`0308X[hP3oool0oooo00/0oooo00<0003o08X[hP3o
ool00P00nYX00`2::n80oooo0?ooo`030?ooo`0308X[hP3oool0oooo0140oooo0P000?l30?ooo`@0
003oCP3oool2003jVP0308X[hP3oool0oooo03T0oooo00<0RR_R0?ooo`3oool01@3oool20000oaT0
oooo0P00nYXP0?ooo`0308X[hP3oool0oooo02/0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0/0?ooo`0408X[hP3oool0oooo0?ooo`800?ZJ00@0oooo0000o`000?l0RR_R1P3oool0
0`2::n80oooo0?ooo`0C0?ooo`80003o0`3oool20000o`<00?ZJ4`3oool00`2::n80oooo0?ooo`1d
0?ooo`0308X[hP3oool0oooo00H0oooo0P000?lH0?ooo`<00?ZJ7`3oool00`2::n80oooo0?ooo`0/
0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo0200oooo00D0RR_R0?oo
o`3oool0oooo08X[hP0=0?ooo`80003o00@0RR_R003jVP00nYX0RR_R1@3oool00`2::n80oooo0?oo
o`0A0?ooo`80003o103oool20000odl0oooo0P00nYX00`2::n80oooo0?ooo`0j0?ooo`0308X[hP3o
ool0oooo00@0oooo0P000?lI0?ooo`<00?ZJ7`3oool00`2::n80oooo0?ooo`0[0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;03oool0102::n80oooo0?ooo`3oool2003jVP040?oo
o`000?l0003o08X[hPH0oooo00<0RR_R0?ooo`3oool04`3oool20000o`<0oooo0P000?l2003jVQ<0
oooo00<0RR_R0?ooo`3oool0MP3oool00`2::n80oooo0?ooo`050?ooo`80003o6@3oool3003jVQh0
oooo00<0RR_R0?ooo`3oool0;03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool200000280oooo
00@0RR_R0?ooo`3oool0RR_R3@3oool30000o`0308X[hP00nYX0RR_R00@0oooo00<0RR_R0?ooo`3o
ool04P3oool20000o`@0oooo0`00nYY>0?ooo`800?ZJ00<0RR_R0?ooo`3oool0>P3oool00`2::n80
oooo0?ooo`040?ooo`80003o6P3oool3003jVQl0oooo00<0RR_R0?ooo`3oool0:@3oool2000002l0
oooo00<000000?ooo`3oool0;@3oool00`2::n80oooo0?ooo`03003jVP80003o00<0oooo08X[hP3o
ool00`3oool00`2::n80oooo0?ooo`0D0?ooo`80003o103oool3003jVQ80oooo00<0RR_R0?ooo`3o
ool0N03oool00`2::n80oooo0?ooo`040?ooo`80003o6P3oool3003jVQh0oooo00<0RR_R0?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`0R0?ooo`0308X[
hP3oool0RR_R00h0oooo0P000?l00`2::n800?ZJ08X[hP030?ooo`0308X[hP3oool0oooo0180oooo
0`000?l40?ooo`H00?ZJB`3oool2003jVP0308X[hP3oool0oooo03/0oooo00<0RR_R0?ooo`3oool0
0`3oool30000oaX0oooo0`00nYXN0?ooo`0308X[hP3oool0oooo02X0oooo00<000000?ooo`3oool0
;@3oool3000002d0oooo00@0RR_R0?ooo`3oool0oooo0P00nYX30000o`0308X[hP3oool0oooo0080
oooo00<0RR_R0?ooo`3oool0503oool20000o`030?ooo`00nYX00?ZJ00<00?ZJ4P3oool00`2::n80
oooo0?ooo`1j0?ooo`0308X[hP3oool0oooo00<0oooo0P000?lK0?ooo`<00?ZJ7P3oool00`2::n80
oooo0?ooo`0Y0?ooo`8000007`3oool003/0oooo00<000000?ooo`3oool08`3oool208X[hPh0oooo
0P000?l00`2::n800?ZJ08X[hP020?ooo`0308X[hP3oool0oooo01<0oooo0P000?l50?ooo`T00?ZJ
B03oool2003jVP0308X[hP3oool0oooo03`0oooo00<0RR_R0?ooo`3oool00`3oool20000oa/0oooo
0P00nYXO0?ooo`0308X[hP3oool0oooo02T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`0408X[hP3oool0oooo0?ooo`800?ZJ00@0oooo0000o`000?l0RR_R103oool00`2:
:n80oooo0?ooo`0C0?ooo`<0003o1P00nYX@0?ooo`80RR_ROP3oool00`2::n80oooo0?ooo`020?oo
o`80003o703oool2003jVQh0oooo00<0RR_R0?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?oo
o`00>`3oool00`000000oooo0?ooo`0S0?ooo`80RR_R3P3oool20000o`0308X[hP00nYX0RR_R0080
oooo00<0RR_R0?ooo`3oool04`3oool20000o`D0oooo0P00nYX30?ooo`P00?ZJA03oool2003jVP03
08X[hP3oool0oooo03d0oooo00<0RR_R0?ooo`3oool00P3oool20000oa/0oooo1000nYXN0?ooo`03
08X[hP3oool0oooo02P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`04
08X[hP3oool0oooo0?ooo`<00?ZJ0P000?l01@2::n80oooo0?ooo`3oool0RR_R01D0oooo1P00nYXC
0?ooo`0308X[hP3oool0oooo07l0oooo00@0RR_R0?ooo`3oool0oooo0P000?lL0?ooo`<00?ZJ7P3o
ool00`2::n80oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0
oooo02@0oooo00<0RR_R0?ooo`3oool0303oool20000o`0508X[hP00nYX0RR_R0?ooo`2::n805P3o
ool20000o`D0oooo00<00?ZJ08X[hP3oool01@3oool8003jVT40oooo0P00nYX00`2::n80oooo0?oo
o`0n0?ooo`0408X[hP3oool0oooo0?ooo`80003o703oool4003jVQd0oooo00<0RR_R0?ooo`3oool0
:03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00@0RR_R0?ooo`3oool0
oooo0P00nYX20000o`0408X[hP3oool0oooo08X[hQD0oooo1P00nYX40?ooo`0308X[hP3oool0oooo
00/0oooo0P2::n:20?ooo`0408X[hP3oool0oooo0?ooo`80003o7@3oool3003jVQh0oooo00<0RR_R
0?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`0c0?oo
o`<0003o0`2::n8G0?ooo`80003o1@3oool00`00nYX0RR_R0?ooo`090?ooo`H00?ZJ?`3oool2003j
VP0308X[hP3oool0oooo03l0oooo00<0RR_R0?ooo`3oool00P000?lH0?ooo`80003o103oool3003j
VQd0oooo00<0RR_R0?ooo`3oool09`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02h0oooo00@0RR_R0?ooo`3oool0oooo0`00nYX01@000?l0RR_R0?ooo`3oool0RR_R0140oooo1P00
nYX20000o`H0oooo00<0RR_R0?ooo`3oool02@3oool208X[hXD0oooo00<0RR_R0?ooo`3oool00`00
0?lM0?ooo`<00?ZJ7@3oool00`2::n80oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo000k
0?ooo`800000=@3oool20000o`<0RR_R5`3oool20000o`@0oooo0P00nYX208X[hP`0oooo1P00nYXl
0?ooo`800?ZJ00<0RR_R0?ooo`3oool0?`3oool00`2::n80oooo0?ooo`020000oaP0oooo0P000?l5
0?ooo`<00?ZJ7@3oool00`2::n80oooo0?ooo`0U0?ooo`800000;`3oool00`000000oooo0?ooo`0_
0?ooo`0408X[hP3oool0oooo0?ooo`800?ZJ0P000?l208X[hQ40oooo1P00nYX00`3oool0003o0000
o`050?ooo`80RR_R2P3oool00`2::n80oooo0?ooo`260?ooo`0308X[hP3oool0oooo0080003o5`3o
ool20000o`D0oooo0P00nYXN0?ooo`0308X[hP3oool0oooo02L0oooo00<000000?ooo`3oool07@3o
ool003/0oooo00<000000?ooo`3oool0=03oool20000o`<0RR_R5`3oool20000o`@0oooo0P00nYX2
08X[hPh0oooo1`00nYXi0?ooo`800?ZJ00<0RR_R0?ooo`3oool0@03oool0102::n80oooo0000o`00
0?lH0?ooo`80003o1P3oool2003jVQd0oooo00<0RR_R0?ooo`3oool09P3oool00`000000oooo0?oo
o`0]0?ooo`<00000;`3oool0102::n80oooo0?ooo`3oool3003jVP030000o`2::n80RR_R00d0oooo
1P00nYX50?ooo`80003o1@3oool00`2::n80oooo08X[hP070?ooo`80RR_RRP3oool0102::n80oooo
0000o`000?lG0?ooo`80003o1@3oool3003jVQd0oooo00<0RR_R0?ooo`3oool09P3oool2000001l0
oooo000k0?ooo`030000003oool0oooo03@0oooo0P000?l208X[hQP0oooo0P000?l40?ooo`800?ZJ
0P2::n8A0?ooo`L00?ZJ=P3oool2003jVP0308X[hP3oool0oooo0440oooo00@0RR_R0000o`000?l0
003o5P3oool40000o`D0oooo0`00nYXB0?ooo`80003o2@3oool00`2::n80oooo0?ooo`0U0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0<03oool0102::n80oooo0?ooo`3oool2003j
VP030000o`2::n80RR_R00`0oooo1P00nYX50?ooo`<0003o1@3oool0102::n80oooo08X[hP2::n84
0?ooo`80RR_RS@3oool00`2::n80003o0000o`0G0?ooo`<0003o1@3oool3003jVQ<0oooo0P000?l8
0?ooo`0308X[hP3oool0oooo02H0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?oo
o`3oool0=03oool20000o`80RR_R603oool20000o`@0oooo0P00nYX00`2::n80oooo08X[hP0C0?oo
o`P00?ZJ<P3oool2003jVP0308X[hP3oool0oooo0480oooo00<0RR_R0000o`000?l05P3oool40000
o`H0oooo0`00nYX60?ooo`80003o2@3oool30000o`P0oooo00<0RR_R0?ooo`3oool09@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0300oooo00@0RR_R0?ooo`3oool0oooo0P00nYX0
0`000?l0RR_R0?ooo`080?ooo`H00?ZJ2@3oool20000o`D0oooo00<0RR_R0?ooo`3oool00P3oool4
08X[hY00oooo00<0RR_R0000o`3oool05P3oool30000o`H0oooo1000nYXA0?ooo`80003o2@3oool0
0`2::n80oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo
03D0oooo00<0003o08X[hP2::n805`3oool30000o`@0oooo0P00nYX00`2::n80oooo08X[hP0F0?oo
o`P00?ZJ;`3oool2003jVP0308X[hP3oool0oooo04<0oooo00<0RR_R0000o`3oool05@3oool40000
o`L0oooo0`00nYX50?ooo`80003o203oool50000o`P0oooo00<0RR_R0?ooo`3oool0903oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0340oooo00<0RR_R0?ooo`3oool00`00nYX00`2:
:n80oooo0?ooo`060?ooo`H00?ZJ2P3oool20000o`D0oooo00<0RR_R0?ooo`3oool0UP3oool00`2:
:n80003o0?ooo`0F0?ooo`@0003o1P3oool4003jVP@0oooo0P000?l90?ooo`@0003o2@3oool00`2:
:n80oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo03D0
oooo00<0003o08X[hP00nYX05@3oool40000o`D0oooo0P00nYX00`2::n80oooo08X[hP0J0?ooo`L0
0?ZJ;03oool2003jVP0308X[hP3oool0oooo04<0oooo00<0003o08X[hP000?l00P000?l00`3oool0
003o0000o`0@0?ooo`@0003o203oool3003jVP@0oooo0`000?l70?ooo`80003o00<0oooo0000o`00
0?l02@3oool00`2::n80oooo0?ooo`0S0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0<@3oool0102::n80oooo0?ooo`3oool2003jVPD0oooo1P00nYX>0?ooo`80003o1@3oool00`2:
:n80oooo0?ooo`2F0?ooo`030000o`2::n80oooo01H0oooo10000?l80?ooo`800?ZJ103oool30000
o`L0oooo1P000?l90?ooo`0308X[hP3oool0oooo02<0oooo00<000000?ooo`3oool07@3oool003/0
oooo0P00000f0?ooo`030000o`2::n800?ZJ01D0oooo10000?l50?ooo`800?ZJ00<0RR_R0?ooo`2:
:n807@3oool8003jVRP0oooo0P00nYX00`2::n80oooo0?ooo`130?ooo`030000o`2::n80003o0080
003o00<0oooo0000o`000?l0403oool40000o`T0oooo0`00nYX20?ooo`@0003o0`3oool20000o`80
oooo0P000?l00`3oool0003o0000o`0:0?ooo`0308X[hP3oool0oooo0240oooo0P00000_0?ooo`03
0000003oool0oooo0340oooo00@0RR_R0?ooo`3oool0oooo0P00nYX010000?l0oooo0?ooo`3oool6
003jVPd0oooo10000?l40?ooo`0308X[hP3oool0oooo09L0oooo0P000?l01@2::n80003o0000o`00
0?l0oooo0080003o3`3oool50000o`P0oooo0`00nYX30?ooo`@0003o1P3oool20000o`80oooo0P00
0?l90?ooo`0308X[hP3oool0oooo02<0oooo00<000000?ooo`3oool07@3oool003/0oooo00<00000
0?ooo`3oool0=@3oool00`000?l0RR_R003jVP0E0?ooo`@0003o1@3oool2003jVP0408X[hP3oool0
oooo08X[hQl0oooo2000nYXU0?ooo`800?ZJ00<0RR_R0?ooo`3oool0A@3oool00`2::n80003o0000
o`030000o`l0oooo1@000?l:0?ooo`800?ZJ0P3oool50000o`80oooo0P000?l20?ooo`80003o00<0
oooo0000o`000?l02`3oool00`2::n80oooo0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo0`00
000b0?ooo`0308X[hP3oool0oooo00P00?ZJ4@3oool40000o`@0oooo00<0RR_R0?ooo`3oool0U`3o
ool30000o`0408X[hP000?l0003o0?ooo`80003o3`3oool20000o`030?ooo`000?l0003o00T0oooo
0`00nYX20?ooo`D0003o0P3oool20000o`030?ooo`000?l0003o0080oooo0P000?l:0?ooo`0308X[
hP3oool0oooo0240oooo0P00000O0?ooo`00>`3oool00`000000oooo0?ooo`0f0?ooo`03003jVP2:
:n800?ZJ00@00?ZJ3`3oool50000o`D0oooo0P00nYX0102::n80oooo0?ooo`2::n8S0?ooo`L00?ZJ
8P3oool2003jVP0308X[hP3oool0oooo04H0oooo00<0RR_R0000o`000?l00`000?l;0?ooo`80003o
00@0oooo0000o`000?l0oooo0`000?l90?ooo`<00?ZJ00@0oooo0000o`000?l0oooo1P000?l20?oo
o`80003o00@0oooo0000o`000?l0003o2P3oool00`2::n80oooo0?ooo`0Q0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0<P3oool0102::n80oooo0?ooo`3oool6003jVQ80oooo1000
0?l30?ooo`0308X[hP3oool0oooo09`0oooo00<0RR_R0000o`000?l00P000?l?0?ooo`80003o00@0
oooo0000o`000?l0003o2@3oool3003jVP<0003o00<0oooo0000o`000?l010000?l00`3oool0003o
0000o`020?ooo`80003o2P3oool00`2::n80oooo0?ooo`0R0?ooo`030000003oool0oooo01d0oooo
000k0?ooo`030000003oool0oooo03H0oooo00<0003o08X[hP00nYX02000nYX;0?ooo`D0003o1@3o
ool2003jVP0408X[hP3oool0oooo08X[hRH0oooo2000nYXN0?ooo`800?ZJ00<0RR_R0?ooo`3oool0
A`3oool00`2::n80003o0000o`020000o`/0oooo0P000?l00`3oool0003o0000o`020?ooo`80003o
2P3oool3003jVP80003o0P3oool50000o`80oooo0P000?l20?ooo`80003o2`3oool00`2::n80oooo
0?ooo`0P0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<P3oool0102::n80oooo
0?ooo`3oool2003jVQD0oooo10000?l40?ooo`0308X[hP3oool0oooo09`0oooo00<0003o08X[hP00
0?l00`000?l:0?ooo`80003o0P3oool20000o`80oooo0P000?l:0?ooo`<00?ZJ00@0003o0?ooo`3o
ool0oooo1@000?l00`3oool0003o0000o`020?ooo`80003o2`3oool00`2::n80oooo0?ooo`0Q0?oo
o`030000003oool0oooo01d0oooo000U0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<0
00001`3oool00`000000oooo0?ooo`0f0?ooo`030000o`2::n80oooo00<0oooo2P00nYX60?ooo`80
003o00<0oooo0000o`000?l01@3oool2003jVP0508X[hP3oool0oooo0?ooo`2::n80:03oool8003j
VQ/0oooo0P00nYX00`2::n80oooo0?ooo`170?ooo`030000o`2::n80003o0080003o2P3oool30000
o`030?ooo`000?l0003o0080oooo0P000?l;0?ooo`@00?ZJ103oool70000o`80oooo0P000?l;0?oo
o`0308X[hP3oool0oooo0200oooo00<000000?ooo`3oool0603oool3000000@0oooo00<000000?oo
o`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0<`3oool00`2::n80oooo0?ooo`020000
oaD0oooo10000?l30?ooo`0308X[hP3oool0oooo09h0oooo00<0RR_R0000o`000?l00P000?l:0?oo
o`80003o0P3oool20000o`80oooo0P000?l;0?ooo`<00?ZJ103oool40000o`030?ooo`000?l0003o
0080oooo0P000?l<0?ooo`0308X[hP3oool0oooo0200oooo00<000000?ooo`3oool07@3oool002H0
oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0=P3oool00`000?l0RR_R0?ooo`070?ooo`/00?ZJ0`000?l70?ooo`<00?ZJ00<0RR_R0?oo
o`3oool00P3oool00`2::n80oooo0?ooo`0Y0?ooo`L00?ZJ603oool2003jVP0308X[hP3oool0oooo
04P0oooo00D0003o08X[hP000?l0003o0?ooo`020000o`H0oooo1`000?l20?ooo`80003o303oool4
003jVPD0oooo10000?l30?ooo`80003o303oool00`2::n80oooo0?ooo`0O0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0=03oool208X[hP80003o5@3oool40000o`<0oooo00<0RR_R0?ooo`3oool0WP3o
ool00`000?l0RR_R0000o`020000o`T0oooo10000?l00`3oool0003o0000o`020?ooo`80003o303o
ool2003jVPH0oooo1@000?l20?ooo`80003o303oool00`2::n80oooo0?ooo`0P0?ooo`030000003o
ool0oooo01d0oooo000V0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool3
000003H0oooo00<0003o08X[hP000?l0303oool9003jVPL0oooo0P00nYX00`2::n80oooo0?ooo`04
0?ooo`0308X[hP3oool0oooo02/0oooo2000nYXD0?ooo`800?ZJ00<0RR_R0?ooo`3oool0B@3oool0
0`2::n80003o0000o`030000o`H0oooo0P000?l0103oool0003o0000o`000?l30?ooo`80003o2`3o
ool30000o`800?ZJ1@3oool40000o`<0oooo0P000?l=0?ooo`0308X[hP3oool0oooo01`0oooo0`00
000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0f0?ooo`80RR_R00<0003o0?ooo`3oool04@3oool30000o`@0oooo00<0RR_R0?ooo`3oool0W`3o
ool20000o`0308X[hP000?l0003o0080003o1`3oool70000o`80oooo0P000?l<0?ooo`<00?ZJ1P3o
ool40000o`80oooo0`000?l<0?ooo`0308X[hP3oool0oooo01l0oooo00<000000?ooo`3oool07@3o
ool002H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03L0oooo00<0RR_R0000o`3oool0403oool9003jVP80oooo0P00nYX00`2::n80oooo0?ooo`05
0?ooo`0308X[hP3oool0oooo02d0oooo2000nYXA0?ooo`800?ZJ00<0RR_R0?ooo`3oool0BP3oool0
0`2::n80003o0000o`030000o`D0oooo0P000?l0103oool0003o0000o`000?l30?ooo`80003o2`3o
ool20000o`040?ooo`00nYX00?ZJ003jVP@0oooo10000?l30?ooo`80003o3@3oool00`2::n80oooo
0?ooo`0N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`<00000=`3oool00`2::n80003o0?ooo`0B0?ooo`80003o103oool00`2::n80oooo
0?ooo`2S0?ooo`0308X[hP000?l0003o0080003o1P3oool60000o`<0oooo0P000?l;0?ooo`80003o
0`00nYX50?ooo`@0003o0`3oool20000o`d0oooo00<0RR_R0?ooo`3oool0703oool3000001l0oooo
000V0?ooo`030000003oool0oooo00L0oooo100000070?ooo`030000003oool0oooo03L0oooo00<0
RR_R0000o`3oool04@3oool20000o`X00?ZJ00<0RR_R0?ooo`3oool01@3oool00`2::n80oooo0?oo
o`0a0?ooo`L00?ZJ3P3oool2003jVP0308X[hP3oool0oooo04/0oooo00<0RR_R0000o`3oool00P00
0?l20?ooo`D0003o00<0oooo0000o`000?l0103oool20000o`X0oooo0`000?l20?ooo`<00?ZJ0`3o
ool40000o`<0oooo0P000?l>0?ooo`0308X[hP3oool0oooo01d0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`070?ooo`@000001P3oool00`000000oooo0?ooo`0g0?ooo`030000o`2:
:n80oooo0180oooo0P000?l30?ooo`0308X[hP3oool0oooo0:D0oooo00<0RR_R0000o`000?l00P00
0?l00`3oool0003o0000o`020?ooo`H0003o0`3oool20000o`X0oooo0`000?l0103oool00?ZJ003j
VP00nYX40?ooo`@0003o0`3oool20000o`d0oooo00<0RR_R0?ooo`3oool07P3oool00`000000oooo
0?ooo`0M0?ooo`009@3oool2000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0g0?ooo`030000o`2::n80oooo0140oooo0P000?l50?ooo`D00?ZJ00<0RR_R0?ooo`3oool01P3o
ool00`2::n80oooo0?ooo`0c0?ooo`P00?ZJ2P3oool2003jVP0308X[hP3oool0oooo04`0oooo00<0
RR_R0?ooo`000?l00P000?l00`3oool0003o0000o`020000o`P0oooo0`000?l30?ooo`80003o00<0
oooo0000o`000?l00`000?l40?ooo`<00?ZJ0P3oool40000o`<0oooo0`000?l>0?ooo`0308X[hP3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool2000000T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0g0?ooo`030000o`2::n80003o0180oooo0P000?l20?ooo`0308X[hP3o
ool0oooo0:H0oooo00<0003o08X[hP3oool00P000?l0103oool0003o0000o`3oool30000o`030?oo
o`000?l0003o00@0oooo0`000?l80?ooo`<0003o0`3oool3003jVP<0oooo0`000?l40?ooo`80003o
3P3oool00`2::n80oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo000V0?ooo`030000003o
ool0oooo00L0oooo1@0000060?ooo`030000003oool0oooo03L0oooo00<0003o08X[hP3oool02`3o
ool20000o`@0oooo0P000?l80?ooo`800?ZJ00<0RR_R0?ooo`3oool01P3oool00`2::n80oooo0?oo
o`0f0?ooo`P00?ZJ1`3oool2003jVP0308X[hP3oool0oooo04d0oooo00<0RR_R0?ooo`000?l01P00
0?l90?ooo`<0003o0P3oool20000o`030?ooo`000?l0003o0080003o1P3oool3003jVP030?ooo`00
0?l0003o0080003o103oool20000o`h0oooo00<0RR_R0?ooo`3oool0703oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00L0oooo1@0000050?ooo`030000003oool0oooo03P0oooo00<0
003o08X[hP3oool0403oool30000o`030?ooo`2::n80oooo0:T0oooo00<0RR_R0?ooo`000?l01000
0?l00`3oool0003o0000o`090?ooo`80003o0P3oool20000o`80oooo10000?l50?ooo`<00?ZJ0P3o
ool30000o`@0oooo0P000?l>0?ooo`0308X[hP3oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool003/0oooo00<000000?ooo`3oool0=`3oool00`000?l0RR_R0000o`0;0?ooo`80003o0`3oool3
0000o`X0oooo00<0RR_R0?ooo`3oool01`3oool00`2::n80oooo0?ooo`0i0?ooo`L00?ZJ103oool2
003jVP0308X[hP3oool0oooo04h0oooo00<0RR_R0000o`000?l01@000?l90?ooo`X0003o2@3oool3
003jVP@0003o103oool20000o`l0oooo00<0RR_R0?ooo`3oool06`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo03P0oooo00<0003o08X[hP3oool02P3oool20000o`@0oooo0P000?l0
0`3oool0RR_R0?ooo`2[0?ooo`0308X[hP3oool0003o00H0003o2@3oool30000o`030?ooo`000?l0
003o0080oooo0`000?l70?ooo`<00?ZJ00@0oooo0000o`000?l0003o103oool20000o`h0oooo00<0
RR_R0?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool2000003T0oooo00<0RR_R
0000o`3oool02P3oool30000o`80oooo0P000?l;0?ooo`0308X[hP3oool0oooo00P0oooo00<0RR_R
0?ooo`3oool0>`3oool6003jVP80oooo0P00nYX00`2::n80oooo0?ooo`1>0?ooo`0308X[hP000?l0
003o00D0003o2@3oool90000o`/0oooo0P00nYX00`3oool0003o0000o`050?ooo`80003o3`3oool0
0`2::n80oooo0?ooo`0J0?ooo`800000;`3oool00`000000oooo0?ooo`0h0?ooo`80003o00<0RR_R
0?ooo`3oool0203oool20000o`@0oooo00<0003o08X[hP2::n80[P3oool00`2::n80003o0000o`05
0000o`T0oooo2P000?l90?ooo`<00?ZJ0`000?l40?ooo`80003o3`3oool00`2::n80oooo0?ooo`0L
0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo03P0oooo00<0003o08X[
hP3oool02P3oool30000o`80oooo0P000?l;0?ooo`0308X[hP3oool0oooo00T0oooo00<0RR_R0?oo
o`3oool0?@3oool7003jVP0308X[hP3oool0oooo04l0oooo0P2::n800`000?l0oooo0000o`020000
o``0oooo0P000?l0103oool0003o0000o`000?l;0?ooo`<00?ZJ0P000?l50?ooo`80003o00<0oooo
0000o`000?l0303oool00`2::n80oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo0`00000i
0?ooo`80003o00<0RR_R0?ooo`3oool01`3oool30000o`<0oooo00<0RR_R0000o`3oool0[`3oool0
0`2::n80003o0000o`040000o`T0oooo2@000?l;0?ooo`<00?ZJ0P000?l40?ooo`80003o403oool0
0`2::n80oooo0?ooo`0J0?ooo`8000007`3oool003/0oooo00<000000?ooo`3oool0>03oool00`00
0?l0RR_R0000o`0:0?ooo`<0003o0P3oool20000o`/0oooo00<0RR_R0?ooo`3oool02P3oool00`2:
:n80oooo0?ooo`0n0?ooo`D00?ZJ00<0RR_R0?ooo`3oool0D@3oool0102::n80oooo0000o`000?l@
0?ooo`80003o3@3oool3003jVP030000o`3oool0oooo00<0oooo0P000?l00`3oool0003o0000o`0=
0?ooo`0308X[hP3oool0oooo01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0i
0?ooo`80003o00<0oooo08X[hP2::n801`3oool20000o`@0RR_R0P000?na0?ooo`0308X[hP000?l0
003o00<0003o303oool60000o``0oooo0`00nYX00`000?l0oooo0?ooo`020?ooo`80003o0P3oool2
0000o`d0oooo00<0RR_R0?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`00
0000oooo0?ooo`0i0?ooo`030000o`2::n80oooo00@0oooo0P000?l20?ooo`D0003o00<0oooo0000
o`000?l02`3oool00`2::n80oooo0?ooo`0:0?ooo`0308X[hP3oool0oooo0440oooo0P00nYX00`2:
:n80oooo0?ooo`1B0?ooo`0308X[hP000?l0003o0200oooo0`00nYX50?ooo`80003o00<0oooo0000
o`000?l03P3oool00`2::n80oooo0?ooo`0I0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0>@3oool30000o`80oooo0`2::n830?ooo`<0RR_R0P000?l0103oool0003o0000o`000?nb
0?ooo`0408X[hP000?l0003o0000oa00oooo0P000?l>0?ooo`<00?ZJ103oool30000o`030?ooo`00
0?l0003o00h0oooo00<0RR_R0?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool0
0`000000oooo0?ooo`0i0?ooo`80003o00@0RR_R0?ooo`3oool0oooo0`000?l20?ooo`80003o00@0
oooo0000o`000?l0oooo0P000?l;0?ooo`0308X[hP3oool0oooo00/0oooo00<0RR_R0?ooo`3oool0
@P3oool00`2::n80oooo0?ooo`1C0?ooo`0308X[hP000?l0oooo0200oooo0`00nYX40?ooo`D0003o
3`3oool00`2::n80oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
>P3oool20000o`@0oooo00D0003o08X[hP2::n80RR_R0?ooo`070000ok<0oooo00@0RR_R0?ooo`00
0?l0003o8@3oool2003jVPD0oooo0P000?l00`3oool0003o0000o`0>0?ooo`0308X[hP3oool0oooo
01T0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0>@3oool20000o`03
0?ooo`2::n80oooo00@0003o0P3oool20000o`030?ooo`000?l0003o00<0003o2`3oool00`2::n80
oooo0?ooo`0<0?ooo`0308X[hP3oool0oooo0440oooo00<0RR_R0?ooo`3oool0D`3oool00`2::n80
oooo0?ooo`0Q0?ooo`<00?ZJ103oool40000oa00oooo00<0RR_R0?ooo`3oool05`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo03X0oooo0P000?l40?ooo`80003o0`3oool20000o`03
0?ooo`000?l0003o0080003o]03oool00`2::n80003o0000o`0Q0?ooo`<00?ZJ103oool50000o`l0
oooo00<0RR_R0?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`00>`3oool2000003X0oooo
0P000?l00`3oool0RR_R0?ooo`040000o`80oooo0P000?l00`3oool0003o0000o`020000o``0oooo
00<0RR_R0?ooo`3oool03@3oool00`2::n80oooo0?ooo`0o0?ooo`0308X[hP3oool0oooo05D0oooo
00<0RR_R0?ooo`3oool08@3oool3003jVP<0oooo1@000?l?0?ooo`0308X[hP3oool0oooo01H0oooo
0P00000_0?ooo`030000003oool0oooo03X0oooo0P000?l30?ooo`<0003o0`3oool20000o`030?oo
o`000?l0003o0080003o]@3oool00`2::n80oooo0?ooo`0Q0?ooo`<00?ZJ0`3oool50000o`l0oooo
00<0RR_R0?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?oo
o`0i0?ooo`80003o0P3oool00`2::n80003o0000o`020000o`80oooo0P000?l20?ooo`<0003o303o
ool00`2::n80oooo0?ooo`0>0?ooo`0308X[hP3oool0oooo03h0oooo00<0RR_R0?ooo`3oool0EP3o
ool00`2::n80oooo0?ooo`0Q0?ooo`<00?ZJ0P3oool50000oa00oooo00<0RR_R0?ooo`3oool05P3o
ool00`000000oooo0?ooo`0]0?ooo`<00000>P3oool20000o`<0oooo10000?l20?ooo`80003o00<0
oooo0000o`000?l00P000?nf0?ooo`80RR_R8P3oool3003jVP80oooo1@000?l?0?ooo`0308X[hP3o
ool0oooo01L0oooo0P00000O0?ooo`00>`3oool00`000000oooo0?ooo`0i0?ooo`<0003o00<0oooo
08X[hP000?l010000?l00`3oool0003o0000o`020?ooo`80003o3@3oool00`2::n80oooo0?ooo`0?
0?ooo`0308X[hP3oool0oooo03d0oooo00<0RR_R0?ooo`3oool0E`3oool00`2::n80oooo0?ooo`0Q
0?ooo`<00?ZJ00@0oooo0000o`000?l0oooo0P000?l@0?ooo`0308X[hP3oool0oooo01H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0j0?ooo`80003o0`3oool40000o`80oooo0P00
0?l20?ooo`80003o^@3oool00`2::n80oooo0?ooo`0P0?ooo`<00?ZJ00<0oooo0000o`000?l00`00
0?l@0?ooo`0308X[hP3oool0oooo01L0oooo00<000000?ooo`3oool07@3oool003/0oooo00<00000
0?ooo`3oool0>P3oool20000o`80oooo00<0RR_R0000o`3oool00P000?l00`3oool0003o0000o`0A
0?ooo`0308X[hP3oool0oooo0100oooo00<0RR_R0?ooo`3oool0?03oool00`2::n80oooo0?ooo`1H
0?ooo`0308X[hP3oool0oooo0240oooo0`00nYX20000o`030?ooo`000?l0003o0100oooo00<0RR_R
0?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03X0oooo0P000?l3
0?ooo`@0003o00@0oooo0000o`000?l0003o0P3oool20000okT0oooo00<0RR_R0?ooo`3oool08@3o
ool3003jVP030?ooo`000?l0003o0080003o4@3oool00`2::n80oooo0?ooo`0F0?ooo`030000003o
ool0oooo01d0oooo000k0?ooo`030000003oool0oooo03X0oooo0P000?l01@3oool0003o0000o`2:
:n80oooo0080003o00<0oooo0000o`000?l04@3oool00`2::n80oooo0?ooo`0A0?ooo`0308X[hP3o
ool0oooo03/0oooo00<0RR_R0?ooo`3oool0F@3oool00`2::n80oooo0?ooo`0Q0?ooo`<00?ZJ0P3o
ool20000o`l0oooo0P000?l00`2::n80oooo0?ooo`0E0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0>P3oool20000o`<0oooo10000?l00`3oool0003o0000o`2o0?ooo`0308X[hP3o
ool0oooo0240oooo0P00nYX00`3oool0003o0000o`020000oa40oooo00<0RR_R0?ooo`3oool05P3o
ool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`0j0?ooo`80003o00D0oooo
0000o`000?l0oooo08X[hP020000o`030?ooo`000?l0003o0140oooo00<0RR_R0?ooo`3oool04P3o
ool00`2::n80oooo0?ooo`0j0?ooo`0308X[hP3oool0oooo05X0oooo00<0RR_R0?ooo`3oool08@3o
ool2003jVP80oooo0P000?l?0?ooo`80003o00<0oooo08X[hP3oool05@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo03X0oooo0P000?l20?ooo`D0003o00<0oooo0000o`000?l0`03o
ool00`2::n80oooo0?ooo`0P0?ooo`@00?ZJ00<0oooo0000o`000?l0403oool20000o`0308X[hP3o
ool0oooo01D0oooo00<000000?ooo`3oool07@3oool003/0oooo0P00000k0?ooo`80003o00<0oooo
0000o`000?l00P3oool00`2::n80003o0000o`020000oa40oooo00<0RR_R0?ooo`3oool04`3oool0
0`2::n80oooo0?ooo`0i0?ooo`0308X[hP3oool0oooo05/0oooo00<0RR_R0?ooo`3oool0803oool3
003jVP030?ooo`000?l0003o00T0oooo0P000?l40?ooo`80003o00<0oooo08X[hP3oool0503oool2
000002l0oooo00<000000?ooo`3oool0>P3oool20000o`80oooo0P000?l00`3oool0003o0000o`03
0000ol40oooo00<0RR_R0?ooo`3oool0803oool4003jVP<0003o3`3oool20000o`030?ooo`2::n80
oooo01D0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0>P3oool20000
o`030?ooo`000?l0003o0080oooo00@0RR_R0000o`000?l0003o4P3oool00`2::n80oooo0?ooo`0D
0?ooo`0308X[hP3oool0oooo03P0oooo00<0RR_R0?ooo`3oool0G03oool00`2::n80oooo0?ooo`0P
0?ooo`<00?ZJ0P000?l90?ooo`80003o103oool20000o`80oooo00<0RR_R0?ooo`3oool04`3oool0
0`000000oooo0?ooo`0]0?ooo`<00000>P3oool30000o`030?ooo`000?l0003o0080oooo10000?o2
0?ooo`0308X[hP3oool0oooo0240oooo0`00nYX20000o`P0oooo0P000?l50?ooo`80003o00<0oooo
08X[hP3oool0503oool2000001l0oooo000k0?ooo`030000003oool0oooo03X0oooo0P000?l00`3o
ool0003o0000o`020?ooo`040000o`2::n80003o0000oa80oooo00<0RR_R0?ooo`3oool05@3oool2
08X[hSP0oooo00<0RR_R0?ooo`3oool0G@3oool00`2::n80oooo0?ooo`0P0?ooo`<00?ZJ00<0003o
0?ooo`3oool01`3oool20000o`@0oooo0`000?l20?ooo`0308X[hP3oool0oooo0180oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0k0?ooo`80003o00<0oooo0000o`000?l00P3oool4
0000ol<0oooo00<0RR_R0?ooo`3oool08@3oool3003jVP030000o`3oool0oooo00H0oooo0P000?l4
0?ooo`<0003o0P3oool00`2::n80oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo000k0?oo
o`030000003oool0oooo03X0oooo0P000?l00`3oool0003o0000o`030?ooo`030000o`2::n80003o
0180oooo00<0RR_R0?ooo`3oool05`3oool00`2::n80oooo0?ooo`0e0?ooo`0308X[hP3oool0oooo
05h0oooo00<0RR_R0?ooo`3oool0803oool3003jVP030000o`3oool0oooo00H0oooo0`000?l30?oo
o`<0003o0P3oool00`2::n80oooo0?ooo`0B0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0>`3oool20000o`030?ooo`000?l0003o0080oooo10000?o30?ooo`0308X[hP3oool0oooo
0280oooo0P00nYX00`000?l0oooo0?ooo`060?ooo`<0003o0`3oool40000o`030?ooo`2::n80oooo
01@0oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0>P3oool20000o`03
0?ooo`000?l0003o00<0oooo0P000?l00`2::n80oooo0?ooo`0@0?ooo`0308X[hP3oool0oooo01L0
oooo00<0RR_R0?ooo`3oool0=@3oool00`2::n80oooo0?ooo`1N0?ooo`0308X[hP3oool0oooo0240
oooo0`00nYX80?ooo`<0003o0P3oool40000o`80oooo00<0RR_R0000o`3oool04P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo03/0oooo0P000?l00`3oool0003o0000o`030?ooo`<0
003oa03oool208X[hR80oooo0`00nYX80?ooo`<0003o0`3oool40000o`030?ooo`2::n80oooo01@0
oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0>P3oool50000o`@0oooo
0P000?l00`2::n80oooo0?ooo`0?0?ooo`0308X[hP3oool0oooo01P0oooo0P2::n8e0?ooo`0308X[
hP3oool0oooo05l0oooo0P2::n8R0?ooo`800?ZJ1`3oool40000o`80oooo10000?l20?ooo`030000
o`2::n80003o0180oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0k0?ooo`80003o
00<0oooo0000o`000?l00`3oool30000olH0oooo00<0RR_R0?ooo`3oool0803oool3003jVPL0oooo
10000?l20?ooo`@0003o0P3oool00`2::n80003o0?ooo`0B0?ooo`030000003oool0oooo01d0oooo
000k0?ooo`800000?03oool30000o`P0oooo00<0RR_R0?ooo`3oool03P3oool00`2::n80oooo0?oo
o`0J0?ooo`80RR_R<`3oool00`2::n80oooo0?ooo`1Q0?ooo`0308X[hP3oool0oooo01l0oooo1000
nYX50?ooo`@0003o0P3oool40000o`80oooo00@0003o08X[hP000?l0003o403oool2000002l0oooo
00<000000?ooo`3oool0>`3oool50000o`@0oooo0P000?o70?ooo`0308X[hP3oool0oooo01l0oooo
00@0003o003jVP00nYX00?ZJ1P3oool40000o`80oooo10000?l20?ooo`030000o`2::n80003o0180
oooo00<000000?ooo`3oool07@3oool003/0oooo00<000000?ooo`3oool0>`3oool30000o`T0oooo
00<0RR_R0?ooo`3oool0303oool00`2::n80oooo0?ooo`0M0?ooo`0308X[hP3oool0oooo0300oooo
00<0RR_R0?ooo`3oool0H@3oool00`2::n80oooo0?ooo`0O0?ooo`030000o`00nYX00?ZJ00800?ZJ
103oool40000o`80oooo10000?l20?ooo`040000o`2::n80003o0000oa40oooo00<000000?ooo`3o
ool0;@3oool3000003/0oooo10000?o?0?ooo`0308X[hP3oool0oooo01h0oooo0P000?l3003jVPD0
oooo10000?l00`3oool0003o0000o`030000o`80oooo00@0003o08X[hP000?l0003o403oool20000
01l0oooo000k0?ooo`030000003oool0oooo03/0oooo0`000?l:0?ooo`0308X[hP3oool0oooo00/0
oooo00<0RR_R0?ooo`3oool07@3oool00`2::n80oooo0?ooo`0`0?ooo`0308X[hP3oool0oooo0680
oooo00<0RR_R0?ooo`3oool07P3oool30000o`<00?ZJ0`3oool50000o`030?ooo`000?l0003o00<0
003o00D0oooo0000o`000?l0RR_R0000o`0A0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0>`3oool40000oll0oooo00<0RR_R0?ooo`3oool07P3oool30000o`<00?ZJ103oool40000
o`040?ooo`000?l0003o0?ooo`80003o0P3oool20000o`0308X[hP000?l0oooo0100oooo00<00000
0?ooo`3oool07@3oool001l0oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000000L0oooo00<000000?ooo`3oool0>`3oool30000o`/0oooo0P2::n8;0?oo
o`0308X[hP3oool0oooo01h0oooo0P2::n8`0?ooo`0308X[hP3oool0oooo06<0oooo00<0RR_R0?oo
o`3oool07P3oool20000o`040?ooo`00nYX00?ZJ003jVP80oooo0P000?l0103oool0003o0000o`3o
ool20000o`040?ooo`000?l0003o0?ooo`<0003o00<0RR_R0000o`3oool03`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo03/0oooo10000?o@0?ooo`80RR_R7P3oool40000o`800?ZJ
0`3oool80000o`050?ooo`000?l0003o0000o`3oool00P000?l00`2::n80003o0?ooo`0@0?ooo`03
0000003oool0oooo01d0oooo000P0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>`3oool20000o`h0
oooo00<0RR_R0?ooo`3oool0203oool00`2::n80oooo0?ooo`0P0?ooo`80RR_R;P3oool00`2::n80
oooo0?ooo`1T0?ooo`80RR_R7P3oool30000o`030?ooo`00nYX00?ZJ0080oooo0P000?l0103oool0
003o0000o`3oool20000o`040?ooo`000?l0003o0?ooo`80003o00<0oooo08X[hP000?l0403oool0
0`000000oooo0?ooo`0B0?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo0`0000060?ooo`030000003oool0oooo03/0oooo10000?oB0?ooo`0308X[hP3oool0
oooo01d0oooo0P000?l3003jVP80oooo0P000?l20?ooo`@0003o0P3oool60000o`0308X[hP3oool0
oooo00l0oooo00<000000?ooo`3oool07@3oool00200oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B`3oool00`2:
:n80oooo0?ooo`080?ooo`0308X[hP3oool0oooo0280oooo00<0RR_R0?ooo`3oool0:`3oool00`2:
:n80oooo0?ooo`1V0?ooo`0308X[hP3oool0oooo01`0oooo0P000?l01@3oool00?ZJ003jVP00nYX0
oooo0080003o00<0oooo0000o`000?l00`000?l0103oool0003o0000o`3oool20000o`030?ooo`00
0?l0RR_R0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03/0oooo
0P000?oD0?ooo`0308X[hP3oool0oooo01d0oooo0`000?l3003jVP030?ooo`000?l0003o0080oooo
10000?l20?ooo`@0003o00<0oooo0000o`2::n804@3oool00`000000oooo0?ooo`0M0?ooo`00803o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool3000004`0oooo0P2::n880?ooo`0308X[hP3oool0oooo02<0oooo00<0RR_R0?ooo`3oool0:P3o
ool00`2::n80oooo0?ooo`1V0?ooo`0308X[hP3oool0oooo01`0oooo0P000?l20?ooo`<00?ZJ0P00
0?l00`3oool0003o0000o`020000o`80oooo1@000?l0103oool0003o0000o`2::n8=0?ooo`<00000
5@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<0RR_R0?ooo`3oool07@3oool20000o`030?oo
o`00nYX00?ZJ00800?ZJ00<0003o0?ooo`3oool010000?l20?ooo`@0003o00@0oooo0000o`000?l0
RR_R403oool00`000000oooo0?ooo`0M0?ooo`00803oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000<000001`3oool00`000000oooo0?ooo`1>0?ooo`80RR_R1P3oool00`2::n80oooo
0?ooo`0T0?ooo`0308X[hP3oool0oooo02T0oooo00<0RR_R0?ooo`3oool0I`3oool00`2::n80oooo
0?ooo`0K0?ooo`<0003o0P3oool3003jVP80oooo10000?l20?ooo`@0003o0P3oool20000o`0308X[
hP3oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool300000?l0oooo503oool00`2::n80oooo
0?ooo`0L0?ooo`80003o0P3oool4003jVP80oooo10000?l20?ooo`@0003o00@0oooo0000o`000?l0
RR_R3P3oool3000001l0oooo000O0?ooo`8000002@3oool01`000000oooo0?ooo`3oool000000?oo
o`0000002P3oool00`000000oooo0?ooo`1@0?ooo`0308X[hP3oool0oooo00<0oooo00<0RR_R0?oo
o`3oool09@3oool208X[hRT0oooo00<0RR_R0?ooo`3oool0J03oool00`2::n80oooo0?ooo`0K0?oo
o`80003o0`3oool3003jVP030?ooo`000?l0003o0080003o0`3oool30000o`80oooo0P000?l00`2:
:n80oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo00000003000000H0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`80RR_R703oool30000
o`<0oooo0P00nYX20?ooo`@0003o0P3oool40000o`80oooo00<0003o08X[hP3oool03`3oool00`00
0000oooo0?ooo`0M0?ooo`00803oool00`000000oooo0?ooo`070?ooo`D0000000<0oooo00000000
00000`0000060?ooo`030000003oool0oooo0500oooo00<0RR_R0?ooo`3oool00`3oool00`2::n80
oooo0?ooo`0W0?ooo`0308X[hP3oool0oooo02H0oooo00<0RR_R0?ooo`3oool0J@3oool208X[hQ/0
oooo0P000?l30?ooo`040000o`00nYX00?ZJ003jVP@0003o0`3oool30000o`<0oooo0P000?l00`2:
:n80oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo0P0000090?ooo`070000003oool0oooo
0?ooo`000000oooo000000090?ooo`030000003oool0oooo0?l0oooo5`3oool00`2::n80oooo0?oo
o`0J0?ooo`80003o0`3oool3003jVP030?ooo`000?l0003o0080003o0P3oool40000o`80oooo0P00
0?l00`2::n80oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0
oooo0540oooo0P2::n830?ooo`0308X[hP3oool0oooo02P0oooo0P2::n8V0?ooo`0308X[hP3oool0
oooo06/0oooo00<0RR_R0?ooo`3oool0603oool20000o`<0oooo0P000?l2003jVP040?ooo`000?l0
003o0000o`<0oooo0`000?l30?ooo`80003o00<0RR_R0?ooo`3oool0303oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00L0oooo1@0000000`3oool0000000000003000000D0oooo00<0
00000?ooo`3oool0o`3ooolG0?ooo`0308X[hP3oool0oooo01X0oooo0P000?l30?ooo`040000o`00
nYX00?ZJ003jVP<0003o0`3oool40000o`80oooo0P000?l00`2::n80oooo0?ooo`0=0?ooo`030000
003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo05<0oooo0P2::n800`3oool0RR_R0?oo
o`0[0?ooo`80RR_R903oool00`2::n80oooo0?ooo`1[0?ooo`0308X[hP3oool0oooo01P0oooo0`00
0?l0103oool0003o0000o`000?l3003jVP80003o103oool30000o`<0oooo0P000?l00`2::n80oooo
0?ooo`0<0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`80RR_R
6P3oool20000o`<0oooo0P000?l3003jVP80003o103oool30000o`80oooo0`000?l00`2::n80oooo
0?ooo`0<0?ooo`030000003oool0oooo01d0oooo000k0?ooo`800000EP3oool208X[hRh0oooo00<0
RR_R0?ooo`3oool08@3oool00`2::n80oooo0?ooo`1/0?ooo`80RR_R6@3oool20000o`030?ooo`00
0?l0003o0080oooo0`00nYX00`000?l0oooo0?ooo`030?ooo`80003o103oool20000o`0308X[hP3o
ool0oooo00X0oooo0P00000_0?ooo`030000003oool0oooo0?l0oooo6P3oool00`2::n80oooo0?oo
o`0G0?ooo`80003o0P3oool30000o`050?ooo`00nYX00?ZJ003jVP000?l0103oool20000o`<0oooo
0`000?l00`2::n80oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003o
ool0oooo05H0oooo00<0RR_R0?ooo`3oool0;@3oool208X[hR40oooo00<0RR_R0?ooo`3oool0KP3o
ool00`2::n80oooo0?ooo`0F0?ooo`D0003o0`3oool4003jVP@0oooo0P000?l40?ooo`80003o00<0
RR_R0?ooo`3oool02`3oool00`000000oooo0?ooo`0]0?ooo`<00000o`3ooolK0?ooo`0308X[hP3o
ool0oooo01H0oooo0P000?l20?ooo`80003o0`3oool3003jVP@0oooo0P000?l50?ooo`80003o00<0
RR_R0?ooo`3oool02P3oool2000001l0oooo000k0?ooo`030000003oool0oooo08P0oooo0P2::n8O
0?ooo`0308X[hP3oool0oooo06l0oooo00<0RR_R0?ooo`3oool05@3oool40000o`D0oooo1000nYX9
0?ooo`<0003o00<0RR_R0?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0?l0oooo703oool00`2::n80oooo0?ooo`0E0?ooo`80003o0P3oool20000o`@0oooo0P00nYX4
0?ooo`80003o1@3oool20000o`0308X[hP3oool0oooo00/0oooo00<000000?ooo`3oool07@3oool0
03/0oooo00<000000?ooo`3oool0RP3oool00`2::n80oooo0?ooo`0L0?ooo`0308X[hP3oool0oooo
0700oooo00<0RR_R0?ooo`3oool0503oool40000o`L0oooo0P00nYX:0?ooo`80003o00<0RR_R0?oo
o`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo703oool00`2:
:n80oooo0?ooo`0E0?ooo`H0003o103oool3003jVP<0oooo0P000?l50?ooo`<0003o00<0RR_R0?oo
o`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`2;0?ooo`80
RR_R703oool00`2::n80oooo0?ooo`1`0?ooo`0308X[hP3oool0oooo01@0oooo10000?l70?ooo`<0
0?ZJ2@3oool20000o`030?ooo`2::n80oooo00X0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`3o0?oooad0oooo0P2::n8F0?ooo`@0003o1P3oool3003jVPX0oooo0P000?l00`2::n80
oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo08d0oooo
0P2::n8J0?ooo`0308X[hP3oool0oooo0740oooo0P2::n8D0?ooo`@0003o203oool3003jVPP0oooo
0P000?l00`3oool0RR_R0?ooo`0:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
o`3ooolO0?ooo`0308X[hP3oool0oooo01<0oooo10000?l70?ooo`<00?ZJ2@3oool20000o`0308X[
hP3oool0oooo00X0oooo00<000000?ooo`3oool07@3oool003/0oooo0P00002@0?ooo`0308X[hP3o
ool0oooo01L0oooo00<0RR_R0?ooo`3oool0L`3oool00`2::n80oooo0?ooo`0A0?ooo`<0003o2P3o
ool3003jVPL0oooo0P000?l20?ooo`0308X[hP3oool0oooo00L0oooo0P00000_0?ooo`030000003o
ool0oooo0?l0oooo803oool00`2::n80oooo0?ooo`0B0?ooo`<0003o2@3oool3003jVPP0oooo0P00
0?l00`3oool0RR_R0?ooo`0:0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0
oooo0900oooo0P2::n8G0?ooo`0308X[hP3oool0oooo07@0oooo00<0RR_R0?ooo`3oool04@3oool2
0000o`/0oooo0`00nYX60?ooo`<0003o00<0oooo08X[hP3oool02@3oool00`000000oooo0?ooo`0]
0?ooo`<00000o`3ooolQ0?ooo`0308X[hP3oool0oooo0140oooo0`000?l:0?ooo`<00?ZJ1`3oool2
0000o`030?ooo`2::n80oooo00T0oooo0P00000O0?ooo`00>`3oool00`000000oooo0?ooo`2B0?oo
o`80RR_R5@3oool00`2::n80oooo0?ooo`1e0?ooo`0308X[hP3oool0oooo0100oooo0P000?l<0?oo
o`<00?ZJ1P3oool20000o`030?ooo`2::n80oooo00T0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`3o0?ooob80oooo00<0RR_R0?ooo`3oool0403oool30000o`/0oooo0P00nYX70?oo
o`<0003o00<0RR_R0?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000
oooo0?ooo`2D0?ooo`0308X[hP3oool0oooo0180oooo00<0RR_R0?ooo`3oool0MP3oool208X[hQ00
oooo0P000?l=0?ooo`800?ZJ1P3oool20000o`80oooo00<0RR_R0?ooo`3oool01`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo8`3oool00`2::n80oooo0?ooo`0?0?ooo`80
003o303oool4003jVPH0oooo0P000?l00`3oool0RR_R0?ooo`090?ooo`030000003oool0oooo01d0
oooo000k0?ooo`030000003oool0oooo09D0oooo0P2::n8B0?ooo`0308X[hP3oool0oooo07P0oooo
00<0RR_R0?ooo`3oool0703oool3003jVPD0oooo0P000?l20?ooo`0308X[hP3oool0oooo00L0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooob@0oooo0P2::n8?0?ooo`80003o
3@3oool4003jVPD0oooo0P000?l00`3oool0RR_R0?ooo`090?ooo`030000003oool0oooo01d0oooo
000k0?ooo`030000003oool0oooo09L0oooo0P2::n8@0?ooo`0308X[hP3oool0oooo07T0oooo00<0
RR_R0?ooo`3oool0703oool3003jVP@0oooo0P000?l20?ooo`0308X[hP3oool0oooo00L0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0RR_R0?ooo`3oool07@3o
ool3003jVP@0oooo0P000?l00`3oool0RR_R0?ooo`090?ooo`030000003oool0oooo01d0oooo000k
0?ooo`800000VP3oool00`2::n80oooo0?ooo`0=0?ooo`0308X[hP3oool0oooo07X0oooo00<0RR_R
0?ooo`3oool0703oool4003jVP80oooo0P000?l20?ooo`0308X[hP3oool0oooo00H0oooo0P00000_
0?ooo`030000003oool0oooo0?l0oooo9`3oool00`2::n80oooo0?ooo`0M0?ooo`<00?ZJ0`3oool2
0000o`80oooo00<0RR_R0?ooo`3oool01`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`00
0000oooo0?ooo`2J0?ooo`80RR_R3@3oool00`2::n80oooo0?ooo`1k0?ooo`0308X[hP3oool0oooo
01`0oooo1000nYX0103oool0003o0000o`000?l20?ooo`0308X[hP3oool0oooo00H0oooo00<00000
0?ooo`3oool0;@3oool300000?l0oooo:03oool00`2::n80oooo0?ooo`0M0?ooo`800?ZJ0`3oool2
0000o`80oooo00<0RR_R0?ooo`3oool01P3oool2000001l0oooo000k0?ooo`030000003oool0oooo
09`0oooo0`2::n8:0?ooo`0308X[hP3oool0oooo07`0oooo00<0RR_R0?ooo`3oool07@3oool2003j
VP80oooo0P000?l20?ooo`0308X[hP3oool0oooo00H0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`3o0?ooobT0oooo0P2::n8M0?ooo`<00?ZJ0P3oool20000o`80oooo00<0RR_R0?oo
o`3oool01`3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`2O0?ooo`80
RR_R203oool00`2::n80oooo0?ooo`1m0?ooo`80RR_R7@3oool3003jVP030?ooo`000?l0003o0080
oooo00<0RR_R0?ooo`3oool01P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0
oooo:`3oool00`2::n80oooo0?ooo`0K0?ooo`<00?ZJ00<0oooo0000o`000?l00`3oool00`2::n80
oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003oool0oooo0:40oooo
0P2::n860?ooo`0308X[hP3oool0oooo07l0oooo00<0RR_R0?ooo`3oool06`3oool3003jVP80003o
0P3oool00`2::n80oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
o`3oool/0?ooo`0308X[hP3oool0oooo01/0oooo0`00nYX20000o`<0oooo00<0RR_R0?ooo`3oool0
1P3oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`2S0?ooo`0308X[hP3o
ool0oooo00<0oooo00<0RR_R0?ooo`3oool0P03oool00`2::n80oooo0?ooo`0K0?ooo`<00?ZJ00@0
003o0?ooo`3oool0RR_R203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo
;@3oool00`2::n80oooo0?ooo`0K0?ooo`<00?ZJ00D0003o0?ooo`3oool0oooo08X[hP080?ooo`03
0000003oool0oooo01d0oooo000k0?ooo`800000Y@3oool208X[hP<0oooo00<0RR_R0?ooo`3oool0
P@3oool00`2::n80oooo0?ooo`0K0?ooo`<00?ZJ0`3oool00`2::n80oooo0?ooo`040?ooo`800000
;`3oool00`000000oooo0?ooo`3o0?ooobh0oooo0P2::n8L0?ooo`<00?ZJ00@0003o0?ooo`3oool0
RR_R203oool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`2V0?ooo`@0RR_R
Q03oool208X[hQ`0oooo0`00nYX20?ooo`0308X[hP3oool0oooo00D0oooo00<000000?ooo`3oool0
;@3oool300000?l0oooo<03oool00`2::n80oooo0?ooo`0J0?ooo`800?ZJ00D0003o0?ooo`3oool0
oooo08X[hP060?ooo`8000007`3oool003/0oooo00<000000?ooo`3oool0Z@3oool00`2::n80oooo
0?ooo`240?ooo`0308X[hP3oool0oooo01T0oooo00<0003o003jVP00nYX02P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo<@3oool208X[hQX0oooo1000nYX20?ooo`0308X[
hP3oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00300oooo1@0000060?ooo`030000003o
ool0oooo0?l0oooo<P3oool208X[hQT0oooo00<0003o003jVP00nYX00P00nYX80?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`0308X[hP3oool0oooo01P0oooo1000
nYX90?ooo`030000003oool0oooo01d0oooo000a0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0o`3ooold0?ooo`80RR_R5`3oool20000o`@00?ZJ1`3oool00`000000oooo0?oo
o`0S0?ooo`D000001@3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<0RR_R0?ooo`3oool05`3o
ool20000o`<00?ZJ203oool00`000000oooo0?ooo`0M0?ooo`00<P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0oooo=P3oool00`2::n80oooo0?ooo`0E0?ooo`80003o00<0oooo
003jVP00nYX01`3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0o`3ooole0?ooo`0308X[hP3oool0oooo01H0oooo0P000?l0103oool00?ZJ003j
VP00nYX70?ooo`030000003oool0oooo01d0oooo000c0?ooo`030000003oool0oooo00D0oooo0`00
003o0?ooocL0oooo00<0RR_R0?ooo`3oool0503oool50000o`D0oooo0`00000W0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`80RR_R5P3oool20000o`80oooo0P00
nYX70?ooo`030000003oool0oooo01d0oooo000`0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`3o0?ooocP0oooo00<0RR_R0?ooo`3oool04`3oool40000o`0308X[hP3o
ool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`<00000o`3o
oolh0?ooo`80RR_R503oool20000o`040?ooo`000?l0003o0000o`D0oooo0`00000O0?ooo`00<03o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0o`3oooli0?ooo`80RR_R
4`3oool30000o`030?ooo`2::n80oooo00H0oooo00<000000?ooo`3oool08`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`0308X[hP3oool0oooo0140
oooo1@000?l80?ooo`030000003oool0oooo01d0oooo000a0?ooo`<000001`3oool00`000000oooo
0?ooo`3o0?oooc/0oooo00<0RR_R0?ooo`3oool04`3oool00`2::n80oooo0?ooo`060?ooo`030000
003oool0oooo02<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0?l0
oooo>`3oool208X[hQ40oooo10000?l00`3oool0RR_R0?ooo`060?ooo`030000003oool0oooo01d0
oooo000k0?ooo`030000003oool0oooo0?l0oooo?03oool408X[hQ40oooo00<0RR_R0?ooo`3oool0
1P3oool00`000000oooo0?ooo`0T0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooocd0oooo
0P2::n8D0?ooo`0308X[hP3oool0oooo00D0oooo00<000000?ooo`3oool07@3oool003/0oooo00<0
00000?ooo`3oool0o`3ooom00?ooo`0308X[hP3oool0oooo00h0oooo00<0RR_R0?ooo`3oool01P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo?`3oool00`2::n80oooo0?oo
o`0@0?ooo`0308X[hP3oool0oooo00H0oooo00<000000?ooo`3oool07@3oool003/0oooo0P00003o
0?oood80oooo0P2::n8=0?ooo`0308X[hP3oool0oooo00H0oooo0P00000_0?ooo`030000003oool0
oooo0?l0oooo@03oool408X[hPh0oooo00<0RR_R0?ooo`3oool01P3oool00`000000oooo0?ooo`0M
0?ooo`00>`3oool00`000000oooo0?ooo`3o0?oood<0oooo0`2::n8:0?ooo`0308X[hP3oool0oooo
00L0oooo00<000000?ooo`3oool0;@3oool300000?l0ooooA03oool00`2::n80oooo0?ooo`090?oo
o`80RR_R203oool2000001l0oooo000k0?ooo`030000003oool0oooo0?l0ooooAP3oool408X[hP@0
oooo0P2::n8:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooom50?ooo`@0
RR_R1P3oool00`2::n80oooo0?ooo`090?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000
003oool0oooo0?l0ooooBP3oool408X[hP`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`3o0?ooodT0oooo1P2::n8<0?ooo`030000003oool0oooo01d0oooo000k0?ooo`030000003o
ool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooF`3o
ool00`000000oooo0?ooo`0M0?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooe/0oooo00<000000?ooo`3oool07@3oool0
03/0oooo0P0000060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`040?ooo`800000;`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01d0oooo000k0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool3000000H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo0P00000O0?ooo`00>`3ooooo000005h00000;`3ooooo000005l000007`3oool00?l0ooooo`3o
oooo0?ooodL0oooo003o0?ooool0ooooo`3ooom70?ooo`00o`3ooooo0?ooool0ooooA`3oool00?l0
ooooo`3ooooo0?ooodL0oooo003o0?ooool0ooooo`3ooom70?ooo`00o`3ooooo0?ooool0ooooA`3o
ool00?l0ooooo`3ooooo0?ooodL0oooo003A0?ooo`D0000000<0oooo0000000000000`0000000`3o
ool0000000000003000000<0oooo0P0000030?ooo`<000000P3oool3000000@0oooo0`0000030?oo
o`@00000o`3ooomO0?ooo`@000000P3oool01@000000oooo0000003oool000000080oooo0`000003
0?ooo`<00000103oool200000080oooo1P000000103oool000000000000000030?ooo`@00000]`3o
ool00=<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?ooof@0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`04
0000003oool0oooo00000;P0oooo003C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`03
0000003oool0oooo0080oooo1@0000001@3oool000000?ooo`3oool000000?l0ooooH@3oool30000
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0000003oool01@0000001@3oool0
00000?ooo`3oool000000;P0oooo003C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo0000
00D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool0]P3oool00=80oooo10000000103oool000000000000000050?ooo`040000003o
ool0oooo0?ooo`@000000`3oool300000080oooo0P0000000`3oool00000000000020?ooo`<00000
0`3oool300000?l0ooooH@3oool4000000050?ooo`00000000000?ooo`0000000`3oool3000000<0
oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`0000030?ooo`<00000^03oool00=<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2f0?ooo`00e03oool2000000<0oooo00@000000?ooo`3oool0oooo
0`0000040?ooo`030000003oool0oooo01H0oooo0P00003o0?ooogT0oooo00<000000?ooo`3oool0
0P3oool2000000`0oooo0P00002h0?ooo`00o`3ooooo0?ooool0ooooA`3oool00?l0ooooo`3ooooo
0?ooodL0oooo003o0?ooool0ooooo`3ooom70?ooo`00o`3ooooo0?ooool0ooooA`3oool00?l0oooo
o`3ooooo0?ooodL0oooo003o0?ooool0ooooo`3ooom70?ooo`00o`3ooooo0?ooool0ooooA`3oool0
0?l0ooooo`3ooooo0?ooodL0oooo0000\
\>"],
  ImageRangeCache->{{{0, 835.312}, {257.438, 0}} -> {-0.0528279, -0.0154541, \
0.0025208, 0.0025208}, {{20.9375, 417.625}, {251.25, 6.125}} -> {-0.203121, \
0.151876, 0.00301255, 0.00837614}, {{417.625, 814.312}, {251.25, 6.125}} -> \
{-1.39816, 0.152938, 0.00301255, 0.00832527}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ML estimation of  {\[Alpha]_,\[Sigma]_}", "Subsection",
  PageWidth->Infinity,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    \(\(F0 = IdentityMatrix[2] // N;\)\), "\[IndentingNewLine]", 
    \(\(THETA0 = Theta;\)\), "\[IndentingNewLine]", 
    \(\(system = {fBrownianBridge, Jacobif, gBrownianBridge, h, Jacobih, R, 
          mue, sigma, dt};\)\), "\[IndentingNewLine]", 
    \(FISHER = True\)}], "Input"],

Cell[CellGroupData[{

Cell["\<\
asymptotic standard deviation using F \[TildeTilde] - Hessian \
(Greene, ch. 4)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\({THETA, COV, LIKI, psii, scoreii, k, ReturnCode}\), "=", 
          "\[IndentingNewLine]", "\n", 
          RowBox[{"BFGS", "[", 
            RowBox[{\({{ZM, X}}\), ",", \({THETA0, F0}\), ",", 
              RowBox[{"{", 
                RowBox[{"system", ",", 
                  RowBox[{"{", 
                    RowBox[{"Lik", ",", "EKF", ",", "Score", ",", 
                      StyleBox["Hesse",
                        FontColor->RGBColor[1, 0, 0]]}], "}"}]}], "}"}], 
              ",", \({{miss, 1}, 
                KMAX = 30, {EPS1 = 10^\(-4\), EPS2 = 10^\(-4\)}, OPTION = 1, 
                PRINT = {1, 1, 1, 1, 1, 1, 1, 1}}\)}], "]"}]}], 
        ";"}]}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("Tiefe von data = "\[InvisibleSpace]5\),
      SequenceForm[ "Tiefe von data = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    \("L\[ADoubleDot]nge der Paneldaten"\)], "Print"],

Cell[BoxData[
    \({201}\)], "Print"],

Cell[BoxData[
    \("***********************LSDE1**********************************"\)], \
"Print"],

Cell[BoxData[
    \("***********************MODUL:    BFGS (skeleton)**************"\)], \
"Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \("Technical Output"\)], "Print"],

Cell[BoxData[
    \(EKF\)], "Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"KMAX\"\>", "\<\"EPS1\"\>", "\<\"EPS2\"\>", "\<\"K\
\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"T\"\>", "\<\"OPTION\"\>"},
          {"1", "30", \(1\/10000\), \(1\/10000\), "1", "1", "1", "200", "1"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"KMAX", "EPS1", "EPS2", "K",
           "Q", "n", "T", "OPTION"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"MAXSTEP\"\>", "\<\"MINSTEP\"\>", "\<\"BOUND\"\>", \
"\<\"STEPREDUCE\"\>", "\<\"FMAX\"\>"},
          {"1", "0.1`", "1.`*^-10", "1.`*^-6", "4", "1000"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"MAXSTEP", "MINSTEP", 
          "BOUND", "STEPREDUCE", "FMAX"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"RESAMPLING\"\>", "\<\"FDIGITS\"\>", \
"\<\"TYP\"\>", "\<\"YMAX\"\>", "\<\"ANALGRAD\"\>", "\<\"FACTOR\"\>", \
"\<\"CSEED\"\>"},
          {"1", "True", "16", "1", "1000.`", "False", "1.`", \(-999\)}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"RESAMPLING", "FDIGITS", 
          "TYP", "YMAX", "ANALGRAD", "FACTOR", "CSEED"}}, TableDirections -> {
          Column, Row}, TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("    SCALING"\)], "Print"],

Cell[BoxData[
    \(Transpose::"nmtx" \(\(:\)\(\ \)\) 
      "The first two levels of the one-dimensional list \!\({}\) cannot be \
transposed."\)], "Message"],

Cell[BoxData[
    TagBox[\(Transpose[{}]\),
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"SCALING"}}, TableDepth -> 
          0]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("STARTWERT THETA0 = "\[InvisibleSpace]{1.`, 1.`}\),
      SequenceForm[ "STARTWERT THETA0 = ", {1.0, 1.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("EIGENWERTE DER HESSE-MATRIX: "\[InvisibleSpace]{1.`, 
          1.`}\),
      SequenceForm[ "EIGENWERTE DER HESSE-MATRIX: ", {1.0, 1.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("{MINI,COND,BOUND} = "\[InvisibleSpace]{1.`, 1.`, 
          1.`*^-6}\),
      SequenceForm[ 
      "{MINI,COND,BOUND} = ", {1.0, 1.0, 9.9999999999999995*^-07}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.4901161193847656`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.4901161193847656*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-2.1843643188476562`\), 
        4.507046937942505`}, \(-14.464980795171083`\)}\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]1\),
      SequenceForm[ "BFGS: Iteration = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -14.039294329072810\"\>",
            -14.039294329072813,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -14.039294329072813, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -14.464980795171080\"\>",
            -14.464980795171083,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -14.464980795171083, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.425686466098270\"\>",
            0.42568646609826999,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.42568646609826999, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.9515\"\>",
                0.95153446704850975,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0000\"\>",
                1.0,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0485\"\>",
                -0.048465532951490232,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.1844\"\>",
                -2.1843643188476562,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.1000\"\>",
                1.1000000000000001,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0000\"\>",
                1.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1000\"\>",
                0.10000000000000001,
                AutoDelete->True], 
              InterpretationBox["\<\" 4.5070\"\>",
                4.5070469379425049,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.6391277313232423`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.6391277313232423*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.0164378429842394`*^-7\),
      SequenceForm[ "NOISE  ", 1.0164378429842394*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]4.081364741345686`\
\[InvisibleSpace]"  "\[InvisibleSpace]80.97882091044148`\),
      SequenceForm[ "*BFGSUP ", 4.0813647413456859, "  ", 80.978820910441485],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.18131731518819535`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.18131731518819535, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]2\),
      SequenceForm[ "BFGS: Iteration = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.910691287595100\"\>",
            -13.910691287595098,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.910691287595098, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -14.039294329072810\"\>",
            -14.039294329072813,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -14.039294329072813, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.128603041477716\"\>",
            0.12860304147771551,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.12860304147771551, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.8515\"\>",
                0.85153446704850977,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.9515\"\>",
                0.95153446704850975,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1000\"\>",
                -0.099999999999999978,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.6535\"\>",
                -1.6535420417785645,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.0882\"\>",
                1.0882217409382227,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.1000\"\>",
                1.1000000000000001,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0118\"\>",
                -0.01177825906177744,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.3142\"\>",
                2.3141519589857622,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 1.96\"\>",
                  1.9598036979163063,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.358\"\>",
                  -4.3583934636927664,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-4.358\"\>",
                  -4.3583934636927664,
                  AutoDelete->True], 
                InterpretationBox["\<\" 19.82\"\>",
                  19.816631169265811,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.621576757636998`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.6215767576369981*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]6.614304008493898`*^-8\),
      SequenceForm[ "NOISE  ", 6.614304008493898*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]47.35517971686297`\
\[InvisibleSpace]"  "\[InvisibleSpace]82.77947676079707`\),
      SequenceForm[ "*BFGSUP ", 47.35517971686297, "  ", 82.779476760797067],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.16620820900813124`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.16620820900813124, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]3\),
      SequenceForm[ "BFGS: Iteration = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.788458572795200\"\>",
            -13.7884585727952,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.7884585727952, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.910691287595100\"\>",
            -13.910691287595098,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.910691287595098, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.122232714799898\"\>",
            0.12223271479989783,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.12223271479989783, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.7515\"\>",
                0.75153446704850979,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.8515\"\>",
                0.85153446704850977,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1000\"\>",
                -0.099999999999999964,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.4200\"\>",
                -1.420049786567688,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.0897\"\>",
                1.0896568182678097,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0882\"\>",
                1.0882217409382227,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0014\"\>",
                0.001435077329586983,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.1246\"\>",
                2.1246323226209558,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 2.81\"\>",
                  2.8095906664140644,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.03\"\>",
                  -4.030036288178465,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-4.03\"\>",
                  -4.030036288178465,
                  AutoDelete->True], 
                InterpretationBox["\<\" 18.13\"\>",
                  18.125258693437456,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.6237151894983794`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.6237151894983794*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]5.7494997403784353`*^-8\),
      SequenceForm[ "NOISE  ", 5.7494997403784353*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]19.488441881688754`\
\[InvisibleSpace]"  "\[InvisibleSpace]34.14144143219437`\),
      SequenceForm[ "*BFGSUP ", 19.488441881688754, "  ", 34.14144143219437],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.13701588692693153`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.13701588692693153, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]4\),
      SequenceForm[ "BFGS: Iteration = ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.670894799035430\"\>",
            -13.67089479903543,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.67089479903543, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.788458572795200\"\>",
            -13.7884585727952,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.7884585727952, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.117563773759770\"\>",
            0.11756377375976967,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.11756377375976967, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6515\"\>",
                0.65153446704850992,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7515\"\>",
                0.75153446704850979,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1000\"\>",
                -0.099999999999999811,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.9125\"\>",
                -0.91253399848937988,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.1646\"\>",
                1.1646406423847311,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0897\"\>",
                1.0896568182678097,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0750\"\>",
                0.074983824116921338,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.7338\"\>",
                1.7337916388299612,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 5.022\"\>",
                  5.0221209882383135,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.696\"\>",
                  -3.6957515425341469,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.696\"\>",
                  -3.6957515425341456,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.82\"\>",
                  14.818385810401113,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.735449794508116`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.7354497945081161*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]3.378135783177036`*^-8\),
      SequenceForm[ "NOISE  ", 3.3781357831770361*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]4.763988353042981`\
\[InvisibleSpace]"  "\[InvisibleSpace]5.2920414222913665`\),
      SequenceForm[ "*BFGSUP ", 4.763988353042981, "  ", 5.2920414222913665],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.04542711988592438`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.045427119885924377, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]5\),
      SequenceForm[ "BFGS: Iteration = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.652987122148940\"\>",
            -13.652987122148938,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.652987122148938, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.670894799035430\"\>",
            -13.67089479903543,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.67089479903543, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.017907676886493\"\>",
            0.017907676886492752,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.017907676886492752, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.7294\"\>",
                0.72942546043343215,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6515\"\>",
                0.65153446704850992,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0779\"\>",
                0.077890993384922211,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2863\"\>",
                0.28632569313049316,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2519\"\>",
                1.2518769366532516,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.1646\"\>",
                1.1646406423847311,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0872\"\>",
                0.087236294268520573,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5332\"\>",
                0.53323690963765091,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 8.655\"\>",
                  8.6550531031113049,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.446\"\>",
                  -4.4456839222943421,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-4.446\"\>",
                  -4.4456839222943412,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.08\"\>",
                  10.08199229455245,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8654420027930314`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8654420027930314*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.2171219420909686`*^-8\),
      SequenceForm[ "NOISE  ", 1.2171219420909686*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]10.699555584275977`\
\[InvisibleSpace]"  "\[InvisibleSpace]14.53070094175386`\),
      SequenceForm[ "*BFGSUP ", 10.699555584275977, "  ", 14.53070094175386],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.020769066626769406`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.020769066626769406, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]6\),
      SequenceForm[ "BFGS: Iteration = ", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647469641765820\"\>",
            -13.64746964176582,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.64746964176582, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.652987122148940\"\>",
            -13.652987122148938,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.652987122148938, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.005517480383118\"\>",
            0.0055174803831175012,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.0055174803831175012, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6995\"\>",
                0.69951120188126104,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7294\"\>",
                0.72942546043343215,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0299\"\>",
                -0.029914258552171089,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2836\"\>",
                -0.28355979919433594,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2384\"\>",
                1.2383766024259275,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2519\"\>",
                1.2518769366532516,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0135\"\>",
                -0.013500334227324062,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0293\"\>",
                -0.029291325704681216,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 10.94\"\>",
                  10.938680372235005,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.234\"\>",
                  -3.2341950165863098,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.234\"\>",
                  -3.2341950165863089,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.336\"\>",
                  9.3360556499326037,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8453249371438138`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8453249371438138*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]5.192854146685022`*^-9\),
      SequenceForm[ "NOISE  ", 5.192854146685022*^-09],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]143.26281919786942`\
\[InvisibleSpace]"  "\[InvisibleSpace]112.63894786403908`\),
      SequenceForm[ "*BFGSUP ", 143.26281919786942, "  ", 112.63894786403908],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.004757419888935873`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.0047574198889358734, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]7\),
      SequenceForm[ "BFGS: Iteration = ", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647238107499670\"\>",
            -13.647238107499669,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.647238107499669, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647469641765820\"\>",
            -13.64746964176582,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.64746964176582, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.000231534266151\"\>",
            0.00023153426615074579,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.00023153426615074579, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6912\"\>",
                0.69119449753918971,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6995\"\>",
                0.69951120188126104,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0083\"\>",
                -0.0083167043420713741,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0649\"\>",
                -0.064926743507385254,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2359\"\>",
                1.2359388283135091,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2384\"\>",
                1.2383766024259275,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0024\"\>",
                -0.0024377741124184914,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0033\"\>",
                0.0032954521350669233,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 8.73\"\>",
                  8.7298370704757211,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.149\"\>",
                  -3.1490737074895785,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.149\"\>",
                  -3.1490737074895776,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.392\"\>",
                  9.3915440010974116,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8416923706434803`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8416923706434803*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.0877663214614586`*^-9\),
      SequenceForm[ "NOISE  ", 1.0877663214614586*^-09],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]1648.0903034481285`\
\[InvisibleSpace]"  "\[InvisibleSpace]1879.9008012576837`\),
      SequenceForm[ "*BFGSUP ", 1648.0903034481285, "  ", 1879.9008012576837],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.0005914763529271299`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.00059147635292712986, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]8\),
      SequenceForm[ "BFGS: Iteration = ", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647232989856580\"\>",
            -13.647232989856576,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.647232989856576, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647238107499670\"\>",
            -13.647238107499669,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.647238107499669, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     5.117643093299762"\[Times]10\^"-6"\),
            5.1176430932997619*^-06,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 5.1176430932997619*^-06, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6922\"\>",
                0.69222068880278365,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6912\"\>",
                0.69119449753918971,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0010\"\>",
                0.0010261912635939248,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0081\"\>",
                0.0080720186233520508,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2366\"\>",
                1.2365779955113509,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2359\"\>",
                1.2359388283135091,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0006\"\>",
                0.00063916719784182165,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0032\"\>",
                0.0031534153821281335,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 9.588\"\>",
                  9.5875244107723514,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.764\"\>",
                  -2.7639327744619697,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-2.764\"\>",
                  -2.7639327744619688,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.371\"\>",
                  9.3711615187177344,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8426448039879664`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8426448039879664*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.287765351716947`*^-10\),
      SequenceForm[ "NOISE  ", 1.2877653517169469*^-10],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]96611.81614849351`\
\[InvisibleSpace]"  "\[InvisibleSpace]97096.85581919421`\),
      SequenceForm[ "*BFGSUP ", 96611.816148493512, "  ", 97096.855819194214],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.00005165036235826567`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 5.1650362358265669*^-05, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]9\),
      SequenceForm[ "BFGS: Iteration = ", 9],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647232966090620\"\>",
            -13.647232966090622,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.647232966090622, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647232989856580\"\>",
            -13.647232989856576,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.647232989856576, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     2.376595453768005"\[Times]10\^"-8"\),
            2.3765954537680045*^-08,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 2.3765954537680045*^-08, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6922\"\>",
                0.69219780034047806,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6922\"\>",
                0.69222068880278365,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -2.2888462305571522*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0004\"\>",
                -0.00040543079376220703,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2366\"\>",
                1.2366330897239159,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2366\"\>",
                1.2365779955113509,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0001\"\>",
                5.509421256491919*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0006\"\>",
                0.00057002836187642573,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 10.2\"\>",
                  10.204153267178276,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.12\"\>",
                  -3.1196274226371581,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.12\"\>",
                  -3.1196274226371563,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.05\"\>",
                  9.0504040985869985,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8427269007621943`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8427269007621943*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]9.959259577316352`*^-12\),
      SequenceForm[ "NOISE  ", 9.9592595773163516*^-12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]2.953114149580902`*^7\
\[InvisibleSpace]"  "\[InvisibleSpace]2.457911269525469`*^7\),
      SequenceForm[ "*BFGSUP ", 29531141.495809019, "  ", 24579112.695254691],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]8.909753035206556`*^-6\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 8.9097530352065556*^-06, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("ReturnCode = 1"\)], "Print"],

Cell[BoxData[
    \("ReturnCode = 2"\)], "Print"],

Cell[BoxData[
    \("ReturnCode = 3"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS:  ENDE DER ITERATION  "\[InvisibleSpace]9\
\[InvisibleSpace]"  "\[InvisibleSpace]30\),
      SequenceForm[ "BFGS:  ENDE DER ITERATION  ", 9, "  ", 30],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.00006139278411865234`\)},
            {"0.0000983262346383948`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 9.659\"\>",
                  9.6593524986472108,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.232\"\>",
                  -2.2316370151794769,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-2.232\"\>",
                  -2.2316370151794742,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.635\"\>",
                  7.634620188840052,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Likelihood\"\>", "\<\"THETA\"\>", "\<\"\"\>"},
          {"1", \(-14.464980795171083`\), "1.`", "1.`"},
          {"2", \(-14.039294329072813`\), "0.9515344670485097`", "1.1`"},
          {"3", \(-13.910691287595098`\), "0.8515344670485098`", 
            "1.0882217409382227`"},
          {"4", \(-13.7884585727952`\), "0.7515344670485098`", 
            "1.0896568182678097`"},
          {"5", \(-13.67089479903543`\), "0.6515344670485099`", 
            "1.164640642384731`"},
          {"6", \(-13.652987122148938`\), "0.7294254604334321`", 
            "1.2518769366532516`"},
          {"7", \(-13.64746964176582`\), "0.699511201881261`", 
            "1.2383766024259275`"},
          {"8", \(-13.64723810749967`\), "0.6911944975391897`", 
            "1.235938828313509`"},
          {"9", \(-13.647232989856576`\), "0.6922206888027836`", 
            "1.236577995511351`"},
          {"10", \(-13.647232966090622`\), "0.6921978003404781`", 
            "1.236633089723916`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"Likelihood", "THETA"}}]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("INK: "\[InvisibleSpace]{6.055454452393343`*^-6, 
          7.488375349145623`*^-6}\),
      SequenceForm[ 
      "INK: ", {6.0554544523933429*^-06, 7.4883753491456232*^-06}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Observed Fisher Information = -Hesse-Matrix"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[GridBox[{
              {"\<\"\"\>", "\<\"THETA\"\>", "\<\"SCORE\"\>"},
              {"1", "0.6921978003404781`", \(-0.00006139278411865234`\)},
              {"2", "1.236633089723916`", "0.0000983262346383948`"}
              },
            RowSpacings->0,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ 
            BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "SCORE"}}, 
              TableDirections -> {Column, Row}, TableSpacing -> {0, 1}]]], 
        "\[InvisibleSpace]", "\<\"   Likelihood = \"\>", 
        "\[InvisibleSpace]", \(-13.647232966090622`\)}],
      SequenceForm[ 
        TableForm[ {{0.69219780034047806, -6.1392784118652344*^-05}, {
          1.2366330897239159, 9.8326234638394794*^-05}}, TableHeadings -> {
          Automatic, {"THETA", "SCORE"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 1}], "   Likelihood = ", -13.647232966090622],
      Editable->False]], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("WALD-TEST:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"CHI \"\>", "\<\"U \"\>", "\<\"PROB \"\>", \
"\<\"ALPHA \"\>"},
          {"1", "12.442284326043927`", "2", "0.0019869744719639426`", 
            "0.05`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"CHI ", "U ", "PROB ", 
          "ALPHA "}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("NULLHYPOTHESE THETA = 0 ABLEHNEN"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("BONFERRONI-KONFIDENZINTERVALLE:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("QUANTIL Z(1-ALPHA/2U) = \
"\[InvisibleSpace]2.2414027276049464`\),
      SequenceForm[ "QUANTIL Z(1-ALPHA/2U) = ", 2.2414027276049464],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA\"\>", "\<\"GRENZE\"\>", "\<\"STD\"\>"},
          {"1", "0.6921978003404781`", "0.7485152372402676`", 
            "0.33394946299547623`"},
          {"2", "1.236633089723916`", "0.8407635449464769`", 
            "0.37510597028891624`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "GRENZE", "STD"}}, 
          TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Korrelation der ML-Sch\[ADoubleDot]tzer"\)], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9999999999999998`", "0.2614483188189441`"},
            {"0.26144831881894404`", "1.`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE"\)], \
"Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.11152224383496694`", "0.03275069944812691`"},
            {"0.032750699448126905`", "0.14070448894638932`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({0.09025936840192757`, 0.1619673643794286`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"9.624720970267534`", \(-2.2402721201696636`\)},
            {\(-2.2402721201696636`\), "7.628544667815582`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({11.079182335366797`, 6.174083302716319`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("KOMPENSIERTE LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("U =  "\[InvisibleSpace]2\[InvisibleSpace]"  Nue = "\
\[InvisibleSpace]201\),
      SequenceForm[ "U =  ", 2, "  Nue = ", 201],
      Editable->False]], "Print"],

Cell[BoxData[
    \("AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE \
(A/D)"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"LIK\"\>", "\<\"AIC\"\>", "\<\"SIC/RISS\"\>", \
"\<\"A/D\"\>"},
          {"\<\"Kompensator\"\>", "0", "2", "5.303304908059076`", 
            "5.009995571918117`"},
          {"\<\"komp. Lik.\"\>", \(-13.647232966090622`\), \
\(-15.647232966090622`\), \(-18.950537874149695`\), \(-18.657228538008738`\)}
          },
        RowSpacings->0,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"Kompensator", "komp. Lik."}, {"LIK", 
          "AIC", "SIC/RISS", "A/D"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 1}]]]], "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
asymptotic standard deviation using F \[TildeTilde] sum of score \
products = BHHH (Greene, ch. 4)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\({THETA, COV, LIKI, psii, scoreii, k, ReturnCode}\), "=", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"BFGS", "[", 
            RowBox[{\({{ZM, X}}\), ",", \({THETA0, F0}\), ",", 
              RowBox[{"{", 
                RowBox[{"system", ",", 
                  RowBox[{"{", 
                    RowBox[{"Lik", ",", "EKF", ",", "Score", ",", 
                      StyleBox["FisherInformation",
                        FontColor->RGBColor[1, 0, 0]]}], "}"}]}], "}"}], 
              ",", \({{miss, 1}, 
                KMAX = 30, {EPS1 = 10^\(-4\), EPS2 = 10^\(-4\)}, OPTION = 1, 
                PRINT = {1, 1, 1, 1, 1, 1, 1, 1}}\)}], "]"}]}], 
        ";"}]}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("Tiefe von data = "\[InvisibleSpace]5\),
      SequenceForm[ "Tiefe von data = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    \("L\[ADoubleDot]nge der Paneldaten"\)], "Print"],

Cell[BoxData[
    \({201}\)], "Print"],

Cell[BoxData[
    \("***********************LSDE1**********************************"\)], \
"Print"],

Cell[BoxData[
    \("***********************MODUL:    BFGS (skeleton)**************"\)], \
"Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \("Technical Output"\)], "Print"],

Cell[BoxData[
    \(EKF\)], "Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"KMAX\"\>", "\<\"EPS1\"\>", "\<\"EPS2\"\>", "\<\"K\
\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"T\"\>", "\<\"OPTION\"\>"},
          {"1", "30", \(1\/10000\), \(1\/10000\), "1", "1", "1", "200", "1"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"KMAX", "EPS1", "EPS2", "K",
           "Q", "n", "T", "OPTION"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"MAXSTEP\"\>", "\<\"MINSTEP\"\>", "\<\"BOUND\"\>", \
"\<\"STEPREDUCE\"\>", "\<\"FMAX\"\>"},
          {"1", "0.1`", "1.`*^-10", "1.`*^-6", "4", "1000"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"MAXSTEP", "MINSTEP", 
          "BOUND", "STEPREDUCE", "FMAX"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"RESAMPLING\"\>", "\<\"FDIGITS\"\>", \
"\<\"TYP\"\>", "\<\"YMAX\"\>", "\<\"ANALGRAD\"\>", "\<\"FACTOR\"\>", \
"\<\"CSEED\"\>"},
          {"1", "True", "16", "1", "1000.`", "False", "1.`", \(-999\)}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"RESAMPLING", "FDIGITS", 
          "TYP", "YMAX", "ANALGRAD", "FACTOR", "CSEED"}}, TableDirections -> {
          Column, Row}, TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("    SCALING"\)], "Print"],

Cell[BoxData[
    \(Transpose::"nmtx" \(\(:\)\(\ \)\) 
      "The first two levels of the one-dimensional list \!\({}\) cannot be \
transposed."\)], "Message"],

Cell[BoxData[
    TagBox[\(Transpose[{}]\),
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"SCALING"}}, TableDepth -> 
          0]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("STARTWERT THETA0 = "\[InvisibleSpace]{1.`, 1.`}\),
      SequenceForm[ "STARTWERT THETA0 = ", {1.0, 1.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("EIGENWERTE DER HESSE-MATRIX: "\[InvisibleSpace]{1.`, 
          1.`}\),
      SequenceForm[ "EIGENWERTE DER HESSE-MATRIX: ", {1.0, 1.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("{MINI,COND,BOUND} = "\[InvisibleSpace]{1.`, 1.`, 
          1.`*^-6}\),
      SequenceForm[ 
      "{MINI,COND,BOUND} = ", {1.0, 1.0, 9.9999999999999995*^-07}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.4901161193847656`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.4901161193847656*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{\(-2.1843643188476562`\), 
        4.507046937942505`}, \(-14.464980795171083`\)}\)], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]1\),
      SequenceForm[ "BFGS: Iteration = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -14.039294329072810\"\>",
            -14.039294329072813,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -14.039294329072813, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -14.464980795171080\"\>",
            -14.464980795171083,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -14.464980795171083, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.425686466098270\"\>",
            0.42568646609826999,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.42568646609826999, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.9515\"\>",
                0.95153446704850975,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0000\"\>",
                1.0,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0485\"\>",
                -0.048465532951490232,
                AutoDelete->True], 
              InterpretationBox["\<\"-2.1844\"\>",
                -2.1843643188476562,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.1000\"\>",
                1.1000000000000001,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0000\"\>",
                1.0,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.1000\"\>",
                0.10000000000000001,
                AutoDelete->True], 
              InterpretationBox["\<\" 4.5070\"\>",
                4.5070469379425049,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.6391277313232423`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.6391277313232423*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.0164378429842394`*^-7\),
      SequenceForm[ "NOISE  ", 1.0164378429842394*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]4.081364741345686`\
\[InvisibleSpace]"  "\[InvisibleSpace]80.97882091044148`\),
      SequenceForm[ "*BFGSUP ", 4.0813647413456859, "  ", 80.978820910441485],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.18131731518819535`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.18131731518819535, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]2\),
      SequenceForm[ "BFGS: Iteration = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.910691287595100\"\>",
            -13.910691287595098,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.910691287595098, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -14.039294329072810\"\>",
            -14.039294329072813,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -14.039294329072813, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.128603041477716\"\>",
            0.12860304147771551,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.12860304147771551, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.8515\"\>",
                0.85153446704850977,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.9515\"\>",
                0.95153446704850975,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1000\"\>",
                -0.099999999999999978,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.6535\"\>",
                -1.6535420417785645,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.0882\"\>",
                1.0882217409382227,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.1000\"\>",
                1.1000000000000001,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0118\"\>",
                -0.01177825906177744,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.3142\"\>",
                2.3141519589857622,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 1.96\"\>",
                  1.9598036979163063,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.358\"\>",
                  -4.3583934636927664,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-4.358\"\>",
                  -4.3583934636927664,
                  AutoDelete->True], 
                InterpretationBox["\<\" 19.82\"\>",
                  19.816631169265811,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.621576757636998`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.6215767576369981*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]6.614304008493898`*^-8\),
      SequenceForm[ "NOISE  ", 6.614304008493898*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]47.35517971686297`\
\[InvisibleSpace]"  "\[InvisibleSpace]82.77947676079707`\),
      SequenceForm[ "*BFGSUP ", 47.35517971686297, "  ", 82.779476760797067],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.16620820900813124`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.16620820900813124, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]3\),
      SequenceForm[ "BFGS: Iteration = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.788458572795200\"\>",
            -13.7884585727952,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.7884585727952, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.910691287595100\"\>",
            -13.910691287595098,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.910691287595098, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.122232714799898\"\>",
            0.12223271479989783,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.12223271479989783, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.7515\"\>",
                0.75153446704850979,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.8515\"\>",
                0.85153446704850977,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1000\"\>",
                -0.099999999999999964,
                AutoDelete->True], 
              InterpretationBox["\<\"-1.4200\"\>",
                -1.420049786567688,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.0897\"\>",
                1.0896568182678097,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0882\"\>",
                1.0882217409382227,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0014\"\>",
                0.001435077329586983,
                AutoDelete->True], 
              InterpretationBox["\<\" 2.1246\"\>",
                2.1246323226209558,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 2.81\"\>",
                  2.8095906664140644,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.03\"\>",
                  -4.030036288178465,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-4.03\"\>",
                  -4.030036288178465,
                  AutoDelete->True], 
                InterpretationBox["\<\" 18.13\"\>",
                  18.125258693437456,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.6237151894983794`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.6237151894983794*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]5.7494997403784353`*^-8\),
      SequenceForm[ "NOISE  ", 5.7494997403784353*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]19.488441881688754`\
\[InvisibleSpace]"  "\[InvisibleSpace]34.14144143219437`\),
      SequenceForm[ "*BFGSUP ", 19.488441881688754, "  ", 34.14144143219437],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.13701588692693153`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.13701588692693153, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]4\),
      SequenceForm[ "BFGS: Iteration = ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.670894799035430\"\>",
            -13.67089479903543,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.67089479903543, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.788458572795200\"\>",
            -13.7884585727952,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.7884585727952, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.117563773759770\"\>",
            0.11756377375976967,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.11756377375976967, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6515\"\>",
                0.65153446704850992,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7515\"\>",
                0.75153446704850979,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.1000\"\>",
                -0.099999999999999811,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.9125\"\>",
                -0.91253399848937988,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.1646\"\>",
                1.1646406423847311,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.0897\"\>",
                1.0896568182678097,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0750\"\>",
                0.074983824116921338,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.7338\"\>",
                1.7337916388299612,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 5.022\"\>",
                  5.0221209882383135,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.696\"\>",
                  -3.6957515425341469,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.696\"\>",
                  -3.6957515425341456,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.82\"\>",
                  14.818385810401113,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.735449794508116`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.7354497945081161*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]3.378135783177036`*^-8\),
      SequenceForm[ "NOISE  ", 3.3781357831770361*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]4.763988353042981`\
\[InvisibleSpace]"  "\[InvisibleSpace]5.2920414222913665`\),
      SequenceForm[ "*BFGSUP ", 4.763988353042981, "  ", 5.2920414222913665],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.04542711988592438`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.045427119885924377, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]5\),
      SequenceForm[ "BFGS: Iteration = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.652987122148940\"\>",
            -13.652987122148938,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.652987122148938, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.670894799035430\"\>",
            -13.67089479903543,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.67089479903543, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.017907676886493\"\>",
            0.017907676886492752,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.017907676886492752, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.7294\"\>",
                0.72942546043343215,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6515\"\>",
                0.65153446704850992,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0779\"\>",
                0.077890993384922211,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.2863\"\>",
                0.28632569313049316,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2519\"\>",
                1.2518769366532516,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.1646\"\>",
                1.1646406423847311,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0872\"\>",
                0.087236294268520573,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.5332\"\>",
                0.53323690963765091,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 8.655\"\>",
                  8.6550531031113049,
                  AutoDelete->True], 
                InterpretationBox["\<\"-4.446\"\>",
                  -4.4456839222943421,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-4.446\"\>",
                  -4.4456839222943412,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.08\"\>",
                  10.08199229455245,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8654420027930314`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8654420027930314*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.2171219420909686`*^-8\),
      SequenceForm[ "NOISE  ", 1.2171219420909686*^-08],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]10.699555584275977`\
\[InvisibleSpace]"  "\[InvisibleSpace]14.53070094175386`\),
      SequenceForm[ "*BFGSUP ", 10.699555584275977, "  ", 14.53070094175386],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.020769066626769406`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.020769066626769406, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]6\),
      SequenceForm[ "BFGS: Iteration = ", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647469641765820\"\>",
            -13.64746964176582,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.64746964176582, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.652987122148940\"\>",
            -13.652987122148938,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.652987122148938, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.005517480383118\"\>",
            0.0055174803831175012,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.0055174803831175012, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6995\"\>",
                0.69951120188126104,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.7294\"\>",
                0.72942546043343215,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0299\"\>",
                -0.029914258552171089,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.2836\"\>",
                -0.28355979919433594,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2384\"\>",
                1.2383766024259275,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2519\"\>",
                1.2518769366532516,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0135\"\>",
                -0.013500334227324062,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0293\"\>",
                -0.029291325704681216,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 10.94\"\>",
                  10.938680372235005,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.234\"\>",
                  -3.2341950165863098,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.234\"\>",
                  -3.2341950165863089,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.336\"\>",
                  9.3360556499326037,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8453249371438138`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8453249371438138*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]5.192854146685022`*^-9\),
      SequenceForm[ "NOISE  ", 5.192854146685022*^-09],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]143.26281919786942`\
\[InvisibleSpace]"  "\[InvisibleSpace]112.63894786403908`\),
      SequenceForm[ "*BFGSUP ", 143.26281919786942, "  ", 112.63894786403908],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.004757419888935873`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.0047574198889358734, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]7\),
      SequenceForm[ "BFGS: Iteration = ", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647238107499670\"\>",
            -13.647238107499669,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.647238107499669, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647469641765820\"\>",
            -13.64746964176582,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.64746964176582, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.000231534266151\"\>",
            0.00023153426615074579,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.00023153426615074579, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6912\"\>",
                0.69119449753918971,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6995\"\>",
                0.69951120188126104,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0083\"\>",
                -0.0083167043420713741,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0649\"\>",
                -0.064926743507385254,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2359\"\>",
                1.2359388283135091,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2384\"\>",
                1.2383766024259275,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0024\"\>",
                -0.0024377741124184914,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0033\"\>",
                0.0032954521350669233,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 8.73\"\>",
                  8.7298370704757211,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.149\"\>",
                  -3.1490737074895785,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.149\"\>",
                  -3.1490737074895776,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.392\"\>",
                  9.3915440010974116,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8416923706434803`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8416923706434803*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.0877663214614586`*^-9\),
      SequenceForm[ "NOISE  ", 1.0877663214614586*^-09],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]1648.0903034481285`\
\[InvisibleSpace]"  "\[InvisibleSpace]1879.9008012576837`\),
      SequenceForm[ "*BFGSUP ", 1648.0903034481285, "  ", 1879.9008012576837],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.0005914763529271299`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 0.00059147635292712986, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]8\),
      SequenceForm[ "BFGS: Iteration = ", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647232989856580\"\>",
            -13.647232989856576,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.647232989856576, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647238107499670\"\>",
            -13.647238107499669,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.647238107499669, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     5.117643093299762"\[Times]10\^"-6"\),
            5.1176430932997619*^-06,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 5.1176430932997619*^-06, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6922\"\>",
                0.69222068880278365,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6912\"\>",
                0.69119449753918971,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0010\"\>",
                0.0010261912635939248,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0081\"\>",
                0.0080720186233520508,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2366\"\>",
                1.2365779955113509,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2359\"\>",
                1.2359388283135091,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0006\"\>",
                0.00063916719784182165,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0032\"\>",
                0.0031534153821281335,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 9.588\"\>",
                  9.5875244107723514,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.764\"\>",
                  -2.7639327744619697,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-2.764\"\>",
                  -2.7639327744619688,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.371\"\>",
                  9.3711615187177344,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8426448039879664`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8426448039879664*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]1.287765351716947`*^-10\),
      SequenceForm[ "NOISE  ", 1.2877653517169469*^-10],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]96611.81614849351`\
\[InvisibleSpace]"  "\[InvisibleSpace]97096.85581919421`\),
      SequenceForm[ "*BFGSUP ", 96611.816148493512, "  ", 97096.855819194214],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]0.00005165036235826567`\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 5.1650362358265669*^-05, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS: Iteration = "\[InvisibleSpace]9\),
      SequenceForm[ "BFGS: Iteration = ", 9],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647232966090620\"\>",
            -13.647232966090622,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ -13.647232966090622, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -13.647232989856580\"\>",
            -13.647232989856576,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKALT  ", 
        PaddedForm[ -13.647232989856576, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     2.376595453768005"\[Times]10\^"-8"\),
            2.3765954537680045*^-08,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 2.3765954537680045*^-08, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[GridBox[{
            {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\
\<\"SCORE\"\>"},
            {
              InterpretationBox["\<\" 1.0000\"\>",
                1,
                Editable->False], 
              InterpretationBox["\<\" 0.6922\"\>",
                0.69219780034047806,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.6922\"\>",
                0.69222068880278365,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0000\"\>",
                -2.2888462305571522*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\"-0.0004\"\>",
                -0.00040543079376220703,
                AutoDelete->True]},
            {
              InterpretationBox["\<\" 2.0000\"\>",
                2,
                Editable->False], 
              InterpretationBox["\<\" 1.2366\"\>",
                1.2366330897239159,
                AutoDelete->True], 
              InterpretationBox["\<\" 1.2366\"\>",
                1.2365779955113509,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0001\"\>",
                5.509421256491919*^-05,
                AutoDelete->True], 
              InterpretationBox["\<\" 0.0006\"\>",
                0.00057002836187642573,
                AutoDelete->True]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ 
          BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
            TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
            "SCORE"}}]]],
      (PaddedForm[ #, {5, 4}]&)]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 10.2\"\>",
                  10.204153267178276,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.12\"\>",
                  -3.1196274226371581,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-3.12\"\>",
                  -3.1196274226371563,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.05\"\>",
                  9.0504040985869985,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8427269007621943`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8427269007621943*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("NOISE  "\[InvisibleSpace]9.959259577316352`*^-12\),
      SequenceForm[ "NOISE  ", 9.9592595773163516*^-12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]2.953114149580902`*^7\
\[InvisibleSpace]"  "\[InvisibleSpace]2.457911269525469`*^7\),
      SequenceForm[ "*BFGSUP ", 29531141.495809019, "  ", 24579112.695254691],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("relgrad = "\[InvisibleSpace]8.909753035206556`*^-6\
\[InvisibleSpace]" = Elastizitaet(d l/l)/(d theta/theta)"\),
      SequenceForm[ 
      "relgrad = ", 8.9097530352065556*^-06, 
        " = Elastizitaet(d l/l)/(d theta/theta)"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("ReturnCode = 1"\)], "Print"],

Cell[BoxData[
    \("ReturnCode = 2"\)], "Print"],

Cell[BoxData[
    \("ReturnCode = 3"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("BFGS:  ENDE DER ITERATION  "\[InvisibleSpace]9\
\[InvisibleSpace]"  "\[InvisibleSpace]30\),
      SequenceForm[ "BFGS:  ENDE DER ITERATION  ", 9, "  ", 30],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.00006139278411865234`\)},
            {"0.0000983262346383948`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 9.659\"\>",
                  9.6593524986472108,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.232\"\>",
                  -2.2316370151794769,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-2.232\"\>",
                  -2.2316370151794742,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.635\"\>",
                  7.634620188840052,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Likelihood\"\>", "\<\"THETA\"\>", "\<\"\"\>"},
          {"1", \(-14.464980795171083`\), "1.`", "1.`"},
          {"2", \(-14.039294329072813`\), "0.9515344670485097`", "1.1`"},
          {"3", \(-13.910691287595098`\), "0.8515344670485098`", 
            "1.0882217409382227`"},
          {"4", \(-13.7884585727952`\), "0.7515344670485098`", 
            "1.0896568182678097`"},
          {"5", \(-13.67089479903543`\), "0.6515344670485099`", 
            "1.164640642384731`"},
          {"6", \(-13.652987122148938`\), "0.7294254604334321`", 
            "1.2518769366532516`"},
          {"7", \(-13.64746964176582`\), "0.699511201881261`", 
            "1.2383766024259275`"},
          {"8", \(-13.64723810749967`\), "0.6911944975391897`", 
            "1.235938828313509`"},
          {"9", \(-13.647232989856576`\), "0.6922206888027836`", 
            "1.236577995511351`"},
          {"10", \(-13.647232966090622`\), "0.6921978003404781`", 
            "1.236633089723916`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"Likelihood", "THETA"}}]]]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Score: INC: \
"\[InvisibleSpace]{1.4901161193847656`*^-8, 1.8427269007621943`*^-8}\),
      SequenceForm[ 
      "Score: INC: ", {1.4901161193847656*^-08, 1.8427269007621943*^-08}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Fisher Information = BHHH (OPG)"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[GridBox[{
              {"\<\"\"\>", "\<\"THETA\"\>", "\<\"SCORE\"\>"},
              {"1", "0.6921978003404781`", \(-0.00006139278411865234`\)},
              {"2", "1.236633089723916`", "0.0000983262346383948`"}
              },
            RowSpacings->0,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ 
            BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "SCORE"}}, 
              TableDirections -> {Column, Row}, TableSpacing -> {0, 1}]]], 
        "\[InvisibleSpace]", "\<\"   Likelihood = \"\>", 
        "\[InvisibleSpace]", \(-13.647232966090622`\)}],
      SequenceForm[ 
        TableForm[ {{0.69219780034047806, -6.1392784118652344*^-05}, {
          1.2366330897239159, 9.8326234638394794*^-05}}, TableHeadings -> {
          Automatic, {"THETA", "SCORE"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 1}], "   Likelihood = ", -13.647232966090622],
      Editable->False]], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("WALD-TEST:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"CHI \"\>", "\<\"U \"\>", "\<\"PROB \"\>", \
"\<\"ALPHA \"\>"},
          {"1", "6.9168217664265095`", "2", "0.031479747286489834`", "0.05`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"CHI ", "U ", "PROB ", 
          "ALPHA "}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("NULLHYPOTHESE THETA = 0 ABLEHNEN"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("BONFERRONI-KONFIDENZINTERVALLE:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("QUANTIL Z(1-ALPHA/2U) = \
"\[InvisibleSpace]2.2414027276049464`\),
      SequenceForm[ "QUANTIL Z(1-ALPHA/2U) = ", 2.2414027276049464],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA\"\>", "\<\"GRENZE\"\>", "\<\"STD\"\>"},
          {"1", "0.6921978003404781`", "2.2347525350217587`", 
            "0.9970330219994451`"},
          {"2", "1.236633089723916`", "1.353289107676437`", 
            "0.6037688323519155`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "GRENZE", "STD"}}, 
          TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Korrelation der ML-Sch\[ADoubleDot]tzer"\)], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0.8106232596574722`"},
            {"0.8106232596574717`", "1.0000000000000002`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE"\)], \
"Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9940748469573459`", "0.48797693370992684`"},
            {"0.4879769337099266`", "0.36453680291959545`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({0.09861569668101411`, 1.259995953195929`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2.933770808290961`", \(-3.927209740612342`\)},
            {\(-3.927209740612342`\), "8.000256061671296`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({10.140373527295925`, 0.7936533426663317`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("KOMPENSIERTE LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("U =  "\[InvisibleSpace]2\[InvisibleSpace]"  Nue = "\
\[InvisibleSpace]201\),
      SequenceForm[ "U =  ", 2, "  Nue = ", 201],
      Editable->False]], "Print"],

Cell[BoxData[
    \("AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE \
(A/D)"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"LIK\"\>", "\<\"AIC\"\>", "\<\"SIC/RISS\"\>", \
"\<\"A/D\"\>"},
          {"\<\"Kompensator\"\>", "0", "2", "5.303304908059076`", 
            "5.009995571918117`"},
          {"\<\"komp. Lik.\"\>", \(-13.647232966090622`\), \
\(-15.647232966090622`\), \(-18.950537874149695`\), \(-18.657228538008738`\)}
          },
        RowSpacings->0,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"Kompensator", "komp. Lik."}, {"LIK", 
          "AIC", "SIC/RISS", "A/D"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 1}]]]], "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowToolbars->{},
WindowSize->{995, 691},
WindowMargins->{{45, Automatic}, {Automatic, 2}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "Default.nb",
MacintoshSystemPageSetup->"\<\
0000001804P000000bd2=_oaoo43?095o`85N@?NW0002008ool000001@050001
0000I24A4R060`410@000BL?0040000000000000000004E3<34100;o00000001
000A0S<R<3`00Q3400018NOWinOWia4A\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 446, 7, 123, "Input"],
Cell[2203, 60, 235, 7, 27, "Input"],

Cell[CellGroupData[{
Cell[2463, 71, 89, 2, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2577, 77, 235, 6, 103, "Input"],
Cell[2815, 85, 37, 1, 38, "Output"],
Cell[2855, 88, 119, 2, 21, "Message"],
Cell[2977, 92, 174, 3, 21, "Message"],
Cell[3154, 97, 115, 2, 21, "Message"],
Cell[3272, 101, 189, 3, 21, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3510, 110, 92, 2, 30, "Subsection"],

Cell[CellGroupData[{
Cell[3627, 116, 602, 25, 339, "Input"],
Cell[4232, 143, 203, 3, 21, "Message"],
Cell[4438, 148, 179, 3, 21, "Message"],
Cell[4620, 153, 179, 3, 21, "Message"],
Cell[4802, 158, 128, 3, 53, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4979, 167, 89, 2, 30, "Subsection"],

Cell[CellGroupData[{
Cell[5093, 173, 251, 14, 189, "Input"],
Cell[5347, 189, 44, 1, 38, "Output"],
Cell[5394, 192, 40, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5471, 198, 86, 5, 54, "Input"],
Cell[5560, 205, 2321, 31, 233, "Output"],
Cell[7884, 238, 37, 1, 38, "Output"]
}, Open  ]],
Cell[7936, 242, 180, 7, 54, "Input"],
Cell[8119, 251, 247, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[8391, 262, 198, 5, 54, "Input"],
Cell[8592, 269, 181, 3, 22, "Print"],
Cell[8776, 274, 118380, 3730, 182, 46342, 2836, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127193, 4009, 87, 2, 39, "Input"],
Cell[127283, 4013, 46, 1, 38, "Output"]
}, Open  ]],
Cell[127344, 4017, 140, 2, 30, "Text"],
Cell[127487, 4021, 206, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[127718, 4032, 88, 2, 39, "Input"],
Cell[127809, 4036, 42, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127888, 4042, 76, 2, 39, "Input"],
Cell[127967, 4046, 2175, 30, 173, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[130191, 4082, 134, 3, 30, "Subsection"],
Cell[130328, 4087, 329, 6, 71, "Input"],

Cell[CellGroupData[{
Cell[130682, 4097, 565, 11, 103, "Input"],
Cell[131250, 4110, 179, 3, 22, "Print"],
Cell[131432, 4115, 66953, 2017, 182, 23440, 1475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198422, 6137, 413, 10, 103, "Input"],
Cell[198838, 6149, 179, 3, 22, "Print"],
Cell[199020, 6154, 64970, 1993, 182, 23421, 1475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264027, 8152, 157, 5, 39, "Input"],
Cell[264187, 8159, 163033, 4402, 267, 47120, 2966, "GraphicsData", \
"PostScript", "Graphics"],
Cell[427223, 12563, 135, 3, 38, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[427407, 12572, 150, 3, 46, "Subsection"],
Cell[427560, 12577, 300, 5, 87, "Input"],

Cell[CellGroupData[{
Cell[427885, 12586, 112, 3, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[428022, 12593, 761, 16, 103, "Input"],
Cell[428786, 12611, 157, 3, 22, "Print"],
Cell[428946, 12616, 67, 1, 22, "Print"],
Cell[429016, 12619, 38, 1, 22, "Print"],
Cell[429057, 12622, 99, 2, 22, "Print"],
Cell[429159, 12626, 99, 2, 22, "Print"],
Cell[429261, 12630, 99, 2, 22, "Print"],
Cell[429363, 12634, 51, 1, 22, "Print"],
Cell[429417, 12637, 36, 1, 22, "Print"],
Cell[429456, 12640, 99, 2, 22, "Print"],
Cell[429558, 12644, 635, 14, 39, "Print"],
Cell[430196, 12660, 45, 1, 22, "Print"],
Cell[430244, 12663, 592, 14, 33, "Print"],
Cell[430839, 12679, 45, 1, 22, "Print"],
Cell[430887, 12682, 657, 15, 31, "Print"],
Cell[431547, 12699, 45, 1, 22, "Print"],
Cell[431595, 12702, 46, 1, 22, "Print"],
Cell[431644, 12705, 159, 3, 21, "Message"],
Cell[431806, 12710, 197, 5, 22, "Print"],
Cell[432006, 12717, 45, 1, 22, "Print"],
Cell[432054, 12720, 99, 2, 22, "Print"],
Cell[432156, 12724, 45, 1, 22, "Print"],
Cell[432204, 12727, 179, 3, 22, "Print"],
Cell[432386, 12732, 210, 4, 22, "Print"],
Cell[432599, 12738, 233, 5, 24, "Print"],
Cell[432835, 12745, 254, 5, 24, "Print"],
Cell[433092, 12752, 116, 2, 22, "Print"],
Cell[433211, 12756, 102, 2, 22, "Print"],
Cell[433316, 12760, 159, 3, 22, "Print"],
Cell[433478, 12765, 396, 10, 22, "Print"],
Cell[433877, 12777, 396, 10, 22, "Print"],
Cell[434276, 12789, 414, 10, 22, "Print"],
Cell[434693, 12801, 45, 1, 22, "Print"],
Cell[434741, 12804, 1753, 47, 53, "Print"],
Cell[436497, 12853, 46, 1, 22, "Print"],
Cell[436546, 12856, 728, 21, 37, "Print"],
Cell[437277, 12879, 254, 5, 24, "Print"],
Cell[437534, 12886, 181, 3, 24, "Print"],
Cell[437718, 12891, 264, 5, 22, "Print"],
Cell[437985, 12898, 297, 6, 22, "Print"],
Cell[438285, 12906, 102, 2, 22, "Print"],
Cell[438390, 12910, 159, 3, 22, "Print"],
Cell[438552, 12915, 396, 10, 22, "Print"],
Cell[438951, 12927, 396, 10, 22, "Print"],
Cell[439350, 12939, 414, 10, 22, "Print"],
Cell[439767, 12951, 45, 1, 22, "Print"],
Cell[439815, 12954, 1785, 47, 53, "Print"],
Cell[441603, 13003, 46, 1, 22, "Print"],
Cell[441652, 13006, 801, 21, 37, "Print"],
Cell[442456, 13029, 253, 5, 24, "Print"],
Cell[442712, 13036, 179, 3, 24, "Print"],
Cell[442894, 13041, 256, 4, 22, "Print"],
Cell[443153, 13047, 297, 6, 22, "Print"],
Cell[443453, 13055, 102, 2, 22, "Print"],
Cell[443558, 13059, 159, 3, 22, "Print"],
Cell[443720, 13064, 392, 10, 22, "Print"],
Cell[444115, 13076, 396, 10, 22, "Print"],
Cell[444514, 13088, 414, 10, 22, "Print"],
Cell[444931, 13100, 45, 1, 22, "Print"],
Cell[444979, 13103, 1784, 47, 53, "Print"],
Cell[446766, 13152, 46, 1, 22, "Print"],
Cell[446815, 13155, 797, 21, 37, "Print"],
Cell[447615, 13178, 254, 5, 24, "Print"],
Cell[447872, 13185, 181, 3, 24, "Print"],
Cell[448056, 13190, 257, 4, 22, "Print"],
Cell[448316, 13196, 297, 6, 22, "Print"],
Cell[448616, 13204, 102, 2, 22, "Print"],
Cell[448721, 13208, 159, 3, 22, "Print"],
Cell[448883, 13213, 394, 10, 22, "Print"],
Cell[449280, 13225, 392, 10, 22, "Print"],
Cell[449675, 13237, 414, 10, 22, "Print"],
Cell[450092, 13249, 45, 1, 22, "Print"],
Cell[450140, 13252, 1786, 47, 53, "Print"],
Cell[451929, 13301, 46, 1, 22, "Print"],
Cell[451978, 13304, 802, 21, 37, "Print"],
Cell[452783, 13327, 253, 5, 24, "Print"],
Cell[453039, 13334, 180, 3, 24, "Print"],
Cell[453222, 13339, 257, 4, 22, "Print"],
Cell[453482, 13345, 298, 6, 22, "Print"],
Cell[453783, 13353, 102, 2, 22, "Print"],
Cell[453888, 13357, 159, 3, 22, "Print"],
Cell[454050, 13362, 396, 10, 22, "Print"],
Cell[454449, 13374, 394, 10, 22, "Print"],
Cell[454846, 13386, 416, 10, 22, "Print"],
Cell[455265, 13398, 45, 1, 22, "Print"],
Cell[455313, 13401, 1785, 47, 53, "Print"],
Cell[457101, 13450, 46, 1, 22, "Print"],
Cell[457150, 13453, 801, 21, 37, "Print"],
Cell[457954, 13476, 254, 5, 24, "Print"],
Cell[458211, 13483, 181, 3, 24, "Print"],
Cell[458395, 13488, 257, 4, 22, "Print"],
Cell[458655, 13494, 299, 6, 22, "Print"],
Cell[458957, 13502, 102, 2, 22, "Print"],
Cell[459062, 13506, 159, 3, 22, "Print"],
Cell[459224, 13511, 394, 10, 22, "Print"],
Cell[459621, 13523, 396, 10, 22, "Print"],
Cell[460020, 13535, 418, 10, 22, "Print"],
Cell[460441, 13547, 45, 1, 22, "Print"],
Cell[460489, 13550, 1790, 47, 53, "Print"],
Cell[462282, 13599, 46, 1, 22, "Print"],
Cell[462331, 13602, 802, 21, 37, "Print"],
Cell[463136, 13625, 254, 5, 24, "Print"],
Cell[463393, 13632, 179, 3, 24, "Print"],
Cell[463575, 13637, 266, 5, 22, "Print"],
Cell[463844, 13644, 300, 6, 22, "Print"],
Cell[464147, 13652, 102, 2, 22, "Print"],
Cell[464252, 13656, 159, 3, 22, "Print"],
Cell[464414, 13661, 396, 10, 22, "Print"],
Cell[464813, 13673, 394, 10, 22, "Print"],
Cell[465210, 13685, 420, 10, 22, "Print"],
Cell[465633, 13697, 45, 1, 22, "Print"],
Cell[465681, 13700, 1793, 47, 53, "Print"],
Cell[467477, 13749, 46, 1, 22, "Print"],
Cell[467526, 13752, 801, 21, 37, "Print"],
Cell[468330, 13775, 254, 5, 24, "Print"],
Cell[468587, 13782, 181, 3, 24, "Print"],
Cell[468771, 13787, 266, 5, 22, "Print"],
Cell[469040, 13794, 302, 6, 22, "Print"],
Cell[469345, 13802, 102, 2, 22, "Print"],
Cell[469450, 13806, 159, 3, 22, "Print"],
Cell[469612, 13811, 396, 10, 22, "Print"],
Cell[470011, 13823, 396, 10, 22, "Print"],
Cell[470410, 13835, 434, 10, 24, "Print"],
Cell[470847, 13847, 45, 1, 22, "Print"],
Cell[470895, 13850, 1792, 47, 53, "Print"],
Cell[472690, 13899, 46, 1, 22, "Print"],
Cell[472739, 13902, 802, 21, 37, "Print"],
Cell[473544, 13925, 254, 5, 24, "Print"],
Cell[473801, 13932, 181, 3, 24, "Print"],
Cell[473985, 13937, 264, 5, 22, "Print"],
Cell[474252, 13944, 304, 6, 22, "Print"],
Cell[474559, 13952, 102, 2, 22, "Print"],
Cell[474664, 13956, 159, 3, 22, "Print"],
Cell[474826, 13961, 396, 10, 22, "Print"],
Cell[475225, 13973, 396, 10, 22, "Print"],
Cell[475624, 13985, 434, 10, 24, "Print"],
Cell[476061, 13997, 45, 1, 22, "Print"],
Cell[476109, 14000, 1798, 47, 53, "Print"],
Cell[477910, 14049, 46, 1, 22, "Print"],
Cell[477959, 14052, 798, 21, 37, "Print"],
Cell[478760, 14075, 254, 5, 24, "Print"],
Cell[479017, 14082, 181, 3, 24, "Print"],
Cell[479201, 14087, 270, 5, 24, "Print"],
Cell[479474, 14094, 303, 6, 24, "Print"],
Cell[479780, 14102, 49, 1, 22, "Print"],
Cell[479832, 14105, 49, 1, 22, "Print"],
Cell[479884, 14108, 49, 1, 22, "Print"],
Cell[479936, 14111, 229, 4, 22, "Print"],
Cell[480168, 14117, 312, 8, 37, "Print"],
Cell[480483, 14127, 46, 1, 22, "Print"],
Cell[480532, 14130, 801, 21, 37, "Print"],
Cell[481336, 14153, 1380, 29, 181, "Print"],
Cell[482719, 14184, 247, 5, 24, "Print"],
Cell[482969, 14191, 78, 1, 22, "Print"],
Cell[483050, 14194, 91, 1, 22, "Print"],
Cell[483144, 14197, 80, 1, 22, "Print"],
Cell[483227, 14200, 91, 1, 22, "Print"],
Cell[483321, 14203, 1111, 23, 41, "Print"],
Cell[484435, 14228, 89, 1, 22, "Print"],
Cell[484527, 14231, 45, 1, 22, "Print"],
Cell[484575, 14234, 89, 1, 22, "Print"],
Cell[484667, 14237, 576, 15, 31, "Print"],
Cell[485246, 14254, 67, 1, 22, "Print"],
Cell[485316, 14257, 89, 1, 22, "Print"],
Cell[485408, 14260, 66, 1, 22, "Print"],
Cell[485477, 14263, 89, 1, 22, "Print"],
Cell[485569, 14266, 89, 1, 22, "Print"],
Cell[485661, 14269, 208, 4, 22, "Print"],
Cell[485872, 14275, 658, 16, 41, "Print"],
Cell[486533, 14293, 90, 1, 22, "Print"],
Cell[486626, 14296, 74, 1, 22, "Print"],
Cell[486703, 14299, 90, 1, 22, "Print"],
Cell[486796, 14302, 283, 7, 37, "Print"],
Cell[487082, 14311, 91, 1, 22, "Print"],
Cell[487176, 14314, 97, 2, 22, "Print"],
Cell[487276, 14318, 91, 1, 22, "Print"],
Cell[487370, 14321, 303, 7, 37, "Print"],
Cell[487676, 14330, 45, 1, 22, "Print"],
Cell[487724, 14333, 76, 1, 22, "Print"],
Cell[487803, 14336, 91, 1, 22, "Print"],
Cell[487897, 14339, 108, 2, 22, "Print"],
Cell[488008, 14343, 91, 1, 22, "Print"],
Cell[488102, 14346, 302, 7, 37, "Print"],
Cell[488407, 14355, 45, 1, 22, "Print"],
Cell[488455, 14358, 74, 1, 22, "Print"],
Cell[488532, 14361, 91, 1, 22, "Print"],
Cell[488626, 14364, 58, 1, 22, "Print"],
Cell[488687, 14367, 91, 1, 22, "Print"],
Cell[488781, 14370, 199, 4, 22, "Print"],
Cell[488983, 14376, 109, 2, 22, "Print"],
Cell[489095, 14380, 745, 17, 41, "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[489889, 14403, 131, 3, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[490045, 14410, 790, 16, 103, "Input"],
Cell[490838, 14428, 157, 3, 22, "Print"],
Cell[490998, 14433, 67, 1, 22, "Print"],
Cell[491068, 14436, 38, 1, 22, "Print"],
Cell[491109, 14439, 99, 2, 22, "Print"],
Cell[491211, 14443, 99, 2, 22, "Print"],
Cell[491313, 14447, 99, 2, 22, "Print"],
Cell[491415, 14451, 51, 1, 22, "Print"],
Cell[491469, 14454, 36, 1, 22, "Print"],
Cell[491508, 14457, 99, 2, 22, "Print"],
Cell[491610, 14461, 635, 14, 39, "Print"],
Cell[492248, 14477, 45, 1, 22, "Print"],
Cell[492296, 14480, 592, 14, 33, "Print"],
Cell[492891, 14496, 45, 1, 22, "Print"],
Cell[492939, 14499, 657, 15, 31, "Print"],
Cell[493599, 14516, 45, 1, 22, "Print"],
Cell[493647, 14519, 46, 1, 22, "Print"],
Cell[493696, 14522, 159, 3, 21, "Message"],
Cell[493858, 14527, 197, 5, 22, "Print"],
Cell[494058, 14534, 45, 1, 22, "Print"],
Cell[494106, 14537, 99, 2, 22, "Print"],
Cell[494208, 14541, 45, 1, 22, "Print"],
Cell[494256, 14544, 179, 3, 22, "Print"],
Cell[494438, 14549, 210, 4, 22, "Print"],
Cell[494651, 14555, 233, 5, 24, "Print"],
Cell[494887, 14562, 254, 5, 24, "Print"],
Cell[495144, 14569, 116, 2, 22, "Print"],
Cell[495263, 14573, 102, 2, 22, "Print"],
Cell[495368, 14577, 159, 3, 22, "Print"],
Cell[495530, 14582, 396, 10, 22, "Print"],
Cell[495929, 14594, 396, 10, 22, "Print"],
Cell[496328, 14606, 414, 10, 22, "Print"],
Cell[496745, 14618, 45, 1, 22, "Print"],
Cell[496793, 14621, 1753, 47, 53, "Print"],
Cell[498549, 14670, 46, 1, 22, "Print"],
Cell[498598, 14673, 728, 21, 37, "Print"],
Cell[499329, 14696, 254, 5, 24, "Print"],
Cell[499586, 14703, 181, 3, 24, "Print"],
Cell[499770, 14708, 264, 5, 22, "Print"],
Cell[500037, 14715, 297, 6, 22, "Print"],
Cell[500337, 14723, 102, 2, 22, "Print"],
Cell[500442, 14727, 159, 3, 22, "Print"],
Cell[500604, 14732, 396, 10, 22, "Print"],
Cell[501003, 14744, 396, 10, 22, "Print"],
Cell[501402, 14756, 414, 10, 22, "Print"],
Cell[501819, 14768, 45, 1, 22, "Print"],
Cell[501867, 14771, 1785, 47, 53, "Print"],
Cell[503655, 14820, 46, 1, 22, "Print"],
Cell[503704, 14823, 801, 21, 37, "Print"],
Cell[504508, 14846, 253, 5, 24, "Print"],
Cell[504764, 14853, 179, 3, 24, "Print"],
Cell[504946, 14858, 256, 4, 22, "Print"],
Cell[505205, 14864, 297, 6, 22, "Print"],
Cell[505505, 14872, 102, 2, 22, "Print"],
Cell[505610, 14876, 159, 3, 22, "Print"],
Cell[505772, 14881, 392, 10, 22, "Print"],
Cell[506167, 14893, 396, 10, 22, "Print"],
Cell[506566, 14905, 414, 10, 22, "Print"],
Cell[506983, 14917, 45, 1, 22, "Print"],
Cell[507031, 14920, 1784, 47, 53, "Print"],
Cell[508818, 14969, 46, 1, 22, "Print"],
Cell[508867, 14972, 797, 21, 37, "Print"],
Cell[509667, 14995, 254, 5, 24, "Print"],
Cell[509924, 15002, 181, 3, 24, "Print"],
Cell[510108, 15007, 257, 4, 22, "Print"],
Cell[510368, 15013, 297, 6, 22, "Print"],
Cell[510668, 15021, 102, 2, 22, "Print"],
Cell[510773, 15025, 159, 3, 22, "Print"],
Cell[510935, 15030, 394, 10, 22, "Print"],
Cell[511332, 15042, 392, 10, 22, "Print"],
Cell[511727, 15054, 414, 10, 22, "Print"],
Cell[512144, 15066, 45, 1, 22, "Print"],
Cell[512192, 15069, 1786, 47, 53, "Print"],
Cell[513981, 15118, 46, 1, 22, "Print"],
Cell[514030, 15121, 802, 21, 37, "Print"],
Cell[514835, 15144, 253, 5, 24, "Print"],
Cell[515091, 15151, 180, 3, 24, "Print"],
Cell[515274, 15156, 257, 4, 22, "Print"],
Cell[515534, 15162, 298, 6, 22, "Print"],
Cell[515835, 15170, 102, 2, 22, "Print"],
Cell[515940, 15174, 159, 3, 22, "Print"],
Cell[516102, 15179, 396, 10, 22, "Print"],
Cell[516501, 15191, 394, 10, 22, "Print"],
Cell[516898, 15203, 416, 10, 22, "Print"],
Cell[517317, 15215, 45, 1, 22, "Print"],
Cell[517365, 15218, 1785, 47, 53, "Print"],
Cell[519153, 15267, 46, 1, 22, "Print"],
Cell[519202, 15270, 801, 21, 37, "Print"],
Cell[520006, 15293, 254, 5, 24, "Print"],
Cell[520263, 15300, 181, 3, 24, "Print"],
Cell[520447, 15305, 257, 4, 22, "Print"],
Cell[520707, 15311, 299, 6, 22, "Print"],
Cell[521009, 15319, 102, 2, 22, "Print"],
Cell[521114, 15323, 159, 3, 22, "Print"],
Cell[521276, 15328, 394, 10, 22, "Print"],
Cell[521673, 15340, 396, 10, 22, "Print"],
Cell[522072, 15352, 418, 10, 22, "Print"],
Cell[522493, 15364, 45, 1, 22, "Print"],
Cell[522541, 15367, 1790, 47, 53, "Print"],
Cell[524334, 15416, 46, 1, 22, "Print"],
Cell[524383, 15419, 802, 21, 37, "Print"],
Cell[525188, 15442, 254, 5, 24, "Print"],
Cell[525445, 15449, 179, 3, 24, "Print"],
Cell[525627, 15454, 266, 5, 22, "Print"],
Cell[525896, 15461, 300, 6, 22, "Print"],
Cell[526199, 15469, 102, 2, 22, "Print"],
Cell[526304, 15473, 159, 3, 22, "Print"],
Cell[526466, 15478, 396, 10, 22, "Print"],
Cell[526865, 15490, 394, 10, 22, "Print"],
Cell[527262, 15502, 420, 10, 22, "Print"],
Cell[527685, 15514, 45, 1, 22, "Print"],
Cell[527733, 15517, 1793, 47, 53, "Print"],
Cell[529529, 15566, 46, 1, 22, "Print"],
Cell[529578, 15569, 801, 21, 37, "Print"],
Cell[530382, 15592, 254, 5, 24, "Print"],
Cell[530639, 15599, 181, 3, 24, "Print"],
Cell[530823, 15604, 266, 5, 22, "Print"],
Cell[531092, 15611, 302, 6, 22, "Print"],
Cell[531397, 15619, 102, 2, 22, "Print"],
Cell[531502, 15623, 159, 3, 22, "Print"],
Cell[531664, 15628, 396, 10, 22, "Print"],
Cell[532063, 15640, 396, 10, 22, "Print"],
Cell[532462, 15652, 434, 10, 24, "Print"],
Cell[532899, 15664, 45, 1, 22, "Print"],
Cell[532947, 15667, 1792, 47, 53, "Print"],
Cell[534742, 15716, 46, 1, 22, "Print"],
Cell[534791, 15719, 802, 21, 37, "Print"],
Cell[535596, 15742, 254, 5, 24, "Print"],
Cell[535853, 15749, 181, 3, 24, "Print"],
Cell[536037, 15754, 264, 5, 22, "Print"],
Cell[536304, 15761, 304, 6, 22, "Print"],
Cell[536611, 15769, 102, 2, 22, "Print"],
Cell[536716, 15773, 159, 3, 22, "Print"],
Cell[536878, 15778, 396, 10, 22, "Print"],
Cell[537277, 15790, 396, 10, 22, "Print"],
Cell[537676, 15802, 434, 10, 24, "Print"],
Cell[538113, 15814, 45, 1, 22, "Print"],
Cell[538161, 15817, 1798, 47, 53, "Print"],
Cell[539962, 15866, 46, 1, 22, "Print"],
Cell[540011, 15869, 798, 21, 37, "Print"],
Cell[540812, 15892, 254, 5, 24, "Print"],
Cell[541069, 15899, 181, 3, 24, "Print"],
Cell[541253, 15904, 270, 5, 24, "Print"],
Cell[541526, 15911, 303, 6, 24, "Print"],
Cell[541832, 15919, 49, 1, 22, "Print"],
Cell[541884, 15922, 49, 1, 22, "Print"],
Cell[541936, 15925, 49, 1, 22, "Print"],
Cell[541988, 15928, 229, 4, 22, "Print"],
Cell[542220, 15934, 312, 8, 37, "Print"],
Cell[542535, 15944, 46, 1, 22, "Print"],
Cell[542584, 15947, 801, 21, 37, "Print"],
Cell[543388, 15970, 1380, 29, 181, "Print"],
Cell[544771, 16001, 254, 5, 24, "Print"],
Cell[545028, 16008, 66, 1, 22, "Print"],
Cell[545097, 16011, 91, 1, 22, "Print"],
Cell[545191, 16014, 80, 1, 22, "Print"],
Cell[545274, 16017, 91, 1, 22, "Print"],
Cell[545368, 16020, 1111, 23, 41, "Print"],
Cell[546482, 16045, 89, 1, 22, "Print"],
Cell[546574, 16048, 45, 1, 22, "Print"],
Cell[546622, 16051, 89, 1, 22, "Print"],
Cell[546714, 16054, 562, 14, 31, "Print"],
Cell[547279, 16070, 67, 1, 22, "Print"],
Cell[547349, 16073, 89, 1, 22, "Print"],
Cell[547441, 16076, 66, 1, 22, "Print"],
Cell[547510, 16079, 89, 1, 22, "Print"],
Cell[547602, 16082, 89, 1, 22, "Print"],
Cell[547694, 16085, 208, 4, 22, "Print"],
Cell[547905, 16091, 655, 16, 41, "Print"],
Cell[548563, 16109, 90, 1, 22, "Print"],
Cell[548656, 16112, 74, 1, 22, "Print"],
Cell[548733, 16115, 90, 1, 22, "Print"],
Cell[548826, 16118, 282, 7, 37, "Print"],
Cell[549111, 16127, 91, 1, 22, "Print"],
Cell[549205, 16130, 97, 2, 22, "Print"],
Cell[549305, 16134, 91, 1, 22, "Print"],
Cell[549399, 16137, 300, 7, 37, "Print"],
Cell[549702, 16146, 45, 1, 22, "Print"],
Cell[549750, 16149, 75, 1, 22, "Print"],
Cell[549828, 16152, 91, 1, 22, "Print"],
Cell[549922, 16155, 108, 2, 22, "Print"],
Cell[550033, 16159, 91, 1, 22, "Print"],
Cell[550127, 16162, 300, 7, 37, "Print"],
Cell[550430, 16171, 45, 1, 22, "Print"],
Cell[550478, 16174, 75, 1, 22, "Print"],
Cell[550556, 16177, 91, 1, 22, "Print"],
Cell[550650, 16180, 58, 1, 22, "Print"],
Cell[550711, 16183, 91, 1, 22, "Print"],
Cell[550805, 16186, 199, 4, 22, "Print"],
Cell[551007, 16192, 109, 2, 22, "Print"],
Cell[551119, 16196, 745, 17, 41, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

