(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    616007,      19949]*)
(*NotebookOutlinePosition[    617059,      19982]*)
(*  CellTagsIndexPosition[    617015,      19978]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Growth Model with EKF", "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(\(@\)\(ARTICLE\)\) {Singer : 
          1998, \[IndentingNewLine]AUTHOR = {Singer, \(\(H\)\(.\)\)}, \
\[IndentingNewLine]TITLE = {{Continuous\ Panel\ Models\ with\ Time\ Dependent\
\ Parameters}}, \[IndentingNewLine]JOURNAL = {Journal\ of\ Mathematical\ \
Sociology}, \[IndentingNewLine]VOLUME = {23}, \[IndentingNewLine]PAGES = \
{\(77--\) 98}, \[IndentingNewLine]YEAR = {1998}}\ \), "\[IndentingNewLine]", 
    \(\(\(=\)\(\ \)\(growth . 
        pdf\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(@\)\(INCOLLECTION\)\) {Singer : 
          2006  b, \[IndentingNewLine]AUTHOR = {Singer, \(\(H\)\(.\)\)}, \
\[IndentingNewLine]TITLE = {{Stochastic\ Differential\ Equation\ Models\ with\
\ Sampled\ Data}}, 
        BOOKTITLE = {Longitudinal\ Models\ in\ the\ Behavioral\ and\ related\ \
Sciences}, 
        SERIES = {{The\ European\ Association\ of\ Methodology\ \((EAM)\)\ \
Methodology\ and\ Statistics\ series, vol . II}}, 
        PUBLISHER = {Erlbaum\ publishers}, \[IndentingNewLine]YEAR = {2006}, \
\[IndentingNewLine]EDITOR = {van\ Montfort, K . and\ Oud, 
            H . and\ Satorra, \(\(A\)\(.\)\)}, \[IndentingNewLine]NOTE = {}, \
\[IndentingNewLine]PAGES = {}}\), "\[IndentingNewLine]", 
    \(\(\(=\)\(SDGL . pdf\)\)\)}], "Input",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["load packages", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["<<Kuba.Impl.m", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["$Path", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({"Macintosh HD:Mathematica 4.2 Files:AddOns:JLink", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Kernel", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Autoload", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Applications", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Kernel", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Autoload", 
      "Macintosh HD:Systemordner:Preferences:Mathematica:Applications", ":", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:StandardPackages", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:StandardPackages:StartUp", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:Autoload", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:Applications", 
      "Macintosh HD:Mathematica 4.2 Files:AddOns:ExtraPackages", 
      "Macintosh HD:Mathematica 4.2 Files:SystemFiles:Graphics:Packages", 
      "Macintosh HD:Mathematica 4.2 Files:Configuration:Kernel", 
      "Macintosh HD:Mathematica 2.2.2:Hermann.Notebooks:SDE", 
      "Macintosh HD:Mathematica 2.2.2:Hermann.Notebooks:SDE:code", 
      "Macintosh HD:Mathematica \
2.2.2:Hermann.Notebooks:SDE:applications"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["system and Jacobi matrices", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Clear[A0,A1,A,t]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
A0 = {{lambda11,lambda12},
\t  {lambda21,lambda22}}/100    (*scaling*)\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(lambda21\)\" is similar \
to existing symbol \"\!\(lambda12\)\"."\)], "Message"],

Cell[BoxData[
    \({{lambda11\/100, lambda12\/100}, {lambda21\/100, 
        lambda22\/100}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "A1[t_] := {{alpha t,     0},\n\t\t   {0,      beta t}}/100; ",
  StyleBox["(*scaling*)",
    FontColor->RGBColor[1, 0, 0]]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(beta\)\" is similar to \
existing symbol \"\!\(Beta\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A[t_] = A0 + A1[t]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{lambda11\/100 + \(alpha\ t\)\/100, lambda12\/100}, {lambda21\/100, 
        lambda22\/100 + \(beta\ t\)\/100}}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Matrices do not commute !",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell["(A[t].A[s]-A[s].A[t]//Simplify)//MatrixForm", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0", \(-\(\(\((alpha - beta)\)\ lambda12\ \((s - 
                          t)\)\)\/10000\)\)},
            {\(\(\((alpha - beta)\)\ lambda21\ \((s - t)\)\)\/10000\), "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
drift//Clear
drift[{y1_,y2_},{t_},{lambda11_,lambda12_,
\t\t\t\t\t  lambda21_,lambda22_,
\t\t\t\t\t  alpha_,beta_}] = A[t].{y1,y2} \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({\((lambda11\/100 + \(alpha\ t\)\/100)\)\ y1 + \(lambda12\ y2\)\/100, \
\(lambda21\ y1\)\/100 + \((lambda22\/100 + \(beta\ t\)\/100)\)\ y2}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
drift[{Y1,Y2},{t},{lambda11,lambda12,lambda21,lambda22,
\t\t\t\t\talpha,beta}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({\((lambda11\/100 + \(alpha\ t\)\/100)\)\ Y1 + \(lambda12\ Y2\)\/100, \
\(lambda21\ Y1\)\/100 + \((lambda22\/100 + \(beta\ t\)\/100)\)\ Y2}\)], \
"Output"]
}, Open  ]],

Cell[TextData[StyleBox["time dependent diffusion ",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell["\<\
diffusion//Clear
diffusion[{y1_,y2_},{t_},
\t{lambda11_,lambda12_,
     lambda21_,lambda22_,
\t\t\talpha_,beta_}] := t{{.01,0},{0,.02}}\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
diffusion[{Y1,Y2},{t},{lambda11,lambda12,lambda21,lambda22,alpha,\
beta}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.01`\ t, 0}, {0, 0.02`\ t}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clear[Jacobif];
Jacobif[{y1_,y2_},{t_},{lambda11_,lambda12_,lambda21_,lambda22_,
\talpha_,beta_}] = 
\t\tOuter[D,drift[{y1,y2},{t},{lambda11,lambda12,
\t \t\tlambda21,lambda22,alpha,beta}],{y1,y2}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{lambda11\/100 + \(alpha\ t\)\/100, lambda12\/100}, {lambda21\/100, 
        lambda22\/100 + \(beta\ t\)\/100}}\)], "Output"]
}, Open  ]],

Cell["\<\
mue[{t_},theta_] := {0,0}//N;

sigma[{t_},theta_] := {{10^16,0},{0,10^16}}//N;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["sigma[{_},_]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1.`*^16, 0.`}, {0.`, 1.`*^16}}\)], "Output"]
}, Open  ]],

Cell["\<\
h//Clear
h[{y1_,y2_},{t_},theta_] := {y1,y2};\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Jacobih//Clear
Jacobih[{y1_,y2_},{t_},theta_] = IdentityMatrix[2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1, 0}, {0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
R//Clear
R[{y1_,y2_},{t_},theta_] = .001 IdentityMatrix[2]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.001`, 0}, {0, 0.001`}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["simulation", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
SeedRandom[9999];
Y0 = {1,2};
n = 10;
Y0 = Shape[1,{n}]/. (1->Y0)
T = 100;
dt = 10.^-1;
Theta = {.1,-.01,.02,.3,.01,-.02}*100;
\t\t(*{lambda11_,lambda12_,lambda21_,lambda22_,alpha_,beta_}*)
k = 2;
p = 2;
q = 1;
X = Shape[1,{n}]/. 1->Shape[dt Range[0,T],{T+1,q}];
Nonlin = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 
        2}, {1, 2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["X//Dimensions", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 101, 1}\)], "Output"]
}, Open  ]],

Cell["Panel data", "Text"],

Cell[CellGroupData[{

Cell["\<\
{Z,Y} = 

MapThread[
     NonLinStateSpace[h,{R,const},drift,diffusion,#1,#2,T,dt,Theta,Gauss,\
EulerStep]&,
\t      {Y0,X}]//Transpose;//Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({1.0333333333333314`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
plot1[Z//flatten[#,{1,3}]&//Transpose//AddTimeAxis,
\t\tdicke->0.002,farbmodell->Hue]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 21}\),
      SequenceForm[ "Dimension der Daten  ", {101, 21}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.0212878 0.0379809 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07366 -18 -4.5 ]
[-0.0125 .07366 0 4.5 ]
[-0.0125 .16862 -6 -4.5 ]
[-0.0125 .16862 0 4.5 ]
[-0.0125 .26357 -18 -4.5 ]
[-0.0125 .26357 0 4.5 ]
[-0.0125 .35852 -12 -4.5 ]
[-0.0125 .35852 0 4.5 ]
[-0.0125 .45347 -24 -4.5 ]
[-0.0125 .45347 0 4.5 ]
[-0.0125 .54842 -12 -4.5 ]
[-0.0125 .54842 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.97619 .10412 -5 -6 ]
[.97619 .10412 5 6 ]
[.97619 .59268 -5 -6 ]
[.97619 .59268 5 6 ]
[.97619 .08556 -5 -6 ]
[.97619 .08556 5 6 ]
[.97619 .53057 -5 -6 ]
[.97619 .53057 5 6 ]
[.97619 .10907 -5 -6 ]
[.97619 .10907 5 6 ]
[.97619 .59327 -5 -6 ]
[.97619 .59327 5 6 ]
[.97619 .10674 -5 -6 ]
[.97619 .10674 5 6 ]
[.97619 .58131 -5 -6 ]
[.97619 .58131 5 6 ]
[.97619 .09345 -5 -6 ]
[.97619 .09345 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .09592 -5 -6 ]
[.97619 .09592 5 6 ]
[.97619 .54961 -5 -6 ]
[.97619 .54961 5 6 ]
[.97619 .10354 -5 -6 ]
[.97619 .10354 5 6 ]
[.97619 .54937 -5 -6 ]
[.97619 .54937 5 6 ]
[.97619 .09403 -5 -6 ]
[.97619 .09403 5 6 ]
[.97619 .57498 -5 -6 ]
[.97619 .57498 5 6 ]
[.97619 .09156 -5 -6 ]
[.97619 .09156 5 6 ]
[.97619 .58622 -5 -6 ]
[.97619 .58622 5 6 ]
[.97619 .09089 -5 -6 ]
[.97619 .09089 5 6 ]
[.97619 .55089 -5 -6 ]
[.97619 .55089 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07366 m
.00625 .07366 L
s
[(2.5)] -0.0125 .07366 1 0 Mshowa
0 .16862 m
.00625 .16862 L
s
[(5)] -0.0125 .16862 1 0 Mshowa
0 .26357 m
.00625 .26357 L
s
[(7.5)] -0.0125 .26357 1 0 Mshowa
0 .35852 m
.00625 .35852 L
s
[(10)] -0.0125 .35852 1 0 Mshowa
0 .45347 m
.00625 .45347 L
s
[(12.5)] -0.0125 .45347 1 0 Mshowa
0 .54842 m
.00625 .54842 L
s
[(15)] -0.0125 .54842 1 0 Mshowa
.125 Mabswid
0 .09265 m
.00375 .09265 L
s
0 .11165 m
.00375 .11165 L
s
0 .13064 m
.00375 .13064 L
s
0 .14963 m
.00375 .14963 L
s
0 .18761 m
.00375 .18761 L
s
0 .2066 m
.00375 .2066 L
s
0 .22559 m
.00375 .22559 L
s
0 .24458 m
.00375 .24458 L
s
0 .28256 m
.00375 .28256 L
s
0 .30155 m
.00375 .30155 L
s
0 .32054 m
.00375 .32054 L
s
0 .33953 m
.00375 .33953 L
s
0 .37751 m
.00375 .37751 L
s
0 .3965 m
.00375 .3965 L
s
0 .41549 m
.00375 .41549 L
s
0 .43448 m
.00375 .43448 L
s
0 .47246 m
.00375 .47246 L
s
0 .49145 m
.00375 .49145 L
s
0 .51044 m
.00375 .51044 L
s
0 .52943 m
.00375 .52943 L
s
0 .05467 m
.00375 .05467 L
s
0 .03568 m
.00375 .03568 L
s
0 .01669 m
.00375 .01669 L
s
0 .56742 m
.00375 .56742 L
s
0 .58641 m
.00375 .58641 L
s
0 .6054 m
.00375 .6054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07366 m
1 .07366 L
s
.99375 .16862 m
1 .16862 L
s
.99375 .26357 m
1 .26357 L
s
.99375 .35852 m
1 .35852 L
s
.99375 .45347 m
1 .45347 L
s
.99375 .54842 m
1 .54842 L
s
.125 Mabswid
.99625 .09265 m
1 .09265 L
s
.99625 .11165 m
1 .11165 L
s
.99625 .13064 m
1 .13064 L
s
.99625 .14963 m
1 .14963 L
s
.99625 .18761 m
1 .18761 L
s
.99625 .2066 m
1 .2066 L
s
.99625 .22559 m
1 .22559 L
s
.99625 .24458 m
1 .24458 L
s
.99625 .28256 m
1 .28256 L
s
.99625 .30155 m
1 .30155 L
s
.99625 .32054 m
1 .32054 L
s
.99625 .33953 m
1 .33953 L
s
.99625 .37751 m
1 .37751 L
s
.99625 .3965 m
1 .3965 L
s
.99625 .41549 m
1 .41549 L
s
.99625 .43448 m
1 .43448 L
s
.99625 .47246 m
1 .47246 L
s
.99625 .49145 m
1 .49145 L
s
.99625 .51044 m
1 .51044 L
s
.99625 .52943 m
1 .52943 L
s
.99625 .05467 m
1 .05467 L
s
.99625 .03568 m
1 .03568 L
s
.99625 .01669 m
1 .01669 L
s
.99625 .56742 m
1 .56742 L
s
.99625 .58641 m
1 .58641 L
s
.99625 .6054 m
1 .6054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
gsave
.97619 .10412 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.002 w
.02381 .01614 m
.03333 .0204 L
.04286 .01773 L
.05238 .01774 L
.0619 .01751 L
.07143 .01811 L
.08095 .01932 L
.09048 .018 L
.1 .01982 L
.10952 .02109 L
.11905 .01965 L
.12857 .02005 L
.1381 .02163 L
.14762 .02043 L
.15714 .02002 L
.16667 .02359 L
.17619 .02131 L
.18571 .0232 L
.19524 .02476 L
.20476 .02291 L
.21429 .02257 L
.22381 .02357 L
.23333 .02231 L
.24286 .02532 L
.25238 .02579 L
.2619 .02439 L
.27143 .0269 L
.28095 .02575 L
.29048 .03143 L
.3 .02822 L
.30952 .0287 L
.31905 .02906 L
.32857 .02965 L
.3381 .03121 L
.34762 .03147 L
.35714 .03121 L
.36667 .03119 L
.37619 .0332 L
.38571 .03373 L
.39524 .03428 L
.40476 .03369 L
.41429 .03617 L
.42381 .03613 L
.43333 .0365 L
.44286 .037 L
.45238 .03565 L
.4619 .03751 L
.47143 .04156 L
.48095 .03863 L
.49048 .03967 L
Mistroke
.5 .04328 L
.50952 .04263 L
.51905 .03992 L
.52857 .04351 L
.5381 .04578 L
.54762 .04699 L
.55714 .04643 L
.56667 .04874 L
.57619 .04732 L
.58571 .04815 L
.59524 .05157 L
.60476 .05033 L
.61429 .05093 L
.62381 .05227 L
.63333 .05521 L
.64286 .0557 L
.65238 .05709 L
.6619 .05675 L
.67143 .06004 L
.68095 .06078 L
.69048 .06285 L
.7 .06486 L
.70952 .06816 L
.71905 .06528 L
.72857 .06768 L
.7381 .06971 L
.74762 .07008 L
.75714 .0715 L
.76667 .0742 L
.77619 .07141 L
.78571 .07402 L
.79524 .0744 L
.80476 .07321 L
.81429 .07429 L
.82381 .07805 L
.83333 .07512 L
.84286 .07969 L
.85238 .0806 L
.8619 .08297 L
.87143 .08579 L
.88095 .08725 L
.89048 .09146 L
.9 .09345 L
.90952 .09406 L
.91905 .09683 L
.92857 .09791 L
.9381 .09924 L
.94762 .09873 L
.95714 .10221 L
.96667 .10544 L
Mistroke
.97619 .10412 L
Mfstroke
1 0 .6 r
gsave
.97619 .59268 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05749 m
.03333 .05678 L
.04286 .05846 L
.05238 .06281 L
.0619 .06444 L
.07143 .0687 L
.08095 .07007 L
.09048 .07012 L
.1 .076 L
.10952 .0766 L
.11905 .08022 L
.12857 .08059 L
.1381 .08482 L
.14762 .0878 L
.15714 .09203 L
.16667 .09704 L
.17619 .09912 L
.18571 .10042 L
.19524 .1041 L
.20476 .10709 L
.21429 .11077 L
.22381 .1167 L
.23333 .12069 L
.24286 .12449 L
.25238 .1283 L
.2619 .13089 L
.27143 .13167 L
.28095 .139 L
.29048 .14477 L
.3 .14559 L
.30952 .14916 L
.31905 .15297 L
.32857 .15614 L
.3381 .16042 L
.34762 .16533 L
.35714 .17137 L
.36667 .17379 L
.37619 .17833 L
.38571 .18248 L
.39524 .18775 L
.40476 .19276 L
.41429 .19668 L
.42381 .20452 L
.43333 .20863 L
.44286 .21564 L
.45238 .2224 L
.4619 .22719 L
.47143 .23343 L
.48095 .24104 L
.49048 .24636 L
Mistroke
.5 .24921 L
.50952 .25514 L
.51905 .26156 L
.52857 .26934 L
.5381 .27708 L
.54762 .28317 L
.55714 .28901 L
.56667 .29687 L
.57619 .30271 L
.58571 .30966 L
.59524 .31336 L
.60476 .32197 L
.61429 .3281 L
.62381 .3324 L
.63333 .33743 L
.64286 .34612 L
.65238 .34984 L
.6619 .35778 L
.67143 .36782 L
.68095 .37204 L
.69048 .37663 L
.7 .38416 L
.70952 .39095 L
.71905 .39683 L
.72857 .40483 L
.7381 .41008 L
.74762 .41835 L
.75714 .4253 L
.76667 .42918 L
.77619 .43433 L
.78571 .44466 L
.79524 .45275 L
.80476 .45963 L
.81429 .47083 L
.82381 .47812 L
.83333 .48443 L
.84286 .48745 L
.85238 .49321 L
.8619 .51021 L
.87143 .51188 L
.88095 .51634 L
.89048 .52382 L
.9 .52963 L
.90952 .53826 L
.91905 .54417 L
.92857 .55164 L
.9381 .56476 L
.94762 .57299 L
.95714 .57811 L
.96667 .58425 L
Mistroke
.97619 .59268 L
Mfstroke
.8 0 1 r
gsave
.97619 .08556 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01674 m
.03333 .01684 L
.04286 .01748 L
.05238 .01792 L
.0619 .01765 L
.07143 .02027 L
.08095 .02013 L
.09048 .01875 L
.1 .0185 L
.10952 .02101 L
.11905 .01916 L
.12857 .0213 L
.1381 .02257 L
.14762 .02071 L
.15714 .02114 L
.16667 .02451 L
.17619 .02393 L
.18571 .02064 L
.19524 .02319 L
.20476 .02328 L
.21429 .02381 L
.22381 .02383 L
.23333 .025 L
.24286 .02652 L
.25238 .02531 L
.2619 .0266 L
.27143 .0271 L
.28095 .02786 L
.29048 .03102 L
.3 .02865 L
.30952 .02818 L
.31905 .03132 L
.32857 .02958 L
.3381 .02905 L
.34762 .03007 L
.35714 .0298 L
.36667 .03158 L
.37619 .03036 L
.38571 .03046 L
.39524 .03265 L
.40476 .03219 L
.41429 .03182 L
.42381 .03359 L
.43333 .0349 L
.44286 .03329 L
.45238 .03575 L
.4619 .03675 L
.47143 .03358 L
.48095 .0341 L
.49048 .03527 L
Mistroke
.5 .03602 L
.50952 .0348 L
.51905 .03665 L
.52857 .0367 L
.5381 .03928 L
.54762 .04248 L
.55714 .03988 L
.56667 .0432 L
.57619 .04641 L
.58571 .04865 L
.59524 .04636 L
.60476 .04726 L
.61429 .04812 L
.62381 .04815 L
.63333 .05095 L
.64286 .05086 L
.65238 .04975 L
.6619 .05251 L
.67143 .05233 L
.68095 .05319 L
.69048 .055 L
.7 .05507 L
.70952 .05411 L
.71905 .05578 L
.72857 .05825 L
.7381 .05985 L
.74762 .05902 L
.75714 .0598 L
.76667 .06084 L
.77619 .06118 L
.78571 .06463 L
.79524 .066 L
.80476 .06798 L
.81429 .07054 L
.82381 .07004 L
.83333 .07046 L
.84286 .07214 L
.85238 .07497 L
.8619 .07536 L
.87143 .07497 L
.88095 .07522 L
.89048 .07481 L
.9 .07793 L
.90952 .07719 L
.91905 .08115 L
.92857 .08141 L
.9381 .08523 L
.94762 .08542 L
.95714 .08637 L
.96667 .08653 L
Mistroke
.97619 .08556 L
Mfstroke
.2 0 1 r
gsave
.97619 .53057 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05434 m
.03333 .05728 L
.04286 .05986 L
.05238 .06169 L
.0619 .06308 L
.07143 .06697 L
.08095 .0717 L
.09048 .07233 L
.1 .0774 L
.10952 .07897 L
.11905 .0811 L
.12857 .08335 L
.1381 .08697 L
.14762 .08982 L
.15714 .09229 L
.16667 .09414 L
.17619 .09652 L
.18571 .10108 L
.19524 .10438 L
.20476 .10992 L
.21429 .11471 L
.22381 .11645 L
.23333 .12017 L
.24286 .12493 L
.25238 .12824 L
.2619 .13027 L
.27143 .13593 L
.28095 .14229 L
.29048 .14447 L
.3 .14544 L
.30952 .15194 L
.31905 .15698 L
.32857 .16152 L
.3381 .16437 L
.34762 .16917 L
.35714 .17654 L
.36667 .17649 L
.37619 .18132 L
.38571 .18882 L
.39524 .19494 L
.40476 .20102 L
.41429 .20404 L
.42381 .20707 L
.43333 .21358 L
.44286 .22199 L
.45238 .22619 L
.4619 .2295 L
.47143 .23483 L
.48095 .23982 L
.49048 .24498 L
Mistroke
.5 .24837 L
.50952 .25379 L
.51905 .26184 L
.52857 .27014 L
.5381 .27426 L
.54762 .27607 L
.55714 .2845 L
.56667 .2902 L
.57619 .29685 L
.58571 .30524 L
.59524 .30598 L
.60476 .31222 L
.61429 .32064 L
.62381 .32403 L
.63333 .32716 L
.64286 .32886 L
.65238 .33369 L
.6619 .34322 L
.67143 .34912 L
.68095 .35309 L
.69048 .35797 L
.7 .36331 L
.70952 .37185 L
.71905 .37697 L
.72857 .38764 L
.7381 .39545 L
.74762 .4007 L
.75714 .40842 L
.76667 .41179 L
.77619 .41536 L
.78571 .42128 L
.79524 .42642 L
.80476 .43642 L
.81429 .4371 L
.82381 .44433 L
.83333 .44726 L
.84286 .45666 L
.85238 .45851 L
.8619 .4666 L
.87143 .47392 L
.88095 .47973 L
.89048 .48585 L
.9 .49085 L
.90952 .49625 L
.91905 .49782 L
.92857 .50502 L
.9381 .50827 L
.94762 .51339 L
.95714 .51747 L
.96667 .52529 L
Mistroke
.97619 .53057 L
Mfstroke
0 .4 1 r
gsave
.97619 .10907 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01499 L
.04286 .01489 L
.05238 .01597 L
.0619 .01843 L
.07143 .01847 L
.08095 .01892 L
.09048 .02062 L
.1 .01993 L
.10952 .01917 L
.11905 .01996 L
.12857 .02188 L
.1381 .02212 L
.14762 .018 L
.15714 .02189 L
.16667 .02246 L
.17619 .01994 L
.18571 .02219 L
.19524 .02287 L
.20476 .02374 L
.21429 .02321 L
.22381 .0263 L
.23333 .02354 L
.24286 .02626 L
.25238 .02558 L
.2619 .02666 L
.27143 .02701 L
.28095 .02438 L
.29048 .02582 L
.3 .02592 L
.30952 .02678 L
.31905 .02662 L
.32857 .02756 L
.3381 .0293 L
.34762 .02809 L
.35714 .02989 L
.36667 .0309 L
.37619 .03035 L
.38571 .02982 L
.39524 .03024 L
.40476 .03408 L
.41429 .03567 L
.42381 .03215 L
.43333 .03546 L
.44286 .03561 L
.45238 .03628 L
.4619 .03882 L
.47143 .0378 L
.48095 .03523 L
.49048 .03903 L
Mistroke
.5 .03848 L
.50952 .04034 L
.51905 .04045 L
.52857 .04053 L
.5381 .04325 L
.54762 .04318 L
.55714 .04519 L
.56667 .04422 L
.57619 .04654 L
.58571 .04445 L
.59524 .04638 L
.60476 .04663 L
.61429 .04654 L
.62381 .04802 L
.63333 .0511 L
.64286 .05321 L
.65238 .05431 L
.6619 .0551 L
.67143 .05794 L
.68095 .06043 L
.69048 .0621 L
.7 .0618 L
.70952 .06161 L
.71905 .06576 L
.72857 .06644 L
.7381 .06619 L
.74762 .07119 L
.75714 .06986 L
.76667 .07029 L
.77619 .0731 L
.78571 .07285 L
.79524 .0782 L
.80476 .07684 L
.81429 .08072 L
.82381 .07897 L
.83333 .07768 L
.84286 .08176 L
.85238 .08161 L
.8619 .08673 L
.87143 .08549 L
.88095 .08654 L
.89048 .0897 L
.9 .09011 L
.90952 .09177 L
.91905 .09604 L
.92857 .09422 L
.9381 .09923 L
.94762 .10196 L
.95714 .10429 L
.96667 .1063 L
Mistroke
.97619 .10907 L
Mfstroke
0 1 1 r
gsave
.97619 .59327 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05569 m
.03333 .05473 L
.04286 .05936 L
.05238 .06282 L
.0619 .06513 L
.07143 .06827 L
.08095 .06945 L
.09048 .0744 L
.1 .07433 L
.10952 .08047 L
.11905 .08156 L
.12857 .08503 L
.1381 .08656 L
.14762 .08885 L
.15714 .09294 L
.16667 .09649 L
.17619 .09759 L
.18571 .10298 L
.19524 .10568 L
.20476 .11066 L
.21429 .11311 L
.22381 .11651 L
.23333 .12274 L
.24286 .12716 L
.25238 .13054 L
.2619 .13299 L
.27143 .13715 L
.28095 .14046 L
.29048 .14609 L
.3 .14909 L
.30952 .15509 L
.31905 .15819 L
.32857 .16421 L
.3381 .16949 L
.34762 .17338 L
.35714 .17646 L
.36667 .18349 L
.37619 .18584 L
.38571 .19314 L
.39524 .19712 L
.40476 .20323 L
.41429 .21066 L
.42381 .21367 L
.43333 .22048 L
.44286 .22364 L
.45238 .23449 L
.4619 .23643 L
.47143 .23886 L
.48095 .24417 L
.49048 .2528 L
Mistroke
.5 .25907 L
.50952 .26316 L
.51905 .26967 L
.52857 .27674 L
.5381 .28268 L
.54762 .28987 L
.55714 .29379 L
.56667 .30125 L
.57619 .30809 L
.58571 .31511 L
.59524 .31987 L
.60476 .33206 L
.61429 .33732 L
.62381 .3397 L
.63333 .34427 L
.64286 .35519 L
.65238 .35774 L
.6619 .36819 L
.67143 .37874 L
.68095 .38161 L
.69048 .39313 L
.7 .4011 L
.70952 .41179 L
.71905 .41508 L
.72857 .41831 L
.7381 .42887 L
.74762 .43921 L
.75714 .45029 L
.76667 .45693 L
.77619 .46578 L
.78571 .4664 L
.79524 .47311 L
.80476 .47997 L
.81429 .48722 L
.82381 .49565 L
.83333 .50045 L
.84286 .50566 L
.85238 .51227 L
.8619 .52 L
.87143 .52634 L
.88095 .53483 L
.89048 .54107 L
.9 .54812 L
.90952 .55285 L
.91905 .56025 L
.92857 .56396 L
.9381 .56818 L
.94762 .57342 L
.95714 .58074 L
.96667 .58755 L
Mistroke
.97619 .59327 L
Mfstroke
0 1 .4 r
gsave
.97619 .10674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01721 m
.03333 .01757 L
.04286 .01827 L
.05238 .01756 L
.0619 .01939 L
.07143 .01873 L
.08095 .0183 L
.09048 .0202 L
.1 .01846 L
.10952 .02114 L
.11905 .01753 L
.12857 .01928 L
.1381 .02247 L
.14762 .0221 L
.15714 .02197 L
.16667 .02299 L
.17619 .02272 L
.18571 .02262 L
.19524 .02395 L
.20476 .02262 L
.21429 .02285 L
.22381 .02337 L
.23333 .02416 L
.24286 .02163 L
.25238 .02336 L
.2619 .02517 L
.27143 .02765 L
.28095 .02739 L
.29048 .02746 L
.3 .03024 L
.30952 .02785 L
.31905 .02728 L
.32857 .02879 L
.3381 .0277 L
.34762 .03223 L
.35714 .02955 L
.36667 .03055 L
.37619 .02973 L
.38571 .03246 L
.39524 .02923 L
.40476 .03121 L
.41429 .03256 L
.42381 .03402 L
.43333 .03343 L
.44286 .03236 L
.45238 .03537 L
.4619 .03601 L
.47143 .03812 L
.48095 .03603 L
.49048 .03906 L
Mistroke
.5 .04053 L
.50952 .03725 L
.51905 .04128 L
.52857 .04198 L
.5381 .04487 L
.54762 .04407 L
.55714 .04654 L
.56667 .04699 L
.57619 .04544 L
.58571 .048 L
.59524 .04768 L
.60476 .04708 L
.61429 .0498 L
.62381 .05091 L
.63333 .0535 L
.64286 .05237 L
.65238 .05342 L
.6619 .05542 L
.67143 .05674 L
.68095 .05733 L
.69048 .06059 L
.7 .06077 L
.70952 .06108 L
.71905 .06363 L
.72857 .06437 L
.7381 .06408 L
.74762 .06357 L
.75714 .06882 L
.76667 .07117 L
.77619 .06905 L
.78571 .06754 L
.79524 .06997 L
.80476 .07131 L
.81429 .07059 L
.82381 .07287 L
.83333 .0769 L
.84286 .07486 L
.85238 .07824 L
.8619 .07921 L
.87143 .08034 L
.88095 .08282 L
.89048 .08651 L
.9 .08358 L
.90952 .08644 L
.91905 .08567 L
.92857 .09184 L
.9381 .0943 L
.94762 .09655 L
.95714 .10061 L
.96667 .10401 L
Mistroke
.97619 .10674 L
Mfstroke
.2 1 0 r
gsave
.97619 .58131 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05596 m
.03333 .05551 L
.04286 .05973 L
.05238 .06429 L
.0619 .06552 L
.07143 .06581 L
.08095 .06887 L
.09048 .07212 L
.1 .07845 L
.10952 .07923 L
.11905 .08014 L
.12857 .08522 L
.1381 .08529 L
.14762 .08884 L
.15714 .0924 L
.16667 .09574 L
.17619 .09958 L
.18571 .10205 L
.19524 .1103 L
.20476 .11143 L
.21429 .1124 L
.22381 .11633 L
.23333 .12209 L
.24286 .1269 L
.25238 .13022 L
.2619 .13471 L
.27143 .1376 L
.28095 .14274 L
.29048 .14515 L
.3 .14977 L
.30952 .15226 L
.31905 .15749 L
.32857 .1627 L
.3381 .16491 L
.34762 .17178 L
.35714 .17463 L
.36667 .17886 L
.37619 .1828 L
.38571 .18729 L
.39524 .19153 L
.40476 .19772 L
.41429 .20557 L
.42381 .20819 L
.43333 .21677 L
.44286 .22087 L
.45238 .22667 L
.4619 .2312 L
.47143 .23616 L
.48095 .24311 L
.49048 .24607 L
Mistroke
.5 .25411 L
.50952 .2587 L
.51905 .26306 L
.52857 .27461 L
.5381 .27837 L
.54762 .28737 L
.55714 .2911 L
.56667 .2964 L
.57619 .29881 L
.58571 .30976 L
.59524 .31368 L
.60476 .31983 L
.61429 .32402 L
.62381 .32848 L
.63333 .33183 L
.64286 .33977 L
.65238 .34478 L
.6619 .35245 L
.67143 .36014 L
.68095 .36569 L
.69048 .37576 L
.7 .37815 L
.70952 .38528 L
.71905 .39248 L
.72857 .40339 L
.7381 .40685 L
.74762 .41358 L
.75714 .42183 L
.76667 .4283 L
.77619 .43904 L
.78571 .44142 L
.79524 .44714 L
.80476 .45195 L
.81429 .46176 L
.82381 .46921 L
.83333 .48351 L
.84286 .49119 L
.85238 .49947 L
.8619 .50577 L
.87143 .50798 L
.88095 .51348 L
.89048 .51753 L
.9 .53225 L
.90952 .53622 L
.91905 .54286 L
.92857 .55563 L
.9381 .56304 L
.94762 .56672 L
.95714 .57369 L
.96667 .57937 L
Mistroke
.97619 .58131 L
Mfstroke
.8 1 0 r
gsave
.97619 .09345 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01699 m
.03333 .01813 L
.04286 .01625 L
.05238 .01831 L
.0619 .01903 L
.07143 .01775 L
.08095 .02 L
.09048 .01937 L
.1 .01856 L
.10952 .01871 L
.11905 .02177 L
.12857 .02324 L
.1381 .02032 L
.14762 .02284 L
.15714 .02079 L
.16667 .02276 L
.17619 .0211 L
.18571 .02237 L
.19524 .02481 L
.20476 .02453 L
.21429 .02254 L
.22381 .02494 L
.23333 .02651 L
.24286 .02505 L
.25238 .02576 L
.2619 .02555 L
.27143 .02697 L
.28095 .02934 L
.29048 .03102 L
.3 .03173 L
.30952 .02927 L
.31905 .03038 L
.32857 .0282 L
.3381 .03041 L
.34762 .0306 L
.35714 .03107 L
.36667 .03126 L
.37619 .03409 L
.38571 .03085 L
.39524 .03197 L
.40476 .03473 L
.41429 .03235 L
.42381 .03355 L
.43333 .03575 L
.44286 .032 L
.45238 .03731 L
.4619 .03795 L
.47143 .03726 L
.48095 .03599 L
.49048 .03962 L
Mistroke
.5 .04211 L
.50952 .03952 L
.51905 .03942 L
.52857 .03899 L
.5381 .03991 L
.54762 .03922 L
.55714 .04317 L
.56667 .04341 L
.57619 .04321 L
.58571 .048 L
.59524 .04437 L
.60476 .04551 L
.61429 .04481 L
.62381 .0442 L
.63333 .04463 L
.64286 .04635 L
.65238 .04902 L
.6619 .05063 L
.67143 .04959 L
.68095 .05297 L
.69048 .05145 L
.7 .05068 L
.70952 .0536 L
.71905 .05707 L
.72857 .05671 L
.7381 .05672 L
.74762 .05953 L
.75714 .06227 L
.76667 .06338 L
.77619 .06495 L
.78571 .06813 L
.79524 .06882 L
.80476 .06872 L
.81429 .07078 L
.82381 .07234 L
.83333 .07178 L
.84286 .07015 L
.85238 .07435 L
.8619 .07494 L
.87143 .07632 L
.88095 .08044 L
.89048 .08056 L
.9 .08286 L
.90952 .08438 L
.91905 .08676 L
.92857 .08733 L
.9381 .08909 L
.94762 .0878 L
.95714 .0875 L
.96667 .09286 L
Mistroke
.97619 .09345 L
Mfstroke
1 .6 0 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0527 m
.03333 .05829 L
.04286 .05832 L
.05238 .06426 L
.0619 .0633 L
.07143 .06724 L
.08095 .06953 L
.09048 .07268 L
.1 .0765 L
.10952 .07769 L
.11905 .07909 L
.12857 .08373 L
.1381 .08524 L
.14762 .08891 L
.15714 .09416 L
.16667 .09218 L
.17619 .0971 L
.18571 .10301 L
.19524 .10575 L
.20476 .11096 L
.21429 .11334 L
.22381 .1181 L
.23333 .12001 L
.24286 .12585 L
.25238 .13047 L
.2619 .13061 L
.27143 .13825 L
.28095 .14088 L
.29048 .14408 L
.3 .15198 L
.30952 .15548 L
.31905 .16189 L
.32857 .16779 L
.3381 .17248 L
.34762 .17576 L
.35714 .18141 L
.36667 .18671 L
.37619 .19013 L
.38571 .19616 L
.39524 .20093 L
.40476 .20579 L
.41429 .21146 L
.42381 .21865 L
.43333 .22343 L
.44286 .22654 L
.45238 .23404 L
.4619 .24168 L
.47143 .24515 L
.48095 .25222 L
.49048 .25841 L
Mistroke
.5 .26362 L
.50952 .2696 L
.51905 .27456 L
.52857 .28334 L
.5381 .28712 L
.54762 .2889 L
.55714 .29609 L
.56667 .30473 L
.57619 .30947 L
.58571 .31573 L
.59524 .32121 L
.60476 .32737 L
.61429 .33475 L
.62381 .34073 L
.63333 .34993 L
.64286 .35628 L
.65238 .36252 L
.6619 .36694 L
.67143 .3782 L
.68095 .38122 L
.69048 .3833 L
.7 .39117 L
.70952 .39535 L
.71905 .40285 L
.72857 .41319 L
.7381 .41885 L
.74762 .42575 L
.75714 .43073 L
.76667 .43763 L
.77619 .44658 L
.78571 .45205 L
.79524 .46036 L
.80476 .46784 L
.81429 .47578 L
.82381 .48325 L
.83333 .489 L
.84286 .49627 L
.85238 .5034 L
.8619 .51304 L
.87143 .52013 L
.88095 .52815 L
.89048 .53614 L
.9 .54775 L
.90952 .5551 L
.91905 .56419 L
.92857 .57004 L
.9381 .57427 L
.94762 .58277 L
.95714 .58923 L
.96667 .59662 L
Mistroke
.97619 .60332 L
Mfstroke
1 0 0 r
gsave
.97619 .09592 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01946 m
.03333 .01628 L
.04286 .01601 L
.05238 .0186 L
.0619 .01769 L
.07143 .01881 L
.08095 .01923 L
.09048 .02094 L
.1 .01911 L
.10952 .01865 L
.11905 .02141 L
.12857 .02076 L
.1381 .01832 L
.14762 .02248 L
.15714 .02127 L
.16667 .02113 L
.17619 .02098 L
.18571 .02076 L
.19524 .02284 L
.20476 .02509 L
.21429 .0234 L
.22381 .02415 L
.23333 .02261 L
.24286 .0254 L
.25238 .02497 L
.2619 .02579 L
.27143 .02548 L
.28095 .02691 L
.29048 .02581 L
.3 .02727 L
.30952 .02828 L
.31905 .02786 L
.32857 .02768 L
.3381 .02805 L
.34762 .03048 L
.35714 .03147 L
.36667 .03271 L
.37619 .03216 L
.38571 .03242 L
.39524 .03291 L
.40476 .03388 L
.41429 .03093 L
.42381 .03337 L
.43333 .03588 L
.44286 .03557 L
.45238 .0346 L
.4619 .03785 L
.47143 .03899 L
.48095 .03877 L
.49048 .03755 L
Mistroke
.5 .03784 L
.50952 .041 L
.51905 .04122 L
.52857 .03904 L
.5381 .04273 L
.54762 .04251 L
.55714 .04103 L
.56667 .04374 L
.57619 .04693 L
.58571 .0474 L
.59524 .04616 L
.60476 .04704 L
.61429 .04918 L
.62381 .05086 L
.63333 .0534 L
.64286 .05368 L
.65238 .05176 L
.6619 .05325 L
.67143 .0575 L
.68095 .05457 L
.69048 .05649 L
.7 .05764 L
.70952 .05681 L
.71905 .05852 L
.72857 .05536 L
.7381 .06028 L
.74762 .06358 L
.75714 .06108 L
.76667 .06502 L
.77619 .0664 L
.78571 .06704 L
.79524 .06743 L
.80476 .06933 L
.81429 .0694 L
.82381 .0697 L
.83333 .07121 L
.84286 .07193 L
.85238 .07385 L
.8619 .07684 L
.87143 .07794 L
.88095 .07721 L
.89048 .08046 L
.9 .08135 L
.90952 .08527 L
.91905 .08465 L
.92857 .08546 L
.9381 .08674 L
.94762 .0895 L
.95714 .09222 L
.96667 .08939 L
Mistroke
.97619 .09592 L
Mfstroke
1 0 .6 r
gsave
.97619 .54961 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05301 m
.03333 .05558 L
.04286 .0584 L
.05238 .0625 L
.0619 .06465 L
.07143 .06716 L
.08095 .07043 L
.09048 .07389 L
.1 .07724 L
.10952 .07734 L
.11905 .07925 L
.12857 .08411 L
.1381 .08679 L
.14762 .08865 L
.15714 .09424 L
.16667 .09692 L
.17619 .09964 L
.18571 .10097 L
.19524 .10596 L
.20476 .1089 L
.21429 .11241 L
.22381 .11605 L
.23333 .12026 L
.24286 .12539 L
.25238 .12851 L
.2619 .13129 L
.27143 .13756 L
.28095 .13989 L
.29048 .14312 L
.3 .14894 L
.30952 .15181 L
.31905 .15683 L
.32857 .16031 L
.3381 .16614 L
.34762 .16948 L
.35714 .17417 L
.36667 .17768 L
.37619 .18404 L
.38571 .1861 L
.39524 .18905 L
.40476 .19741 L
.41429 .20199 L
.42381 .20452 L
.43333 .20876 L
.44286 .21606 L
.45238 .21976 L
.4619 .2281 L
.47143 .22964 L
.48095 .23509 L
.49048 .23764 L
Mistroke
.5 .2436 L
.50952 .2464 L
.51905 .25457 L
.52857 .25777 L
.5381 .26531 L
.54762 .2711 L
.55714 .27999 L
.56667 .28461 L
.57619 .29073 L
.58571 .29297 L
.59524 .3003 L
.60476 .30632 L
.61429 .31391 L
.62381 .31784 L
.63333 .32175 L
.64286 .32939 L
.65238 .33167 L
.6619 .33702 L
.67143 .35037 L
.68095 .35602 L
.69048 .36294 L
.7 .36997 L
.70952 .37647 L
.71905 .38235 L
.72857 .38923 L
.7381 .39646 L
.74762 .4026 L
.75714 .40747 L
.76667 .41062 L
.77619 .41448 L
.78571 .42264 L
.79524 .43249 L
.80476 .43757 L
.81429 .44324 L
.82381 .45069 L
.83333 .45556 L
.84286 .46275 L
.85238 .46756 L
.8619 .47101 L
.87143 .47673 L
.88095 .48561 L
.89048 .49145 L
.9 .49828 L
.90952 .50447 L
.91905 .51199 L
.92857 .51804 L
.9381 .52554 L
.94762 .53169 L
.95714 .53967 L
.96667 .5438 L
Mistroke
.97619 .54961 L
Mfstroke
.8 0 1 r
gsave
.97619 .10354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01503 m
.03333 .01679 L
.04286 .01912 L
.05238 .01939 L
.0619 .01997 L
.07143 .01774 L
.08095 .01757 L
.09048 .01981 L
.1 .01906 L
.10952 .01891 L
.11905 .02037 L
.12857 .02005 L
.1381 .02005 L
.14762 .02336 L
.15714 .02148 L
.16667 .02126 L
.17619 .02053 L
.18571 .0219 L
.19524 .02245 L
.20476 .02119 L
.21429 .0241 L
.22381 .02269 L
.23333 .02314 L
.24286 .02376 L
.25238 .02469 L
.2619 .02449 L
.27143 .02452 L
.28095 .02556 L
.29048 .02832 L
.3 .02862 L
.30952 .02726 L
.31905 .02757 L
.32857 .02948 L
.3381 .03174 L
.34762 .03013 L
.35714 .0305 L
.36667 .03249 L
.37619 .03289 L
.38571 .03273 L
.39524 .03426 L
.40476 .03271 L
.41429 .03495 L
.42381 .03777 L
.43333 .03879 L
.44286 .03584 L
.45238 .03495 L
.4619 .03478 L
.47143 .03901 L
.48095 .03871 L
.49048 .03939 L
Mistroke
.5 .04177 L
.50952 .04196 L
.51905 .0426 L
.52857 .04166 L
.5381 .04352 L
.54762 .04525 L
.55714 .04654 L
.56667 .04619 L
.57619 .0457 L
.58571 .04855 L
.59524 .04786 L
.60476 .04942 L
.61429 .05031 L
.62381 .05027 L
.63333 .05048 L
.64286 .05339 L
.65238 .05453 L
.6619 .05466 L
.67143 .0563 L
.68095 .05642 L
.69048 .05894 L
.7 .0588 L
.70952 .05887 L
.71905 .05742 L
.72857 .05646 L
.7381 .05892 L
.74762 .05926 L
.75714 .06063 L
.76667 .05896 L
.77619 .06372 L
.78571 .06453 L
.79524 .06764 L
.80476 .06727 L
.81429 .07024 L
.82381 .06998 L
.83333 .06942 L
.84286 .07354 L
.85238 .07527 L
.8619 .07705 L
.87143 .07986 L
.88095 .07929 L
.89048 .08652 L
.9 .09109 L
.90952 .09209 L
.91905 .09246 L
.92857 .09397 L
.9381 .0937 L
.94762 .09664 L
.95714 .10032 L
.96667 .10147 L
Mistroke
.97619 .10354 L
Mfstroke
.2 0 1 r
gsave
.97619 .54937 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05517 m
.03333 .05633 L
.04286 .06079 L
.05238 .06012 L
.0619 .06532 L
.07143 .0678 L
.08095 .07093 L
.09048 .07211 L
.1 .07562 L
.10952 .077 L
.11905 .08039 L
.12857 .08337 L
.1381 .08719 L
.14762 .08882 L
.15714 .09505 L
.16667 .09625 L
.17619 .09788 L
.18571 .10242 L
.19524 .10378 L
.20476 .11008 L
.21429 .10911 L
.22381 .11909 L
.23333 .1179 L
.24286 .12287 L
.25238 .12613 L
.2619 .13052 L
.27143 .13464 L
.28095 .13796 L
.29048 .14212 L
.3 .14598 L
.30952 .15167 L
.31905 .15349 L
.32857 .15695 L
.3381 .16219 L
.34762 .16371 L
.35714 .16647 L
.36667 .16989 L
.37619 .17341 L
.38571 .17927 L
.39524 .18301 L
.40476 .18789 L
.41429 .19017 L
.42381 .19473 L
.43333 .19804 L
.44286 .20377 L
.45238 .2093 L
.4619 .21573 L
.47143 .21886 L
.48095 .22309 L
.49048 .23027 L
Mistroke
.5 .23614 L
.50952 .24186 L
.51905 .24481 L
.52857 .25418 L
.5381 .26107 L
.54762 .26713 L
.55714 .27265 L
.56667 .28001 L
.57619 .28911 L
.58571 .2946 L
.59524 .29779 L
.60476 .30472 L
.61429 .31226 L
.62381 .31703 L
.63333 .32368 L
.64286 .32746 L
.65238 .3365 L
.6619 .34154 L
.67143 .34369 L
.68095 .35057 L
.69048 .35713 L
.7 .36041 L
.70952 .36564 L
.71905 .37184 L
.72857 .37823 L
.7381 .38207 L
.74762 .38624 L
.75714 .39258 L
.76667 .40086 L
.77619 .40637 L
.78571 .4181 L
.79524 .42366 L
.80476 .43165 L
.81429 .44214 L
.82381 .44626 L
.83333 .45493 L
.84286 .46029 L
.85238 .46247 L
.8619 .47462 L
.87143 .48188 L
.88095 .48597 L
.89048 .49334 L
.9 .49929 L
.90952 .50666 L
.91905 .50904 L
.92857 .51909 L
.9381 .52577 L
.94762 .53242 L
.95714 .53953 L
.96667 .54301 L
Mistroke
.97619 .54937 L
Mfstroke
0 .4 1 r
gsave
.97619 .09403 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01627 m
.03333 .01809 L
.04286 .01933 L
.05238 .0175 L
.0619 .01962 L
.07143 .01927 L
.08095 .01719 L
.09048 .01823 L
.1 .01956 L
.10952 .02094 L
.11905 .02067 L
.12857 .02236 L
.1381 .01947 L
.14762 .0198 L
.15714 .02202 L
.16667 .02232 L
.17619 .02373 L
.18571 .0242 L
.19524 .02145 L
.20476 .02396 L
.21429 .02196 L
.22381 .0239 L
.23333 .0242 L
.24286 .02649 L
.25238 .02197 L
.2619 .02618 L
.27143 .0244 L
.28095 .0268 L
.29048 .02474 L
.3 .02747 L
.30952 .02721 L
.31905 .02553 L
.32857 .02754 L
.3381 .02736 L
.34762 .03055 L
.35714 .03035 L
.36667 .02984 L
.37619 .03074 L
.38571 .02988 L
.39524 .03215 L
.40476 .03164 L
.41429 .03269 L
.42381 .03475 L
.43333 .03673 L
.44286 .03623 L
.45238 .03871 L
.4619 .03714 L
.47143 .03581 L
.48095 .03742 L
.49048 .03772 L
Mistroke
.5 .03869 L
.50952 .0387 L
.51905 .04064 L
.52857 .03943 L
.5381 .04131 L
.54762 .04321 L
.55714 .04358 L
.56667 .04374 L
.57619 .04221 L
.58571 .04328 L
.59524 .04542 L
.60476 .0451 L
.61429 .04973 L
.62381 .04882 L
.63333 .05068 L
.64286 .05246 L
.65238 .05277 L
.6619 .05392 L
.67143 .05342 L
.68095 .05563 L
.69048 .05364 L
.7 .05339 L
.70952 .05762 L
.71905 .05898 L
.72857 .0589 L
.7381 .05765 L
.74762 .06151 L
.75714 .0636 L
.76667 .06071 L
.77619 .06551 L
.78571 .06132 L
.79524 .06586 L
.80476 .06659 L
.81429 .0703 L
.82381 .06974 L
.83333 .06825 L
.84286 .07 L
.85238 .07513 L
.8619 .07486 L
.87143 .07873 L
.88095 .07648 L
.89048 .07818 L
.9 .07986 L
.90952 .08138 L
.91905 .08125 L
.92857 .08486 L
.9381 .08508 L
.94762 .08888 L
.95714 .08998 L
.96667 .09458 L
Mistroke
.97619 .09403 L
Mfstroke
0 1 1 r
gsave
.97619 .57498 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05816 m
.03333 .05902 L
.04286 .06102 L
.05238 .06319 L
.0619 .06501 L
.07143 .06903 L
.08095 .06985 L
.09048 .07262 L
.1 .07429 L
.10952 .07859 L
.11905 .08039 L
.12857 .08533 L
.1381 .08949 L
.14762 .09033 L
.15714 .09456 L
.16667 .09385 L
.17619 .09763 L
.18571 .10337 L
.19524 .10632 L
.20476 .11021 L
.21429 .11493 L
.22381 .11687 L
.23333 .12447 L
.24286 .12584 L
.25238 .13063 L
.2619 .13384 L
.27143 .13869 L
.28095 .14079 L
.29048 .14582 L
.3 .14894 L
.30952 .1542 L
.31905 .16011 L
.32857 .16256 L
.3381 .16839 L
.34762 .17309 L
.35714 .17859 L
.36667 .18239 L
.37619 .18512 L
.38571 .19092 L
.39524 .19465 L
.40476 .2013 L
.41429 .20849 L
.42381 .21191 L
.43333 .21922 L
.44286 .22473 L
.45238 .23194 L
.4619 .23534 L
.47143 .24035 L
.48095 .24842 L
.49048 .24939 L
Mistroke
.5 .25592 L
.50952 .26191 L
.51905 .26452 L
.52857 .26792 L
.5381 .27728 L
.54762 .28239 L
.55714 .2881 L
.56667 .29373 L
.57619 .30011 L
.58571 .30797 L
.59524 .31118 L
.60476 .32296 L
.61429 .3287 L
.62381 .33757 L
.63333 .34292 L
.64286 .35212 L
.65238 .35837 L
.6619 .36523 L
.67143 .36807 L
.68095 .37338 L
.69048 .37944 L
.7 .38359 L
.70952 .39341 L
.71905 .4005 L
.72857 .40805 L
.7381 .41409 L
.74762 .42088 L
.75714 .42871 L
.76667 .4383 L
.77619 .44272 L
.78571 .45087 L
.79524 .45785 L
.80476 .46616 L
.81429 .4717 L
.82381 .48201 L
.83333 .48761 L
.84286 .494 L
.85238 .49813 L
.8619 .51101 L
.87143 .51956 L
.88095 .52318 L
.89048 .52565 L
.9 .53417 L
.90952 .54147 L
.91905 .54922 L
.92857 .55168 L
.9381 .55765 L
.94762 .56382 L
.95714 .56831 L
.96667 .56972 L
Mistroke
.97619 .57498 L
Mfstroke
0 1 .4 r
gsave
.97619 .09156 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01789 m
.03333 .01715 L
.04286 .01921 L
.05238 .01729 L
.0619 .01796 L
.07143 .0198 L
.08095 .01788 L
.09048 .01726 L
.1 .01926 L
.10952 .01955 L
.11905 .02026 L
.12857 .01996 L
.1381 .01939 L
.14762 .02243 L
.15714 .02087 L
.16667 .02279 L
.17619 .02314 L
.18571 .02271 L
.19524 .02235 L
.20476 .02307 L
.21429 .02384 L
.22381 .0223 L
.23333 .02375 L
.24286 .02248 L
.25238 .02511 L
.2619 .02503 L
.27143 .02548 L
.28095 .02373 L
.29048 .02586 L
.3 .02761 L
.30952 .02771 L
.31905 .02525 L
.32857 .02743 L
.3381 .02825 L
.34762 .02502 L
.35714 .02722 L
.36667 .02495 L
.37619 .02697 L
.38571 .02702 L
.39524 .028 L
.40476 .02982 L
.41429 .03096 L
.42381 .03011 L
.43333 .03149 L
.44286 .03026 L
.45238 .03232 L
.4619 .0332 L
.47143 .03452 L
.48095 .03491 L
.49048 .03514 L
Mistroke
.5 .03367 L
.50952 .03456 L
.51905 .03227 L
.52857 .03447 L
.5381 .03418 L
.54762 .03591 L
.55714 .03648 L
.56667 .03983 L
.57619 .04073 L
.58571 .04202 L
.59524 .0436 L
.60476 .04563 L
.61429 .04696 L
.62381 .04655 L
.63333 .05026 L
.64286 .04964 L
.65238 .05072 L
.6619 .05016 L
.67143 .05068 L
.68095 .0536 L
.69048 .05357 L
.7 .05599 L
.70952 .05552 L
.71905 .05678 L
.72857 .05431 L
.7381 .05397 L
.74762 .05506 L
.75714 .05784 L
.76667 .05944 L
.77619 .0628 L
.78571 .06274 L
.79524 .06233 L
.80476 .06404 L
.81429 .06784 L
.82381 .0669 L
.83333 .07026 L
.84286 .07084 L
.85238 .07369 L
.8619 .0737 L
.87143 .07543 L
.88095 .07517 L
.89048 .07414 L
.9 .0761 L
.90952 .0793 L
.91905 .08186 L
.92857 .08168 L
.9381 .07932 L
.94762 .08213 L
.95714 .08382 L
.96667 .08706 L
Mistroke
.97619 .09156 L
Mfstroke
.2 1 0 r
gsave
.97619 .58622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05521 m
.03333 .05704 L
.04286 .06157 L
.05238 .06419 L
.0619 .06194 L
.07143 .06808 L
.08095 .06928 L
.09048 .07262 L
.1 .07331 L
.10952 .07642 L
.11905 .0806 L
.12857 .08331 L
.1381 .08576 L
.14762 .09039 L
.15714 .09504 L
.16667 .09714 L
.17619 .10002 L
.18571 .10378 L
.19524 .10887 L
.20476 .11192 L
.21429 .11738 L
.22381 .11986 L
.23333 .12228 L
.24286 .12729 L
.25238 .13036 L
.2619 .13225 L
.27143 .1401 L
.28095 .14379 L
.29048 .14582 L
.3 .15364 L
.30952 .15928 L
.31905 .1631 L
.32857 .16611 L
.3381 .17161 L
.34762 .17524 L
.35714 .17981 L
.36667 .18484 L
.37619 .19044 L
.38571 .19649 L
.39524 .20063 L
.40476 .20614 L
.41429 .21248 L
.42381 .21626 L
.43333 .2228 L
.44286 .22804 L
.45238 .23381 L
.4619 .23771 L
.47143 .24392 L
.48095 .24687 L
.49048 .25457 L
Mistroke
.5 .25945 L
.50952 .26274 L
.51905 .27148 L
.52857 .27819 L
.5381 .2825 L
.54762 .28973 L
.55714 .29436 L
.56667 .30405 L
.57619 .30945 L
.58571 .31545 L
.59524 .32245 L
.60476 .32529 L
.61429 .33762 L
.62381 .34563 L
.63333 .35085 L
.64286 .35869 L
.65238 .3641 L
.6619 .37036 L
.67143 .37519 L
.68095 .38896 L
.69048 .39375 L
.7 .40084 L
.70952 .40657 L
.71905 .41592 L
.72857 .42361 L
.7381 .42691 L
.74762 .43435 L
.75714 .44115 L
.76667 .44795 L
.77619 .45303 L
.78571 .46054 L
.79524 .46526 L
.80476 .47099 L
.81429 .46982 L
.82381 .47484 L
.83333 .48096 L
.84286 .48958 L
.85238 .49793 L
.8619 .50716 L
.87143 .51083 L
.88095 .52016 L
.89048 .53081 L
.9 .53435 L
.90952 .53763 L
.91905 .54566 L
.92857 .55948 L
.9381 .56663 L
.94762 .57249 L
.95714 .57667 L
.96667 .58544 L
Mistroke
.97619 .58622 L
Mfstroke
.8 1 0 r
gsave
.97619 .09089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01635 m
.03333 .01648 L
.04286 .01722 L
.05238 .01713 L
.0619 .02008 L
.07143 .01962 L
.08095 .01713 L
.09048 .01957 L
.1 .02115 L
.10952 .02238 L
.11905 .0195 L
.12857 .01972 L
.1381 .02181 L
.14762 .0196 L
.15714 .02201 L
.16667 .02187 L
.17619 .02368 L
.18571 .02011 L
.19524 .02336 L
.20476 .02377 L
.21429 .02511 L
.22381 .02278 L
.23333 .025 L
.24286 .0259 L
.25238 .02406 L
.2619 .02577 L
.27143 .02556 L
.28095 .02763 L
.29048 .02868 L
.3 .02651 L
.30952 .02817 L
.31905 .02906 L
.32857 .03092 L
.3381 .03018 L
.34762 .02967 L
.35714 .02874 L
.36667 .03142 L
.37619 .02934 L
.38571 .03342 L
.39524 .02945 L
.40476 .03093 L
.41429 .03216 L
.42381 .03098 L
.43333 .02995 L
.44286 .03236 L
.45238 .0342 L
.4619 .03193 L
.47143 .03379 L
.48095 .03479 L
.49048 .03264 L
Mistroke
.5 .03434 L
.50952 .03709 L
.51905 .03357 L
.52857 .03793 L
.5381 .04032 L
.54762 .03872 L
.55714 .04024 L
.56667 .04313 L
.57619 .04256 L
.58571 .04284 L
.59524 .04413 L
.60476 .0457 L
.61429 .04488 L
.62381 .04614 L
.63333 .04343 L
.64286 .04279 L
.65238 .0427 L
.6619 .04305 L
.67143 .04499 L
.68095 .04897 L
.69048 .04858 L
.7 .0537 L
.70952 .05236 L
.71905 .05553 L
.72857 .05519 L
.7381 .05677 L
.74762 .05513 L
.75714 .05454 L
.76667 .05628 L
.77619 .05871 L
.78571 .06014 L
.79524 .06484 L
.80476 .06375 L
.81429 .06493 L
.82381 .06735 L
.83333 .06776 L
.84286 .0679 L
.85238 .06735 L
.8619 .07083 L
.87143 .07007 L
.88095 .07453 L
.89048 .07403 L
.9 .0748 L
.90952 .07997 L
.91905 .07922 L
.92857 .08395 L
.9381 .08737 L
.94762 .08948 L
.95714 .09148 L
.96667 .09295 L
Mistroke
.97619 .09089 L
Mfstroke
1 .6 0 r
gsave
.97619 .55089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05493 m
.03333 .05714 L
.04286 .05794 L
.05238 .06295 L
.0619 .06575 L
.07143 .06604 L
.08095 .06991 L
.09048 .07221 L
.1 .07606 L
.10952 .07689 L
.11905 .08005 L
.12857 .08473 L
.1381 .08876 L
.14762 .09098 L
.15714 .09413 L
.16667 .09874 L
.17619 .1007 L
.18571 .10322 L
.19524 .105 L
.20476 .10978 L
.21429 .11343 L
.22381 .11703 L
.23333 .12003 L
.24286 .12246 L
.25238 .12568 L
.2619 .12835 L
.27143 .13283 L
.28095 .13663 L
.29048 .13984 L
.3 .14556 L
.30952 .14807 L
.31905 .15241 L
.32857 .15701 L
.3381 .16339 L
.34762 .16735 L
.35714 .17311 L
.36667 .17557 L
.37619 .18157 L
.38571 .1871 L
.39524 .19077 L
.40476 .1949 L
.41429 .20197 L
.42381 .20341 L
.43333 .21023 L
.44286 .21619 L
.45238 .22092 L
.4619 .2278 L
.47143 .23155 L
.48095 .23732 L
.49048 .24318 L
Mistroke
.5 .24641 L
.50952 .25012 L
.51905 .25902 L
.52857 .26389 L
.5381 .26844 L
.54762 .27349 L
.55714 .28334 L
.56667 .28807 L
.57619 .29577 L
.58571 .29861 L
.59524 .30886 L
.60476 .31516 L
.61429 .32281 L
.62381 .32764 L
.63333 .33329 L
.64286 .34136 L
.65238 .34826 L
.6619 .35072 L
.67143 .35664 L
.68095 .3624 L
.69048 .36433 L
.7 .37184 L
.70952 .37548 L
.71905 .38513 L
.72857 .39115 L
.7381 .39656 L
.74762 .40276 L
.75714 .41102 L
.76667 .42009 L
.77619 .42511 L
.78571 .42892 L
.79524 .43534 L
.80476 .44333 L
.81429 .45179 L
.82381 .45996 L
.83333 .46672 L
.84286 .47629 L
.85238 .47361 L
.8619 .48221 L
.87143 .48573 L
.88095 .49144 L
.89048 .49349 L
.9 .50366 L
.90952 .50662 L
.91905 .51485 L
.92857 .51847 L
.9381 .53038 L
.94762 .53052 L
.95714 .53696 L
.96667 .54049 L
Mistroke
.97619 .55089 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00803oool2000002P0oooo1@0000030?ooo`800000:03oool3000000<0
oooo0P00000W0?ooo`<00000103oool2000002H0oooo0`0000040?ooo`800000903oool3000000@0
oooo0P0000040?ooo`8000000`3oool001l0oooo00@000000?ooo`3oool00000:03oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo000O0?ooo`040000003oool0oooo000002T0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000U0?ooo`D000000P3oool010000000oooo0?ooo`00000U0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`007`3oool01000
0000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0S0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000009@3oool4000000<0
oooo00@000000?ooo`3oool000009@3oool3000000<0oooo00@000000?ooo`3oool00000903oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool001l0oooo00@000000?ooo`3oool000009`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000009P3oool00`000000oooo000000030?ooo`040000003oool0oooo
000002D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000T0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`007`3oool01000
0000oooo0?ooo`00000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000W0?ooo`8000000`3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000903oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000008`3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`00803oool2000002T0oooo0`0000040?ooo`800000:@3oool00`000000oooo
0?ooo`020?ooo`800000:03oool2000000@0oooo0P00000V0?ooo`<00000103oool2000002D0oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P0000030?ooo`00o`3ooolJ0?ooo`00o`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`006`3ooook000000<0oooo000K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`80
c03o1@00I_o]0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000103oool90<co00<00?mV
00<006Ko0<co003<o`00103<o`03003oIP@0c?l01@00ofH2001Vom80oooo0P0000030?ooo`006`3o
ool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo103<o`000`3<0?l0c?l00?oo
o`020<`0o`05001Vo`3<o`00c?l00<co0000I_l00`00ofH<0<co0003003oIP3<o`00c?l000@0c?l0
0P00ofH2001Vo`<0c?l000<0c03o003oIP00ofH00P00ofH2001VokT0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool09P3oool30<`0o`040<co0000I_l006Ko0?ooo`L0c?l0
00<0c03o001Vo`00I_l0303<o`04003oIP<0c?l000<006Ko003oIP00ofH01000ofH2001Vo`d00?mV
U`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`110?ooo`03003oIP3o
ool0c?l000<0c?l000<0c03o003oIP00ofH04`3<o`02001Vo`D0c?l00P00ofH50<co00<00?mVR@3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`180?ooo`030<co003oool0
oooo00H0oooo0P3<0?l00`3oool00?mV0?ooo`020?ooo`D0c03o0P3<o`000`3<0?l006Ko001Vo`02
001Vo`80c?l00`00I_l00`00ofH0c?l00<co000@0<co00800?mV0`3<o`05003oIW40oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00001U0?ooo`8006Ko00<0o`000<`0o`3<0?l04`00I_l20<co
0003001Vo`3<o`0006Ko0080c?l00P3<0?l30<co00800?mVK03oool2000000<0oooo000K0?ooo`03
0000003oool0oooo07<0oooo00@0o`000?ooo`3oool0oooo0`3<o`050<`0o`04001Vo`3<0?l0c03o
0<`0o`80c?l00`00I_l:0<co00P0oooo2`3<o`1B0?ooo`030000003oool0oooo0040oooo000K0?oo
o`030000003oool0oooo08<0oooo0`00ofH20<`0o`@006Ko0`3<0?l30?l000P0c?l000<00?mV0<co
003<o`000`3<o`050?ooo`80c?l0D03oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`2:0?ooo`80o`000`3oool70<`0o`D006Ko3000ofH70<co04T0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P0000040?ooo`80oiT000<0<ol0003oo`3oool0RP3oool00`3o0000oooo
0?ooo`040?ooo`D0o`002@00I_l5003oIPT0c?l00P00ofH60<co03T0oooo0P0000030?ooo`006`3o
ool00`000000oooo0?ooo`030?ooo`800?oo1@3oV@2D0?ooo`L0o`000P3<0?l00`00I_l0c03o0<`0
o`020<`0o`03003oIP3<0?l006Ko008006Ko00@00?mV001Vo`00I_l006Ko0P3<o`000`00I_l0c03o
0<`0o`03003oIP@0c?l0=P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`070?ooo`<0<ol00P3oV@0203?o00030?nI003oool0oooo09@0oooo0P3o0002001Vo`P00?mV103o
ool30?l0008006Ko0P3<0?l3001Vo`800?mV0`3<o`02003oIS40oooo00<000000?ooo`3oool00@3o
ool000H0oooo1@0000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo00X0oooo0P0co`050?nI09/0oooo0P3o00020?ooo`030?l00000ofH00?mV00D00?mV00D0o`00
003oIP00I_l006Ko0?ooo`020?l00003001Vo`3<0?l0c03o0080c03o2@3<o`040?ooo`<0c?l08`3o
ool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0?0?ooo`80<ol00P3oV@020?l0VIT0oooo
0P3o00030?ooo`D0o`000P00I_l7003oIP<0c?l000@0c03o0<co003o0000o`000P00ofH3001Vo`@0
c?l000<00?mV0?ooo`3oool01@3<o`0N0?ooo`030000003oool0oooo0040oooo00080?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool200000180oooo0P0c0?l30?nI0080<ol0
Y@3oool00`3o0000oooo001Vo`04001Vo`L0o`00103<o`000`00ofH0c03o0<`0o`07003oIPH0c?l0
5P3oool3000000<0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`@0oiT00P3o09VX0?ooo`@006Ko0P3oool3001Vo`800?mV00<0
06Ko0?ooo`3oool00P00ofH30<`0o`L006Ko00@00?mV0<co0000ofH00?mV0P3<o`020?ooo`@00?mV
3@3oool00`000000oooo0?ooo`010?ooo`001P3oool01@000000oooo0?ooo`3oool0000000L0oooo
100000050?ooo`030000003oool0oooo01P0oooo0P00ool30?nI0080<ol0Z@3oool2001Vo`H0oooo
1000I_l30?l000040<`0o`00ofH0c?l00<`0o`<0o`000P00I_l20<co0005001Vo`00ofH0c?l0003o
IP3<0?l00`3oool2003oIP/0oooo00<000000?ooo`3oool00@3oool000H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool20?nI
00<0<ol0/P3oool7001Vo`<0c03o0P00ofH50?l000D0c?l000<0c03o0<co0000ofH00`00ofH20<`0
o`D0oooo00<000000?ooo`3oool00@3oool000L0oooo0`0000080?ooo`D00000103oool00`000000
oooo0?ooo`0O0?ooo`D0oiT0]`3oool3001Vo`80c03o103oool00`00ofH0oooo0?ooo`080<co0003
0?l0003<o`00c?l000D0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00000U0?ooo`80oiT0
0`00oone0?ooo`80o`002P3<0?l20?ooo`80o`0000@0oooo0<co0000I_l00?mV103oool2000000<0
oooo000K0?ooo`030000003oool0oooo02H0oooo0`3oV@02003ookP0oooo00@006Ko0?l0003o0000
o`000`00I_l20<`0o`D0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`0Y0?ooo`@0oiT0_@3oool2001Vo`D0c03o1P3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`80<ol00`3oV@020?l0VKX0oooo0`00
I_l2003oIP030<`0o`3oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0;@3oool303?o0080oiT00P0c0?nm0?ooo`03001Vo`3oool0oooo00<0oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00000a0?ooo`80<ol00`3oV@310?ooo`8000000`3oool001/0
oooo00<000000?ooo`3oool0<P3oool303?o0080oiT00P0c0?nn0?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo03D0oooo0P0co`050?nI0;/0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool0=`3oool2003oo`<0<ol00P3oV@2i0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`800000?@3oool203?o00<0oiT0]@3oool2000000<0oooo000K0?oo
o`030000003oool0oooo03h0oooo0P0co`000`00ool0oiT00?nI002d0?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo0400oooo00<0<ol0003oo`00ool00P3oV@2b0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0440oooo0P0co`02003oo`<0oiT0
[`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`130?ooo`@0<ol000<0
0?oo0?nI003oV@00[@3oool00`000000oooo0?ooo`010?ooo`006`3oool2000004P0oooo00<0<ol0
003oo`00ool00P3oV@2Z0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0B03oool203?o
0003003oo`0c0?l0oiT00080oiT0Z03oool00`000000oooo0?ooo`010?ooo`004`3oool3000000D0
oooo00<000000?ooo`3oool0BP3oool203?o00<0o`2I0P3oV@2V0?ooo`030000003oool0oooo0040
oooo000B0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1<0?ooo`<0
<ol000<00?oo0?l0V@3oV@000P3oV@2S0?ooo`030000003oool0oooo0040oooo000F0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`3oV@00<ol0003oo`030?l0V@040?nI
000c0?l0<`3o03<0oil0oooo00<000000?ooo`3oool00@3oool001H0oooo00<000000?ooo`3oool0
0P3oool200000500oooo00<0oiT003?o0000ool00P00ool0103o09T0oiT00?l0V@3o09T303<0oiX0
oooo0`0000030?ooo`004P3oool4000000D0oooo00<000000?ooo`3oool0D@3oool403?o0003003o
o`3oV@00oiT000<0o`2I0P0c0?nJ0?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0E03oool0103oV@00<ol0003oo`00ool30?nI0080o`2I
0`0c0?nG0?ooo`030000003oool0oooo0040oooo000B0?ooo`D00000103oool00`000000oooo0?oo
o`1F0?ooo`80<ol00`00ool20?nI0080o`2I00<0oooo03<0o`3oool0U@3oool00`000000oooo0?oo
o`010?ooo`006`3oool00`000000oooo0?ooo`1H0?ooo`<0<ol00P00ool30?nI00030?ooo`0c0?l0
oooo09@0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001L0?ooo`0303?o0000ool00?oo
00800?oo0P3oV@0503<0ohl0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`03
03?o0000ool00?oo00800?oo00<0o`2I0?nI003o09T00`3oool203<0ohh0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool0G@3oool303?o00800?oo00@0o`2I0?nI003o09T0
o`2I0`3oool00`0c0?l0oooo0?ooo`2;0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo0600oooo0P0co`000`00ool0<ol00?nI00020?nI00<0oooo00<0<`3o0?ooo`3oool0
RP3oool00`000000oooo0?ooo`010?ooo`006`3oool2000006<0oooo00<0<ol0003oo`0co`000P0c
o`020?nI0080oooo0`0c0?n80?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0H`3oool0
1`0co`000?oo003oo`00ool0<ol003<0o`3oV@00103oool00`0c0?l0oooo0?ooo`260?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06@0oooo0`0co`02003oo`0303<0o`3o
V@00oooo00<0oooo00<0<`3o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`010?ooo`006`3oool0
0`000000oooo0?ooo`1W0?ooo`80<ol000<00?oo03?o003oV@000P3oV@020?ooo`D0<`3oPP3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1X0?ooo`030?nI000co`000?oo
00<0<ol000<0oiT00?l0V@3oool0103oool00`0c0?l0oooo0?ooo`1o0?ooo`030000003oool0oooo
0040oooo000K0?ooo`800000JP3oool01`3oV@00<ol0003oo`00ool0oooo03?o003oV@000P3o09T4
0?ooo`0303<0o`3oool0oooo07d0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1[0?oo
o`<0<ol00P3oool30?nI0080o`2I0P3oool203<0ogh0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0KP3oool203?o00800?oo00<0<ol00?nI003oV@000P3o09T20?ooo`03
03<0o`3oool0oooo07/0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
K`3oool0103oV@00<ol003?o0000ool203?o0080oiT00P3o09T00`3oool0<`3o03<0o`1k0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0700oooo0P3oV@000`0co`000?oo
003oo`0203?o00<0oiT00P3oool303<0ogP0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00
001d0?ooo`<0<ol000@0oooo03?o000co`00<`3o0P3oV@020?l0V@030?ooo`0c0?l0oooo07D0oooo
0P0000030?ooo`006`3oool00`000000oooo0?ooo`1d0?ooo`030?nI0000ool0<ol000800?oo00<0
<ol003<0o`0c0?l00P3oV@000`3o09T0oooo03<0o`1f0?ooo`030000003oool0oooo0040oooo0008
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<00000
0?ooo`3oool0M@3oool20?nI0080<ol000<00?oo03?o000co`000P0c0?l0103oV@00o`2I0?l0V@0c
0?me0?ooo`030000003oool0oooo0040oooo00080?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07L0oooo0P3oV@000`0co`000?oo003o
o`0303?o00040?nI003oool0o`2I03<0og@0oooo00<000000?ooo`3oool00@3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00@0
oiT003?o000co`00<ol00P00ool0100co`00oiT00?ooo`3o09T303<0og40oooo00<000000?ooo`3o
ool00@3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000
N`3oool20?nI00030?ooo`0co`000?oo00800?oo0P3oV@030?l0V@0303<0o`3oool0oooo06`0oooo
0`0000030?ooo`002P3oool00`000000oooo0?ooo`050?ooo`@000001@3oool00`000000oooo0?oo
o`1l0?ooo`80oiT000D0<ol0003oo`0co`000?oo03<0o`030?nI00030?l0V@0c0?l0oooo06h0oooo
00<000000?ooo`3oool00@3oool000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0O`3oool303?o0007003oo`0c0?l0<`3o03<0o`3o
V@00oooo03<0o`1^0?ooo`030000003oool0oooo0040oooo00060?ooo`D000001`3oool5000000@0
oooo00<000000?ooo`3oool0O`3oool0103oV@00oooo03?o000co`03003oo`040?nI003o09T0oooo
03<0ofd0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000210?ooo`030?nI003oool0oooo
0080<ol000<0oooo003oo`3oV@000P3o09T203<0ofX0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`210?ooo`@0oiT000<0<ol00?ooo`00ool00P3oV@020?l0V@0303<0o`3oool0oooo06P0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0QP3oool203?o00800?oo
0P3oV@000`3oool0<`3o03<0o`1X0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo08L0oooo00<0oiT003?o000co`000P00ool00`3oV@00oooo0?ooo`0303<0ofD0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0R03oool01@0co`000?oo03?o000c
o`000?oo00<0oiT000<0oooo0?l0V@0c0?l0I03oool00`000000oooo0?ooo`010?ooo`006`3oool2
000008X0oooo00/0<ol0003oo`00ool0oooo003oo`0c0?l0oooo0?nI003oool0o`2I03<0o`1R0?oo
o`8000000`3oool001/0oooo00<000000?ooo`3oool0RP3oool303?o00080?ooo`00ool0<`3o03<0
o`3oV@00<`3o0?ooo`0c0?mR0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo08d0oooo00<0<ol0003oo`00ool00P00ool20?nI00030?ooo`0c0?l0oooo0600oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0SP3oool0200co`000?oo003oo`3oool0
0?oo0?ooo`3oV@00oooo0`0c0?mN0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo08l0oooo0`0co`00103oool00?oo0?ooo`3oV@030?ooo`0303<0o`3o09T0oooo05/0oooo
00<000000?ooo`3oool00@3oool001/0oooo0P00002C0?ooo`80<ol000L00?oo03?o003oV@00oiT0
03<0o`3oool0<`3o0080o`2IF@3oool2000000<0oooo000K0?ooo`030000003oool0oooo0980oooo
00@00?oo0?nI000co`000?oo0P0co`000`3oV@00<`3o03<0o`0303<0oeT0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool0T`3oool00`00ool0<ol00?nI0002003oo`030?l0
V@3oV@00oiT000<0oooo00<0<`3o0?l0V@3oool0EP3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`2D0?ooo`05003oo`0co`00oiT00?nI0000ool00P3o09T20?nI0080oooo
00<0<`3o0?l0V@3o09T0E@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`2F0?ooo`80<ol000<0oiT0003oo`00ool00P3o09T00`3oV@00oooo0?ooo`0203<0o`030?l0V@3o
ool0oooo0580oooo00<000000?ooo`3oool00@3oool001/0oooo0P00002I0?ooo`0803?o003oV@00
0?oo003oo`3oool0o`2I0?nI000co`020?ooo`<0<`3oD@3oool2000000<0oooo000K0?ooo`030000
003oool0oooo09T0oooo0P0co`02003oo`040?ooo`3o09T0oiT003?o00<0oooo00<0o`2I03<0o`0c
0?l0D03oool00`000000oooo0?ooo`010?ooo`003@3oool3000000@0oooo0P0000050?ooo`030000
003oool0oooo09/0oooo0P0co`000`00ool0oooo0?ooo`040?nI00040?ooo`3o09T0<`3o03<0odl0
oooo00<000000?ooo`3oool00@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo09d0oooo00D0<ol0003oo`00ool0oooo0?l0V@0203?o
00030?nI003oool0o`2I0080<`3oCP3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00002O0?ooo`0703?o003oV@000?oo
0?ooo`3o09T0oooo03?o00020?nI0080o`2I0`0c0?m90?ooo`<000000`3oool000h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo09l0oooo00H0
<ol00?nI0000ool0oooo0?l0V@3oool203?o0080oiT00P3o09T303<0odT0oooo00<000000?ooo`3o
ool00@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0:00oooo0P0co`03003oo`80oooo00L0<ol00?ooo`3oV@00oiT00?l0V@0c0?l0
oooo0080<`3oA`3oool00`000000oooo0?ooo`010?ooo`003@3oool2000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`2R0?ooo`<0<ol00P00ool01`0co`00oooo0?ooo`3o
ool0oiT00?l0V@0c0?l00P3oool00`0c0?l0oooo0?ooo`140?ooo`030000003oool0oooo0040oooo
000>0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0:@0oooo00D0
oiT003?o003oool00?oo03?o00030?ooo`80oiT01@0c0?m40?ooo`030000003oool0oooo0040oooo
000K0?ooo`800000YP3oool0100co`00oiT00?ooo`00ool403?o00060?ooo`3oV@00oiT00?l0V@0c
0?l0oooo0P0c0?m10?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0YP3oool00`0co`00
oiT00?nI0003003oo`060?ooo`0co`00oooo0?ooo`3oV@00o`2I0`3oool303<0ocl0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0YP3oool00`0co`000?oo0?ooo`030?nI
0005003oo`3o09T0<ol003?o003oool00P3oV@050?ooo`0303<0o`3oool0oooo03`0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0Y`3oool203?o00<0oooo00D0oiT0003o
o`3o09T0o`2I03?o00020?ooo`030?nI003oool0oooo00<0oooo00<0<`3o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2Y0?ooo`80<ol00P3oool01@3o
V@000?oo003oo`3o09T0<ol00080oooo00<0oiT00?ooo`3oool00`3oool203<0oc/0oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00002/0?ooo`0303?o003oool0oooo0080oiT000<00?oo03?o
003oool00P3oool30?nI00@0oooo00<0<`3o0?ooo`3oool0=`3oool2000000<0oooo000K0?ooo`03
0000003oool0oooo0:`0oooo0P0co`030?ooo`03003oo`0co`00oooo00@0oooo00<0oiT00?ooo`3o
ool00P3oool203<0ocP0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
[03oool00`00ool0oooo03?o00020?ooo`030?nI0000ool0<ol000<0<ol00P3oool00`3oV@00oooo
0?ooo`030?ooo`0303<0o`3oool0oooo03D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0[@3oool00`00ool0oooo03?o00020?ooo`030?nI0000ool00?oo0080o`2I00@0
<ol00?ooo`3oool0oiT0103o09T00`0c0?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo0:h0oooo0P00ool00`0co`000?oo003oo`020?nI00800?oo00H0
o`2I03?o003oool0oooo0?nI003oool203<0o`030?l0V@0c0?l0oooo03D0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00002b0?ooo`0403?o003oool00?oo0?ooo`80oiT000<00?oo0?l0V@0c
o`000P3oool01@3oV@00oooo0?ooo`0c0?l0o`2I0080<`3o<`3oool2000000<0oooo000K0?ooo`03
0000003oool0oooo0;80oooo00<0<ol0003oo`3oool00P3oool00`3oV@000?oo0?l0V@0203?o0003
0?ooo`3oV@00oiT00080oooo00<0o`2I03<0o`0c0?l0<`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`2c0?ooo`@0<ol000<0oooo0?nI0000ool00P3o09T00`0co`00oooo
0?ooo`020?nI00040?ooo`3o09T0oooo03<0oc80oooo00<000000?ooo`3oool00@3oool001/0oooo
00<000000?ooo`3oool0]@3oool00`00ool0oooo03?o00020?ooo`800?oo00<0oooo03?o003o09T0
0P3oool20?nI00030?l0V@0c0?l0<`3o0340oooo00<000000?ooo`3oool00@3oool001/0oooo0P00
002g0?ooo`03003oo`3oool0<ol000<0oooo00@00?oo0?ooo`0co`00o`2I0`3oool0103oV@00o`2I
0?l0V@0c0?l_0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0]`3oool00`00ool0oooo
03?o00030?ooo`800?oo0P0co`030?ooo`030?nI003oool0o`2I00<0<`3o;@3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`04003oo`3oool0<ol003?o0080oooo
00<0oiT0003oo`3o09T00P0co`020?ooo`030?nI003oool0o`2I00<0<`3o;03oool00`000000oooo
0?ooo`010?ooo`0000@0oooo00000000000000000P3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool3000000D0oooo00<000000?ooo`3oool0^@3oool01000ool0oooo0?ooo`0co`020?ooo`05
0?nI0000ool0o`2I0?l0V@0co`000P3oool00`3oV@00oooo0?l0V@020?l0V@80<`3o:P3oool00`00
0000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0;X0oooo0P00ool0
1@3oool0<ol003?o003oool0oiT000800?oo00D0o`2I03?o000co`00oooo0?nI00030?ooo`040?l0
V@0c0?l0<`3o03<0obP0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00002m0?ooo`05003o
o`3oool0oooo03?o003oool00P3oV@001@00ool0o`2I0?ooo`0co`00oooo0080oiT00P3oool0103o
09T0<`3o03<0o`0c0?lU0?ooo`<000000`3oool00080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0_@3oool01000
ool0oooo0?ooo`0co`020?ooo`050?nI0000ool0o`2I0?ooo`0co`000P3oool00`3oV@00oooo0?oo
o`020?l0V@@0<`3o903oool00`000000oooo0?ooo`010?ooo`000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<000000?ooo`3oool0_P3o
ool00`00ool0oooo0?ooo`0303?o00040?nI0000ool0o`2I0?ooo`80<ol000<0oooo0?nI003oV@00
0`3oool403<0ob<0oooo00<000000?ooo`3oool00@3oool000030?ooo`000000000000<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
_`3oool4003oo`050?ooo`0co`00<ol0003oo`3o09T00P3oool0100co`00oooo0?ooo`3oV@030?oo
o`030?l0V@0c0?l0oooo0080<`3o8@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`<00000203oool5000000@0oooo00<000000?ooo`3oool0``3oool00`00ool0
oooo0?ooo`0603?o0080oooo00H0oiT00?ooo`3oool0oooo0?l0V@0c0?l20?l0V@0303<0o`3oool0
oooo01h0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000350?ooo`04003oo`3oool0oooo
0?nI00800?oo00<0o`2I03?o003oool00P3oool01@3oV@00oooo0?nI003oV@00oooo0080<`3o00<0
o`2I03<0o`3oool07@3oool2000000<0oooo000K0?ooo`030000003oool0oooo0<D0oooo00<00?oo
0?ooo`3oool00P3oV@000`00ool0o`2I03?o00030?ooo`040?nI003oool0oooo0?nI0080oooo00<0
<`3o0?l0V@0c0?l07P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`36
0?ooo`06003oo`3oool0oooo0?ooo`3oV@000?oo0`0co`050?ooo`<0oiT0100c0?lL0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0<L0oooo00H00?oo0?ooo`3oool0oooo
0?nI0000ool303?o00L0oooo00@0oiT00?ooo`0c0?l0oooo0`0c0?lI0?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo0<P0oooo0P00ool30?ooo`<00?oo00<0<ol00?l0V@3o
ool01@3oool00`3oV@00oooo03<0o`030?ooo`0303<0o`3oool0oooo01H0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00003;0?ooo`03003oo`3oool0oooo0080oooo00@0oiT0003oo`0co`00
o`2I1P3oool30?nI000403<0o`3o09T0oooo03<0oaH0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`3;0?ooo`800?oo0`3oool00`3oV@00<ol003?o00090?ooo`040?nI000c0?l0o`2I0?oo
o`@0<`3o4`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3=0?ooo`<0
0?oo00@0oooo0?nI000co`00<ol02@3oool00`3oV@00<`3o03<0o`040?ooo`0303<0o`3oool0oooo
0100oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0d03oool00`00ool0
oooo0?nI000403?o00L0oooo103oV@000`0c0?l0oooo0?ooo`0203<0oa00oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00003B0?ooo`03003oo`3oool0oiT000D0<ol02@3oool00`3oV@00<`3o
0?ooo`020?ooo`<0<`3o303oool2000000<0oooo000K0?ooo`030000003oool0oooo0=80oooo00L0
0?oo0?ooo`3oV@000?oo0?ooo`0co`00o`2I0080<ol0203oool20?nI00D0oooo0P0c0?l;0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0=<0oooo00T00?oo0?ooo`3oool0
0?oo0?ooo`0co`00o`2I0?ooo`0co`00203oool00`0c0?l0oiT00?ooo`050?ooo`80<`3o2@3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`D00?oo00<0<ol00?l0
V@0co`002@3oool00`3oV@00<`3o0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0e`3oool01000ool0oiT0003oo`0co`02003o
o`030?l0V@3oool0oooo00H0oooo00<0oiT003<0o`0c0?l01P3oool203<0o`H0oooo00<000000?oo
o`3oool00@3oool001/0oooo0P00003I0?ooo`03003oo`3oV@00oooo00<0<ol000<0o`2I0?ooo`3o
ool01P3oool40?nI00H0oooo00<0<`3o0?ooo`3oool00P3oool2000000<0oooo000K0?ooo`030000
003oool0oooo0=T0oooo00<00?oo0?nI003oool00P3oool203?o00X0oooo00<0<`3o0?nI003oool0
2P3oool00`000000oooo0?ooo`010?ooo`003@3oool3000000<0oooo0`0000050?ooo`030000003o
ool0oooo0=X0oooo00<00?oo0?nI003oool00P3oool01000ool0<ol003?o000co`080?ooo`0403<0
o`3oV@00oiT00?nI00P0oooo00<000000?ooo`3oool00@3oool000h0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0f`3oool00`00ool0
oiT00?ooo`020?ooo`800?oo0P0co`080?ooo`<0<`3o00<0oiT00?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0g@3oool00`3oV@00oooo0?ooo`020?ooo`03003oo`0co`00oooo00X0oooo
00<0o`2I0?nI003oool01@3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo0P00003O0?ooo`030?nI0000ool0oooo0080oooo00<0
<ol0003oo`3oool02`3oool0103oV@00oooo0?ooo`3oool3000000<0oooo000>0?ooo`040000003o
ool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`3O0?ooo`030?nI0000ool00?oo0080oooo
00<0<ol0003oo`00ool0403oool00`000000oooo0?ooo`010?ooo`003@3oool2000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3P0?ooo`80oiT000D00?oo0?ooo`0co`00<ol0
0?ooo`02003oo`h0oooo00<000000?ooo`3oool00@3oool000h0oooo00@000000?ooo`3oool0oooo
1@0000040?ooo`030000003oool0oooo0>80oooo00<0oiT0003oo`00ool00P0co`020?ooo`03003o
o`3oool0oooo00/0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0h`3o
ool20?nI00800?oo0`0co`02003oo`/0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00003V
0?ooo`80oiT00P00ool00`0co`00oooo03?o0005003oo`D0oooo0P0000030?ooo`006`3oool00`00
0000oooo0?ooo`3W0?ooo`80oiT000<0oooo03?o000co`000P0co`030?ooo`03003oo`3oool0oooo
00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0j@3oool00`3oV@00
oooo003oo`0303?o00P0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
jP3oool0103oV@00oooo003oo`00ool403?o00D0oooo00<000000?ooo`3oool00@3oool001/0oooo
0P00003/0?ooo`040?nI003oool0oooo003oo`<0<ol0103oool2000000<0oooo000K0?ooo`030000
003oool0oooo0>`0oooo0P3oV@000`3oool00?oo003oo`060?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo0>h0oooo00@0oiT00?ooo`3oool00?oo1@3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3_0?ooo`030?nI003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0l03oool00`3oV@00oooo0?ooo`04
0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000lP3oool00`3oV@00oooo0?ooo`020?oo
o`8000000`3oool001/0oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000K0?oooo/000000`3o
ool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.938, 0}} -> {-13.8823, -0.916352, \
0.419554, 0.105204}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvalues of A[t]", "Subsection"],

Cell["\<\
r = \
MapThread[Rule[#1,#2]&,{{lambda11,lambda12,lambda21,lambda22,alpha,beta},\
Theta}];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["r", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({lambda11 \[Rule] 10.`, lambda12 \[Rule] \(-1.`\), 
      lambda21 \[Rule] 2.`, lambda22 \[Rule] 30.`, alpha \[Rule] 1.`, 
      beta \[Rule] \(-2.`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A[t]/.r
A[t]/.r//Eigenvalues\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{\(\(0.1`\)\(\[InvisibleSpace]\)\) + 
          0.01`\ t, \(-0.01`\)}, {0.02`, \(\(0.3`\)\(\[InvisibleSpace]\)\) - 
          0.02`\ t}}\)], "Output"],

Cell[BoxData[
    \({1\/2\ \((\(\(0.4`\)\(\[InvisibleSpace]\)\) - 
            0.030000000000000002`\ \@\(\(-7.609475708248709`\) + t\)\ \
\@\(\(-5.723857625084625`\) + t\) - 0.01`\ t)\), 
      1\/2\ \((\(\(0.4`\)\(\[InvisibleSpace]\)\) + 
            0.030000000000000002`\ \@\(\(-7.609475708248709`\) + t\)\ \
\@\(\(-5.723857625084625`\) + t\) - 0.01`\ t)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Map[{Re[#],Im[#]}&,A[t]/.r//Eigenvalues]/.t->5", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.19561552812808852`, 0.`}, {0.15438447187191148`, 0.`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[A[t]/.r//Flatten//Evaluate,{t,0,10},
\tAxes->None]
Plot[Map[{Re[#],Im[#]}&,A[t]/.r//Eigenvalues]//Evaluate,{t,0,10},
\tAxes->None]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0337023 1.89872 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0337 -6 -4.5 ]
[-0.0125 .0337 0 4.5 ]
[-0.0125 .12864 -24 -4.5 ]
[-0.0125 .12864 0 4.5 ]
[-0.0125 .22357 -18 -4.5 ]
[-0.0125 .22357 0 4.5 ]
[-0.0125 .31851 -24 -4.5 ]
[-0.0125 .31851 0 4.5 ]
[-0.0125 .41345 -18 -4.5 ]
[-0.0125 .41345 0 4.5 ]
[-0.0125 .50838 -24 -4.5 ]
[-0.0125 .50838 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0337 m
.00625 .0337 L
s
[(0)] -0.0125 .0337 1 0 Mshowa
0 .12864 m
.00625 .12864 L
s
[(0.05)] -0.0125 .12864 1 0 Mshowa
0 .22357 m
.00625 .22357 L
s
[(0.1)] -0.0125 .22357 1 0 Mshowa
0 .31851 m
.00625 .31851 L
s
[(0.15)] -0.0125 .31851 1 0 Mshowa
0 .41345 m
.00625 .41345 L
s
[(0.2)] -0.0125 .41345 1 0 Mshowa
0 .50838 m
.00625 .50838 L
s
[(0.25)] -0.0125 .50838 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05269 m
.00375 .05269 L
s
0 .07168 m
.00375 .07168 L
s
0 .09066 m
.00375 .09066 L
s
0 .10965 m
.00375 .10965 L
s
0 .14763 m
.00375 .14763 L
s
0 .16661 m
.00375 .16661 L
s
0 .1856 m
.00375 .1856 L
s
0 .20459 m
.00375 .20459 L
s
0 .24256 m
.00375 .24256 L
s
0 .26155 m
.00375 .26155 L
s
0 .28054 m
.00375 .28054 L
s
0 .29952 m
.00375 .29952 L
s
0 .3375 m
.00375 .3375 L
s
0 .35649 m
.00375 .35649 L
s
0 .37547 m
.00375 .37547 L
s
0 .39446 m
.00375 .39446 L
s
0 .43243 m
.00375 .43243 L
s
0 .45142 m
.00375 .45142 L
s
0 .47041 m
.00375 .47041 L
s
0 .4894 m
.00375 .4894 L
s
0 .52737 m
.00375 .52737 L
s
0 .54636 m
.00375 .54636 L
s
0 .56534 m
.00375 .56534 L
s
0 .58433 m
.00375 .58433 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0337 m
1 .0337 L
s
.99375 .12864 m
1 .12864 L
s
.99375 .22357 m
1 .22357 L
s
.99375 .31851 m
1 .31851 L
s
.99375 .41345 m
1 .41345 L
s
.99375 .50838 m
1 .50838 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05269 m
1 .05269 L
s
.99625 .07168 m
1 .07168 L
s
.99625 .09066 m
1 .09066 L
s
.99625 .10965 m
1 .10965 L
s
.99625 .14763 m
1 .14763 L
s
.99625 .16661 m
1 .16661 L
s
.99625 .1856 m
1 .1856 L
s
.99625 .20459 m
1 .20459 L
s
.99625 .24256 m
1 .24256 L
s
.99625 .26155 m
1 .26155 L
s
.99625 .28054 m
1 .28054 L
s
.99625 .29952 m
1 .29952 L
s
.99625 .3375 m
1 .3375 L
s
.99625 .35649 m
1 .35649 L
s
.99625 .37547 m
1 .37547 L
s
.99625 .39446 m
1 .39446 L
s
.99625 .43243 m
1 .43243 L
s
.99625 .45142 m
1 .45142 L
s
.99625 .47041 m
1 .47041 L
s
.99625 .4894 m
1 .4894 L
s
.99625 .52737 m
1 .52737 L
s
.99625 .54636 m
1 .54636 L
s
.99625 .56534 m
1 .56534 L
s
.99625 .58433 m
1 .58433 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.007 w
.02381 .22357 m
.06244 .23128 L
.10458 .23968 L
.14415 .24757 L
.18221 .25515 L
.22272 .26323 L
.26171 .271 L
.30316 .27927 L
.34309 .28723 L
.3815 .29489 L
.42237 .30303 L
.46172 .31088 L
.49955 .31842 L
.53984 .32645 L
.57861 .33418 L
.61984 .3424 L
.65954 .35032 L
.69774 .35793 L
.73838 .36604 L
.77751 .37384 L
.81909 .38213 L
.85916 .39011 L
.89771 .3978 L
.93871 .40598 L
.97619 .41345 L
s
1 .6 0 r
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.49955 .01472 L
.53984 .01472 L
.57861 .01472 L
.61984 .01472 L
.65954 .01472 L
.69774 .01472 L
.73838 .01472 L
.77751 .01472 L
.81909 .01472 L
.85916 .01472 L
.89771 .01472 L
.93871 .01472 L
.97619 .01472 L
s
.8 1 0 r
.02381 .07168 m
.06244 .07168 L
.10458 .07168 L
.14415 .07168 L
.18221 .07168 L
.22272 .07168 L
.26171 .07168 L
.30316 .07168 L
.34309 .07168 L
.3815 .07168 L
.42237 .07168 L
.46172 .07168 L
.49955 .07168 L
.53984 .07168 L
.57861 .07168 L
.61984 .07168 L
.65954 .07168 L
.69774 .07168 L
.73838 .07168 L
.77751 .07168 L
.81909 .07168 L
.85916 .07168 L
.89771 .07168 L
.93871 .07168 L
.97619 .07168 L
s
.2 1 0 r
.02381 .60332 m
.06244 .58791 L
.10458 .57111 L
.14415 .55533 L
.18221 .54016 L
.22272 .52401 L
.26171 .50846 L
.30316 .49193 L
.34309 .47601 L
.3815 .4607 L
.42237 .4444 L
.46172 .42871 L
.49955 .41363 L
.53984 .39756 L
.57861 .3821 L
.61984 .36566 L
.65954 .34983 L
.69774 .3346 L
.73838 .3184 L
.77751 .30279 L
.81909 .28621 L
.85916 .27024 L
.89771 .25487 L
.93871 .23852 L
.97619 .22357 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00803oool2000002`0oooo1@00000]0?ooo`<00000;03oool3000002h0
oooo0`00000Z0?ooo`<00000103oool2000000<0oooo000O0?ooo`040000003oool0oooo000002`0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo
0?ooo`000000;03oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000]0?ooo`030000
003oool0oooo02/0oooo1@00000[0?ooo`050000003oool0oooo0?ooo`000000;03oool01@000000
oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`007`3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo02X0oooo00@00000
0?ooo`3oool00000;03oool4000002h0oooo0`00000[0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool00000:`3oool01@000000oooo
0?ooo`3oool0000002`0oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`0^0?ooo`05
0000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo000O0?ooo`040000003oool0oooo000002/0oooo00D000000?ooo`3oool0oooo0000
000]0?ooo`800000;@3oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`000000
:@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool00200oooo0P00000]0?ooo`<00000
;`3oool00`000000oooo0?ooo`0/0?ooo`800000;P3oool3000002/0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0
oooo000K0?ooooh00000000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0@00000001/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool00`3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`80
0000103oooob0?nI00@0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3o
ool00`000000oooo0?ooo`3j0?ooo`400000000D0?ooo`8000001@3oool00`000000oooo0?ooo`3j
0?ooo`400000000C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0nP3oool1
000000004`3oool010000000oooo0?ooo`0000040?ooo`800000n@3oool3000000004`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0?X0oooo0@00000001<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3j0?ooo`400000000C0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0nP3oool100000000503oool2000000D0oooo00<000000?oo
o`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0
nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0
oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool2000000@0
oooolP3<o`040?ooo`800000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?oo
o`800000nP3oool2000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000
003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool0
0`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`800000nP3oool2000000006`3oool00`000000
oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@0000000080oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`3j0?ooo`40000000001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0nP3oool100000000
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00P3oool200000?T0oooo0`00000000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0nP3oool1
0000000000D0oooo0000003oool0oooo000000080?ooo`050000003oool0oooo0000003oool01000
00050?ooo`030000003oool0oooo0?X0oooo0@00000000050?ooo`000000oooo0?ooo`000000203o
ool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0nP3oool100000000
0P3oool2000000X0oooo0P0000020?ooo`D00000103oool00`000000oooo0?ooo`3j0?ooo`400000
000K0?ooo`800000nP3oool2000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?oo
o`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool100000000
6`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`800000nP3oool2000000006`3oool0
0`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0
oooo00<000000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?oo
o`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool100000000
6`3oool200000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool0
0`000000oooo0?ooo`3j0?ooo`40000000080?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`<000001@3oool00`000000oooo0?ooo`3j0?ooo`40000000070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3j0?ooo`40000000070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000000@0oooo0`3o003]0?oo
o`80<ol00`3oool3000000001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool50?l00>D0oooo0`0co`070?ooo`40000000070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`D0o`00gP3oool203?o00X0oooo0@00000000L0oooo00@000000?ooo`3oool00000203oool20000
00H0oooo00<000000?ooo`3oool0403oool50?l00=H0oooo0`0co`0<0?ooo`40000000080?ooo`80
00002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo1P3o003>0?ooo`80
<ol03`3oool1000000006`3oool2000001`0oooo1@3o00360?ooo`<0<ol0403oool2000000006`3o
ool00`000000oooo0?ooo`0P0?ooo`D0o`00_`3oool203?o01@0oooo0@00000001/0oooo00<00000
0?ooo`3oool09@3oool50?l00;L0oooo0`0co`0F0?ooo`400000000K0?ooo`030000003oool0oooo
02X0oooo1@3o002`0?ooo`80<ol06@3oool1000000006`3oool00`000000oooo0?ooo`0_0?ooo`D0
o`00Z03oool303?o01/0oooo0@00000001/0oooo0P00000e0?ooo`D0o`00X@3oool203?o01d0oooo
0P00000001/0oooo00<000000?ooo`3oool0>@3oool50?l009T0oooo0`0co`0P0?ooo`400000000K
0?ooo`030000003oool0oooo03h0oooo1@3o002B0?ooo`80<ol08`3oool1000000006`3oool00`00
0000oooo0?ooo`130?ooo`D0o`00RP3oool303?o02D0oooo0@00000001/0oooo00<000000?ooo`3o
ool0B03oool50?l008<0oooo0P0co`0X0?ooo`400000000K0?ooo`800000CP3oool50?l007/0oooo
0`0co`0Y0?ooo`800000000K0?ooo`030000003oool0oooo0580oooo1@3o001d0?ooo`80<ol0;@3o
ool1000000006`3oool00`000000oooo0?ooo`1G0?ooo`D0o`00K03oool303?o02l0oooo0@000000
01/0oooo00<000000?ooo`3oool0G03oool50?l006@0oooo0`0co`0b0?ooo`400000000K0?ooo`80
0000HP3oool50?l005`0oooo0`0co`0d0?ooo`800000000K0?ooo`030000003oool0oooo06H0oooo
1P3o001D0?ooo`80<ol0>03oool1000000006`3oool00`000000oooo0?ooo`1/0?ooo`D0o`00C@3o
ool203?o03X0oooo0@0000000080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`000003
0?ooo`<000001@3oool00`000000oooo0?ooo`1a0?ooo`@0o`00AP3oool303?o03`0oooo0@000000
00050?ooo`000000oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`D0o`00?`3oool203?o03l0oooo0@00
000000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo0P00001k0?ooo`D0o`00>03oool203?o03l0oooo0`00000000050?ooo`000000
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0O`3oool50?l00300oooo0`0co`130?ooo`40000000001@3oool000000?ooo`3o
ool0000000T0oooo00@000000?ooo`3oool0oooo100000050?ooo`030000003oool0oooo08@0oooo
1@3o000X0?ooo`<0<ol0AP3oool10000000000D0oooo0000003oool0oooo000000080?ooo`800000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08T0oooo1@3o000P0?ooo`<0<ol0
B@3oool1000000000P3oool2000000X0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000
003oool0oooo08h0oooo1@3o000I0?ooo`80<ol0C03oool1000000006`3oool2000009@0oooo1@3o
000B0?ooo`80<ol0C@3oool2000000006`3oool00`000000oooo0?ooo`2H0?ooo`H0o`002@3oool3
03?o0500oooo0@00000001/0oooo00<000000?ooo`3oool0WP3oool50?l00080oooo0P0co`1C0?oo
o`400000000K0?ooo`030000003oool0oooo0:<0oooo0P0co`020?l005<0oooo0@00000001/0oooo
00<000000?ooo`3oool0X03oool303?o00@0oooo1@3o001>0?ooo`400000000K0?ooo`800000W`3o
ool203?o00`0oooo1@3o00180?ooo`800000000K0?ooo`030000003oool0oooo09/0oooo0`0co`0C
0?ooo`D0o`00A03oool1000000006`3oool00`000000oooo0?ooo`2I0?ooo`80<ol06`3oool50?l0
03l0oooo0@00000001/0oooo00<000000?ooo`3oool0UP3oool303?o0280oooo1@3o000j0?ooo`40
0000000K0?ooo`030000003oool0oooo09<0oooo0`0co`0Z0?ooo`D0o`00=@3oool1000000006`3o
ool200000940oooo0`0co`0b0?ooo`D0o`00;`3oool2000000006`3oool00`000000oooo0?ooo`2>
0?ooo`80<ol0>P3oool60?l002X0oooo0@00000001/0oooo00<000000?ooo`3oool0R`3oool303?o
0480oooo1@3o000U0?ooo`400000000K0?ooo`030000003oool0oooo08T0oooo0P0co`1:0?ooo`D0
o`00803oool1000000006`3oool2000008L0oooo0`0co`1A0?ooo`D0o`006P3oool2000000006`3o
ool00`000000oooo0?ooo`240?ooo`80<ol0F@3oool50?l001H0oooo0@00000001/0oooo00<00000
0?ooo`3oool0P@3oool303?o0600oooo1@3o000A0?ooo`40000000080?ooo`800000103oool01000
0000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0O`3oool203?o06P0oooo1@3o000<
0?ooo`40000000070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1l0?ooo`<0<ol0K`3oool50?l000L0oooo0@00000000L0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000N`3oool203?o07L0oooo0P3o
00030?ooo`<0000000070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1h0?ooo`80<ol0P03oool1000000001`3oool010000000oooo0?ooo`00
00070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1e0?ooo`<0<ol0
PP3oool1000000001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`1c0?ooo`80<ol0Q@3oool100000000203oool2000000T0oooo
0`0000050?ooo`030000003oool0oooo0740oooo0P0co`270?ooo`400000000K0?ooo`800000K`3o
ool303?o08P0oooo0P00000001/0oooo00<000000?ooo`3oool0K03oool203?o08`0oooo0@000000
01/0oooo00<000000?ooo`3oool0J@3oool303?o08h0oooo0@00000001/0oooo00<000000?ooo`3o
ool0I`3oool203?o0940oooo0@00000001/0oooo00<000000?ooo`3oool0I03oool303?o09<0oooo
0@00000001/0oooo0P00001R0?ooo`<0<ol0U@3oool2000000006`3oool00`000000oooo0?ooo`1N
0?ooo`<0<ol0V@3oool1000000006`3oool00`000000oooo0?ooo`1L0?ooo`80<ol0W03oool10000
00006`3oool00`000000oooo0?ooo`1J0?ooo`80<ol0WP3oool1000000006`3oool00`000000oooo
0?ooo`1G0?ooo`<0<ol0X03oool1000000006`3oool2000005H0oooo0P0co`2R0?ooo`800000000K
0?ooo`030000003oool0oooo05<0oooo0P0co`2U0?ooo`400000000K0?ooo`030000003oool0oooo
0500oooo0`0co`2W0?ooo`400000000K0?ooo`030000003oool0oooo04d0oooo0`0co`2Z0?ooo`40
0000000K0?ooo`800000B`3oool303?o0:`0oooo0P00000001/0oooo00<000000?ooo`3oool0B03o
ool203?o0;00oooo0@00000001/0oooo00<000000?ooo`3oool0A@3oool303?o0;80oooo0@000000
0080oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000D0oooo00<00000
0?ooo`3oool0@`3oool203?o0;D0oooo0@00000000050?ooo`000000oooo0?ooo`000000203oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`100?ooo`<0<ol0]`3oool10000000000D0oooo0000003oool0oooo000000090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000003l0oooo0P0co`2h0?ooo`<00000
00001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03/0oooo0`0co`2l0?ooo`40000000001@3oool000000?oo
o`3oool0000000L0oooo00H000000?ooo`3oool0oooo0000003oool4000000D0oooo00<000000?oo
o`3oool0>@3oool203?o0;l0oooo0@00000000050?ooo`000000oooo0?ooo`0000001`3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo0?ooo`0f0?ooo`<0<ol0`@3o
ool1000000000P3oool2000000T0oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`0d
0?ooo`80<ol0a03oool1000000006`3oool200000380oooo0`0co`350?ooo`800000000K0?ooo`03
0000003oool0oooo02l0oooo0P0co`390?ooo`400000000K0?ooo`030000003oool0oooo02`0oooo
0`0co`3;0?ooo`400000000K0?ooo`030000003oool0oooo02X0oooo0P0co`3>0?ooo`400000000K
0?ooo`030000003oool0oooo02L0oooo0`0co`3@0?ooo`400000000K0?ooo`8000009P3oool203?o
0=80oooo0P00000001/0oooo00<000000?ooo`3oool08P3oool303?o0=D0oooo0@00000001/0oooo
00<000000?ooo`3oool0803oool203?o0=P0oooo0@00000001/0oooo00<000000?ooo`3oool07@3o
ool303?o0=X0oooo0@00000001/0oooo00<000000?ooo`3oool06`3oool203?o0=d0oooo0@000000
01/0oooo0P00000I0?ooo`<0<ol0gP3oool2000000006`3oool00`000000oooo0?ooo`0F0?ooo`80
<ol0hP3oool1000000006`3oool00`000000oooo0?ooo`0C0?ooo`<0<ol0i03oool1000000006`3o
ool00`000000oooo0?ooo`0@0?ooo`<0<ol0i`3oool1000000006`3oool2000000h0oooo0`0co`3Y
0?ooo`800000000K0?ooo`030000003oool0oooo00/0oooo0P0co`3]0?ooo`400000000K0?ooo`03
0000003oool0oooo00T0oooo0P0co`3_0?ooo`40000000080?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`060?ooo`<0<ol0l@3oool1000000001`3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`80<ol0m03oool1000000001`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`0303?o003oool0oooo0?80oooo0`00000000L0oooo
00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3oool0nP3oool100000000
1`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool00`3oool1000000001`3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000080?ooo`8000002@3oool3000000D0
oooooP0000000?l0oooo6P3oool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.938, 0}} -> {-1.37678, -0.046746, \
0.0414781, 0.0020805}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.041298 1.8797 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0413 -6 -4.5 ]
[-0.0125 .0413 0 4.5 ]
[-0.0125 .13528 -24 -4.5 ]
[-0.0125 .13528 0 4.5 ]
[-0.0125 .22927 -18 -4.5 ]
[-0.0125 .22927 0 4.5 ]
[-0.0125 .32325 -24 -4.5 ]
[-0.0125 .32325 0 4.5 ]
[-0.0125 .41724 -18 -4.5 ]
[-0.0125 .41724 0 4.5 ]
[-0.0125 .51122 -24 -4.5 ]
[-0.0125 .51122 0 4.5 ]
[-0.0125 .60521 -18 -4.5 ]
[-0.0125 .60521 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0413 m
.00625 .0413 L
s
[(0)] -0.0125 .0413 1 0 Mshowa
0 .13528 m
.00625 .13528 L
s
[(0.05)] -0.0125 .13528 1 0 Mshowa
0 .22927 m
.00625 .22927 L
s
[(0.1)] -0.0125 .22927 1 0 Mshowa
0 .32325 m
.00625 .32325 L
s
[(0.15)] -0.0125 .32325 1 0 Mshowa
0 .41724 m
.00625 .41724 L
s
[(0.2)] -0.0125 .41724 1 0 Mshowa
0 .51122 m
.00625 .51122 L
s
[(0.25)] -0.0125 .51122 1 0 Mshowa
0 .60521 m
.00625 .60521 L
s
[(0.3)] -0.0125 .60521 1 0 Mshowa
.125 Mabswid
0 .06009 m
.00375 .06009 L
s
0 .07889 m
.00375 .07889 L
s
0 .09769 m
.00375 .09769 L
s
0 .11649 m
.00375 .11649 L
s
0 .15408 m
.00375 .15408 L
s
0 .17288 m
.00375 .17288 L
s
0 .19167 m
.00375 .19167 L
s
0 .21047 m
.00375 .21047 L
s
0 .24807 m
.00375 .24807 L
s
0 .26686 m
.00375 .26686 L
s
0 .28566 m
.00375 .28566 L
s
0 .30446 m
.00375 .30446 L
s
0 .34205 m
.00375 .34205 L
s
0 .36085 m
.00375 .36085 L
s
0 .37964 m
.00375 .37964 L
s
0 .39844 m
.00375 .39844 L
s
0 .43604 m
.00375 .43604 L
s
0 .45483 m
.00375 .45483 L
s
0 .47363 m
.00375 .47363 L
s
0 .49243 m
.00375 .49243 L
s
0 .53002 m
.00375 .53002 L
s
0 .54882 m
.00375 .54882 L
s
0 .56761 m
.00375 .56761 L
s
0 .58641 m
.00375 .58641 L
s
0 .0225 m
.00375 .0225 L
s
0 .0037 m
.00375 .0037 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0413 m
1 .0413 L
s
.99375 .13528 m
1 .13528 L
s
.99375 .22927 m
1 .22927 L
s
.99375 .32325 m
1 .32325 L
s
.99375 .41724 m
1 .41724 L
s
.99375 .51122 m
1 .51122 L
s
.99375 .60521 m
1 .60521 L
s
.125 Mabswid
.99625 .06009 m
1 .06009 L
s
.99625 .07889 m
1 .07889 L
s
.99625 .09769 m
1 .09769 L
s
.99625 .11649 m
1 .11649 L
s
.99625 .15408 m
1 .15408 L
s
.99625 .17288 m
1 .17288 L
s
.99625 .19167 m
1 .19167 L
s
.99625 .21047 m
1 .21047 L
s
.99625 .24807 m
1 .24807 L
s
.99625 .26686 m
1 .26686 L
s
.99625 .28566 m
1 .28566 L
s
.99625 .30446 m
1 .30446 L
s
.99625 .34205 m
1 .34205 L
s
.99625 .36085 m
1 .36085 L
s
.99625 .37964 m
1 .37964 L
s
.99625 .39844 m
1 .39844 L
s
.99625 .43604 m
1 .43604 L
s
.99625 .45483 m
1 .45483 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .49243 m
1 .49243 L
s
.99625 .53002 m
1 .53002 L
s
.99625 .54882 m
1 .54882 L
s
.99625 .56761 m
1 .56761 L
s
.99625 .58641 m
1 .58641 L
s
.99625 .0225 m
1 .0225 L
s
.99625 .0037 m
1 .0037 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.007 w
.02381 .60332 m
.06244 .58794 L
.10458 .57116 L
.14415 .55537 L
.18221 .54016 L
.22272 .52393 L
.26171 .50825 L
.30316 .49153 L
.34309 .47532 L
.3815 .45959 L
.42237 .44264 L
.46172 .42594 L
.49955 .4092 L
.53984 .38938 L
.55838 .37775 L
.5608 .37582 L
.56342 .37345 L
.56462 .37221 L
.56589 .37072 L
.56817 .367 L
.56943 .36339 L
.57014 .36332 L
.57078 .36326 L
.57226 .36311 L
.57365 .36298 L
.57861 .36249 L
.58957 .36141 L
.59975 .3604 L
.61984 .35842 L
.65968 .35449 L
.69801 .35071 L
.7174 .34879 L
.72769 .34778 L
.7331 .34724 L
.73879 .34668 L
.74384 .34618 L
.74522 .34605 L
.7467 .3459 L
.74741 .34583 L
.74809 .34576 L
.74936 .342 L
.75053 .33986 L
.75178 .33818 L
.75401 .33575 L
.75905 .33144 L
.77806 .31954 L
.81595 .30086 L
.85629 .28299 L
.89511 .26652 L
.93639 .2494 L
Mistroke
.97615 .23312 L
.97619 .23311 L
Mfstroke
1 .6 0 r
.02381 .0413 m
.06244 .0413 L
.10458 .0413 L
.14415 .0413 L
.18221 .0413 L
.22272 .0413 L
.26171 .0413 L
.30316 .0413 L
.34309 .0413 L
.3815 .0413 L
.42237 .0413 L
.46172 .0413 L
.49955 .0413 L
.52059 .0413 L
.53984 .0413 L
.54934 .0413 L
.55436 .0413 L
.55972 .0413 L
.56236 .0413 L
.56486 .0413 L
.56709 .0413 L
.56835 .0413 L
.56951 .03829 L
.57061 .0362 L
.57162 .03485 L
.57394 .03255 L
.57619 .03083 L
.57861 .0293 L
.58878 .02463 L
.59453 .02271 L
.59985 .02123 L
.60961 .01905 L
.61997 .01732 L
.62934 .01618 L
.63461 .01569 L
.63944 .01534 L
.6437 .01509 L
.64835 .01489 L
.6507 .01482 L
.65199 .01479 L
.6532 .01477 L
.65434 .01475 L
.65557 .01473 L
.65669 .01472 L
.65772 .01472 L
.65898 .01472 L
.66016 .01472 L
.66123 .01473 L
.6624 .01474 L
.66366 .01476 L
Mistroke
.665 .01478 L
.66742 .01484 L
.66987 .01492 L
.67218 .01501 L
.67649 .01524 L
.68166 .0156 L
.68641 .01601 L
.69713 .01727 L
.70689 .01886 L
.71599 .02082 L
.72597 .02368 L
.73157 .02575 L
.73667 .0281 L
.74673 .03601 L
.74792 .03822 L
.74917 .0413 L
.74983 .0413 L
.75055 .0413 L
.7518 .0413 L
.75469 .0413 L
.7574 .0413 L
.77656 .0413 L
.81494 .0413 L
.85556 .0413 L
.89466 .0413 L
.93621 .0413 L
.97619 .0413 L
Mfstroke
.8 1 0 r
.02381 .23116 m
.06244 .23891 L
.10458 .24738 L
.14415 .25536 L
.18221 .26306 L
.22272 .27129 L
.26171 .27927 L
.30316 .28781 L
.34309 .29614 L
.3815 .30429 L
.42237 .31318 L
.46172 .32211 L
.49955 .33138 L
.52059 .33713 L
.53984 .34324 L
.55972 .352 L
.56217 .35359 L
.56346 .35455 L
.56482 .3557 L
.56601 .35689 L
.56732 .35854 L
.56851 .36089 L
.56963 .36337 L
.57079 .36326 L
.57189 .36315 L
.57396 .36295 L
.57861 .36249 L
.5882 .36154 L
.59842 .36053 L
.6168 .35872 L
.65513 .35494 L
.69592 .35091 L
.71617 .34891 L
.72609 .34793 L
.73518 .34704 L
.74403 .34616 L
.74618 .34595 L
.74737 .34583 L
.74848 .34572 L
.7498 .3501 L
.751 .35177 L
.75335 .35408 L
.75572 .35587 L
.75824 .35746 L
.76275 .35986 L
.77293 .3642 L
.81082 .37591 L
.85116 .38598 L
.88998 .39485 L
.93126 .40387 L
Mistroke
.97102 .41231 L
.97619 .4134 L
Mfstroke
.2 1 0 r
.02381 .0413 m
.06244 .0413 L
.10458 .0413 L
.14415 .0413 L
.18221 .0413 L
.22272 .0413 L
.26171 .0413 L
.30316 .0413 L
.34309 .0413 L
.3815 .0413 L
.42237 .0413 L
.46172 .0413 L
.49955 .0413 L
.52059 .0413 L
.53984 .0413 L
.54934 .0413 L
.55436 .0413 L
.55972 .0413 L
.56236 .0413 L
.56486 .0413 L
.56709 .0413 L
.56835 .0413 L
.56951 .0443 L
.57061 .0464 L
.57162 .04775 L
.57394 .05004 L
.57619 .05177 L
.57861 .0533 L
.58878 .05797 L
.59453 .05988 L
.59985 .06137 L
.60961 .06355 L
.61997 .06528 L
.62934 .06642 L
.63461 .0669 L
.63944 .06726 L
.6437 .06751 L
.64835 .0677 L
.6507 .06777 L
.65199 .06781 L
.6532 .06783 L
.65434 .06785 L
.65557 .06786 L
.65669 .06787 L
.65772 .06788 L
.65898 .06788 L
.66016 .06788 L
.66123 .06787 L
.6624 .06786 L
.66366 .06784 L
Mistroke
.665 .06782 L
.66742 .06776 L
.66987 .06768 L
.67218 .06758 L
.67649 .06736 L
.68166 .067 L
.68641 .06659 L
.69713 .06533 L
.70689 .06373 L
.71599 .06177 L
.72597 .05891 L
.73157 .05684 L
.73667 .0545 L
.74673 .04659 L
.74792 .04437 L
.74917 .0413 L
.74983 .0413 L
.75055 .0413 L
.7518 .0413 L
.75469 .0413 L
.7574 .0413 L
.77656 .0413 L
.81494 .0413 L
.85556 .0413 L
.89466 .0413 L
.93621 .0413 L
.97619 .0413 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00803oool2000002`0oooo1@00000]0?ooo`<00000;03oool3000002h0
oooo0`00000Z0?ooo`<00000103oool2000000<0oooo000O0?ooo`040000003oool0oooo000002`0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo
0?ooo`000000;03oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000]0?ooo`030000
003oool0oooo02/0oooo1@00000[0?ooo`050000003oool0oooo0?ooo`000000;03oool01@000000
oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`007`3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo02X0oooo00@00000
0?ooo`3oool00000;03oool4000002h0oooo0`00000[0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool00000:`3oool01@000000oooo
0?ooo`3oool0000002`0oooo00<000000?ooo`000000;03oool00`000000oooo0?ooo`0^0?ooo`05
0000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo000O0?ooo`040000003oool0oooo000002/0oooo00D000000?ooo`3oool0oooo0000
000]0?ooo`800000;@3oool00`000000oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`000000
:@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool00200oooo0P00000]0?ooo`<00000
;`3oool00`000000oooo0?ooo`0/0?ooo`800000;P3oool3000002/0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0oooo003o0?oooaX0
oooo000K0?ooooh00000000K0?ooo`800000103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000006`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`03
0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3o
ool0V`3ooolB0?nI04d0oooo0@00000001/0oooo00<000000?ooo`3oool0UP3oool50?nI0180oooo
1@3oV@180?ooo`400000000K0?ooo`800000TP3oool50?nI01`0oooo103oV@130?ooo`800000000K
0?ooo`030000003oool0oooo0900oooo00<0oiT00?ooo`3oool08`3oool30?nI0440oooo0@000000
01@0oooo0P0000050?ooo`030000003oool0oooo08h0oooo0P3oV@0Y0?ooo`030?nI003oool0oooo
03h0oooo0@00000001<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2=0?oo
o`030?nI003oool0oooo02X0oooo00<0oiT00?ooo`3oool0?@3oool1000000004`3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo08d0oooo00<0oiT00?ooo`3oool0:P3oool00`3o
V@00oooo0?ooo`0m0?ooo`400000000C0?ooo`040000003oool0oooo000000@0oooo0P0000040?oo
oh/0<ol0;03ooolk03?o00<0oooo0`00000001<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`2=0?ooo`0303?o003oool0oooo02T0oooo0P0co`0o0?ooo`400000000C0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0SP3oool203?o02P0oooo00<0<ol00?oo
o`3oool0?`3oool100000000503oool2000000D0oooo00<000000?ooo`3oool0S`3oool303?o02D0
oooo00<0<ol00?ooo`3oool0@03oool1000000006`3oool2000009<0oooo0`0co`0N0?ooo`@0<ol0
@P3oool2000000006`3oool00`000000oooo0?ooo`2E0?ooo`D0<ol05@3oool403?o04L0oooo0@00
000001/0oooo00<000000?ooo`3oool0VP3ooolE03?o04/0oooo0@00000001/0oooo00<000000?oo
o`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`800000
nP3oool2000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0
oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000
oooo0?ooo`3j0?ooo`400000000K0?ooo`800000nP3oool2000000006`3oool00`000000oooo0?oo
o`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<000000?oo
o`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`800000
nP3oool2000000006`3oool00`000000oooo0?ooo`3j0?ooo`40000000020?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0nP3oool1
0000000000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?X0oooo0@00000000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0nP3oool10000000000D0oooo0000003oool0oooo000000080?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool200000?T0oooo0`0000000005
0?ooo`000000oooo0?ooo`000000203oool01@000000oooo0?ooo`000000oooo00@000001@3oool0
0`000000oooo0?ooo`3j0?ooo`40000000001@3oool000000?ooo`3oool0000000P0oooo00H00000
0?ooo`3oool000000?ooo`0000080?ooo`030000003oool0oooo0?X0oooo0@0000000080oooo0P00
000:0?ooo`8000000P3oool5000000@0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool2
00000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000
oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<000000?oo
o`3oool0nP3oool1000000006`3oool00`000000oooo0?ooo`3j0?ooo`400000000K0?ooo`030000
003oool0oooo0?X0oooo0@00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool2
00000?X0oooo0P00000001/0oooo00<000000?ooo`3oool0nP3oool1000000006`3oool00`000000
oooo0?ooo`3j0?ooo`400000000K0?ooo`030000003oool0oooo0?X0oooo0@00000001/0oooo00<0
00000?ooo`3oool0nP3oool1000000006`3oool200000?X0oooo0P00000001/0oooo00<000000?oo
o`3oool0nP3oool100000000203oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0
oooo00<000000?ooo`3oool0nP3oool1000000001`3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0nP3oool1000000001`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0P00003i0?ooo`<0000000070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`<0
c?l0k@3oool20?l000D0oooo0@00000000L0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo1@3<o`3U0?ooo`@0o`001P3oool100000000
1`3oool010000000oooo0?ooo`0000080?ooo`8000001P3oool00`000000oooo0?ooo`0;0?ooo`D0
c?l0gP3oool20?l000X0oooo0@00000000P0oooo0P00000:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0403oool50<co0=H0oooo0`3o000<0?ooo`400000000K0?ooo`8000005P3o
ool60<co0<h0oooo0P3o000>0?ooo`800000000K0?ooo`030000003oool0oooo01/0oooo1@3<o`37
0?ooo`80o`004@3oool1000000006`3oool00`000000oooo0?ooo`0P0?ooo`D0c?l0_`3oool30?l0
01<0oooo0@00000001/0oooo00<000000?ooo`3oool09@3oool50<co0;P0oooo0P3o000F0?ooo`40
0000000K0?ooo`030000003oool0oooo02X0oooo1@3<o`2a0?ooo`80o`00603oool1000000006`3o
ool200000300oooo1@3<o`2Z0?ooo`80o`006@3oool2000000006`3oool00`000000oooo0?ooo`0d
0?ooo`D0c?l0XP3oool30?l001`0oooo0@00000001/0oooo00<000000?ooo`3oool0>@3oool50<co
09/0oooo0P3o000O0?ooo`400000000K0?ooo`030000003oool0oooo03h0oooo1@3<o`2C0?ooo`<0
o`008@3oool1000000006`3oool00`000000oooo0?ooo`130?ooo`D0c?l0S03oool20?l002@0oooo
0@00000001/0oooo0P0000190?ooo`D0c?l0Q03oool30?l002D0oooo0P00000001/0oooo00<00000
0?ooo`3oool0C@3oool50<co07d0oooo0P3o000Y0?ooo`400000000K0?ooo`030000003oool0oooo
0580oooo1@3<o`1e0?ooo`<0o`00:`3oool1000000006`3oool00`000000oooo0?ooo`1G0?ooo`D0
c?l0KP3oool20?l002h0oooo0@00000001/0oooo0P00001M0?ooo`@0c?l0J03oool20?l002l0oooo
0P00000001/0oooo00<000000?ooo`3oool0H03oool40<co0680oooo0P3o000b0?ooo`400000000K
0?ooo`030000003oool0oooo06@0oooo0`3<o`1N0?ooo`030?l0003oool0oooo0380oooo0@000000
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`<000001@3oool00`00
0000oooo0?ooo`1W0?ooo`D0c?l0E`3oool20?l003D0oooo0@00000000050?ooo`000000oooo0?oo
o`0000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1/0?ooo`D0c?l0D03oool20?l003L0oooo0@00000000050?ooo`000000oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00001b
0?ooo`@0c?l0BP3oool20?l003L0oooo0`00000000050?ooo`000000oooo0?ooo`0000002@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool5
0<co04@0oooo00<0o`000?ooo`3oool0>@3oool10000000000D0oooo0000003oool0oooo00000009
0?ooo`040000003oool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`1j0?ooo`<0c?l0@03o
ool00`3o0000oooo0?ooo`0j0?ooo`40000000001@3oool000000?ooo`3oool0000000P0oooo0P00
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0O@3oool30<co03`0oooo00<0
o`000?ooo`3oool0>`3oool1000000000P3oool2000000X0oooo00@000000?ooo`3oool0oooo1@00
00040?ooo`030000003oool0oooo0800oooo103<o`0g0?ooo`030?l0003oool0oooo03`0oooo0@00
000001/0oooo0P0000250?ooo`<0c?l0<`3oool00`3o0000oooo0?ooo`0l0?ooo`800000000K0?oo
o`030000003oool0oooo08L0oooo0`3<o`0Y0?ooo`P0c?l0?`3oool1000000006`3oool00`000000
oooo0?ooo`2:0?ooo`030<co003oool0oooo01/0oooo2`3<o`000`3o0000oooo0?ooo`040?ooo`80
c?l0?P3oool1000000006`3oool00`000000oooo0?ooo`2;0?ooo`80c?l04@3oool:0<co00030?l0
003oool0oooo0100oooo0P3<o`0m0?ooo`400000000K0?ooo`030000003oool0oooo08`0oooo00<0
c?l00?ooo`3oool0103oool40?l000L0c?l000<0o`000?ooo`3oool0703oool30<co03X0oooo0@00
000001/0oooo0P00002>0?ooo`X0c?l0:@3oool30<co03H0oooo0P00000001/0oooo00<000000?oo
o`3oool0S03oool00`3o0000oooo0?ooo`0d0?ooo`<0c?l0=03oool1000000006`3oool00`000000
oooo0?ooo`2<0?ooo`030?l0003oool0oooo03L0oooo0`3<o`0a0?ooo`400000000K0?ooo`030000
003oool0oooo08/0oooo00<0o`000?ooo`3oool0>`3oool40<co02d0oooo0@00000001/0oooo0P00
002:0?ooo`80o`00@P3oool30<co02T0oooo0P00000001/0oooo00<000000?ooo`3oool0Q`3oool2
0?l004L0oooo0`3<o`0W0?ooo`400000000K0?ooo`030000003oool0oooo08H0oooo00<0o`000?oo
o`3oool0BP3oool50<co0280oooo0@00000001/0oooo00<000000?ooo`3oool0Q03oool20?l00580
oooo1@3<o`0M0?ooo`400000000K0?ooo`030000003oool0oooo0880oooo0P3o001I0?ooo`D0c?l0
603oool1000000006`3oool200000840oooo0P3o001P0?ooo`D0c?l04P3oool2000000006`3oool0
0`000000oooo0?ooo`1n0?ooo`80o`00I`3oool40<co00l0oooo0@00000000P0oooo0P0000040?oo
o`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`1l0?ooo`80o`00K@3oool3
0<co00`0oooo0@00000000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo07X0oooo0P3o001b0?ooo`<0c?l02@3oool1000000001`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0N03o
ool20?l007L0oooo103<o`050?ooo`40000000070?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool00`3oool2000007H0oooo0`3o00200?ooo`<0000000070?ooo`040000003oool0
oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07<0oooo
0P3o00250?ooo`40000000070?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0740oooo0P3o00270?ooo`40000000080?ooo`800000
2@3oool3000000D0oooo00<000000?ooo`3oool0KP3oool30?l008T0oooo0@00000001/0oooo00<0
00000?ooo`3oool0K03oool20?l008`0oooo0@00000001/0oooo0P00001Z0?ooo`<0o`00S@3oool2
000000006`3oool00`000000oooo0?ooo`1W0?ooo`80o`00T@3oool1000000006`3oool00`000000
oooo0?ooo`1U0?ooo`80o`00T`3oool1000000006`3oool00`000000oooo0?ooo`1R0?ooo`<0o`00
U@3oool1000000006`3oool200000640oooo0P3o002G0?ooo`800000000K0?ooo`030000003oool0
oooo05h0oooo0P3o002J0?ooo`400000000K0?ooo`030000003oool0oooo05`0oooo0P3o002L0?oo
o`400000000K0?ooo`030000003oool0oooo05X0oooo0P3o002N0?ooo`400000000K0?ooo`030000
003oool0oooo05L0oooo0`3o002P0?ooo`400000000K0?ooo`800000EP3oool20?l00:80oooo0P00
000001/0oooo00<000000?ooo`3oool0D`3oool20?l00:D0oooo0@00000001/0oooo00<000000?oo
o`3oool0D03oool30?l00:L0oooo0@00000001/0oooo00<000000?ooo`3oool0C@3oool30?l00:X0
oooo0@00000001/0oooo00<000000?ooo`3oool0BP3oool30?l00:d0oooo0@00000001/0oooo0P00
00190?ooo`80o`00[`3oool2000000006`3oool00`000000oooo0?ooo`150?ooo`<0o`00/P3oool1
000000000P3oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<000001@3oool0
0`000000oooo0?ooo`130?ooo`80o`00]@3oool10000000000D0oooo0000003oool0oooo00000008
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0400oooo0`3o002g0?ooo`40000000001@3oool000000?ooo`3oool0000000T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo
0P3o002j0?ooo`40000000001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`800000?03oool30?l00;X0oooo0`00000000050?ooo`00
0000oooo0?ooo`0000001`3oool01P000000oooo0?ooo`3oool000000?ooo`@000001@3oool00`00
0000oooo0?ooo`0i0?ooo`80o`00_`3oool10000000000D0oooo0000003oool0oooo000000070?oo
o`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo03H0oooo0`3o
00310?ooo`40000000020?ooo`8000002@3oool300000080oooo1@0000040?ooo`030000003oool0
oooo03@0oooo0P3o00340?ooo`400000000K0?ooo`800000<P3oool30?l00<D0oooo0P00000001/0
oooo00<000000?ooo`3oool0;`3oool20?l00<T0oooo0@00000001/0oooo00<000000?ooo`3oool0
;03oool30?l00</0oooo0@00000001/0oooo00<000000?ooo`3oool0:P3oool20?l00<h0oooo0@00
000001/0oooo00<000000?ooo`3oool09`3oool30?l00=00oooo0@00000001/0oooo0P00000V0?oo
o`80o`00dP3oool2000000006`3oool00`000000oooo0?ooo`0R0?ooo`<0o`00e@3oool100000000
6`3oool00`000000oooo0?ooo`0P0?ooo`80o`00f03oool1000000006`3oool00`000000oooo0?oo
o`0M0?ooo`<0o`00fP3oool1000000006`3oool00`000000oooo0?ooo`0K0?ooo`80o`00g@3oool1
000000006`3oool2000001T0oooo0`3o003N0?ooo`800000000K0?ooo`030000003oool0oooo01H0
oooo0P3o003R0?ooo`400000000K0?ooo`030000003oool0oooo01<0oooo0`3o003T0?ooo`400000
000K0?ooo`030000003oool0oooo0100oooo0`3o003W0?ooo`400000000K0?ooo`030000003oool0
oooo00d0oooo0`3o003Z0?ooo`400000000K0?ooo`800000303oool20?l00>`0oooo0P00000001/0
oooo00<000000?ooo`3oool02@3oool20?l00>l0oooo0@00000000P0oooo0P0000040?ooo`030000
003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo00H0oooo0`3o003a0?ooo`400000
00070?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00@0oooo0P3o003d0?ooo`40000000070?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<0o`000?ooo`3oool0lP3oool300000000
1`3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`3j0?ooo`40
000000070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`030?ooo`40000000070?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0@00000000P0oooo0P0000090?ooo`<0
00001@3oooon00000000o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.938, 0}} -> {-1.37678, -0.0507572, \
0.0414781, 0.00210156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Missing data and ML;  n= 10", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
SeedRandom[9999];

n = 10;
Y0 = {1,2};
Y0 = Shape[1,{n}]/. (1->Y0)
T = 100;
dt = 10.^-1;

Theta = {.1,-.01,.02,.3,.01,-.02}*100;  (*scaling in f !!*)
      (*{lambda11_,lambda12_,lambda21_,lambda22_,alpha_,beta_}*)

k = 2;
p = 2;
q = 1;
X = Shape[1,{n}]/. 1->Shape[dt Range[0,T],{T+1,q}];
Nonlin = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 2}, {1, 
        2}, {1, 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["panel data",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell["\<\
{Z,Y} = MapThread[NonLinStateSpace[h,{R,const},drift,diffusion,
\t                    #1,#2,T,dt,Theta,Gauss,EulerStep]&,{Y0,X}]//Transpose;//\
Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({1.0999999999999943`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Z\)\(//\)\(Dimensions\)\(\ \)\( (*\ 
        N\ x\ T1\ x\ k*) \)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
plot1[Z//flatten[#,{1,3}]&//Transpose//AddTimeAxis,dicke->0.007,\
farbmodell->Hue]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 21}\),
      SequenceForm[ "Dimension der Daten  ", {101, 21}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.0212878 0.0379809 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07366 -18 -4.5 ]
[-0.0125 .07366 0 4.5 ]
[-0.0125 .16862 -6 -4.5 ]
[-0.0125 .16862 0 4.5 ]
[-0.0125 .26357 -18 -4.5 ]
[-0.0125 .26357 0 4.5 ]
[-0.0125 .35852 -12 -4.5 ]
[-0.0125 .35852 0 4.5 ]
[-0.0125 .45347 -24 -4.5 ]
[-0.0125 .45347 0 4.5 ]
[-0.0125 .54842 -12 -4.5 ]
[-0.0125 .54842 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.97619 .10412 -5 -6 ]
[.97619 .10412 5 6 ]
[.97619 .59268 -5 -6 ]
[.97619 .59268 5 6 ]
[.97619 .08556 -5 -6 ]
[.97619 .08556 5 6 ]
[.97619 .53057 -5 -6 ]
[.97619 .53057 5 6 ]
[.97619 .10907 -5 -6 ]
[.97619 .10907 5 6 ]
[.97619 .59327 -5 -6 ]
[.97619 .59327 5 6 ]
[.97619 .10674 -5 -6 ]
[.97619 .10674 5 6 ]
[.97619 .58131 -5 -6 ]
[.97619 .58131 5 6 ]
[.97619 .09345 -5 -6 ]
[.97619 .09345 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .09592 -5 -6 ]
[.97619 .09592 5 6 ]
[.97619 .54961 -5 -6 ]
[.97619 .54961 5 6 ]
[.97619 .10354 -5 -6 ]
[.97619 .10354 5 6 ]
[.97619 .54937 -5 -6 ]
[.97619 .54937 5 6 ]
[.97619 .09403 -5 -6 ]
[.97619 .09403 5 6 ]
[.97619 .57498 -5 -6 ]
[.97619 .57498 5 6 ]
[.97619 .09156 -5 -6 ]
[.97619 .09156 5 6 ]
[.97619 .58622 -5 -6 ]
[.97619 .58622 5 6 ]
[.97619 .09089 -5 -6 ]
[.97619 .09089 5 6 ]
[.97619 .55089 -5 -6 ]
[.97619 .55089 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07366 m
.00625 .07366 L
s
[(2.5)] -0.0125 .07366 1 0 Mshowa
0 .16862 m
.00625 .16862 L
s
[(5)] -0.0125 .16862 1 0 Mshowa
0 .26357 m
.00625 .26357 L
s
[(7.5)] -0.0125 .26357 1 0 Mshowa
0 .35852 m
.00625 .35852 L
s
[(10)] -0.0125 .35852 1 0 Mshowa
0 .45347 m
.00625 .45347 L
s
[(12.5)] -0.0125 .45347 1 0 Mshowa
0 .54842 m
.00625 .54842 L
s
[(15)] -0.0125 .54842 1 0 Mshowa
.125 Mabswid
0 .09265 m
.00375 .09265 L
s
0 .11165 m
.00375 .11165 L
s
0 .13064 m
.00375 .13064 L
s
0 .14963 m
.00375 .14963 L
s
0 .18761 m
.00375 .18761 L
s
0 .2066 m
.00375 .2066 L
s
0 .22559 m
.00375 .22559 L
s
0 .24458 m
.00375 .24458 L
s
0 .28256 m
.00375 .28256 L
s
0 .30155 m
.00375 .30155 L
s
0 .32054 m
.00375 .32054 L
s
0 .33953 m
.00375 .33953 L
s
0 .37751 m
.00375 .37751 L
s
0 .3965 m
.00375 .3965 L
s
0 .41549 m
.00375 .41549 L
s
0 .43448 m
.00375 .43448 L
s
0 .47246 m
.00375 .47246 L
s
0 .49145 m
.00375 .49145 L
s
0 .51044 m
.00375 .51044 L
s
0 .52943 m
.00375 .52943 L
s
0 .05467 m
.00375 .05467 L
s
0 .03568 m
.00375 .03568 L
s
0 .01669 m
.00375 .01669 L
s
0 .56742 m
.00375 .56742 L
s
0 .58641 m
.00375 .58641 L
s
0 .6054 m
.00375 .6054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07366 m
1 .07366 L
s
.99375 .16862 m
1 .16862 L
s
.99375 .26357 m
1 .26357 L
s
.99375 .35852 m
1 .35852 L
s
.99375 .45347 m
1 .45347 L
s
.99375 .54842 m
1 .54842 L
s
.125 Mabswid
.99625 .09265 m
1 .09265 L
s
.99625 .11165 m
1 .11165 L
s
.99625 .13064 m
1 .13064 L
s
.99625 .14963 m
1 .14963 L
s
.99625 .18761 m
1 .18761 L
s
.99625 .2066 m
1 .2066 L
s
.99625 .22559 m
1 .22559 L
s
.99625 .24458 m
1 .24458 L
s
.99625 .28256 m
1 .28256 L
s
.99625 .30155 m
1 .30155 L
s
.99625 .32054 m
1 .32054 L
s
.99625 .33953 m
1 .33953 L
s
.99625 .37751 m
1 .37751 L
s
.99625 .3965 m
1 .3965 L
s
.99625 .41549 m
1 .41549 L
s
.99625 .43448 m
1 .43448 L
s
.99625 .47246 m
1 .47246 L
s
.99625 .49145 m
1 .49145 L
s
.99625 .51044 m
1 .51044 L
s
.99625 .52943 m
1 .52943 L
s
.99625 .05467 m
1 .05467 L
s
.99625 .03568 m
1 .03568 L
s
.99625 .01669 m
1 .01669 L
s
.99625 .56742 m
1 .56742 L
s
.99625 .58641 m
1 .58641 L
s
.99625 .6054 m
1 .6054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
gsave
.97619 .10412 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.007 w
.02381 .01614 m
.03333 .0204 L
.04286 .01773 L
.05238 .01774 L
.0619 .01751 L
.07143 .01811 L
.08095 .01932 L
.09048 .018 L
.1 .01982 L
.10952 .02109 L
.11905 .01965 L
.12857 .02005 L
.1381 .02163 L
.14762 .02043 L
.15714 .02002 L
.16667 .02359 L
.17619 .02131 L
.18571 .0232 L
.19524 .02476 L
.20476 .02291 L
.21429 .02257 L
.22381 .02357 L
.23333 .02231 L
.24286 .02532 L
.25238 .02579 L
.2619 .02439 L
.27143 .0269 L
.28095 .02575 L
.29048 .03143 L
.3 .02822 L
.30952 .0287 L
.31905 .02906 L
.32857 .02965 L
.3381 .03121 L
.34762 .03147 L
.35714 .03121 L
.36667 .03119 L
.37619 .0332 L
.38571 .03373 L
.39524 .03428 L
.40476 .03369 L
.41429 .03617 L
.42381 .03613 L
.43333 .0365 L
.44286 .037 L
.45238 .03565 L
.4619 .03751 L
.47143 .04156 L
.48095 .03863 L
.49048 .03967 L
Mistroke
.5 .04328 L
.50952 .04263 L
.51905 .03992 L
.52857 .04351 L
.5381 .04578 L
.54762 .04699 L
.55714 .04643 L
.56667 .04874 L
.57619 .04732 L
.58571 .04815 L
.59524 .05157 L
.60476 .05033 L
.61429 .05093 L
.62381 .05227 L
.63333 .05521 L
.64286 .0557 L
.65238 .05709 L
.6619 .05675 L
.67143 .06004 L
.68095 .06078 L
.69048 .06285 L
.7 .06486 L
.70952 .06816 L
.71905 .06528 L
.72857 .06768 L
.7381 .06971 L
.74762 .07008 L
.75714 .0715 L
.76667 .0742 L
.77619 .07141 L
.78571 .07402 L
.79524 .0744 L
.80476 .07321 L
.81429 .07429 L
.82381 .07805 L
.83333 .07512 L
.84286 .07969 L
.85238 .0806 L
.8619 .08297 L
.87143 .08579 L
.88095 .08725 L
.89048 .09146 L
.9 .09345 L
.90952 .09406 L
.91905 .09683 L
.92857 .09791 L
.9381 .09924 L
.94762 .09873 L
.95714 .10221 L
.96667 .10544 L
Mistroke
.97619 .10412 L
Mfstroke
1 0 .6 r
gsave
.97619 .59268 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05749 m
.03333 .05678 L
.04286 .05846 L
.05238 .06281 L
.0619 .06444 L
.07143 .0687 L
.08095 .07007 L
.09048 .07012 L
.1 .076 L
.10952 .0766 L
.11905 .08022 L
.12857 .08059 L
.1381 .08482 L
.14762 .0878 L
.15714 .09203 L
.16667 .09704 L
.17619 .09912 L
.18571 .10042 L
.19524 .1041 L
.20476 .10709 L
.21429 .11077 L
.22381 .1167 L
.23333 .12069 L
.24286 .12449 L
.25238 .1283 L
.2619 .13089 L
.27143 .13167 L
.28095 .139 L
.29048 .14477 L
.3 .14559 L
.30952 .14916 L
.31905 .15297 L
.32857 .15614 L
.3381 .16042 L
.34762 .16533 L
.35714 .17137 L
.36667 .17379 L
.37619 .17833 L
.38571 .18248 L
.39524 .18775 L
.40476 .19276 L
.41429 .19668 L
.42381 .20452 L
.43333 .20863 L
.44286 .21564 L
.45238 .2224 L
.4619 .22719 L
.47143 .23343 L
.48095 .24104 L
.49048 .24636 L
Mistroke
.5 .24921 L
.50952 .25514 L
.51905 .26156 L
.52857 .26934 L
.5381 .27708 L
.54762 .28317 L
.55714 .28901 L
.56667 .29687 L
.57619 .30271 L
.58571 .30966 L
.59524 .31336 L
.60476 .32197 L
.61429 .3281 L
.62381 .3324 L
.63333 .33743 L
.64286 .34612 L
.65238 .34984 L
.6619 .35778 L
.67143 .36782 L
.68095 .37204 L
.69048 .37663 L
.7 .38416 L
.70952 .39095 L
.71905 .39683 L
.72857 .40483 L
.7381 .41008 L
.74762 .41835 L
.75714 .4253 L
.76667 .42918 L
.77619 .43433 L
.78571 .44466 L
.79524 .45275 L
.80476 .45963 L
.81429 .47083 L
.82381 .47812 L
.83333 .48443 L
.84286 .48745 L
.85238 .49321 L
.8619 .51021 L
.87143 .51188 L
.88095 .51634 L
.89048 .52382 L
.9 .52963 L
.90952 .53826 L
.91905 .54417 L
.92857 .55164 L
.9381 .56476 L
.94762 .57299 L
.95714 .57811 L
.96667 .58425 L
Mistroke
.97619 .59268 L
Mfstroke
.8 0 1 r
gsave
.97619 .08556 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01674 m
.03333 .01684 L
.04286 .01748 L
.05238 .01792 L
.0619 .01765 L
.07143 .02027 L
.08095 .02013 L
.09048 .01875 L
.1 .0185 L
.10952 .02101 L
.11905 .01916 L
.12857 .0213 L
.1381 .02257 L
.14762 .02071 L
.15714 .02114 L
.16667 .02451 L
.17619 .02393 L
.18571 .02064 L
.19524 .02319 L
.20476 .02328 L
.21429 .02381 L
.22381 .02383 L
.23333 .025 L
.24286 .02652 L
.25238 .02531 L
.2619 .0266 L
.27143 .0271 L
.28095 .02786 L
.29048 .03102 L
.3 .02865 L
.30952 .02818 L
.31905 .03132 L
.32857 .02958 L
.3381 .02905 L
.34762 .03007 L
.35714 .0298 L
.36667 .03158 L
.37619 .03036 L
.38571 .03046 L
.39524 .03265 L
.40476 .03219 L
.41429 .03182 L
.42381 .03359 L
.43333 .0349 L
.44286 .03329 L
.45238 .03575 L
.4619 .03675 L
.47143 .03358 L
.48095 .0341 L
.49048 .03527 L
Mistroke
.5 .03602 L
.50952 .0348 L
.51905 .03665 L
.52857 .0367 L
.5381 .03928 L
.54762 .04248 L
.55714 .03988 L
.56667 .0432 L
.57619 .04641 L
.58571 .04865 L
.59524 .04636 L
.60476 .04726 L
.61429 .04812 L
.62381 .04815 L
.63333 .05095 L
.64286 .05086 L
.65238 .04975 L
.6619 .05251 L
.67143 .05233 L
.68095 .05319 L
.69048 .055 L
.7 .05507 L
.70952 .05411 L
.71905 .05578 L
.72857 .05825 L
.7381 .05985 L
.74762 .05902 L
.75714 .0598 L
.76667 .06084 L
.77619 .06118 L
.78571 .06463 L
.79524 .066 L
.80476 .06798 L
.81429 .07054 L
.82381 .07004 L
.83333 .07046 L
.84286 .07214 L
.85238 .07497 L
.8619 .07536 L
.87143 .07497 L
.88095 .07522 L
.89048 .07481 L
.9 .07793 L
.90952 .07719 L
.91905 .08115 L
.92857 .08141 L
.9381 .08523 L
.94762 .08542 L
.95714 .08637 L
.96667 .08653 L
Mistroke
.97619 .08556 L
Mfstroke
.2 0 1 r
gsave
.97619 .53057 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05434 m
.03333 .05728 L
.04286 .05986 L
.05238 .06169 L
.0619 .06308 L
.07143 .06697 L
.08095 .0717 L
.09048 .07233 L
.1 .0774 L
.10952 .07897 L
.11905 .0811 L
.12857 .08335 L
.1381 .08697 L
.14762 .08982 L
.15714 .09229 L
.16667 .09414 L
.17619 .09652 L
.18571 .10108 L
.19524 .10438 L
.20476 .10992 L
.21429 .11471 L
.22381 .11645 L
.23333 .12017 L
.24286 .12493 L
.25238 .12824 L
.2619 .13027 L
.27143 .13593 L
.28095 .14229 L
.29048 .14447 L
.3 .14544 L
.30952 .15194 L
.31905 .15698 L
.32857 .16152 L
.3381 .16437 L
.34762 .16917 L
.35714 .17654 L
.36667 .17649 L
.37619 .18132 L
.38571 .18882 L
.39524 .19494 L
.40476 .20102 L
.41429 .20404 L
.42381 .20707 L
.43333 .21358 L
.44286 .22199 L
.45238 .22619 L
.4619 .2295 L
.47143 .23483 L
.48095 .23982 L
.49048 .24498 L
Mistroke
.5 .24837 L
.50952 .25379 L
.51905 .26184 L
.52857 .27014 L
.5381 .27426 L
.54762 .27607 L
.55714 .2845 L
.56667 .2902 L
.57619 .29685 L
.58571 .30524 L
.59524 .30598 L
.60476 .31222 L
.61429 .32064 L
.62381 .32403 L
.63333 .32716 L
.64286 .32886 L
.65238 .33369 L
.6619 .34322 L
.67143 .34912 L
.68095 .35309 L
.69048 .35797 L
.7 .36331 L
.70952 .37185 L
.71905 .37697 L
.72857 .38764 L
.7381 .39545 L
.74762 .4007 L
.75714 .40842 L
.76667 .41179 L
.77619 .41536 L
.78571 .42128 L
.79524 .42642 L
.80476 .43642 L
.81429 .4371 L
.82381 .44433 L
.83333 .44726 L
.84286 .45666 L
.85238 .45851 L
.8619 .4666 L
.87143 .47392 L
.88095 .47973 L
.89048 .48585 L
.9 .49085 L
.90952 .49625 L
.91905 .49782 L
.92857 .50502 L
.9381 .50827 L
.94762 .51339 L
.95714 .51747 L
.96667 .52529 L
Mistroke
.97619 .53057 L
Mfstroke
0 .4 1 r
gsave
.97619 .10907 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01499 L
.04286 .01489 L
.05238 .01597 L
.0619 .01843 L
.07143 .01847 L
.08095 .01892 L
.09048 .02062 L
.1 .01993 L
.10952 .01917 L
.11905 .01996 L
.12857 .02188 L
.1381 .02212 L
.14762 .018 L
.15714 .02189 L
.16667 .02246 L
.17619 .01994 L
.18571 .02219 L
.19524 .02287 L
.20476 .02374 L
.21429 .02321 L
.22381 .0263 L
.23333 .02354 L
.24286 .02626 L
.25238 .02558 L
.2619 .02666 L
.27143 .02701 L
.28095 .02438 L
.29048 .02582 L
.3 .02592 L
.30952 .02678 L
.31905 .02662 L
.32857 .02756 L
.3381 .0293 L
.34762 .02809 L
.35714 .02989 L
.36667 .0309 L
.37619 .03035 L
.38571 .02982 L
.39524 .03024 L
.40476 .03408 L
.41429 .03567 L
.42381 .03215 L
.43333 .03546 L
.44286 .03561 L
.45238 .03628 L
.4619 .03882 L
.47143 .0378 L
.48095 .03523 L
.49048 .03903 L
Mistroke
.5 .03848 L
.50952 .04034 L
.51905 .04045 L
.52857 .04053 L
.5381 .04325 L
.54762 .04318 L
.55714 .04519 L
.56667 .04422 L
.57619 .04654 L
.58571 .04445 L
.59524 .04638 L
.60476 .04663 L
.61429 .04654 L
.62381 .04802 L
.63333 .0511 L
.64286 .05321 L
.65238 .05431 L
.6619 .0551 L
.67143 .05794 L
.68095 .06043 L
.69048 .0621 L
.7 .0618 L
.70952 .06161 L
.71905 .06576 L
.72857 .06644 L
.7381 .06619 L
.74762 .07119 L
.75714 .06986 L
.76667 .07029 L
.77619 .0731 L
.78571 .07285 L
.79524 .0782 L
.80476 .07684 L
.81429 .08072 L
.82381 .07897 L
.83333 .07768 L
.84286 .08176 L
.85238 .08161 L
.8619 .08673 L
.87143 .08549 L
.88095 .08654 L
.89048 .0897 L
.9 .09011 L
.90952 .09177 L
.91905 .09604 L
.92857 .09422 L
.9381 .09923 L
.94762 .10196 L
.95714 .10429 L
.96667 .1063 L
Mistroke
.97619 .10907 L
Mfstroke
0 1 1 r
gsave
.97619 .59327 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05569 m
.03333 .05473 L
.04286 .05936 L
.05238 .06282 L
.0619 .06513 L
.07143 .06827 L
.08095 .06945 L
.09048 .0744 L
.1 .07433 L
.10952 .08047 L
.11905 .08156 L
.12857 .08503 L
.1381 .08656 L
.14762 .08885 L
.15714 .09294 L
.16667 .09649 L
.17619 .09759 L
.18571 .10298 L
.19524 .10568 L
.20476 .11066 L
.21429 .11311 L
.22381 .11651 L
.23333 .12274 L
.24286 .12716 L
.25238 .13054 L
.2619 .13299 L
.27143 .13715 L
.28095 .14046 L
.29048 .14609 L
.3 .14909 L
.30952 .15509 L
.31905 .15819 L
.32857 .16421 L
.3381 .16949 L
.34762 .17338 L
.35714 .17646 L
.36667 .18349 L
.37619 .18584 L
.38571 .19314 L
.39524 .19712 L
.40476 .20323 L
.41429 .21066 L
.42381 .21367 L
.43333 .22048 L
.44286 .22364 L
.45238 .23449 L
.4619 .23643 L
.47143 .23886 L
.48095 .24417 L
.49048 .2528 L
Mistroke
.5 .25907 L
.50952 .26316 L
.51905 .26967 L
.52857 .27674 L
.5381 .28268 L
.54762 .28987 L
.55714 .29379 L
.56667 .30125 L
.57619 .30809 L
.58571 .31511 L
.59524 .31987 L
.60476 .33206 L
.61429 .33732 L
.62381 .3397 L
.63333 .34427 L
.64286 .35519 L
.65238 .35774 L
.6619 .36819 L
.67143 .37874 L
.68095 .38161 L
.69048 .39313 L
.7 .4011 L
.70952 .41179 L
.71905 .41508 L
.72857 .41831 L
.7381 .42887 L
.74762 .43921 L
.75714 .45029 L
.76667 .45693 L
.77619 .46578 L
.78571 .4664 L
.79524 .47311 L
.80476 .47997 L
.81429 .48722 L
.82381 .49565 L
.83333 .50045 L
.84286 .50566 L
.85238 .51227 L
.8619 .52 L
.87143 .52634 L
.88095 .53483 L
.89048 .54107 L
.9 .54812 L
.90952 .55285 L
.91905 .56025 L
.92857 .56396 L
.9381 .56818 L
.94762 .57342 L
.95714 .58074 L
.96667 .58755 L
Mistroke
.97619 .59327 L
Mfstroke
0 1 .4 r
gsave
.97619 .10674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01721 m
.03333 .01757 L
.04286 .01827 L
.05238 .01756 L
.0619 .01939 L
.07143 .01873 L
.08095 .0183 L
.09048 .0202 L
.1 .01846 L
.10952 .02114 L
.11905 .01753 L
.12857 .01928 L
.1381 .02247 L
.14762 .0221 L
.15714 .02197 L
.16667 .02299 L
.17619 .02272 L
.18571 .02262 L
.19524 .02395 L
.20476 .02262 L
.21429 .02285 L
.22381 .02337 L
.23333 .02416 L
.24286 .02163 L
.25238 .02336 L
.2619 .02517 L
.27143 .02765 L
.28095 .02739 L
.29048 .02746 L
.3 .03024 L
.30952 .02785 L
.31905 .02728 L
.32857 .02879 L
.3381 .0277 L
.34762 .03223 L
.35714 .02955 L
.36667 .03055 L
.37619 .02973 L
.38571 .03246 L
.39524 .02923 L
.40476 .03121 L
.41429 .03256 L
.42381 .03402 L
.43333 .03343 L
.44286 .03236 L
.45238 .03537 L
.4619 .03601 L
.47143 .03812 L
.48095 .03603 L
.49048 .03906 L
Mistroke
.5 .04053 L
.50952 .03725 L
.51905 .04128 L
.52857 .04198 L
.5381 .04487 L
.54762 .04407 L
.55714 .04654 L
.56667 .04699 L
.57619 .04544 L
.58571 .048 L
.59524 .04768 L
.60476 .04708 L
.61429 .0498 L
.62381 .05091 L
.63333 .0535 L
.64286 .05237 L
.65238 .05342 L
.6619 .05542 L
.67143 .05674 L
.68095 .05733 L
.69048 .06059 L
.7 .06077 L
.70952 .06108 L
.71905 .06363 L
.72857 .06437 L
.7381 .06408 L
.74762 .06357 L
.75714 .06882 L
.76667 .07117 L
.77619 .06905 L
.78571 .06754 L
.79524 .06997 L
.80476 .07131 L
.81429 .07059 L
.82381 .07287 L
.83333 .0769 L
.84286 .07486 L
.85238 .07824 L
.8619 .07921 L
.87143 .08034 L
.88095 .08282 L
.89048 .08651 L
.9 .08358 L
.90952 .08644 L
.91905 .08567 L
.92857 .09184 L
.9381 .0943 L
.94762 .09655 L
.95714 .10061 L
.96667 .10401 L
Mistroke
.97619 .10674 L
Mfstroke
.2 1 0 r
gsave
.97619 .58131 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05596 m
.03333 .05551 L
.04286 .05973 L
.05238 .06429 L
.0619 .06552 L
.07143 .06581 L
.08095 .06887 L
.09048 .07212 L
.1 .07845 L
.10952 .07923 L
.11905 .08014 L
.12857 .08522 L
.1381 .08529 L
.14762 .08884 L
.15714 .0924 L
.16667 .09574 L
.17619 .09958 L
.18571 .10205 L
.19524 .1103 L
.20476 .11143 L
.21429 .1124 L
.22381 .11633 L
.23333 .12209 L
.24286 .1269 L
.25238 .13022 L
.2619 .13471 L
.27143 .1376 L
.28095 .14274 L
.29048 .14515 L
.3 .14977 L
.30952 .15226 L
.31905 .15749 L
.32857 .1627 L
.3381 .16491 L
.34762 .17178 L
.35714 .17463 L
.36667 .17886 L
.37619 .1828 L
.38571 .18729 L
.39524 .19153 L
.40476 .19772 L
.41429 .20557 L
.42381 .20819 L
.43333 .21677 L
.44286 .22087 L
.45238 .22667 L
.4619 .2312 L
.47143 .23616 L
.48095 .24311 L
.49048 .24607 L
Mistroke
.5 .25411 L
.50952 .2587 L
.51905 .26306 L
.52857 .27461 L
.5381 .27837 L
.54762 .28737 L
.55714 .2911 L
.56667 .2964 L
.57619 .29881 L
.58571 .30976 L
.59524 .31368 L
.60476 .31983 L
.61429 .32402 L
.62381 .32848 L
.63333 .33183 L
.64286 .33977 L
.65238 .34478 L
.6619 .35245 L
.67143 .36014 L
.68095 .36569 L
.69048 .37576 L
.7 .37815 L
.70952 .38528 L
.71905 .39248 L
.72857 .40339 L
.7381 .40685 L
.74762 .41358 L
.75714 .42183 L
.76667 .4283 L
.77619 .43904 L
.78571 .44142 L
.79524 .44714 L
.80476 .45195 L
.81429 .46176 L
.82381 .46921 L
.83333 .48351 L
.84286 .49119 L
.85238 .49947 L
.8619 .50577 L
.87143 .50798 L
.88095 .51348 L
.89048 .51753 L
.9 .53225 L
.90952 .53622 L
.91905 .54286 L
.92857 .55563 L
.9381 .56304 L
.94762 .56672 L
.95714 .57369 L
.96667 .57937 L
Mistroke
.97619 .58131 L
Mfstroke
.8 1 0 r
gsave
.97619 .09345 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01699 m
.03333 .01813 L
.04286 .01625 L
.05238 .01831 L
.0619 .01903 L
.07143 .01775 L
.08095 .02 L
.09048 .01937 L
.1 .01856 L
.10952 .01871 L
.11905 .02177 L
.12857 .02324 L
.1381 .02032 L
.14762 .02284 L
.15714 .02079 L
.16667 .02276 L
.17619 .0211 L
.18571 .02237 L
.19524 .02481 L
.20476 .02453 L
.21429 .02254 L
.22381 .02494 L
.23333 .02651 L
.24286 .02505 L
.25238 .02576 L
.2619 .02555 L
.27143 .02697 L
.28095 .02934 L
.29048 .03102 L
.3 .03173 L
.30952 .02927 L
.31905 .03038 L
.32857 .0282 L
.3381 .03041 L
.34762 .0306 L
.35714 .03107 L
.36667 .03126 L
.37619 .03409 L
.38571 .03085 L
.39524 .03197 L
.40476 .03473 L
.41429 .03235 L
.42381 .03355 L
.43333 .03575 L
.44286 .032 L
.45238 .03731 L
.4619 .03795 L
.47143 .03726 L
.48095 .03599 L
.49048 .03962 L
Mistroke
.5 .04211 L
.50952 .03952 L
.51905 .03942 L
.52857 .03899 L
.5381 .03991 L
.54762 .03922 L
.55714 .04317 L
.56667 .04341 L
.57619 .04321 L
.58571 .048 L
.59524 .04437 L
.60476 .04551 L
.61429 .04481 L
.62381 .0442 L
.63333 .04463 L
.64286 .04635 L
.65238 .04902 L
.6619 .05063 L
.67143 .04959 L
.68095 .05297 L
.69048 .05145 L
.7 .05068 L
.70952 .0536 L
.71905 .05707 L
.72857 .05671 L
.7381 .05672 L
.74762 .05953 L
.75714 .06227 L
.76667 .06338 L
.77619 .06495 L
.78571 .06813 L
.79524 .06882 L
.80476 .06872 L
.81429 .07078 L
.82381 .07234 L
.83333 .07178 L
.84286 .07015 L
.85238 .07435 L
.8619 .07494 L
.87143 .07632 L
.88095 .08044 L
.89048 .08056 L
.9 .08286 L
.90952 .08438 L
.91905 .08676 L
.92857 .08733 L
.9381 .08909 L
.94762 .0878 L
.95714 .0875 L
.96667 .09286 L
Mistroke
.97619 .09345 L
Mfstroke
1 .6 0 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0527 m
.03333 .05829 L
.04286 .05832 L
.05238 .06426 L
.0619 .0633 L
.07143 .06724 L
.08095 .06953 L
.09048 .07268 L
.1 .0765 L
.10952 .07769 L
.11905 .07909 L
.12857 .08373 L
.1381 .08524 L
.14762 .08891 L
.15714 .09416 L
.16667 .09218 L
.17619 .0971 L
.18571 .10301 L
.19524 .10575 L
.20476 .11096 L
.21429 .11334 L
.22381 .1181 L
.23333 .12001 L
.24286 .12585 L
.25238 .13047 L
.2619 .13061 L
.27143 .13825 L
.28095 .14088 L
.29048 .14408 L
.3 .15198 L
.30952 .15548 L
.31905 .16189 L
.32857 .16779 L
.3381 .17248 L
.34762 .17576 L
.35714 .18141 L
.36667 .18671 L
.37619 .19013 L
.38571 .19616 L
.39524 .20093 L
.40476 .20579 L
.41429 .21146 L
.42381 .21865 L
.43333 .22343 L
.44286 .22654 L
.45238 .23404 L
.4619 .24168 L
.47143 .24515 L
.48095 .25222 L
.49048 .25841 L
Mistroke
.5 .26362 L
.50952 .2696 L
.51905 .27456 L
.52857 .28334 L
.5381 .28712 L
.54762 .2889 L
.55714 .29609 L
.56667 .30473 L
.57619 .30947 L
.58571 .31573 L
.59524 .32121 L
.60476 .32737 L
.61429 .33475 L
.62381 .34073 L
.63333 .34993 L
.64286 .35628 L
.65238 .36252 L
.6619 .36694 L
.67143 .3782 L
.68095 .38122 L
.69048 .3833 L
.7 .39117 L
.70952 .39535 L
.71905 .40285 L
.72857 .41319 L
.7381 .41885 L
.74762 .42575 L
.75714 .43073 L
.76667 .43763 L
.77619 .44658 L
.78571 .45205 L
.79524 .46036 L
.80476 .46784 L
.81429 .47578 L
.82381 .48325 L
.83333 .489 L
.84286 .49627 L
.85238 .5034 L
.8619 .51304 L
.87143 .52013 L
.88095 .52815 L
.89048 .53614 L
.9 .54775 L
.90952 .5551 L
.91905 .56419 L
.92857 .57004 L
.9381 .57427 L
.94762 .58277 L
.95714 .58923 L
.96667 .59662 L
Mistroke
.97619 .60332 L
Mfstroke
1 0 0 r
gsave
.97619 .09592 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01946 m
.03333 .01628 L
.04286 .01601 L
.05238 .0186 L
.0619 .01769 L
.07143 .01881 L
.08095 .01923 L
.09048 .02094 L
.1 .01911 L
.10952 .01865 L
.11905 .02141 L
.12857 .02076 L
.1381 .01832 L
.14762 .02248 L
.15714 .02127 L
.16667 .02113 L
.17619 .02098 L
.18571 .02076 L
.19524 .02284 L
.20476 .02509 L
.21429 .0234 L
.22381 .02415 L
.23333 .02261 L
.24286 .0254 L
.25238 .02497 L
.2619 .02579 L
.27143 .02548 L
.28095 .02691 L
.29048 .02581 L
.3 .02727 L
.30952 .02828 L
.31905 .02786 L
.32857 .02768 L
.3381 .02805 L
.34762 .03048 L
.35714 .03147 L
.36667 .03271 L
.37619 .03216 L
.38571 .03242 L
.39524 .03291 L
.40476 .03388 L
.41429 .03093 L
.42381 .03337 L
.43333 .03588 L
.44286 .03557 L
.45238 .0346 L
.4619 .03785 L
.47143 .03899 L
.48095 .03877 L
.49048 .03755 L
Mistroke
.5 .03784 L
.50952 .041 L
.51905 .04122 L
.52857 .03904 L
.5381 .04273 L
.54762 .04251 L
.55714 .04103 L
.56667 .04374 L
.57619 .04693 L
.58571 .0474 L
.59524 .04616 L
.60476 .04704 L
.61429 .04918 L
.62381 .05086 L
.63333 .0534 L
.64286 .05368 L
.65238 .05176 L
.6619 .05325 L
.67143 .0575 L
.68095 .05457 L
.69048 .05649 L
.7 .05764 L
.70952 .05681 L
.71905 .05852 L
.72857 .05536 L
.7381 .06028 L
.74762 .06358 L
.75714 .06108 L
.76667 .06502 L
.77619 .0664 L
.78571 .06704 L
.79524 .06743 L
.80476 .06933 L
.81429 .0694 L
.82381 .0697 L
.83333 .07121 L
.84286 .07193 L
.85238 .07385 L
.8619 .07684 L
.87143 .07794 L
.88095 .07721 L
.89048 .08046 L
.9 .08135 L
.90952 .08527 L
.91905 .08465 L
.92857 .08546 L
.9381 .08674 L
.94762 .0895 L
.95714 .09222 L
.96667 .08939 L
Mistroke
.97619 .09592 L
Mfstroke
1 0 .6 r
gsave
.97619 .54961 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.600 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05301 m
.03333 .05558 L
.04286 .0584 L
.05238 .0625 L
.0619 .06465 L
.07143 .06716 L
.08095 .07043 L
.09048 .07389 L
.1 .07724 L
.10952 .07734 L
.11905 .07925 L
.12857 .08411 L
.1381 .08679 L
.14762 .08865 L
.15714 .09424 L
.16667 .09692 L
.17619 .09964 L
.18571 .10097 L
.19524 .10596 L
.20476 .1089 L
.21429 .11241 L
.22381 .11605 L
.23333 .12026 L
.24286 .12539 L
.25238 .12851 L
.2619 .13129 L
.27143 .13756 L
.28095 .13989 L
.29048 .14312 L
.3 .14894 L
.30952 .15181 L
.31905 .15683 L
.32857 .16031 L
.3381 .16614 L
.34762 .16948 L
.35714 .17417 L
.36667 .17768 L
.37619 .18404 L
.38571 .1861 L
.39524 .18905 L
.40476 .19741 L
.41429 .20199 L
.42381 .20452 L
.43333 .20876 L
.44286 .21606 L
.45238 .21976 L
.4619 .2281 L
.47143 .22964 L
.48095 .23509 L
.49048 .23764 L
Mistroke
.5 .2436 L
.50952 .2464 L
.51905 .25457 L
.52857 .25777 L
.5381 .26531 L
.54762 .2711 L
.55714 .27999 L
.56667 .28461 L
.57619 .29073 L
.58571 .29297 L
.59524 .3003 L
.60476 .30632 L
.61429 .31391 L
.62381 .31784 L
.63333 .32175 L
.64286 .32939 L
.65238 .33167 L
.6619 .33702 L
.67143 .35037 L
.68095 .35602 L
.69048 .36294 L
.7 .36997 L
.70952 .37647 L
.71905 .38235 L
.72857 .38923 L
.7381 .39646 L
.74762 .4026 L
.75714 .40747 L
.76667 .41062 L
.77619 .41448 L
.78571 .42264 L
.79524 .43249 L
.80476 .43757 L
.81429 .44324 L
.82381 .45069 L
.83333 .45556 L
.84286 .46275 L
.85238 .46756 L
.8619 .47101 L
.87143 .47673 L
.88095 .48561 L
.89048 .49145 L
.9 .49828 L
.90952 .50447 L
.91905 .51199 L
.92857 .51804 L
.9381 .52554 L
.94762 .53169 L
.95714 .53967 L
.96667 .5438 L
Mistroke
.97619 .54961 L
Mfstroke
.8 0 1 r
gsave
.97619 .10354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01503 m
.03333 .01679 L
.04286 .01912 L
.05238 .01939 L
.0619 .01997 L
.07143 .01774 L
.08095 .01757 L
.09048 .01981 L
.1 .01906 L
.10952 .01891 L
.11905 .02037 L
.12857 .02005 L
.1381 .02005 L
.14762 .02336 L
.15714 .02148 L
.16667 .02126 L
.17619 .02053 L
.18571 .0219 L
.19524 .02245 L
.20476 .02119 L
.21429 .0241 L
.22381 .02269 L
.23333 .02314 L
.24286 .02376 L
.25238 .02469 L
.2619 .02449 L
.27143 .02452 L
.28095 .02556 L
.29048 .02832 L
.3 .02862 L
.30952 .02726 L
.31905 .02757 L
.32857 .02948 L
.3381 .03174 L
.34762 .03013 L
.35714 .0305 L
.36667 .03249 L
.37619 .03289 L
.38571 .03273 L
.39524 .03426 L
.40476 .03271 L
.41429 .03495 L
.42381 .03777 L
.43333 .03879 L
.44286 .03584 L
.45238 .03495 L
.4619 .03478 L
.47143 .03901 L
.48095 .03871 L
.49048 .03939 L
Mistroke
.5 .04177 L
.50952 .04196 L
.51905 .0426 L
.52857 .04166 L
.5381 .04352 L
.54762 .04525 L
.55714 .04654 L
.56667 .04619 L
.57619 .0457 L
.58571 .04855 L
.59524 .04786 L
.60476 .04942 L
.61429 .05031 L
.62381 .05027 L
.63333 .05048 L
.64286 .05339 L
.65238 .05453 L
.6619 .05466 L
.67143 .0563 L
.68095 .05642 L
.69048 .05894 L
.7 .0588 L
.70952 .05887 L
.71905 .05742 L
.72857 .05646 L
.7381 .05892 L
.74762 .05926 L
.75714 .06063 L
.76667 .05896 L
.77619 .06372 L
.78571 .06453 L
.79524 .06764 L
.80476 .06727 L
.81429 .07024 L
.82381 .06998 L
.83333 .06942 L
.84286 .07354 L
.85238 .07527 L
.8619 .07705 L
.87143 .07986 L
.88095 .07929 L
.89048 .08652 L
.9 .09109 L
.90952 .09209 L
.91905 .09246 L
.92857 .09397 L
.9381 .0937 L
.94762 .09664 L
.95714 .10032 L
.96667 .10147 L
Mistroke
.97619 .10354 L
Mfstroke
.2 0 1 r
gsave
.97619 .54937 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05517 m
.03333 .05633 L
.04286 .06079 L
.05238 .06012 L
.0619 .06532 L
.07143 .0678 L
.08095 .07093 L
.09048 .07211 L
.1 .07562 L
.10952 .077 L
.11905 .08039 L
.12857 .08337 L
.1381 .08719 L
.14762 .08882 L
.15714 .09505 L
.16667 .09625 L
.17619 .09788 L
.18571 .10242 L
.19524 .10378 L
.20476 .11008 L
.21429 .10911 L
.22381 .11909 L
.23333 .1179 L
.24286 .12287 L
.25238 .12613 L
.2619 .13052 L
.27143 .13464 L
.28095 .13796 L
.29048 .14212 L
.3 .14598 L
.30952 .15167 L
.31905 .15349 L
.32857 .15695 L
.3381 .16219 L
.34762 .16371 L
.35714 .16647 L
.36667 .16989 L
.37619 .17341 L
.38571 .17927 L
.39524 .18301 L
.40476 .18789 L
.41429 .19017 L
.42381 .19473 L
.43333 .19804 L
.44286 .20377 L
.45238 .2093 L
.4619 .21573 L
.47143 .21886 L
.48095 .22309 L
.49048 .23027 L
Mistroke
.5 .23614 L
.50952 .24186 L
.51905 .24481 L
.52857 .25418 L
.5381 .26107 L
.54762 .26713 L
.55714 .27265 L
.56667 .28001 L
.57619 .28911 L
.58571 .2946 L
.59524 .29779 L
.60476 .30472 L
.61429 .31226 L
.62381 .31703 L
.63333 .32368 L
.64286 .32746 L
.65238 .3365 L
.6619 .34154 L
.67143 .34369 L
.68095 .35057 L
.69048 .35713 L
.7 .36041 L
.70952 .36564 L
.71905 .37184 L
.72857 .37823 L
.7381 .38207 L
.74762 .38624 L
.75714 .39258 L
.76667 .40086 L
.77619 .40637 L
.78571 .4181 L
.79524 .42366 L
.80476 .43165 L
.81429 .44214 L
.82381 .44626 L
.83333 .45493 L
.84286 .46029 L
.85238 .46247 L
.8619 .47462 L
.87143 .48188 L
.88095 .48597 L
.89048 .49334 L
.9 .49929 L
.90952 .50666 L
.91905 .50904 L
.92857 .51909 L
.9381 .52577 L
.94762 .53242 L
.95714 .53953 L
.96667 .54301 L
Mistroke
.97619 .54937 L
Mfstroke
0 .4 1 r
gsave
.97619 .09403 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01627 m
.03333 .01809 L
.04286 .01933 L
.05238 .0175 L
.0619 .01962 L
.07143 .01927 L
.08095 .01719 L
.09048 .01823 L
.1 .01956 L
.10952 .02094 L
.11905 .02067 L
.12857 .02236 L
.1381 .01947 L
.14762 .0198 L
.15714 .02202 L
.16667 .02232 L
.17619 .02373 L
.18571 .0242 L
.19524 .02145 L
.20476 .02396 L
.21429 .02196 L
.22381 .0239 L
.23333 .0242 L
.24286 .02649 L
.25238 .02197 L
.2619 .02618 L
.27143 .0244 L
.28095 .0268 L
.29048 .02474 L
.3 .02747 L
.30952 .02721 L
.31905 .02553 L
.32857 .02754 L
.3381 .02736 L
.34762 .03055 L
.35714 .03035 L
.36667 .02984 L
.37619 .03074 L
.38571 .02988 L
.39524 .03215 L
.40476 .03164 L
.41429 .03269 L
.42381 .03475 L
.43333 .03673 L
.44286 .03623 L
.45238 .03871 L
.4619 .03714 L
.47143 .03581 L
.48095 .03742 L
.49048 .03772 L
Mistroke
.5 .03869 L
.50952 .0387 L
.51905 .04064 L
.52857 .03943 L
.5381 .04131 L
.54762 .04321 L
.55714 .04358 L
.56667 .04374 L
.57619 .04221 L
.58571 .04328 L
.59524 .04542 L
.60476 .0451 L
.61429 .04973 L
.62381 .04882 L
.63333 .05068 L
.64286 .05246 L
.65238 .05277 L
.6619 .05392 L
.67143 .05342 L
.68095 .05563 L
.69048 .05364 L
.7 .05339 L
.70952 .05762 L
.71905 .05898 L
.72857 .0589 L
.7381 .05765 L
.74762 .06151 L
.75714 .0636 L
.76667 .06071 L
.77619 .06551 L
.78571 .06132 L
.79524 .06586 L
.80476 .06659 L
.81429 .0703 L
.82381 .06974 L
.83333 .06825 L
.84286 .07 L
.85238 .07513 L
.8619 .07486 L
.87143 .07873 L
.88095 .07648 L
.89048 .07818 L
.9 .07986 L
.90952 .08138 L
.91905 .08125 L
.92857 .08486 L
.9381 .08508 L
.94762 .08888 L
.95714 .08998 L
.96667 .09458 L
Mistroke
.97619 .09403 L
Mfstroke
0 1 1 r
gsave
.97619 .57498 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05816 m
.03333 .05902 L
.04286 .06102 L
.05238 .06319 L
.0619 .06501 L
.07143 .06903 L
.08095 .06985 L
.09048 .07262 L
.1 .07429 L
.10952 .07859 L
.11905 .08039 L
.12857 .08533 L
.1381 .08949 L
.14762 .09033 L
.15714 .09456 L
.16667 .09385 L
.17619 .09763 L
.18571 .10337 L
.19524 .10632 L
.20476 .11021 L
.21429 .11493 L
.22381 .11687 L
.23333 .12447 L
.24286 .12584 L
.25238 .13063 L
.2619 .13384 L
.27143 .13869 L
.28095 .14079 L
.29048 .14582 L
.3 .14894 L
.30952 .1542 L
.31905 .16011 L
.32857 .16256 L
.3381 .16839 L
.34762 .17309 L
.35714 .17859 L
.36667 .18239 L
.37619 .18512 L
.38571 .19092 L
.39524 .19465 L
.40476 .2013 L
.41429 .20849 L
.42381 .21191 L
.43333 .21922 L
.44286 .22473 L
.45238 .23194 L
.4619 .23534 L
.47143 .24035 L
.48095 .24842 L
.49048 .24939 L
Mistroke
.5 .25592 L
.50952 .26191 L
.51905 .26452 L
.52857 .26792 L
.5381 .27728 L
.54762 .28239 L
.55714 .2881 L
.56667 .29373 L
.57619 .30011 L
.58571 .30797 L
.59524 .31118 L
.60476 .32296 L
.61429 .3287 L
.62381 .33757 L
.63333 .34292 L
.64286 .35212 L
.65238 .35837 L
.6619 .36523 L
.67143 .36807 L
.68095 .37338 L
.69048 .37944 L
.7 .38359 L
.70952 .39341 L
.71905 .4005 L
.72857 .40805 L
.7381 .41409 L
.74762 .42088 L
.75714 .42871 L
.76667 .4383 L
.77619 .44272 L
.78571 .45087 L
.79524 .45785 L
.80476 .46616 L
.81429 .4717 L
.82381 .48201 L
.83333 .48761 L
.84286 .494 L
.85238 .49813 L
.8619 .51101 L
.87143 .51956 L
.88095 .52318 L
.89048 .52565 L
.9 .53417 L
.90952 .54147 L
.91905 .54922 L
.92857 .55168 L
.9381 .55765 L
.94762 .56382 L
.95714 .56831 L
.96667 .56972 L
Mistroke
.97619 .57498 L
Mfstroke
0 1 .4 r
gsave
.97619 .09156 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01789 m
.03333 .01715 L
.04286 .01921 L
.05238 .01729 L
.0619 .01796 L
.07143 .0198 L
.08095 .01788 L
.09048 .01726 L
.1 .01926 L
.10952 .01955 L
.11905 .02026 L
.12857 .01996 L
.1381 .01939 L
.14762 .02243 L
.15714 .02087 L
.16667 .02279 L
.17619 .02314 L
.18571 .02271 L
.19524 .02235 L
.20476 .02307 L
.21429 .02384 L
.22381 .0223 L
.23333 .02375 L
.24286 .02248 L
.25238 .02511 L
.2619 .02503 L
.27143 .02548 L
.28095 .02373 L
.29048 .02586 L
.3 .02761 L
.30952 .02771 L
.31905 .02525 L
.32857 .02743 L
.3381 .02825 L
.34762 .02502 L
.35714 .02722 L
.36667 .02495 L
.37619 .02697 L
.38571 .02702 L
.39524 .028 L
.40476 .02982 L
.41429 .03096 L
.42381 .03011 L
.43333 .03149 L
.44286 .03026 L
.45238 .03232 L
.4619 .0332 L
.47143 .03452 L
.48095 .03491 L
.49048 .03514 L
Mistroke
.5 .03367 L
.50952 .03456 L
.51905 .03227 L
.52857 .03447 L
.5381 .03418 L
.54762 .03591 L
.55714 .03648 L
.56667 .03983 L
.57619 .04073 L
.58571 .04202 L
.59524 .0436 L
.60476 .04563 L
.61429 .04696 L
.62381 .04655 L
.63333 .05026 L
.64286 .04964 L
.65238 .05072 L
.6619 .05016 L
.67143 .05068 L
.68095 .0536 L
.69048 .05357 L
.7 .05599 L
.70952 .05552 L
.71905 .05678 L
.72857 .05431 L
.7381 .05397 L
.74762 .05506 L
.75714 .05784 L
.76667 .05944 L
.77619 .0628 L
.78571 .06274 L
.79524 .06233 L
.80476 .06404 L
.81429 .06784 L
.82381 .0669 L
.83333 .07026 L
.84286 .07084 L
.85238 .07369 L
.8619 .0737 L
.87143 .07543 L
.88095 .07517 L
.89048 .07414 L
.9 .0761 L
.90952 .0793 L
.91905 .08186 L
.92857 .08168 L
.9381 .07932 L
.94762 .08213 L
.95714 .08382 L
.96667 .08706 L
Mistroke
.97619 .09156 L
Mfstroke
.2 1 0 r
gsave
.97619 .58622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05521 m
.03333 .05704 L
.04286 .06157 L
.05238 .06419 L
.0619 .06194 L
.07143 .06808 L
.08095 .06928 L
.09048 .07262 L
.1 .07331 L
.10952 .07642 L
.11905 .0806 L
.12857 .08331 L
.1381 .08576 L
.14762 .09039 L
.15714 .09504 L
.16667 .09714 L
.17619 .10002 L
.18571 .10378 L
.19524 .10887 L
.20476 .11192 L
.21429 .11738 L
.22381 .11986 L
.23333 .12228 L
.24286 .12729 L
.25238 .13036 L
.2619 .13225 L
.27143 .1401 L
.28095 .14379 L
.29048 .14582 L
.3 .15364 L
.30952 .15928 L
.31905 .1631 L
.32857 .16611 L
.3381 .17161 L
.34762 .17524 L
.35714 .17981 L
.36667 .18484 L
.37619 .19044 L
.38571 .19649 L
.39524 .20063 L
.40476 .20614 L
.41429 .21248 L
.42381 .21626 L
.43333 .2228 L
.44286 .22804 L
.45238 .23381 L
.4619 .23771 L
.47143 .24392 L
.48095 .24687 L
.49048 .25457 L
Mistroke
.5 .25945 L
.50952 .26274 L
.51905 .27148 L
.52857 .27819 L
.5381 .2825 L
.54762 .28973 L
.55714 .29436 L
.56667 .30405 L
.57619 .30945 L
.58571 .31545 L
.59524 .32245 L
.60476 .32529 L
.61429 .33762 L
.62381 .34563 L
.63333 .35085 L
.64286 .35869 L
.65238 .3641 L
.6619 .37036 L
.67143 .37519 L
.68095 .38896 L
.69048 .39375 L
.7 .40084 L
.70952 .40657 L
.71905 .41592 L
.72857 .42361 L
.7381 .42691 L
.74762 .43435 L
.75714 .44115 L
.76667 .44795 L
.77619 .45303 L
.78571 .46054 L
.79524 .46526 L
.80476 .47099 L
.81429 .46982 L
.82381 .47484 L
.83333 .48096 L
.84286 .48958 L
.85238 .49793 L
.8619 .50716 L
.87143 .51083 L
.88095 .52016 L
.89048 .53081 L
.9 .53435 L
.90952 .53763 L
.91905 .54566 L
.92857 .55948 L
.9381 .56663 L
.94762 .57249 L
.95714 .57667 L
.96667 .58544 L
Mistroke
.97619 .58622 L
Mfstroke
.8 1 0 r
gsave
.97619 .09089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01635 m
.03333 .01648 L
.04286 .01722 L
.05238 .01713 L
.0619 .02008 L
.07143 .01962 L
.08095 .01713 L
.09048 .01957 L
.1 .02115 L
.10952 .02238 L
.11905 .0195 L
.12857 .01972 L
.1381 .02181 L
.14762 .0196 L
.15714 .02201 L
.16667 .02187 L
.17619 .02368 L
.18571 .02011 L
.19524 .02336 L
.20476 .02377 L
.21429 .02511 L
.22381 .02278 L
.23333 .025 L
.24286 .0259 L
.25238 .02406 L
.2619 .02577 L
.27143 .02556 L
.28095 .02763 L
.29048 .02868 L
.3 .02651 L
.30952 .02817 L
.31905 .02906 L
.32857 .03092 L
.3381 .03018 L
.34762 .02967 L
.35714 .02874 L
.36667 .03142 L
.37619 .02934 L
.38571 .03342 L
.39524 .02945 L
.40476 .03093 L
.41429 .03216 L
.42381 .03098 L
.43333 .02995 L
.44286 .03236 L
.45238 .0342 L
.4619 .03193 L
.47143 .03379 L
.48095 .03479 L
.49048 .03264 L
Mistroke
.5 .03434 L
.50952 .03709 L
.51905 .03357 L
.52857 .03793 L
.5381 .04032 L
.54762 .03872 L
.55714 .04024 L
.56667 .04313 L
.57619 .04256 L
.58571 .04284 L
.59524 .04413 L
.60476 .0457 L
.61429 .04488 L
.62381 .04614 L
.63333 .04343 L
.64286 .04279 L
.65238 .0427 L
.6619 .04305 L
.67143 .04499 L
.68095 .04897 L
.69048 .04858 L
.7 .0537 L
.70952 .05236 L
.71905 .05553 L
.72857 .05519 L
.7381 .05677 L
.74762 .05513 L
.75714 .05454 L
.76667 .05628 L
.77619 .05871 L
.78571 .06014 L
.79524 .06484 L
.80476 .06375 L
.81429 .06493 L
.82381 .06735 L
.83333 .06776 L
.84286 .0679 L
.85238 .06735 L
.8619 .07083 L
.87143 .07007 L
.88095 .07453 L
.89048 .07403 L
.9 .0748 L
.90952 .07997 L
.91905 .07922 L
.92857 .08395 L
.9381 .08737 L
.94762 .08948 L
.95714 .09148 L
.96667 .09295 L
Mistroke
.97619 .09089 L
Mfstroke
1 .6 0 r
gsave
.97619 .55089 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.600 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05493 m
.03333 .05714 L
.04286 .05794 L
.05238 .06295 L
.0619 .06575 L
.07143 .06604 L
.08095 .06991 L
.09048 .07221 L
.1 .07606 L
.10952 .07689 L
.11905 .08005 L
.12857 .08473 L
.1381 .08876 L
.14762 .09098 L
.15714 .09413 L
.16667 .09874 L
.17619 .1007 L
.18571 .10322 L
.19524 .105 L
.20476 .10978 L
.21429 .11343 L
.22381 .11703 L
.23333 .12003 L
.24286 .12246 L
.25238 .12568 L
.2619 .12835 L
.27143 .13283 L
.28095 .13663 L
.29048 .13984 L
.3 .14556 L
.30952 .14807 L
.31905 .15241 L
.32857 .15701 L
.3381 .16339 L
.34762 .16735 L
.35714 .17311 L
.36667 .17557 L
.37619 .18157 L
.38571 .1871 L
.39524 .19077 L
.40476 .1949 L
.41429 .20197 L
.42381 .20341 L
.43333 .21023 L
.44286 .21619 L
.45238 .22092 L
.4619 .2278 L
.47143 .23155 L
.48095 .23732 L
.49048 .24318 L
Mistroke
.5 .24641 L
.50952 .25012 L
.51905 .25902 L
.52857 .26389 L
.5381 .26844 L
.54762 .27349 L
.55714 .28334 L
.56667 .28807 L
.57619 .29577 L
.58571 .29861 L
.59524 .30886 L
.60476 .31516 L
.61429 .32281 L
.62381 .32764 L
.63333 .33329 L
.64286 .34136 L
.65238 .34826 L
.6619 .35072 L
.67143 .35664 L
.68095 .3624 L
.69048 .36433 L
.7 .37184 L
.70952 .37548 L
.71905 .38513 L
.72857 .39115 L
.7381 .39656 L
.74762 .40276 L
.75714 .41102 L
.76667 .42009 L
.77619 .42511 L
.78571 .42892 L
.79524 .43534 L
.80476 .44333 L
.81429 .45179 L
.82381 .45996 L
.83333 .46672 L
.84286 .47629 L
.85238 .47361 L
.8619 .48221 L
.87143 .48573 L
.88095 .49144 L
.89048 .49349 L
.9 .50366 L
.90952 .50662 L
.91905 .51485 L
.92857 .51847 L
.9381 .53038 L
.94762 .53052 L
.95714 .53696 L
.96667 .54049 L
Mistroke
.97619 .55089 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00803oool2000002P0oooo1@0000030?ooo`800000:03oool3000000<0
oooo0P00000W0?ooo`<00000103oool2000002H0oooo0`0000040?ooo`800000903oool3000000@0
oooo0P0000040?ooo`8000000`3oool001l0oooo00@000000?ooo`3oool00000:03oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000002@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo000O0?ooo`040000003oool0oooo000002T0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000U0?ooo`D000000P3oool010000000oooo0?ooo`00000U0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`007`3oool01000
0000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0S0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000009@3oool4000000<0
oooo00@000000?ooo`3oool000009@3oool3000000<0oooo00@000000?ooo`3oool00000903oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool001l0oooo00@000000?ooo`3oool000009`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000009P3oool00`000000oooo000000030?ooo`040000003oool0oooo
000002D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000T0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`007`3oool01000
0000oooo0?ooo`00000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00000W0?ooo`8000000`3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000903oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000008`3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`00803oool2000002T0oooo0`0000040?ooo`800000:@3oool00`000000oooo
0?ooo`020?ooo`800000:03oool2000000@0oooo0P00000V0?ooo`<00000103oool2000002D0oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P0000030?ooo`00o`3ooolJ0?ooo`00o`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`006`3ooook000000<0oooo000K
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`80
c03o1@00I_o]0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000103oool90<co00<00?mV
00<006Ko0<co003<o`00103<o`03003oIP@0c?l01@00ofH2001Vom80oooo0P0000030?ooo`006`3o
ool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo103<o`000`3<0?l0c?l00?oo
o`020<`0o`05001Vo`3<o`00c?l00<co0000I_l00`00ofH<0<co0003003oIP3<o`00c?l000@0c?l0
0P00ofH2001Vo`<0c?l000<0c03o003oIP00ofH00P00ofH2001VokT0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool09P3oool30<`0o`040<co0000I_l006Ko0?ooo`L0c?l0
00<0c03o001Vo`00I_l0303<o`04003oIP<0c?l000<006Ko003oIP00ofH01000ofH2001Vo`d00?mV
U`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`110?ooo`03003oIP3o
ool0c?l000<0c?l000<0c03o003oIP00ofH04`3<o`02001Vo`D0c?l00P00ofH50<co00<00?mVR@3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`180?ooo`030<co003oool0
oooo00H0oooo0P3<0?l00`3oool00?mV0?ooo`020?ooo`D0c03o0P3<o`000`3<0?l006Ko001Vo`02
001Vo`80c?l00`00I_l00`00ofH0c?l00<co000@0<co00800?mV0`3<o`05003oIW40oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00001U0?ooo`8006Ko00<0o`000<`0o`3<0?l04`00I_l20<co
0003001Vo`3<o`0006Ko0080c?l00P3<0?l30<co00800?mVK03oool2000000<0oooo000K0?ooo`03
0000003oool0oooo07<0oooo00@0o`000?ooo`3oool0oooo0`3<o`050<`0o`04001Vo`3<0?l0c03o
0<`0o`80c?l00`00I_l:0<co00P0oooo2`3<o`1B0?ooo`030000003oool0oooo0040oooo000K0?oo
o`030000003oool0oooo08<0oooo0`00ofH20<`0o`@006Ko0`3<0?l30?l000P0c?l000<00?mV0<co
003<o`000`3<o`050?ooo`80c?l0D03oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`2:0?ooo`80o`000`3oool70<`0o`D006Ko3000ofH70<co04T0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P0000040?ooo`80oiT000<0<ol0003oo`3oool0RP3oool00`3o0000oooo
0?ooo`040?ooo`D0o`002@00I_l5003oIPT0c?l00P00ofH60<co03T0oooo0P0000030?ooo`006`3o
ool00`000000oooo0?ooo`030?ooo`800?oo1@3oV@2D0?ooo`L0o`000P3<0?l00`00I_l0c03o0<`0
o`020<`0o`03003oIP3<0?l006Ko008006Ko00@00?mV001Vo`00I_l006Ko0P3<o`000`00I_l0c03o
0<`0o`03003oIP@0c?l0=P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`070?ooo`<0<ol00P3oV@0203?o00030?nI003oool0oooo09@0oooo0P3o0002001Vo`P00?mV103o
ool30?l0008006Ko0P3<0?l3001Vo`800?mV0`3<o`02003oIS40oooo00<000000?ooo`3oool00@3o
ool000H0oooo1@0000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo00X0oooo0P0co`050?nI09/0oooo0P3o00020?ooo`030?l00000ofH00?mV00D00?mV00D0o`00
003oIP00I_l006Ko0?ooo`020?l00003001Vo`3<0?l0c03o0080c03o2@3<o`040?ooo`<0c?l08`3o
ool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0?0?ooo`80<ol00P3oV@020?l0VIT0oooo
0P3o00030?ooo`D0o`000P00I_l7003oIP<0c?l000@0c03o0<co003o0000o`000P00ofH3001Vo`@0
c?l000<00?mV0?ooo`3oool01@3<o`0N0?ooo`030000003oool0oooo0040oooo00080?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool200000180oooo0P0c0?l30?nI0080<ol0
Y@3oool00`3o0000oooo001Vo`04001Vo`L0o`00103<o`000`00ofH0c03o0<`0o`07003oIPH0c?l0
5P3oool3000000<0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`@0oiT00P3o09VX0?ooo`@006Ko0P3oool3001Vo`800?mV00<0
06Ko0?ooo`3oool00P00ofH30<`0o`L006Ko00@00?mV0<co0000ofH00?mV0P3<o`020?ooo`@00?mV
3@3oool00`000000oooo0?ooo`010?ooo`001P3oool01@000000oooo0?ooo`3oool0000000L0oooo
100000050?ooo`030000003oool0oooo01P0oooo0P00ool30?nI0080<ol0Z@3oool2001Vo`H0oooo
1000I_l30?l000040<`0o`00ofH0c?l00<`0o`<0o`000P00I_l20<co0005001Vo`00ofH0c?l0003o
IP3<0?l00`3oool2003oIP/0oooo00<000000?ooo`3oool00@3oool000H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool20?nI
00<0<ol0/P3oool7001Vo`<0c03o0P00ofH50?l000D0c?l000<0c03o0<co0000ofH00`00ofH20<`0
o`D0oooo00<000000?ooo`3oool00@3oool000L0oooo0`0000080?ooo`D00000103oool00`000000
oooo0?ooo`0O0?ooo`D0oiT0]`3oool3001Vo`80c03o103oool00`00ofH0oooo0?ooo`080<co0003
0?l0003<o`00c?l000D0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00000U0?ooo`80oiT0
0`00oone0?ooo`80o`002P3<0?l20?ooo`80o`0000@0oooo0<co0000I_l00?mV103oool2000000<0
oooo000K0?ooo`030000003oool0oooo02H0oooo0`3oV@02003ookP0oooo00@006Ko0?l0003o0000
o`000`00I_l20<`0o`D0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`0Y0?ooo`@0oiT0_@3oool2001Vo`D0c03o1P3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`80<ol00`3oV@020?l0VKX0oooo0`00
I_l2003oIP030<`0o`3oool0oooo00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0;@3oool303?o0080oiT00P0c0?nm0?ooo`03001Vo`3oool0oooo00<0oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00000a0?ooo`80<ol00`3oV@310?ooo`8000000`3oool001/0
oooo00<000000?ooo`3oool0<P3oool303?o0080oiT00P0c0?nn0?ooo`030000003oool0oooo0040
oooo000K0?ooo`030000003oool0oooo03D0oooo0P0co`050?nI0;/0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool0=`3oool2003oo`<0<ol00P3oV@2i0?ooo`030000003o
ool0oooo0040oooo000K0?ooo`800000?@3oool203?o00<0oiT0]@3oool2000000<0oooo000K0?oo
o`030000003oool0oooo03h0oooo0P0co`000`00ool0oiT00?nI002d0?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo0400oooo00<0<ol0003oo`00ool00P3oV@2b0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0440oooo0P0co`02003oo`<0oiT0
[`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`130?ooo`@0<ol000<0
0?oo0?nI003oV@00[@3oool00`000000oooo0?ooo`010?ooo`006`3oool2000004P0oooo00<0<ol0
003oo`00ool00P3oV@2Z0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0B03oool203?o
0003003oo`0c0?l0oiT00080oiT0Z03oool00`000000oooo0?ooo`010?ooo`004`3oool3000000D0
oooo00<000000?ooo`3oool0BP3oool203?o00<0o`2I0P3oV@2V0?ooo`030000003oool0oooo0040
oooo000B0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1<0?ooo`<0
<ol000<00?oo0?l0V@3oV@000P3oV@2S0?ooo`030000003oool0oooo0040oooo000F0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`3oV@00<ol0003oo`030?l0V@040?nI
000c0?l0<`3o03<0oil0oooo00<000000?ooo`3oool00@3oool001H0oooo00<000000?ooo`3oool0
0P3oool200000500oooo00<0oiT003?o0000ool00P00ool0103o09T0oiT00?l0V@3o09T303<0oiX0
oooo0`0000030?ooo`004P3oool4000000D0oooo00<000000?ooo`3oool0D@3oool403?o0003003o
o`3oV@00oiT000<0o`2I0P0c0?nJ0?ooo`030000003oool0oooo0040oooo000B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0E03oool0103oV@00<ol0003oo`00ool30?nI0080o`2I
0`0c0?nG0?ooo`030000003oool0oooo0040oooo000B0?ooo`D00000103oool00`000000oooo0?oo
o`1F0?ooo`80<ol00`00ool20?nI0080o`2I00<0oooo03<0o`3oool0U@3oool00`000000oooo0?oo
o`010?ooo`006`3oool00`000000oooo0?ooo`1H0?ooo`<0<ol00P00ool30?nI00030?ooo`0c0?l0
oooo09@0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001L0?ooo`0303?o0000ool00?oo
00800?oo0P3oV@0503<0ohl0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1L0?ooo`03
03?o0000ool00?oo00800?oo00<0o`2I0?nI003o09T00`3oool203<0ohh0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool0G@3oool303?o00800?oo00@0o`2I0?nI003o09T0
o`2I0`3oool00`0c0?l0oooo0?ooo`2;0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000
003oool0oooo0600oooo0P0co`000`00ool0<ol00?nI00020?nI00<0oooo00<0<`3o0?ooo`3oool0
RP3oool00`000000oooo0?ooo`010?ooo`006`3oool2000006<0oooo00<0<ol0003oo`0co`000P0c
o`020?nI0080oooo0`0c0?n80?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0H`3oool0
1`0co`000?oo003oo`00ool0<ol003<0o`3oV@00103oool00`0c0?l0oooo0?ooo`260?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06@0oooo0`0co`02003oo`0303<0o`3o
V@00oooo00<0oooo00<0<`3o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`010?ooo`006`3oool0
0`000000oooo0?ooo`1W0?ooo`80<ol000<00?oo03?o003oV@000P3oV@020?ooo`D0<`3oPP3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1X0?ooo`030?nI000co`000?oo
00<0<ol000<0oiT00?l0V@3oool0103oool00`0c0?l0oooo0?ooo`1o0?ooo`030000003oool0oooo
0040oooo000K0?ooo`800000JP3oool01`3oV@00<ol0003oo`00ool0oooo03?o003oV@000P3o09T4
0?ooo`0303<0o`3oool0oooo07d0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1[0?oo
o`<0<ol00P3oool30?nI0080o`2I0P3oool203<0ogh0oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0KP3oool203?o00800?oo00<0<ol00?nI003oV@000P3o09T20?ooo`03
03<0o`3oool0oooo07/0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
K`3oool0103oV@00<ol003?o0000ool203?o0080oiT00P3o09T00`3oool0<`3o03<0o`1k0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0700oooo0P3oV@000`0co`000?oo
003oo`0203?o00<0oiT00P3oool303<0ogP0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00
001d0?ooo`<0<ol000@0oooo03?o000co`00<`3o0P3oV@020?l0V@030?ooo`0c0?l0oooo07D0oooo
0P0000030?ooo`006`3oool00`000000oooo0?ooo`1d0?ooo`030?nI0000ool0<ol000800?oo00<0
<ol003<0o`0c0?l00P3oV@000`3o09T0oooo03<0o`1f0?ooo`030000003oool0oooo0040oooo0008
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<00000
0?ooo`3oool0M@3oool20?nI0080<ol000<00?oo03?o000co`000P0c0?l0103oV@00o`2I0?l0V@0c
0?me0?ooo`030000003oool0oooo0040oooo00080?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07L0oooo0P3oV@000`0co`000?oo003o
o`0303?o00040?nI003oool0o`2I03<0og@0oooo00<000000?ooo`3oool00@3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00@0
oiT003?o000co`00<ol00P00ool0100co`00oiT00?ooo`3o09T303<0og40oooo00<000000?ooo`3o
ool00@3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000
N`3oool20?nI00030?ooo`0co`000?oo00800?oo0P3oV@030?l0V@0303<0o`3oool0oooo06`0oooo
0`0000030?ooo`002P3oool00`000000oooo0?ooo`050?ooo`@000001@3oool00`000000oooo0?oo
o`1l0?ooo`80oiT000D0<ol0003oo`0co`000?oo03<0o`030?nI00030?l0V@0c0?l0oooo06h0oooo
00<000000?ooo`3oool00@3oool000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0O`3oool303?o0007003oo`0c0?l0<`3o03<0o`3o
V@00oooo03<0o`1^0?ooo`030000003oool0oooo0040oooo00060?ooo`D000001`3oool5000000@0
oooo00<000000?ooo`3oool0O`3oool0103oV@00oooo03?o000co`03003oo`040?nI003o09T0oooo
03<0ofd0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000210?ooo`030?nI003oool0oooo
0080<ol000<0oooo003oo`3oV@000P3o09T203<0ofX0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`210?ooo`@0oiT000<0<ol00?ooo`00ool00P3oV@020?l0V@0303<0o`3oool0oooo06P0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0QP3oool203?o00800?oo
0P3oV@000`3oool0<`3o03<0o`1X0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo08L0oooo00<0oiT003?o000co`000P00ool00`3oV@00oooo0?ooo`0303<0ofD0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0R03oool01@0co`000?oo03?o000c
o`000?oo00<0oiT000<0oooo0?l0V@0c0?l0I03oool00`000000oooo0?ooo`010?ooo`006`3oool2
000008X0oooo00/0<ol0003oo`00ool0oooo003oo`0c0?l0oooo0?nI003oool0o`2I03<0o`1R0?oo
o`8000000`3oool001/0oooo00<000000?ooo`3oool0RP3oool303?o00080?ooo`00ool0<`3o03<0
o`3oV@00<`3o0?ooo`0c0?mR0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo08d0oooo00<0<ol0003oo`00ool00P00ool20?nI00030?ooo`0c0?l0oooo0600oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0SP3oool0200co`000?oo003oo`3oool0
0?oo0?ooo`3oV@00oooo0`0c0?mN0?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003o
ool0oooo08l0oooo0`0co`00103oool00?oo0?ooo`3oV@030?ooo`0303<0o`3o09T0oooo05/0oooo
00<000000?ooo`3oool00@3oool001/0oooo0P00002C0?ooo`80<ol000L00?oo03?o003oV@00oiT0
03<0o`3oool0<`3o0080o`2IF@3oool2000000<0oooo000K0?ooo`030000003oool0oooo0980oooo
00@00?oo0?nI000co`000?oo0P0co`000`3oV@00<`3o03<0o`0303<0oeT0oooo00<000000?ooo`3o
ool00@3oool001/0oooo00<000000?ooo`3oool0T`3oool00`00ool0<ol00?nI0002003oo`030?l0
V@3oV@00oiT000<0oooo00<0<`3o0?l0V@3oool0EP3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`2D0?ooo`05003oo`0co`00oiT00?nI0000ool00P3o09T20?nI0080oooo
00<0<`3o0?l0V@3o09T0E@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?oo
o`2F0?ooo`80<ol000<0oiT0003oo`00ool00P3o09T00`3oV@00oooo0?ooo`0203<0o`030?l0V@3o
ool0oooo0580oooo00<000000?ooo`3oool00@3oool001/0oooo0P00002I0?ooo`0803?o003oV@00
0?oo003oo`3oool0o`2I0?nI000co`020?ooo`<0<`3oD@3oool2000000<0oooo000K0?ooo`030000
003oool0oooo09T0oooo0P0co`02003oo`040?ooo`3o09T0oiT003?o00<0oooo00<0o`2I03<0o`0c
0?l0D03oool00`000000oooo0?ooo`010?ooo`003@3oool3000000@0oooo0P0000050?ooo`030000
003oool0oooo09/0oooo0P0co`000`00ool0oooo0?ooo`040?nI00040?ooo`3o09T0<`3o03<0odl0
oooo00<000000?ooo`3oool00@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo09d0oooo00D0<ol0003oo`00ool0oooo0?l0V@0203?o
00030?nI003oool0o`2I0080<`3oCP3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00002O0?ooo`0703?o003oV@000?oo
0?ooo`3o09T0oooo03?o00020?nI0080o`2I0`0c0?m90?ooo`<000000`3oool000h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo09l0oooo00H0
<ol00?nI0000ool0oooo0?l0V@3oool203?o0080oiT00P3o09T303<0odT0oooo00<000000?ooo`3o
ool00@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0:00oooo0P0co`03003oo`80oooo00L0<ol00?ooo`3oV@00oiT00?l0V@0c0?l0
oooo0080<`3oA`3oool00`000000oooo0?ooo`010?ooo`003@3oool2000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`2R0?ooo`<0<ol00P00ool01`0co`00oooo0?ooo`3o
ool0oiT00?l0V@0c0?l00P3oool00`0c0?l0oooo0?ooo`140?ooo`030000003oool0oooo0040oooo
000>0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0:@0oooo00D0
oiT003?o003oool00?oo03?o00030?ooo`80oiT01@0c0?m40?ooo`030000003oool0oooo0040oooo
000K0?ooo`800000YP3oool0100co`00oiT00?ooo`00ool403?o00060?ooo`3oV@00oiT00?l0V@0c
0?l0oooo0P0c0?m10?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0YP3oool00`0co`00
oiT00?nI0003003oo`060?ooo`0co`00oooo0?ooo`3oV@00o`2I0`3oool303<0ocl0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0YP3oool00`0co`000?oo0?ooo`030?nI
0005003oo`3o09T0<ol003?o003oool00P3oV@050?ooo`0303<0o`3oool0oooo03`0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0Y`3oool203?o00<0oooo00D0oiT0003o
o`3o09T0o`2I03?o00020?ooo`030?nI003oool0oooo00<0oooo00<0<`3o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2Y0?ooo`80<ol00P3oool01@3o
V@000?oo003oo`3o09T0<ol00080oooo00<0oiT00?ooo`3oool00`3oool203<0oc/0oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00002/0?ooo`0303?o003oool0oooo0080oiT000<00?oo03?o
003oool00P3oool30?nI00@0oooo00<0<`3o0?ooo`3oool0=`3oool2000000<0oooo000K0?ooo`03
0000003oool0oooo0:`0oooo0P0co`030?ooo`03003oo`0co`00oooo00@0oooo00<0oiT00?ooo`3o
ool00P3oool203<0ocP0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
[03oool00`00ool0oooo03?o00020?ooo`030?nI0000ool0<ol000<0<ol00P3oool00`3oV@00oooo
0?ooo`030?ooo`0303<0o`3oool0oooo03D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0[@3oool00`00ool0oooo03?o00020?ooo`030?nI0000ool00?oo0080o`2I00@0
<ol00?ooo`3oool0oiT0103o09T00`0c0?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo0:h0oooo0P00ool00`0co`000?oo003oo`020?nI00800?oo00H0
o`2I03?o003oool0oooo0?nI003oool203<0o`030?l0V@0c0?l0oooo03D0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00002b0?ooo`0403?o003oool00?oo0?ooo`80oiT000<00?oo0?l0V@0c
o`000P3oool01@3oV@00oooo0?ooo`0c0?l0o`2I0080<`3o<`3oool2000000<0oooo000K0?ooo`03
0000003oool0oooo0;80oooo00<0<ol0003oo`3oool00P3oool00`3oV@000?oo0?l0V@0203?o0003
0?ooo`3oV@00oiT00080oooo00<0o`2I03<0o`0c0?l0<`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`2c0?ooo`@0<ol000<0oooo0?nI0000ool00P3o09T00`0co`00oooo
0?ooo`020?nI00040?ooo`3o09T0oooo03<0oc80oooo00<000000?ooo`3oool00@3oool001/0oooo
00<000000?ooo`3oool0]@3oool00`00ool0oooo03?o00020?ooo`800?oo00<0oooo03?o003o09T0
0P3oool20?nI00030?l0V@0c0?l0<`3o0340oooo00<000000?ooo`3oool00@3oool001/0oooo0P00
002g0?ooo`03003oo`3oool0<ol000<0oooo00@00?oo0?ooo`0co`00o`2I0`3oool0103oV@00o`2I
0?l0V@0c0?l_0?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0]`3oool00`00ool0oooo
03?o00030?ooo`800?oo0P0co`030?ooo`030?nI003oool0o`2I00<0<`3o;@3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2h0?ooo`04003oo`3oool0<ol003?o0080oooo
00<0oiT0003oo`3o09T00P0co`020?ooo`030?nI003oool0o`2I00<0<`3o;03oool00`000000oooo
0?ooo`010?ooo`0000@0oooo00000000000000000P3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool3000000D0oooo00<000000?ooo`3oool0^@3oool01000ool0oooo0?ooo`0co`020?ooo`05
0?nI0000ool0o`2I0?l0V@0co`000P3oool00`3oV@00oooo0?l0V@020?l0V@80<`3o:P3oool00`00
0000oooo0?ooo`010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0;X0oooo0P00ool0
1@3oool0<ol003?o003oool0oiT000800?oo00D0o`2I03?o000co`00oooo0?nI00030?ooo`040?l0
V@0c0?l0<`3o03<0obP0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00002m0?ooo`05003o
o`3oool0oooo03?o003oool00P3oV@001@00ool0o`2I0?ooo`0co`00oooo0080oiT00P3oool0103o
09T0<`3o03<0o`0c0?lU0?ooo`<000000`3oool00080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0_@3oool01000
ool0oooo0?ooo`0co`020?ooo`050?nI0000ool0o`2I0?ooo`0co`000P3oool00`3oV@00oooo0?oo
o`020?l0V@@0<`3o903oool00`000000oooo0?ooo`010?ooo`000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<000000?ooo`3oool0_P3o
ool00`00ool0oooo0?ooo`0303?o00040?nI0000ool0o`2I0?ooo`80<ol000<0oooo0?nI003oV@00
0`3oool403<0ob<0oooo00<000000?ooo`3oool00@3oool000030?ooo`000000000000<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
_`3oool4003oo`050?ooo`0co`00<ol0003oo`3o09T00P3oool0100co`00oooo0?ooo`3oV@030?oo
o`030?l0V@0c0?l0oooo0080<`3o8@3oool00`000000oooo0?ooo`010?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`<00000203oool5000000@0oooo00<000000?ooo`3oool0``3oool00`00ool0
oooo0?ooo`0603?o0080oooo00H0oiT00?ooo`3oool0oooo0?l0V@0c0?l20?l0V@0303<0o`3oool0
oooo01h0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000350?ooo`04003oo`3oool0oooo
0?nI00800?oo00<0o`2I03?o003oool00P3oool01@3oV@00oooo0?nI003oV@00oooo0080<`3o00<0
o`2I03<0o`3oool07@3oool2000000<0oooo000K0?ooo`030000003oool0oooo0<D0oooo00<00?oo
0?ooo`3oool00P3oV@000`00ool0o`2I03?o00030?ooo`040?nI003oool0oooo0?nI0080oooo00<0
<`3o0?l0V@0c0?l07P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`36
0?ooo`06003oo`3oool0oooo0?ooo`3oV@000?oo0`0co`050?ooo`<0oiT0100c0?lL0?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0<L0oooo00H00?oo0?ooo`3oool0oooo
0?nI0000ool303?o00L0oooo00@0oiT00?ooo`0c0?l0oooo0`0c0?lI0?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo0<P0oooo0P00ool30?ooo`<00?oo00<0<ol00?l0V@3o
ool01@3oool00`3oV@00oooo03<0o`030?ooo`0303<0o`3oool0oooo01H0oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00003;0?ooo`03003oo`3oool0oooo0080oooo00@0oiT0003oo`0co`00
o`2I1P3oool30?nI000403<0o`3o09T0oooo03<0oaH0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`3;0?ooo`800?oo0`3oool00`3oV@00<ol003?o00090?ooo`040?nI000c0?l0o`2I0?oo
o`@0<`3o4`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3=0?ooo`<0
0?oo00@0oooo0?nI000co`00<ol02@3oool00`3oV@00<`3o03<0o`040?ooo`0303<0o`3oool0oooo
0100oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0d03oool00`00ool0
oooo0?nI000403?o00L0oooo103oV@000`0c0?l0oooo0?ooo`0203<0oa00oooo00<000000?ooo`3o
ool00@3oool001/0oooo0P00003B0?ooo`03003oo`3oool0oiT000D0<ol02@3oool00`3oV@00<`3o
0?ooo`020?ooo`<0<`3o303oool2000000<0oooo000K0?ooo`030000003oool0oooo0=80oooo00L0
0?oo0?ooo`3oV@000?oo0?ooo`0co`00o`2I0080<ol0203oool20?nI00D0oooo0P0c0?l;0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0=<0oooo00T00?oo0?ooo`3oool0
0?oo0?ooo`0co`00o`2I0?ooo`0co`00203oool00`0c0?l0oiT00?ooo`050?ooo`80<`3o2@3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3D0?ooo`D00?oo00<0<ol00?l0
V@0co`002@3oool00`3oV@00<`3o0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<000000?oo
o`3oool00@3oool001/0oooo00<000000?ooo`3oool0e`3oool01000ool0oiT0003oo`0co`02003o
o`030?l0V@3oool0oooo00H0oooo00<0oiT003<0o`0c0?l01P3oool203<0o`H0oooo00<000000?oo
o`3oool00@3oool001/0oooo0P00003I0?ooo`03003oo`3oV@00oooo00<0<ol000<0o`2I0?ooo`3o
ool01P3oool40?nI00H0oooo00<0<`3o0?ooo`3oool00P3oool2000000<0oooo000K0?ooo`030000
003oool0oooo0=T0oooo00<00?oo0?nI003oool00P3oool203?o00X0oooo00<0<`3o0?nI003oool0
2P3oool00`000000oooo0?ooo`010?ooo`003@3oool3000000<0oooo0`0000050?ooo`030000003o
ool0oooo0=X0oooo00<00?oo0?nI003oool00P3oool01000ool0<ol003?o000co`080?ooo`0403<0
o`3oV@00oiT00?nI00P0oooo00<000000?ooo`3oool00@3oool000h0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0f`3oool00`00ool0
oiT00?ooo`020?ooo`800?oo0P0co`080?ooo`<0<`3o00<0oiT00?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0g@3oool00`3oV@00oooo0?ooo`020?ooo`03003oo`0co`00oooo00X0oooo
00<0o`2I0?nI003oool01@3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo0P00003O0?ooo`030?nI0000ool0oooo0080oooo00<0
<ol0003oo`3oool02`3oool0103oV@00oooo0?ooo`3oool3000000<0oooo000>0?ooo`040000003o
ool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`3O0?ooo`030?nI0000ool00?oo0080oooo
00<0<ol0003oo`00ool0403oool00`000000oooo0?ooo`010?ooo`003@3oool2000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3P0?ooo`80oiT000D00?oo0?ooo`0co`00<ol0
0?ooo`02003oo`h0oooo00<000000?ooo`3oool00@3oool000h0oooo00@000000?ooo`3oool0oooo
1@0000040?ooo`030000003oool0oooo0>80oooo00<0oiT0003oo`00ool00P0co`020?ooo`03003o
o`3oool0oooo00/0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0h`3o
ool20?nI00800?oo0`0co`02003oo`/0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00003V
0?ooo`80oiT00P00ool00`0co`00oooo03?o0005003oo`D0oooo0P0000030?ooo`006`3oool00`00
0000oooo0?ooo`3W0?ooo`80oiT000<0oooo03?o000co`000P0co`030?ooo`03003oo`3oool0oooo
00<0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0j@3oool00`3oV@00
oooo003oo`0303?o00P0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
jP3oool0103oV@00oooo003oo`00ool403?o00D0oooo00<000000?ooo`3oool00@3oool001/0oooo
0P00003/0?ooo`040?nI003oool0oooo003oo`<0<ol0103oool2000000<0oooo000K0?ooo`030000
003oool0oooo0>`0oooo0P3oV@000`3oool00?oo003oo`060?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo0>h0oooo00@0oiT00?ooo`3oool00?oo1@3oool00`000000oooo
0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`3_0?ooo`030?nI003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0l03oool00`3oV@00oooo0?ooo`04
0?ooo`030000003oool0oooo0040oooo000K0?ooo`800000lP3oool00`3oV@00oooo0?ooo`020?oo
o`8000000`3oool001/0oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000K0?oooo/000000`3o
ool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.938, 0}} -> {-13.8823, -0.916352, \
0.419554, 0.105204}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["missing data",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell["\<\
miss = -9;
ZM = Shape[miss,{n,T+1,p}];
tau = {0,10,20,30,50,60,70,80,85,90,95,100}+1;
Do[ ZM[[nn,tau[[i]] ]] = Z[[nn,tau[[i]] ]],{nn,1,n},{i,Length[tau]}];\
\>", \
"Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ZM//Dimensions", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ZM[[1]]
ZM[[2]]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({{0.9853538461030534`, 
        2.0740187211878744`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.077813796071975`, 
        2.6727319749555356`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.1547349018773654`, 
        3.476976675906855`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.3162220258133948`, 
        4.487641258324093`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {1.699958532544524`, 
        7.122032367816248`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.9182695333607016`, 
        8.811001611446317`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {2.2151775751822593`, 
        10.47686958122993`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {2.5094680754457346`, 
        12.268076240053894`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {2.5382540514572045`, 
        13.315073620425721`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {2.8576034804390558`, 
        14.155208911389128`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {3.1382659546867404`, 
        15.084669071317837`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {3.3017516132652562`, 
        16.165136811661313`}}\)], "Output"],

Cell[BoxData[
    \({{1.0011589276984616`, 
        1.9912078153611885`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.064869019779939`, 
        2.6957188358119186`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.1874673263177777`, 
        3.5806419825250693`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.3024870421659107`, 
        4.560941918139714`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {1.5087429282705067`, 
        7.099903994222946`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {1.7810333101693296`, 
        8.616641018934835`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {2.00857418253858`, 
        9.985498667481055`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {2.2622503022499734`, 
        11.652451900193467`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {2.4157030218437976`, 
        12.336379400117938`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {2.5408723037240164`, 
        13.191257451315202`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {2.7039454237561675`, 
        13.85723942809691`}, {\(-9\), \(-9\)}, {\(-9\), \(-9\)}, {\(-9\), \
\(-9\)}, {\(-9\), \(-9\)}, {2.8132844213439983`, 
        14.529854700309267`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fisher=True", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

F0 = IdentityMatrix[6]//N;
Alles = {1,1,1,1,1,1,1,1};

{THETA,COV,likpsi,k} =
\tMNonLinBFGS[Theta,F0,KMAX=100,EPS=.001,ZM,X,k,p,q,n,np=1,T,dt,
\t\t\tOPTION=0,Nonlin,miss,mue,sigma,
\t\t\tdrift,diffusion,Jacobif,h,R,Jacobih,PRINT = Alles];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("***********************LSDE1**********************************"\)], \
"Print"],

Cell[BoxData[
    \("***********************MODUL: MNonLinBFGS*********************"\)], \
"Print"],

Cell[BoxData[
    \("**************************************************************"\)], \
"Print"],

Cell[BoxData[
    \("Technical Output"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"KMAX\"\>", "\<\"EPS\"\>", "\<\"K\"\>", \
"\<\"P\"\>", "\<\"Q\"\>", "\<\"n\"\>", "\<\"np\"\>", "\<\"T\"\>", \
"\<\"DT\"\>", "\<\"OPTION\"\>", "\<\"NONLIN\"\>", "\<\"MISS\"\>", \
"\<\"MAXSTEP\"\>", "\<\"MINSTEP\"\>", "\<\"BOUND\"\>", "\<\"stepreduce\"\>"},
          {"1", "100", "0.001`", "16", "2", "1", "1", "1", "100", "0.1`", "0",
             "0", \(-9\), "100.`", "1.`*^-10", "1.`*^-6", "3"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"KMAX", "EPS", "K", "P", 
          "Q", "n", "np", "T", "DT", "OPTION", "NONLIN", "MISS", "MAXSTEP", 
          "MINSTEP", "BOUND", "stepreduce"}}, TableDirections -> {Column, 
          Row}, TableSpacing -> {0, 2}]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("STARTWERT THETA0 = "\[InvisibleSpace]{10.`, \
\(-1.`\), 2.`, 30.`, 1.`, \(-2.`\)}\),
      SequenceForm[ 
      "STARTWERT THETA0 = ", {10.0, -1.0, 2.0, 30.0, 1.0, -2.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]1\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{15.407956790924072`, 29.137200355529785`, 
          3.225025177001953`, 36.03093582789103`, 44.37734317779541`, 
          31.40488290786743`}\[InvisibleSpace]"   "\[InvisibleSpace]{10.`, \
\(-1.`\), 2.`, 30.`, 1.`, \(-2.`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {15.407956790924072, 29.137200355529785, 
        3.2250251770019531, 36.030935827891028, 44.37734317779541, 
        31.404882907867432}, "   ", {10.0, -1.0, 2.0, 30.0, 1.0, -2.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-169191.397525182000000\"\>",
            -169191.39752518202,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ -169191.39752518202, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-21081.567795814660000\"\>",
            -21081.567795814659,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 2, "  LIKNEU  ", 
        PaddedForm[ -21081.567795814659, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "3", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" -2240.784216064595000\"\>",
            -2240.7842160645951,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 3, "  LIKNEU  ", 
        PaddedForm[ -2240.7842160645951, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "4", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  -159.654681688826000\"\>",
            -159.65468168882603,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 4, "  LIKNEU  ", 
        PaddedForm[ -159.65468168882603, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "5", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    50.932750572699160\"\>",
            50.932750572699163,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 5, "  LIKNEU  ", 
        PaddedForm[ 50.932750572699163, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "6", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 6, "  LIKNEU  ", 
        PaddedForm[ 67.096741204098592, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    65.031154713832660\"\>",
            65.031154713832663,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 67.096741204098592, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 65.031154713832663, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     2.065586490265929\"\>",
            2.0655864902659289,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 2.0655864902659289, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "10.007418322072597`", "10.`", "0.007418322072598177`", 
            "5.407956790924072`"},
          {"2", \(-0.9586595331199866`\), \(-1.`\), "0.0413404668800134`", 
            "30.137200355529785`"},
          {"3", "2.0016804186241455`", "2.`", "0.0016804186241453395`", 
            "1.2250251770019531`"},
          {"4", "30.0082728886528`", "30.`", "0.008272888652799766`", 
            "6.030935827891032`"},
          {"5", "1.0595025283646027`", "1.`", "0.059502528364602736`", 
            "43.37734317779541`"},
          {"6", \(-1.9541771153527197`\), \(-2.`\), "0.04582288464728042`", 
            "33.40488290786743`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.\"\>",
                  0.0,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.\"\>",
                  1.0,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.14775937713642712`\
\[InvisibleSpace]"  "\[InvisibleSpace]133.76820776930393`\),
      SequenceForm[ 
      "*BFGSUP ", 0.14775937713642712, "  ", 133.76820776930393],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]2\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{13.887703615608103`, 26.112649916793178`, 
          1.4346863580307083`, 28.219567632013913`, 
          43.62712672304869`, \(-22.43762144518468`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{10.007418322072597`, \(-0.9586595331199866`\), 
          2.0016804186241455`, 30.0082728886528`, 
          1.0595025283646027`, \(-1.9541771153527197`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {13.887703615608103, 26.112649916793178, 
        1.4346863580307083, 28.219567632013913, 
        43.62712672304869, -22.437621445184678}, "   ", {
        10.007418322072597, -0.95865953311998664, 2.0016804186241455, 
        30.008272888652801, 1.0595025283646027, -1.9541771153527197}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-99352.894256691700000\"\>",
            -99352.894256691652,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ -99352.894256691652, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-12195.621433827290000\"\>",
            -12195.621433827288,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 2, "  LIKNEU  ", 
        PaddedForm[ -12195.621433827288, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "3", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" -1268.433549169957000\"\>",
            -1268.4335491699571,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 3, "  LIKNEU  ", 
        PaddedForm[ -1268.4335491699571, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "4", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   -65.231142648313070\"\>",
            -65.231142648313067,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 4, "  LIKNEU  ", 
        PaddedForm[ -65.231142648313067, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "5", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    57.845567236538270\"\>",
            57.845567236538272,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 5, "  LIKNEU  ", 
        PaddedForm[ 57.845567236538272, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "6", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.887582673859810\"\>",
            67.887582673859811,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 6, "  LIKNEU  ", 
        PaddedForm[ 67.887582673859811, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.887582673859810\"\>",
            67.887582673859811,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.096741204098600\"\>",
            67.096741204098592,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 67.887582673859811, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 67.096741204098592, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.790841469761219\"\>",
            0.79084146976121872,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.79084146976121872, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "10.012741072818187`", "10.007418322072597`", 
            "0.005322750745590543`", "0.15091686885860095`"},
          {"2", \(-0.9215246779074857`\), \(-0.9586595331199866`\), 
            "0.03713485521250089`", "7.605947831068893`"},
          {"3", "2.000902648993702`", 
            "2.0016804186241455`", \(-0.0007777696304436723`\), \
\(-1.7614928090647488`\)},
          {"4", "30.00581924632545`", 
            "30.0082728886528`", \(-0.002453642327351009`\), \
\(-7.426856958201539`\)},
          {"5", "1.117894331100795`", "1.0595025283646027`", 
            "0.058391802736192155`", "15.421990338776007`"},
          {
            "6", \(-1.9822751185486482`\), \(-1.9541771153527197`\), \
\(-0.028098003195928596`\), \(-54.27055492215573`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 5.076\"\>",
                  5.0761859421530913,
                  AutoDelete->True], 
                InterpretationBox["\<\" 17.46\"\>",
                  17.460733871933705,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.318\"\>",
                  2.3181907765040064,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.45\"\>",
                  10.445493677309223,
                  AutoDelete->True], 
                InterpretationBox["\<\" 21.66\"\>",
                  21.656027079694145,
                  AutoDelete->True], 
                InterpretationBox["\<\" 68.06\"\>",
                  68.058787020356306,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 17.46\"\>",
                  17.460733871933705,
                  AutoDelete->True], 
                InterpretationBox["\<\" 75.78\"\>",
                  75.782517962371003,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.933\"\>",
                  9.9334343623259169,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.76\"\>",
                  44.757986002999409,
                  AutoDelete->True], 
                InterpretationBox["\<\" 92.74\"\>",
                  92.740016623909185,
                  AutoDelete->True], 
                InterpretationBox["\<\" 291.6\"\>",
                  291.63600182757648,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 2.318\"\>",
                  2.3181907765040064,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.933\"\>",
                  9.9334343623259169,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.318\"\>",
                  2.3175309522103325,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.937\"\>",
                  5.9368764166909722,
                  AutoDelete->True], 
                InterpretationBox["\<\" 12.32\"\>",
                  12.32293150892327,
                  AutoDelete->True], 
                InterpretationBox["\<\" 38.68\"\>",
                  38.679646169895406,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 10.45\"\>",
                  10.445493677309225,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.76\"\>",
                  44.757986002999409,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.937\"\>",
                  5.9368764166909722,
                  AutoDelete->True], 
                InterpretationBox["\<\" 27.75\"\>",
                  27.751868706685453,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.52\"\>",
                  55.523792236281132,
                  AutoDelete->True], 
                InterpretationBox["\<\" 174.3\"\>",
                  174.29322037282301,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 21.66\"\>",
                  21.656027079694145,
                  AutoDelete->True], 
                InterpretationBox["\<\" 92.74\"\>",
                  92.74001662390917,
                  AutoDelete->True], 
                InterpretationBox["\<\" 12.32\"\>",
                  12.322931508923268,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.52\"\>",
                  55.523792236281125,
                  AutoDelete->True], 
                InterpretationBox["\<\" 116.\"\>",
                  116.00059901289195,
                  AutoDelete->True], 
                InterpretationBox["\<\" 361.8\"\>",
                  361.79317888450583,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 68.06\"\>",
                  68.058787020356306,
                  AutoDelete->True], 
                InterpretationBox["\<\" 291.6\"\>",
                  291.63600182757648,
                  AutoDelete->True], 
                InterpretationBox["\<\" 38.68\"\>",
                  38.679646169895406,
                  AutoDelete->True], 
                InterpretationBox["\<\" 174.3\"\>",
                  174.29322037282299,
                  AutoDelete->True], 
                InterpretationBox["\<\" 361.8\"\>",
                  361.79317888450583,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1137.\"\>",
                  1136.5428532657352,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.2580783217749249`\
\[InvisibleSpace]"  "\[InvisibleSpace]267.2038606536172`\),
      SequenceForm[ "*BFGSUP ", 0.2580783217749249, "  ", 267.2038606536172],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]3\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{7.737793123831384`, \(-3.670394101954403`\), 
          2.0862625123362135`, 30.896958957868314`, 
          3.7092319251356964`, \(-2.120551580155041`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{10.012741072818187`, \(-0.9215246779074857`\), 
          2.000902648993702`, 30.00581924632545`, 
          1.117894331100795`, \(-1.9822751185486482`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {7.7377931238313842, -3.6703941019544031, 
        2.0862625123362135, 30.896958957868314, 
        3.7092319251356964, -2.1205515801550412}, "   ", {
        10.012741072818187, -0.92152467790748571, 2.0009026489937018, 
        30.005819246325451, 1.1178943311007949, -1.9822751185486482}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    57.365191479460470\"\>",
            57.365191479460471,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.887582673859810\"\>",
            67.887582673859811,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ 57.365191479460471, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.887582673859811, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    68.252399320682620\"\>",
            68.252399320682613,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.887582673859810\"\>",
            67.887582673859811,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 2, "  LIKNEU  ", 
        PaddedForm[ 68.252399320682613, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 67.887582673859811, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    68.252399320682620\"\>",
            68.252399320682613,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    67.887582673859810\"\>",
            67.887582673859811,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 68.252399320682613, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 67.887582673859811, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.364816646822803\"\>",
            0.36481664682280268,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.36481664682280268, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "9.75996907848632`", 
            "10.012741072818187`", \(-0.25277199433186703`\), \
\(-4.7976549540092694`\)},
          {
            "2", \(-1.2269546139126986`\), \(-0.9215246779074857`\), \
\(-0.30542993600521295`\), \(-13.684959307032672`\)},
          {"3", "2.0103870782539808`", "2.000902648993702`", 
            "0.00948442926027906`", "0.045119426079025506`"},
          {"4", "30.104834769830212`", "30.00581924632545`", 
            "0.09901552350476273`", "0.6976185222043154`"},
          {"5", "1.4058207304380061`", "1.117894331100795`", 
            "0.28792639933721126`", \(-11.092232924385302`\)},
          {
            "6", \(-1.9976391698382474`\), \(-1.9822751185486482`\), \
\(-0.015364051289599234`\), \(-1.3036251196568813`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 11.4\"\>",
                  11.396090138901254,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.65\"\>",
                  44.651181136548551,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.01107\"\>",
                  0.011065425923456385,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.07013\"\>",
                  0.070134320063361955,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.52\"\>",
                  55.516678112850464,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4178\"\>",
                  0.41782673852311802,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 44.65\"\>",
                  44.651181136548551,
                  AutoDelete->True], 
                InterpretationBox["\<\" 192.7\"\>",
                  192.74103824779635,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.01334\"\>",
                  0.013339428558223787,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1447\"\>",
                  0.14465704175097471,
                  AutoDelete->True], 
                InterpretationBox["\<\" 238.4\"\>",
                  238.36931461945761,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.805\"\>",
                  0.8050110978871885,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.01107\"\>",
                  0.011065425923456385,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.01334\"\>",
                  0.013339428558225563,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.158\"\>",
                  3.1582992175815705,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.718\"\>",
                  9.7183147293404399,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.0256\"\>",
                  -0.025598887881315591,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.33\"\>",
                  63.327276895486577,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.07013\"\>",
                  0.070134320063363731,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1447\"\>",
                  0.14465704175097471,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.718\"\>",
                  9.7183147293404417,
                  AutoDelete->True], 
                InterpretationBox["\<\" 44.76\"\>",
                  44.759137712659658,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.01234\"\>",
                  -0.012343678865420316,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.1\"\>",
                  285.14902841308219,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.52\"\>",
                  55.516678112850464,
                  AutoDelete->True], 
                InterpretationBox["\<\" 238.4\"\>",
                  238.36931461945758,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.0256\"\>",
                  -0.025598887881317367,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.01234\"\>",
                  -0.012343678865427421,
                  AutoDelete->True], 
                InterpretationBox["\<\" 297.3\"\>",
                  297.31111788392599,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.2253\"\>",
                  -0.22526490715995351,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4178\"\>",
                  0.41782673852311802,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.805\"\>",
                  0.8050110978871885,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.33\"\>",
                  63.327276895486577,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.1\"\>",
                  285.14902841308214,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.2253\"\>",
                  -0.22526490715995351,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1859.\"\>",
                  1859.0995955801181,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.25965268503211936`\
\[InvisibleSpace]"  "\[InvisibleSpace]3.9330604850738866`\),
      SequenceForm[ 
      "*BFGSUP ", 0.25965268503211936, "  ", 3.9330604850738866],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]4\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{9.155154643998525`, \(-0.8326342469318819`\), 
          1.7538550073651837`, 30.13925968929484`, 
          1.1598131833932508`, \(-1.9949214275970049`\)}\[InvisibleSpace]"   \
"\[InvisibleSpace]{9.75996907848632`, \(-1.2269546139126986`\), 
          2.0103870782539808`, 30.104834769830212`, 
          1.4058207304380061`, \(-1.9976391698382474`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {9.1551546439985252, -0.83263424693188193, 
        1.7538550073651837, 30.139259689294839, 
        1.1598131833932508, -1.9949214275970049}, "   ", {
        9.7599690784863196, -1.2269546139126986, 2.0103870782539808, 
        30.104834769830212, 1.4058207304380061, -1.9976391698382474}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.398624716465970\"\>",
            69.398624716465974,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    68.252399320682620\"\>",
            68.252399320682613,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 69.398624716465974, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 68.252399320682613, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.146225395783361\"\>",
            1.146225395783361,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 1.146225395783361, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "9.155154643998525`", 
            "9.75996907848632`", \(-0.604814434487795`\), \
\(-1.5799667237372992`\)},
          {"2", \(-0.8326342469318819`\), \(-1.2269546139126986`\), 
            "0.3943203669808167`", \(-6.606696903551422`\)},
          {"3", "1.7538550073651837`", 
            "2.0103870782539808`", \(-0.25653207088879715`\), \
\(-0.5344073424794453`\)},
          {"4", "30.13925968929484`", "30.104834769830212`", 
            "0.034424919464627245`", \(-0.7589913428287254`\)},
          {"5", "1.1598131833932508`", 
            "1.4058207304380061`", \(-0.24600754704475544`\), \
\(-13.609213462401762`\)},
          {"6", \(-1.9949214275970049`\), \(-1.9976391698382474`\), 
            "0.0027177422412425194`", \(-1.1984967663514745`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.97\"\>",
                  12.96676441881602,
                  AutoDelete->True], 
                InterpretationBox["\<\" 47.38\"\>",
                  47.376939000024116,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.4626\"\>",
                  -0.46260754503795387,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.9843\"\>",
                  -0.98432142411564905,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.83\"\>",
                  50.829781243075331,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.202\"\>",
                  0.20197172688800025,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 47.38\"\>",
                  47.376939000024116,
                  AutoDelete->True], 
                InterpretationBox["\<\" 196.7\"\>",
                  196.65657221239437,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.022\"\>",
                  -1.0217854769748909,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.069\"\>",
                  -2.0688701837478458,
                  AutoDelete->True], 
                InterpretationBox["\<\" 226.4\"\>",
                  226.37269248548759,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.132\"\>",
                  0.13197824356726895,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.4626\"\>",
                  -0.46260754503795387,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.022\"\>",
                  -1.0217854769748891,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.245\"\>",
                  3.2454050539256731,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.936\"\>",
                  9.9359707261418233,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3774\"\>",
                  0.3774466982047851,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.31\"\>",
                  63.314313659146556,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.9843\"\>",
                  -0.98432142411564727,
                  AutoDelete->True], 
                InterpretationBox["\<\"-2.069\"\>",
                  -2.0688701837478458,
                  AutoDelete->True], 
                InterpretationBox["\<\" 9.936\"\>",
                  9.9359707261418251,
                  AutoDelete->True], 
                InterpretationBox["\<\" 45.29\"\>",
                  45.28641503449218,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.315\"\>",
                  1.3153460435651483,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.2\"\>",
                  285.15342624376171,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.83\"\>",
                  50.829781243075331,
                  AutoDelete->True], 
                InterpretationBox["\<\" 226.4\"\>",
                  226.37269248548756,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3774\"\>",
                  0.37744669820478327,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.315\"\>",
                  1.315346043565141,
                  AutoDelete->True], 
                InterpretationBox["\<\" 293.\"\>",
                  292.9818148294022,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.9961\"\>",
                  -0.99610021142098215,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.202\"\>",
                  0.20197172688800025,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.132\"\>",
                  0.13197824356726884,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.31\"\>",
                  63.314313659146556,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.2\"\>",
                  285.15342624376166,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.9961\"\>",
                  -0.99610021142098215,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1859.\"\>",
                  1859.0199468067583,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.7570479849486812`\
\[InvisibleSpace]"  "\[InvisibleSpace]0.5536767595299494`\),
      SequenceForm[ 
      "*BFGSUP ", 0.7570479849486812, "  ", 0.55367675952994944],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]5\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{8.166284991610697`, \(-0.30438613157421324`\), 
          1.4866737502042344`, 30.638095611952924`, 
          0.9050013658416445`, \(-2.062676370524414`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{9.155154643998525`, \(-0.8326342469318819`\), 
          1.7538550073651837`, 30.13925968929484`, 
          1.1598131833932508`, \(-1.9949214275970049`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {8.1662849916106968, -0.30438613157421324, 
        1.4866737502042344, 30.638095611952924, 
        0.90500136584164448, -2.062676370524414}, "   ", {
        9.1551546439985252, -0.83263424693188193, 1.7538550073651837, 
        30.139259689294839, 1.1598131833932508, -1.9949214275970049}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"STEP-REDUCTION:  \"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"  LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.535666855311420\"\>",
            69.535666855311419,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], 
        "\[InvisibleSpace]", "\<\"  LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.398624716465970\"\>",
            69.398624716465974,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "STEP-REDUCTION:  ", 1, "  LIKNEU  ", 
        PaddedForm[ 69.535666855311419, {20, 15}], "  LIKALT  ", 
        PaddedForm[ 69.398624716465974, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.535666855311420\"\>",
            69.535666855311419,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.398624716465970\"\>",
            69.398624716465974,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 69.535666855311419, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 69.398624716465974, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.137042138845445\"\>",
            0.13704213884544458,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.13704213884544458, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "8.825531426535916`", 
            "9.155154643998525`", \(-0.32962321746260925`\), \
\(-0.36351930014827205`\)},
          {"2", \(-0.6565515418126591`\), \(-0.8326342469318819`\), 
            "0.1760827051192229`", "0.8960023615842792`"},
          {"3", "1.664794588311534`", 
            "1.7538550073651837`", \(-0.08906041905364973`\), \
\(-0.12092654771058023`\)},
          {"4", "30.305538330180866`", "30.13925968929484`", 
            "0.16627864088602856`", "0.3393781192979614`"},
          {"5", "1.0748759108760486`", 
            "1.1598131833932508`", \(-0.0849372725172021`\), 
            "0.5310330101582454`"},
          {
            "6", \(-2.017506408572808`\), \(-1.9949214275970049`\), \
\(-0.02258498097580307`\), \(-0.019299399612952715`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.7\"\>",
                  12.704861443042923,
                  AutoDelete->True], 
                InterpretationBox["\<\" 48.51\"\>",
                  48.506764770921563,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.5493\"\>",
                  -0.54932398697792184,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.6368\"\>",
                  -0.63678170963763114,
                  AutoDelete->True], 
                InterpretationBox["\<\" 51.95\"\>",
                  51.946446992294511,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2395\"\>",
                  0.23947126634236959,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 48.51\"\>",
                  48.506764770921556,
                  AutoDelete->True], 
                InterpretationBox["\<\" 215.1\"\>",
                  215.10404996128932,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.6281\"\>",
                  -0.62810297023533246,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.393\"\>",
                  1.3933912124390515,
                  AutoDelete->True], 
                InterpretationBox["\<\" 256.9\"\>",
                  256.90576968482418,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.446\"\>",
                  2.4456346805148605,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.5493\"\>",
                  -0.54932398697792195,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.6281\"\>",
                  -0.62810297023533024,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.217\"\>",
                  3.2167095836162343,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.06\"\>",
                  10.055210477080749,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7769\"\>",
                  0.77687900713211766,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.33\"\>",
                  63.32880976137784,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.6368\"\>",
                  -0.63678170963762959,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.393\"\>",
                  1.3933912124390515,
                  AutoDelete->True], 
                InterpretationBox["\<\" 10.06\"\>",
                  10.055210477080751,
                  AutoDelete->True], 
                InterpretationBox["\<\" 45.88\"\>",
                  45.880774053946006,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.354\"\>",
                  7.3541413754052591,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.6\"\>",
                  285.63029920936941,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 51.95\"\>",
                  51.946446992294511,
                  AutoDelete->True], 
                InterpretationBox["\<\" 256.9\"\>",
                  256.90576968482418,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7769\"\>",
                  0.77687900713211588,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.354\"\>",
                  7.3541413754052503,
                  AutoDelete->True], 
                InterpretationBox["\<\" 341.8\"\>",
                  341.80410771671757,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.596\"\>",
                  2.5962257125038342,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2395\"\>",
                  0.23947126634236937,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.446\"\>",
                  2.4456346805148614,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.33\"\>",
                  63.32880976137784,
                  AutoDelete->True], 
                InterpretationBox["\<\" 285.6\"\>",
                  285.63029920936935,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.596\"\>",
                  2.5962257125038359,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1859.\"\>",
                  1859.2773286458503,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]3.0659508249553213`\
\[InvisibleSpace]"  "\[InvisibleSpace]9.995755020870034`\),
      SequenceForm[ "*BFGSUP ", 3.0659508249553213, "  ", 9.9957550208700336],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]6\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{4.742322606760308`, 
          1.1334822735409986`, \(-0.05274896725825928`\), 30.67745991345653`, 
          0.3580090530056941`, \(-2.016781003870994`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{8.825531426535916`, \(-0.6565515418126591`\), 
          1.664794588311534`, 30.305538330180866`, 
          1.0748759108760486`, \(-2.017506408572808`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {4.7423226067603084, 
        1.1334822735409986, -0.052748967258259283, 30.677459913456531, 
        0.35800905300569408, -2.0167810038709941}, "   ", {
        8.8255314265359157, -0.65655154181265907, 1.664794588311534, 
        30.305538330180866, 1.0748759108760486, -2.0175064085728081}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.648072353319130\"\>",
            69.648072353319122,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.535666855311420\"\>",
            69.535666855311419,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 69.648072353319122, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 69.535666855311419, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.112405498007703\"\>",
            0.11240549800770339,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.11240549800770339, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "4.742322606760308`", 
            "8.825531426535916`", \(-4.083208819775607`\), \
\(-0.3507500178599426`\)},
          {"2", "1.1334822735409986`", \(-0.6565515418126591`\), 
            "1.7900338153536577`", "1.4276509482965642`"},
          {"3", \(-0.05274896725825928`\), 
            "1.664794588311534`", \(-1.7175435555697933`\), \
\(-0.8251205779575315`\)},
          {"4", "30.67745991345653`", "30.305538330180866`", 
            "0.37192158327566455`", \(-1.4672294550663965`\)},
          {"5", "0.3580090530056941`", 
            "1.0748759108760486`", \(-0.7168668578703545`\), 
            "2.4998831433922297`"},
          {"6", \(-2.016781003870994`\), \(-2.017506408572808`\), 
            "0.0007254047018141447`", "0.45247271013775464`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.56\"\>",
                  12.558594487270652,
                  AutoDelete->True], 
                InterpretationBox["\<\" 48.89\"\>",
                  48.889329793537208,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.6257\"\>",
                  -0.62571592558119971,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.5705\"\>",
                  -0.570490241054186,
                  AutoDelete->True], 
                InterpretationBox["\<\" 52.24\"\>",
                  52.237926128198232,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2501\"\>",
                  0.25014922258376027,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 48.89\"\>",
                  48.8893297935372,
                  AutoDelete->True], 
                InterpretationBox["\<\" 215.1\"\>",
                  215.07899781743578,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.656\"\>",
                  -1.6556068623343421,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.889\"\>",
                  -1.8891215880931069,
                  AutoDelete->True], 
                InterpretationBox["\<\" 259.6\"\>",
                  259.58656214990435,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.234\"\>",
                  3.2338327121328074,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.6257\"\>",
                  -0.62571592558119982,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.656\"\>",
                  -1.6556068623343398,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.721\"\>",
                  4.7208404482631678,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.\"\>",
                  14.001300520616356,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.403\"\>",
                  -3.4025954004095547,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.31\"\>",
                  62.307650306287698,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.5705\"\>",
                  -0.57049024105418444,
                  AutoDelete->True], 
                InterpretationBox["\<\"-1.889\"\>",
                  -1.8891215880931069,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.\"\>",
                  14.001300520616358,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.76\"\>",
                  55.759598495790627,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.751\"\>",
                  -3.7514209478571328,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.\"\>",
                  283.02444211416963,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 52.24\"\>",
                  52.237926128198232,
                  AutoDelete->True], 
                InterpretationBox["\<\" 259.6\"\>",
                  259.58656214990435,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.403\"\>",
                  -3.4025954004095564,
                  AutoDelete->True], 
                InterpretationBox["\<\"-3.751\"\>",
                  -3.7514209478571434,
                  AutoDelete->True], 
                InterpretationBox["\<\" 353.4\"\>",
                  353.37567416761459,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.455\"\>",
                  5.455412305831068,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2501\"\>",
                  0.25014922258376004,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.234\"\>",
                  3.2338327121328083,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.31\"\>",
                  62.307650306287691,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.\"\>",
                  283.02444211416957,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.455\"\>",
                  5.4554123058310697,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.959300344234,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.1691052384526445`\
\[InvisibleSpace]"  "\[InvisibleSpace]0.3260026081481789`\),
      SequenceForm[ 
      "*BFGSUP ", 0.1691052384526445, "  ", 0.32600260814817889],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]7\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 7],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{6.08892469481173`, 0.45982015914473795`, 
          0.43644170093427426`, 30.645911039124925`, 
          0.6837275929179625`, \(-2.0279802493043717`\)}\[InvisibleSpace]"   \
"\[InvisibleSpace]{4.742322606760308`, 
          1.1334822735409986`, \(-0.05274896725825928`\), 30.67745991345653`, 
          0.3580090530056941`, \(-2.016781003870994`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {6.0889246948117304, 0.45982015914473795, 
        0.43644170093427426, 30.645911039124925, 
        0.68372759291796248, -2.0279802493043717}, "   ", {4.7423226067603084,
         1.1334822735409986, -0.052748967258259283, 30.677459913456531, 
        0.35800905300569408, -2.0167810038709941}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.694413722801270\"\>",
            70.694413722801272,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    69.648072353319130\"\>",
            69.648072353319122,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.694413722801272, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 69.648072353319122, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.046341369482150\"\>",
            1.0463413694821497,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 1.0463413694821497, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "6.08892469481173`", "4.742322606760308`", 
            "1.3466020880514218`", "1.4593462128943724`"},
          {"2", "0.45982015914473795`", 
            "1.1334822735409986`", \(-0.6736621143962607`\), 
            "8.635791024801275`"},
          {"3", "0.43644170093427426`", \(-0.05274896725825928`\), 
            "0.48919066819253354`", "0.9006839292628531`"},
          {"4", "30.645911039124925`", 
            "30.67745991345653`", \(-0.03154887433160568`\), 
            "2.7747166789383693`"},
          {"5", "0.6837275929179625`", "0.3580090530056941`", 
            "0.32571853991226835`", "16.504304578246817`"},
          {
            "6", \(-2.0279802493043717`\), \(-2.016781003870994`\), \
\(-0.011199245433377617`\), "1.1248190433915366`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 13.07\"\>",
                  13.072552410914286,
                  AutoDelete->True], 
                InterpretationBox["\<\" 51.26\"\>",
                  51.258963426747187,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.1918\"\>",
                  -0.19180152619040874,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5602\"\>",
                  0.56018473507762112,
                  AutoDelete->True], 
                InterpretationBox["\<\" 56.81\"\>",
                  56.810484270751559,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5077\"\>",
                  0.50769043560774429,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 51.26\"\>",
                  51.258963426747179,
                  AutoDelete->True], 
                InterpretationBox["\<\" 223.2\"\>",
                  223.20079225687479,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.8321\"\>",
                  0.83206126776898004,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.964\"\>",
                  3.9644067259173905,
                  AutoDelete->True], 
                InterpretationBox["\<\" 275.5\"\>",
                  275.49354059387656,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.843\"\>",
                  3.842789769860592,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.1918\"\>",
                  -0.19180152619040874,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.8321\"\>",
                  0.83206126776898226,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.003\"\>",
                  5.0025533036006644,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.84\"\>",
                  14.844608842172232,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.357\"\>",
                  1.356938338281473,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.63\"\>",
                  62.625580891778341,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.5602\"\>",
                  0.56018473507762268,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.964\"\>",
                  3.9644067259173905,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.84\"\>",
                  14.844608842172233,
                  AutoDelete->True], 
                InterpretationBox["\<\" 58.1\"\>",
                  58.100690135423775,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.49\"\>",
                  7.4901907562465926,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.7\"\>",
                  283.72316691260374,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 56.81\"\>",
                  56.810484270751559,
                  AutoDelete->True], 
                InterpretationBox["\<\" 275.5\"\>",
                  275.49354059387656,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.357\"\>",
                  1.3569383382814713,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.49\"\>",
                  7.4901907562465819,
                  AutoDelete->True], 
                InterpretationBox["\<\" 384.5\"\>",
                  384.50391364087341,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.679\"\>",
                  6.6789260572345386,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.5077\"\>",
                  0.50769043560774407,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.843\"\>",
                  3.8427897698605928,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.63\"\>",
                  62.625580891778334,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.7\"\>",
                  283.72316691260369,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.679\"\>",
                  6.6789260572345404,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.9690012778694,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]0.6119036063745125`\
\[InvisibleSpace]"  "\[InvisibleSpace]0.5365436480897843`\),
      SequenceForm[ 
      "*BFGSUP ", 0.61190360637451247, "  ", 0.53654364808978428],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]8\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.85871827230464`, 0.5149342566795839`, 
          0.19831202626280006`, 30.76125236550082`, 
          0.6921723573944843`, \(-2.0374051555317307`\)}\[InvisibleSpace]"   \
"\[InvisibleSpace]{6.08892469481173`, 0.45982015914473795`, 
          0.43644170093427426`, 30.645911039124925`, 
          0.6837275929179625`, \(-2.0279802493043717`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.8587182723046398, 0.51493425667958392, 
        0.19831202626280006, 30.76125236550082, 
        0.69217235739448435, -2.0374051555317307}, "   ", {6.0889246948117304,
         0.45982015914473795, 0.43644170093427426, 30.645911039124925, 
        0.68372759291796248, -2.0279802493043717}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.795026074683620\"\>",
            70.795026074683619,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.694413722801270\"\>",
            70.694413722801272,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.795026074683619, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.694413722801272, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.100612351882347\"\>",
            0.10061235188234718,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.10061235188234718, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.85871827230464`", 
            "6.08892469481173`", \(-0.23020642250709017`\), 
            "0.27429713494682817`"},
          {"2", "0.5149342566795839`", "0.45982015914473795`", 
            "0.055114097534846015`", "2.2177161544841835`"},
          {"3", "0.19831202626280006`", 
            "0.43644170093427426`", \(-0.2381296746714742`\), \
\(-0.019486835321888097`\)},
          {"4", "30.76125236550082`", "30.645911039124925`", 
            "0.11534132637589303`", "0.41879743013174014`"},
          {"5", "0.6921723573944843`", "0.6837275929179625`", 
            "0.008444764476521857`", "4.2382982397785804`"},
          {
            "6", \(-2.0374051555317307`\), \(-2.0279802493043717`\), \
\(-0.009424906227358974`\), "0.32035680664748944`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.79\"\>",
                  12.789201550979211,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.15\"\>",
                  49.151089541997187,
                  AutoDelete->True], 
                InterpretationBox["\<\"-0.2298\"\>",
                  -0.22979092393842465,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.09593\"\>",
                  0.095934815209589241,
                  AutoDelete->True], 
                InterpretationBox["\<\" 52.78\"\>",
                  52.782085623178233,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2103\"\>",
                  0.21029818791334132,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.15\"\>",
                  49.15108954199718,
                  AutoDelete->True], 
                InterpretationBox["\<\" 208.4\"\>",
                  208.39237807366354,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2725\"\>",
                  0.27249569793128692,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3601\"\>",
                  0.36008351425986262,
                  AutoDelete->True], 
                InterpretationBox["\<\" 247.2\"\>",
                  247.19278436461644,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.79\"\>",
                  1.7902833713423849,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\"-0.2298\"\>",
                  -0.22979092393842465,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2725\"\>",
                  0.27249569793128869,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.085\"\>",
                  5.0853996680264624,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.83\"\>",
                  14.830223708914456,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2876\"\>",
                  0.28757627061689517,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.53\"\>",
                  62.534962204643591,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.09593\"\>",
                  0.095934815209590352,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3601\"\>",
                  0.36008351425986262,
                  AutoDelete->True], 
                InterpretationBox["\<\" 14.83\"\>",
                  14.830223708914458,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.37\"\>",
                  57.366094891958582,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.6019\"\>",
                  0.60191758542688056,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.2\"\>",
                  283.20829425553006,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 52.78\"\>",
                  52.782085623178233,
                  AutoDelete->True], 
                InterpretationBox["\<\" 247.2\"\>",
                  247.19278436461644,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2876\"\>",
                  0.28757627061689428,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.6019\"\>",
                  0.60191758542686991,
                  AutoDelete->True], 
                InterpretationBox["\<\" 330.4\"\>",
                  330.41758184153042,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.756\"\>",
                  2.7563213534520434,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2103\"\>",
                  0.21029818791334109,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.79\"\>",
                  1.7902833713423849,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.53\"\>",
                  62.534962204643584,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.2\"\>",
                  283.20829425553001,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.756\"\>",
                  2.7563213534520434,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.686155886747,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]11.315399769021754`\
\[InvisibleSpace]"  "\[InvisibleSpace]6.906096202146874`\),
      SequenceForm[ "*BFGSUP ", 11.315399769021754, "  ", 6.9060962021468741],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]9\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 9],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.570640959380418`, 
          0.6103765020594341`, \(-0.18937049245303303`\), 30.91700447731448`, 
          0.6745002560377688`, \(-2.048023554075866`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{5.85871827230464`, 0.5149342566795839`, 
          0.19831202626280006`, 30.76125236550082`, 
          0.6921723573944843`, \(-2.0374051555317307`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.5706409593804178, 
        0.61037650205943406, -0.18937049245303303, 30.917004477314482, 
        0.67450025603776875, -2.0480235540758658}, "   ", {5.8587182723046398,
         0.51493425667958392, 0.19831202626280006, 30.76125236550082, 
        0.69217235739448435, -2.0374051555317307}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.842942071522830\"\>",
            70.842942071522828,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.795026074683620\"\>",
            70.795026074683619,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.842942071522828, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.795026074683619, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.047915996839208\"\>",
            0.047915996839208219,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.047915996839208219, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.570640959380418`", 
            "5.85871827230464`", \(-0.28807731292422223`\), 
            "0.06722498259534664`"},
          {"2", "0.6103765020594341`", "0.5149342566795839`", 
            "0.09544224537985012`", "0.4650857824625004`"},
          {"3", \(-0.18937049245303303`\), 
            "0.19831202626280006`", \(-0.3876825187158331`\), \
\(-0.14276355279449401`\)},
          {"4", "30.91700447731448`", "30.76125236550082`", 
            "0.15575211181366247`", "0.04519516065919385`"},
          {"5", "0.6745002560377688`", 
            "0.6921723573944843`", \(-0.01767210135671557`\), 
            "0.9070201752508149`"},
          {
            "6", \(-2.048023554075866`\), \(-2.0374051555317307`\), \
\(-0.01061839854413514`\), "0.06380670731491792`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.75\"\>",
                  12.754785970216727,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.06\"\>",
                  49.056615708713856,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.09597\"\>",
                  0.09597361736369292,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.178\"\>",
                  0.17798650253123127,
                  AutoDelete->True], 
                InterpretationBox["\<\" 52.56\"\>",
                  52.558913895587494,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2046\"\>",
                  0.20456272385449448,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.06\"\>",
                  49.056615708713849,
                  AutoDelete->True], 
                InterpretationBox["\<\" 209.2\"\>",
                  209.18403030817603,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.016\"\>",
                  3.0157399308632202,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.355\"\>",
                  1.3550552190073111,
                  AutoDelete->True], 
                InterpretationBox["\<\" 248.3\"\>",
                  248.34497252387916,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.972\"\>",
                  1.9716030689339288,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.09597\"\>",
                  0.095973617363692976,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.016\"\>",
                  3.015739930863222,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.255\"\>",
                  5.2547389865792695,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.41\"\>",
                  15.407731885390962,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.505\"\>",
                  5.5048419872696712,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.94\"\>",
                  62.935943404609851,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.178\"\>",
                  0.17798650253123238,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.355\"\>",
                  1.3550552190073102,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.41\"\>",
                  15.407731885390964,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.73\"\>",
                  57.734214076660038,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.427\"\>",
                  2.4265184093425294,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.36629560527234,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 52.56\"\>",
                  52.558913895587494,
                  AutoDelete->True], 
                InterpretationBox["\<\" 248.3\"\>",
                  248.34497252387916,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.505\"\>",
                  5.5048419872696712,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.427\"\>",
                  2.4265184093425205,
                  AutoDelete->True], 
                InterpretationBox["\<\" 331.9\"\>",
                  331.93385876927374,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.05\"\>",
                  3.0500371398289987,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2046\"\>",
                  0.20456272385449437,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.972\"\>",
                  1.9716030689339288,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.94\"\>",
                  62.935943404609844,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.36629560527228,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.05\"\>",
                  3.0500371398289987,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.7221501616282,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]21.92951701320578`\
\[InvisibleSpace]"  "\[InvisibleSpace]14.143764044555468`\),
      SequenceForm[ "*BFGSUP ", 21.929517013205778, "  ", 14.143764044555468],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]10\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 10],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.44196755981056`, 
          0.6543210827288416`, \(-0.6178827842508849`\), 31.083109983222002`, 
          0.6651002746898389`, \(-2.0588986716675994`\)}\[InvisibleSpace]"   \
"\[InvisibleSpace]{5.570640959380418`, 
          0.6103765020594341`, \(-0.18937049245303303`\), 30.91700447731448`, 
          0.6745002560377688`, \(-2.048023554075866`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.4419675598105597, 
        0.6543210827288416, -0.61788278425088494, 31.083109983222002, 
        0.6651002746898389, -2.0588986716675994}, "   ", {5.5706409593804178, 
        0.61037650205943406, -0.18937049245303303, 30.917004477314482, 
        0.67450025603776875, -2.0480235540758658}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.880217576118110\"\>",
            70.880217576118113,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.842942071522830\"\>",
            70.842942071522828,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.880217576118113, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.842942071522828, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.037275504595286\"\>",
            0.037275504595285724,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.037275504595285724, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.44196755981056`", 
            "5.570640959380418`", \(-0.1286733995698583`\), \
\(-0.015485067139773517`\)},
          {"2", "0.6543210827288416`", "0.6103765020594341`", 
            "0.043944580669407575`", \(-0.48729258875011455`\)},
          {
            "3", \(-0.6178827842508849`\), \(-0.18937049245303303`\), \
\(-0.4285122917978519`\), \(-0.1568117106292195`\)},
          {"4", "31.083109983222002`", "30.91700447731448`", 
            "0.16610550590751855`", \(-0.06507992646393101`\)},
          {"5", "0.6651002746898389`", 
            "0.6745002560377688`", \(-0.009399981347929865`\), \
\(-0.8858351458970934`\)},
          {
            "6", \(-2.0588986716675994`\), \(-2.048023554075866`\), \
\(-0.010875117591733813`\), \(-0.07891098551342603`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.84\"\>",
                  12.840886276449467,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.34\"\>",
                  50.341821239910303,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2572\"\>",
                  0.25719567216669392,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.335\"\>",
                  0.33503030724072125,
                  AutoDelete->True], 
                InterpretationBox["\<\" 54.95\"\>",
                  54.948371789802707,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4028\"\>",
                  0.40275452462378064,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.34\"\>",
                  50.341821239910296,
                  AutoDelete->True], 
                InterpretationBox["\<\" 226.\"\>",
                  226.015277029495,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.248\"\>",
                  4.2482462099076885,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.361\"\>",
                  3.3608755745884782,
                  AutoDelete->True], 
                InterpretationBox["\<\" 279.8\"\>",
                  279.8226739737986,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.533\"\>",
                  4.5325657214006592,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2572\"\>",
                  0.25719567216669403,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.248\"\>",
                  4.2482462099076903,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.971\"\>",
                  4.9707966277676805,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.53\"\>",
                  15.532962957435577,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.889\"\>",
                  7.8886335407566088,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.11\"\>",
                  63.108749743670991,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.335\"\>",
                  0.33503030724072236,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.361\"\>",
                  3.3608755745884773,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.53\"\>",
                  15.532962957435579,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.97\"\>",
                  57.971999959633081,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.182\"\>",
                  6.1823492742943804,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.7\"\>",
                  283.67063972011078,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 54.95\"\>",
                  54.948371789802707,
                  AutoDelete->True], 
                InterpretationBox["\<\" 279.8\"\>",
                  279.8226739737986,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.889\"\>",
                  7.8886335407566079,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.182\"\>",
                  6.1823492742943715,
                  AutoDelete->True], 
                InterpretationBox["\<\" 390.8\"\>",
                  390.78669664717881,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.843\"\>",
                  7.8426345668629658,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4028\"\>",
                  0.40275452462378047,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.533\"\>",
                  4.5325657214006592,
                  AutoDelete->True], 
                InterpretationBox["\<\" 63.11\"\>",
                  63.108749743670984,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.7\"\>",
                  283.67063972011073,
                  AutoDelete->True], 
                InterpretationBox["\<\" 7.843\"\>",
                  7.8426345668629649,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1860.111234568275,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]56.20275620484309`\
\[InvisibleSpace]"  "\[InvisibleSpace]21.668820180140536`\),
      SequenceForm[ "*BFGSUP ", 56.202756204843091, "  ", 21.668820180140536],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]11\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 11],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.415898358729398`, 
          0.6613531748409642`, \(-1.571726609251579`\), 31.450249579921852`, 
          0.6649271082819362`, \(-2.0827627961099204`\)}\[InvisibleSpace]"   \
"\[InvisibleSpace]{5.44196755981056`, 
          0.6543210827288416`, \(-0.6178827842508849`\), 31.083109983222002`, 
          0.6651002746898389`, \(-2.0588986716675994`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.4158983587293976, 
        0.66135317484096423, -1.5717266092515789, 31.450249579921852, 
        0.66492710828193624, -2.0827627961099204}, "   ", {5.4419675598105597,
         0.6543210827288416, -0.61788278425088494, 31.083109983222002, 
        0.6651002746898389, -2.0588986716675994}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.946120235975740\"\>",
            70.946120235975741,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.880217576118110\"\>",
            70.880217576118113,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.946120235975741, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.880217576118113, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.065902659857628\"\>",
            0.065902659857627555,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.065902659857627555, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.415898358729398`", 
            "5.44196755981056`", \(-0.026069201081162285`\), \
\(-0.04049407300184204`\)},
          {"2", "0.6613531748409642`", "0.6543210827288416`", 
            "0.007032092112122684`", \(-0.8319494550076413`\)},
          {
            "3", \(-1.571726609251579`\), \(-0.6178827842508849`\), \
\(-0.953843825000694`\), \(-0.13457230415305171`\)},
          {"4", "31.450249579921852`", "31.083109983222002`", 
            "0.36713959669984975`", \(-0.08320144630031152`\)},
          {"5", "0.6649271082819362`", 
            "0.6651002746898389`", \(-0.0001731664079026169`\), \
\(-1.5393194718891137`\)},
          {
            "6", \(-2.0827627961099204`\), \(-2.0588986716675994`\), \
\(-0.023864124442320903`\), \(-0.12785654721838258`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.87\"\>",
                  12.870842403370501,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.66\"\>",
                  50.662754652117982,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1733\"\>",
                  0.17331942404727102,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3387\"\>",
                  0.33866434098830517,
                  AutoDelete->True], 
                InterpretationBox["\<\" 55.57\"\>",
                  55.569657157881181,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.4451\"\>",
                  0.44507314593308067,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.66\"\>",
                  50.662754652117975,
                  AutoDelete->True], 
                InterpretationBox["\<\" 227.5\"\>",
                  227.54616053133444,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.162\"\>",
                  2.1616705462676156,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.025\"\>",
                  3.0247189254300819,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.1\"\>",
                  283.12751802449793,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.647\"\>",
                  4.6474483669041566,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1733\"\>",
                  0.17331942404727113,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.162\"\>",
                  2.1616705462676173,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.466\"\>",
                  4.4657596222574139,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.29\"\>",
                  15.289175887433791,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.062\"\>",
                  4.0618318896360242,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.78\"\>",
                  62.779438314394532,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.3387\"\>",
                  0.33866434098830628,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.025\"\>",
                  3.024718925430081,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.29\"\>",
                  15.289175887433792,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.9\"\>",
                  57.898680301314691,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.599\"\>",
                  5.5987002230883443,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.6\"\>",
                  283.60920908054783,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 55.57\"\>",
                  55.569657157881181,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.1\"\>",
                  283.12751802449793,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.062\"\>",
                  4.0618318896360233,
                  AutoDelete->True], 
                InterpretationBox["\<\" 5.599\"\>",
                  5.5987002230883354,
                  AutoDelete->True], 
                InterpretationBox["\<\" 397.8\"\>",
                  397.78401298897836,
                  AutoDelete->True], 
                InterpretationBox["\<\" 8.126\"\>",
                  8.125592007369951,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.4451\"\>",
                  0.44507314593308051,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.647\"\>",
                  4.6474483669041566,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.78\"\>",
                  62.779438314394525,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.6\"\>",
                  283.60920908054777,
                  AutoDelete->True], 
                InterpretationBox["\<\" 8.126\"\>",
                  8.125592007369951,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1860.1109471915311,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]16.426381404065364`\
\[InvisibleSpace]"  "\[InvisibleSpace]10.38017798372135`\),
      SequenceForm[ "*BFGSUP ", 16.426381404065364, "  ", 10.380177983721349],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]12\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.614622254662147`, 
          0.5899789686413528`, \(-2.158785673133894`\), 31.67490582832742`, 
          0.6828851567890089`, \(-2.0972885148051`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{5.415898358729398`, 
          0.6613531748409642`, \(-1.571726609251579`\), 31.450249579921852`, 
          0.6649271082819362`, \(-2.0827627961099204`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.6146222546621471, 
        0.5899789686413528, -2.1587856731338939, 31.674905828327422, 
        0.68288515678900885, -2.0972885148051001}, "   ", {5.4158983587293976,
         0.66135317484096423, -1.5717266092515789, 31.450249579921852, 
        0.66492710828193624, -2.0827627961099204}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.979121724757960\"\>",
            70.97912172475796,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.946120235975740\"\>",
            70.946120235975741,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.97912172475796, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.946120235975741, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.033001488782219\"\>",
            0.033001488782218757,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.033001488782218757, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.614622254662147`", "5.415898358729398`", 
            "0.1987238959327495`", \(-0.050538643835875`\)},
          {"2", "0.5899789686413528`", 
            "0.6613531748409642`", \(-0.07137420619961148`\), \
\(-0.9407868692278052`\)},
          {
            "3", \(-2.158785673133894`\), \(-1.571726609251579`\), \
\(-0.587059063882315`\), \(-0.06580041144535041`\)},
          {"4", "31.67490582832742`", "31.450249579921852`", 
            "0.22465624840556958`", \(-0.06972240919226451`\)},
          {"5", "0.6828851567890089`", "0.6649271082819362`", 
            "0.017958048507072562`", \(-1.7637565560216597`\)},
          {
            "6", \(-2.0972885148051`\), \(-2.0827627961099204`\), \
\(-0.014525718695179525`\), \(-0.13774218955569795`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.86\"\>",
                  12.855478612977786,
                  AutoDelete->True], 
                InterpretationBox["\<\" 50.33\"\>",
                  50.331014340749178,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.1054\"\>",
                  0.10540679851513597,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3015\"\>",
                  0.30146781750718021,
                  AutoDelete->True], 
                InterpretationBox["\<\" 54.96\"\>",
                  54.959657463423476,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.393\"\>",
                  0.39296156753479505,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 50.33\"\>",
                  50.331014340749171,
                  AutoDelete->True], 
                InterpretationBox["\<\" 220.6\"\>",
                  220.55620528440801,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.8766\"\>",
                  0.87658254856644335,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.282\"\>",
                  2.282111366966876,
                  AutoDelete->True], 
                InterpretationBox["\<\" 270.2\"\>",
                  270.23553817015051,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.561\"\>",
                  3.5609805163356216,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.1054\"\>",
                  0.10540679851513608,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.8766\"\>",
                  0.87658254856644535,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.355\"\>",
                  4.3554674343555586,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.19\"\>",
                  15.188179988179211,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.658\"\>",
                  1.6580398365121258,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.59\"\>",
                  62.589669942760054,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.3015\"\>",
                  0.30146781750718127,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.282\"\>",
                  2.2821113669668751,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.19\"\>",
                  15.188179988179213,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.83\"\>",
                  57.829808137836892,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.22\"\>",
                  4.2195803740593387,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.5\"\>",
                  283.49659750993385,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 54.96\"\>",
                  54.959657463423476,
                  AutoDelete->True], 
                InterpretationBox["\<\" 270.2\"\>",
                  270.23553817015051,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.658\"\>",
                  1.6580398365121249,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.22\"\>",
                  4.2195803740593298,
                  AutoDelete->True], 
                InterpretationBox["\<\" 374.\"\>",
                  374.01556496635391,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.119\"\>",
                  6.1190929532635874,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.393\"\>",
                  0.39296156753479483,
                  AutoDelete->True], 
                InterpretationBox["\<\" 3.561\"\>",
                  3.5609805163356216,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.59\"\>",
                  62.589669942760047,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.5\"\>",
                  283.49659750993379,
                  AutoDelete->True], 
                InterpretationBox["\<\" 6.119\"\>",
                  6.1190929532635874,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.9428646258866,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]28.749056064386803`\
\[InvisibleSpace]"  "\[InvisibleSpace]19.842446461567345`\),
      SequenceForm[ "*BFGSUP ", 28.749056064386803, "  ", 19.842446461567345],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]13\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 13],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.804671016407954`, 
          0.5225935714459449`, \(-2.2656579234960015`\), 31.715074694354687`, 
          0.6992460672050599`, \(-2.099843049969027`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{5.614622254662147`, 
          0.5899789686413528`, \(-2.158785673133894`\), 31.67490582832742`, 
          0.6828851567890089`, \(-2.0972885148051`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.804671016407954, 
        0.52259357144594487, -2.2656579234960015, 31.715074694354687, 
        0.69924606720505988, -2.099843049969027}, "   ", {5.6146222546621471, 
        0.5899789686413528, -2.1587856731338939, 31.674905828327422, 
        0.68288515678900885, -2.0972885148051001}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987138391021830\"\>",
            70.98713839102183,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.979121724757960\"\>",
            70.97912172475796,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.98713839102183, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.97912172475796, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.008016666263870\"\>",
            0.0080166662638703201,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.0080166662638703201, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.804671016407954`", "5.614622254662147`", 
            "0.1900487617458067`", \(-0.02930686323841314`\)},
          {"2", "0.5225935714459449`", 
            "0.5899789686413528`", \(-0.06738539719540798`\), \
\(-0.523170434767592`\)},
          {
            "3", \(-2.2656579234960015`\), \(-2.158785673133894`\), \
\(-0.10687225036210751`\), \(-0.012547871528107478`\)},
          {"4", "31.715074694354687`", "31.67490582832742`", 
            "0.040168866027264924`", \(-0.02923003157886637`\)},
          {"5", "0.6992460672050599`", "0.6828851567890089`", 
            "0.016360910416051047`", \(-0.9853782780316643`\)},
          {
            "6", \(-2.099843049969027`\), \(-2.0972885148051`\), \
\(-0.002554535163926959`\), \(-0.06830633638448669`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.82\"\>",
                  12.817757682715511,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.64\"\>",
                  49.642493965715765,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.07193\"\>",
                  0.071926478151294132,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2563\"\>",
                  0.25626575521791473,
                  AutoDelete->True], 
                InterpretationBox["\<\" 53.67\"\>",
                  53.666061320169852,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2972\"\>",
                  0.29721548025394134,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.64\"\>",
                  49.642493965715758,
                  AutoDelete->True], 
                InterpretationBox["\<\" 208.\"\>",
                  208.00798969982986,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2876\"\>",
                  0.2876066702171669,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.467\"\>",
                  1.4667220367762508,
                  AutoDelete->True], 
                InterpretationBox["\<\" 246.7\"\>",
                  246.65586012592064,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.823\"\>",
                  1.823328679678059,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.07193\"\>",
                  0.071926478151294271,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2876\"\>",
                  0.2876066702171689,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.351\"\>",
                  4.3510832321869124,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.16\"\>",
                  15.159139763053433,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5469\"\>",
                  0.54687292128007248,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.52\"\>",
                  62.516131604712186,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2563\"\>",
                  0.25626575521791584,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.467\"\>",
                  1.4667220367762499,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.16\"\>",
                  15.159139763053435,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.78\"\>",
                  57.78048764331627,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.686\"\>",
                  2.685612014666837,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.38686776463373,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 53.67\"\>",
                  53.666061320169852,
                  AutoDelete->True], 
                InterpretationBox["\<\" 246.7\"\>",
                  246.65586012592064,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5469\"\>",
                  0.54687292128007114,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.686\"\>",
                  2.6856120146668281,
                  AutoDelete->True], 
                InterpretationBox["\<\" 329.7\"\>",
                  329.70721406974883,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.852\"\>",
                  2.8523063715091466,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2972\"\>",
                  0.29721548025394112,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.823\"\>",
                  1.823328679678059,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.52\"\>",
                  62.516131604712179,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.38686776463368,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.852\"\>",
                  2.8523063715091466,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.7050045674471,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]84.92623142083269`\
\[InvisibleSpace]"  "\[InvisibleSpace]71.92174019323413`\),
      SequenceForm[ "*BFGSUP ", 84.926231420832693, "  ", 71.921740193234129],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]14\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.84774599514823`, 
          0.5073778083281724`, \(-2.2129778560235196`\), 31.694658205454438`, 
          0.7028773118915637`, \(-2.098508383817929`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{5.804671016407954`, 
          0.5225935714459449`, \(-2.2656579234960015`\), 31.715074694354687`, 
          0.6992460672050599`, \(-2.099843049969027`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.8477459951482302, 
        0.50737780832817236, -2.2129778560235196, 31.694658205454438, 
        0.70287731189156366, -2.0985083838179288}, "   ", {5.804671016407954, 
        0.52259357144594487, -2.2656579234960015, 31.715074694354687, 
        0.69924606720505988, -2.099843049969027}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987597436710740\"\>",
            70.987597436710743,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987138391021830\"\>",
            70.98713839102183,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987597436710743, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.98713839102183, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.000459045688913\"\>",
            0.00045904568891330655,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 0.00045904568891330655, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.84774599514823`", "5.804671016407954`", 
            "0.04307497874027638`", \(-0.007152716307556631`\)},
          {"2", "0.5073778083281724`", 
            "0.5225935714459449`", \(-0.01521576311777249`\), \
\(-0.10704058327458989`\)},
          {"3", \(-2.2129778560235196`\), \(-2.2656579234960015`\), 
            "0.05268006747248189`", "0.003617438003416131`"},
          {"4", "31.694658205454438`", 
            "31.715074694354687`", \(-0.020416488900248216`\), \
\(-0.0029157136569025878`\)},
          {"5", "0.7028773118915637`", "0.6992460672050599`", 
            "0.0036312446865037515`", \(-0.198538583804236`\)},
          {"6", \(-2.098508383817929`\), \(-2.099843049969027`\), 
            "0.0013346661510983723`", \(-0.010751892036376044`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.8\"\>",
                  12.797666981840615,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.32\"\>",
                  49.322690093943763,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.07589\"\>",
                  0.075892582944183731,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2442\"\>",
                  0.24416422962592241,
                  AutoDelete->True], 
                InterpretationBox["\<\" 53.07\"\>",
                  53.069494261260822,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2615\"\>",
                  0.2615262005234299,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.32\"\>",
                  49.322690093943756,
                  AutoDelete->True], 
                InterpretationBox["\<\" 203.\"\>",
                  203.02865457049296,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3868\"\>",
                  0.38675132761125558,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.297\"\>",
                  1.296830992636409,
                  AutoDelete->True], 
                InterpretationBox["\<\" 237.4\"\>",
                  237.38589074326546,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.287\"\>",
                  1.2871373859222726,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.07589\"\>",
                  0.075892582944183884,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.3868\"\>",
                  0.38675132761125758,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.362\"\>",
                  4.361951908110008,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.168886533141837,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7378\"\>",
                  0.73782356678616434,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.53\"\>",
                  62.533501669965723,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2442\"\>",
                  0.24416422962592352,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.297\"\>",
                  1.2968309926364081,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.168886533141839,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.78\"\>",
                  57.777844688658597,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.372\"\>",
                  2.3724865035700029,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.37189036176386,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 53.07\"\>",
                  53.069494261260822,
                  AutoDelete->True], 
                InterpretationBox["\<\" 237.4\"\>",
                  237.38589074326546,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.7378\"\>",
                  0.73782356678616312,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.372\"\>",
                  2.372486503569994,
                  AutoDelete->True], 
                InterpretationBox["\<\" 312.5\"\>",
                  312.45258527836972,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.857\"\>",
                  1.8574077062236634,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2615\"\>",
                  0.26152620052342967,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.287\"\>",
                  1.287137385922273,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.53\"\>",
                  62.533501669965716,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.3718903617638,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.857\"\>",
                  1.8574077062236642,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6507546420812,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]1328.9483660201115`\
\[InvisibleSpace]"  "\[InvisibleSpace]1197.0253356064457`\),
      SequenceForm[ "*BFGSUP ", 1328.9483660201115, "  ", 1197.0253356064457],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]15\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 15],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.8500085318459565`, 
          0.506578551906823`, \(-2.1977191008894525`\), 31.688791679221644`, 
          0.7030629210375299`, \(-2.098127915041671`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{5.84774599514823`, 
          0.5073778083281724`, \(-2.2129778560235196`\), 31.694658205454438`, 
          0.7028773118915637`, \(-2.098508383817929`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.8500085318459565, 
        0.50657855190682299, -2.1977191008894525, 31.688791679221644, 
        0.70306292103752988, -2.0981279150416712}, "   ", {5.8477459951482302,
         0.50737780832817236, -2.2129778560235196, 31.694658205454438, 
        0.70287731189156366, -2.0985083838179288}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606692409170\"\>",
            70.987606692409173,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987597436710740\"\>",
            70.987597436710743,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987606692409173, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.987597436710743, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     9.255698429910810"\[Times]10\^"-6"\),
            9.255698429910808*^-06,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 9.255698429910808*^-06, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.8500085318459565`", "5.84774599514823`", 
            "0.0022625366977260314`", \(-0.0006456499002837826`\)},
          {"2", "0.506578551906823`", 
            "0.5073778083281724`", \(-0.0007992564213494094`\), \
\(-0.006056115575069629`\)},
          {"3", \(-2.1977191008894525`\), \(-2.2129778560235196`\), 
            "0.015258755134067`", "0.0011919970875441295`"},
          {"4", "31.688791679221644`", 
            "31.694658205454438`", \(-0.005866526232791861`\), 
            "0.00027360322054489547`"},
          {"5", "0.7030629210375299`", "0.7028773118915637`", 
            "0.0001856091459662495`", \(-0.010413553339373084`\)},
          {"6", \(-2.098127915041671`\), \(-2.098508383817929`\), 
            "0.00038046877625749645`", \(-0.0006007874240632286`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.79\"\>",
                  12.792695765396228,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.28\"\>",
                  49.279479244122008,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.08589\"\>",
                  0.085890889952484895,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2468\"\>",
                  0.24677973388630736,
                  AutoDelete->True], 
                InterpretationBox["\<\" 53.\"\>",
                  52.996431952173346,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2573\"\>",
                  0.25725092575815017,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.28\"\>",
                  49.279479244122001,
                  AutoDelete->True], 
                InterpretationBox["\<\" 202.9\"\>",
                  202.86594657520769,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5248\"\>",
                  0.52475291357004317,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.351\"\>",
                  1.3512561059464521,
                  AutoDelete->True], 
                InterpretationBox["\<\" 237.2\"\>",
                  237.19405483067999,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.272\"\>",
                  1.2718044873591303,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.08589\"\>",
                  0.085890889952485033,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5248\"\>",
                  0.52475291357004505,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.354\"\>",
                  4.3541056940169787,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.171231974576374,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.9911\"\>",
                  0.99114765321168063,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.547339225138423,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2468\"\>",
                  0.24677973388630847,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.351\"\>",
                  1.3512561059464512,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.171231974576376,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.78\"\>",
                  57.781186034177225,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.477\"\>",
                  2.4769066649384244,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.37738911166275,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 53.\"\>",
                  52.996431952173346,
                  AutoDelete->True], 
                InterpretationBox["\<\" 237.2\"\>",
                  237.19405483067999,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.9911\"\>",
                  0.99114765321167952,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.477\"\>",
                  2.4769066649384155,
                  AutoDelete->True], 
                InterpretationBox["\<\" 312.3\"\>",
                  312.30160382691599,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.84\"\>",
                  1.8400210663215031,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2573\"\>",
                  0.25725092575815001,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.272\"\>",
                  1.2718044873591305,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.547339225138415,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.37738911166269,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.84\"\>",
                  1.8400210663215035,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6493160884236,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]58955.52461466548`\
\[InvisibleSpace]"  "\[InvisibleSpace]56175.22357494546`\),
      SequenceForm[ "*BFGSUP ", 58955.524614665483, "  ", 56175.223574945463],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("MNonLinBFGS: Iteration = "\[InvisibleSpace]16\),
      SequenceForm[ "MNonLinBFGS: Iteration = ", 16],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("VOLLER NEWTON-STEP  \
"\[InvisibleSpace]{5.849811452732074`, 
          0.5066461376707909`, \(-2.1967441942674477`\), 31.688419003824684`, 
          0.7030480192829497`, \(-2.098103906446469`\)}\[InvisibleSpace]"   "\
\[InvisibleSpace]{5.8500085318459565`, 
          0.506578551906823`, \(-2.1977191008894525`\), 31.688791679221644`, 
          0.7030629210375299`, \(-2.098127915041671`\)}\),
      SequenceForm[ 
      "VOLLER NEWTON-STEP  ", {5.8498114527320739, 
        0.50664613767079092, -2.1967441942674477, 31.688419003824684, 
        0.70304801928294969, -2.098103906446469}, "   ", {5.8500085318459565, 
        0.50657855190682299, -2.1977191008894525, 31.688791679221644, 
        0.70306292103752988, -2.0981279150416712}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606729093870\"\>",
            70.987606729093869,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)], "\[InvisibleSpace]", "\<\"      \"\>",
         "\[InvisibleSpace]", "\<\"LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    70.987606692409170\"\>",
            70.987606692409173,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU  ", 
        PaddedForm[ 70.987606729093869, {20, 15}], "      ", "LIKALT  ", 
        PaddedForm[ 70.987606692409173, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LIKNEU - LIKALT  \"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("     3.668469616968650"\[Times]10\^"-8"\),
            3.6684696169686504*^-08,
            AutoDelete->True],
          (PaddedForm[ #, {20, 15}]&)]}],
      SequenceForm[ "LIKNEU - LIKALT  ", 
        PaddedForm[ 3.6684696169686504*^-08, {20, 15}]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA1\"\>", "\<\"THETA\"\>", "\<\"STEP\"\>", "\<\
\"SCORE\"\>"},
          {"1", "5.849811452732074`", 
            "5.8500085318459565`", \(-0.0001970791138827879`\), 
            "0.000018095332433248703`"},
          {"2", "0.5066461376707909`", "0.506578551906823`", 
            "0.0000675857639679393`", "0.0004913532079972744`"},
          {"3", \(-2.1967441942674477`\), \(-2.1977191008894525`\), 
            "0.0009749066220047715`", "0.00008939127347993572`"},
          {"4", "31.688419003824684`", 
            "31.688791679221644`", \(-0.0003726753969585132`\), 
            "0.00006250732357442901`"},
          {"5", "0.7030480192829497`", 
            "0.7030629210375299`", \(-0.000014901754580204222`\), 
            "0.0009929262072008924`"},
          {"6", \(-2.098103906446469`\), \(-2.098127915041671`\), 
            "0.000024008595202003984`", "0.000025454006562650065`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Column, TableSpacing -> Automatic, 
          TableHeadings -> {Automatic, {"THETA1", "THETA", "STEP", 
          "SCORE"}}]]]], "Print"],

Cell[BoxData[
    \("BFGS update"\)], "Print"],

Cell[BoxData[
    TagBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                InterpretationBox["\<\" 12.8\"\>",
                  12.795251660911124,
                  AutoDelete->True], 
                InterpretationBox["\<\" 49.32\"\>",
                  49.31603873060137,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.08598\"\>",
                  0.08597749857413528,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.2484\"\>",
                  0.24844270521696143,
                  AutoDelete->True], 
                InterpretationBox["\<\" 53.07\"\>",
                  53.065089358825638,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.26\"\>",
                  0.25996638399149774,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 49.32\"\>",
                  49.316038730601363,
                  AutoDelete->True], 
                InterpretationBox["\<\" 203.3\"\>",
                  203.33301884309765,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5047\"\>",
                  0.50465839770462062,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.363\"\>",
                  1.3628519066842075,
                  AutoDelete->True], 
                InterpretationBox["\<\" 238.1\"\>",
                  238.05433498848009,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.309\"\>",
                  1.3091495295556441,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.08598\"\>",
                  0.085977498574135419,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.5047\"\>",
                  0.50465839770462262,
                  AutoDelete->True], 
                InterpretationBox["\<\" 4.346\"\>",
                  4.3459632959929868,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.16663353695756,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.947\"\>",
                  0.94697167541712612,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.546859734380533,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.2484\"\>",
                  0.24844270521696254,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.363\"\>",
                  1.3628519066842066,
                  AutoDelete->True], 
                InterpretationBox["\<\" 15.17\"\>",
                  15.166633536957562,
                  AutoDelete->True], 
                InterpretationBox["\<\" 57.78\"\>",
                  57.779607974012364,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.495\"\>",
                  2.4950033753900298,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.37882930412053,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 53.07\"\>",
                  53.065089358825638,
                  AutoDelete->True], 
                InterpretationBox["\<\" 238.1\"\>",
                  238.05433498848009,
                  AutoDelete->True], 
                InterpretationBox["\<\" 0.947\"\>",
                  0.94697167541712501,
                  AutoDelete->True], 
                InterpretationBox["\<\" 2.495\"\>",
                  2.4950033753900209,
                  AutoDelete->True], 
                InterpretationBox["\<\" 313.9\"\>",
                  313.88041716885044,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.91\"\>",
                  1.9097019209495087,
                  AutoDelete->True]},
              {
                InterpretationBox["\<\" 0.26\"\>",
                  0.25996638399149757,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.309\"\>",
                  1.3091495295556443,
                  AutoDelete->True], 
                InterpretationBox["\<\" 62.55\"\>",
                  62.546859734380526,
                  AutoDelete->True], 
                InterpretationBox["\<\" 283.4\"\>",
                  283.37882930412047,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1.91\"\>",
                  1.9097019209495092,
                  AutoDelete->True], 
                InterpretationBox["\<\" 1860.\"\>",
                  1859.6521609717927,
                  AutoDelete->True]}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]],
      (NumberForm[ #, 4, NumberSigns -> {"-", " "}]&)]], "Print"],

Cell[BoxData[
    InterpretationBox[\("*BFGSUP "\[InvisibleSpace]1.3463167459145976`*^7\
\[InvisibleSpace]"  "\[InvisibleSpace]1.260871152553102`*^7\),
      SequenceForm[ "*BFGSUP ", 13463167.459145976, "  ", 12608711.52553102],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("MBFGS:  ENDE DER ITERATION  k="\[InvisibleSpace]16\
\[InvisibleSpace]"  KMAX="\[InvisibleSpace]100\),
      SequenceForm[ "MBFGS:  ENDE DER ITERATION  k=", 16, "  KMAX=", 100],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"65.03115471383266`", "10.`", \(-1.`\), "2.`", "30.`", 
              "1.`", \(-2.`\)},
            {"67.09674120409859`", 
              "10.007418322072597`", \(-0.9586595331199866`\), 
              "2.0016804186241455`", "30.0082728886528`", 
              "1.0595025283646027`", \(-1.9541771153527197`\)},
            {"67.88758267385981`", 
              "10.012741072818187`", \(-0.9215246779074857`\), 
              "2.000902648993702`", "30.00581924632545`", 
              "1.117894331100795`", \(-1.9822751185486482`\)},
            {"68.25239932068261`", 
              "9.75996907848632`", \(-1.2269546139126986`\), 
              "2.0103870782539808`", "30.104834769830212`", 
              "1.4058207304380061`", \(-1.9976391698382474`\)},
            {"69.39862471646597`", 
              "9.155154643998525`", \(-0.8326342469318819`\), 
              "1.7538550073651837`", "30.13925968929484`", 
              "1.1598131833932508`", \(-1.9949214275970049`\)},
            {"69.53566685531142`", 
              "8.825531426535916`", \(-0.6565515418126591`\), 
              "1.664794588311534`", "30.305538330180866`", 
              "1.0748759108760486`", \(-2.017506408572808`\)},
            {"69.64807235331912`", "4.742322606760308`", 
              "1.1334822735409986`", \(-0.05274896725825928`\), 
              "30.67745991345653`", 
              "0.3580090530056941`", \(-2.016781003870994`\)},
            {"70.69441372280127`", "6.08892469481173`", 
              "0.45982015914473795`", "0.43644170093427426`", 
              "30.645911039124925`", 
              "0.6837275929179625`", \(-2.0279802493043717`\)},
            {"70.79502607468362`", "5.85871827230464`", "0.5149342566795839`",
               "0.19831202626280006`", "30.76125236550082`", 
              "0.6921723573944843`", \(-2.0374051555317307`\)},
            {"70.84294207152283`", "5.570640959380418`", 
              "0.6103765020594341`", \(-0.18937049245303303`\), 
              "30.91700447731448`", 
              "0.6745002560377688`", \(-2.048023554075866`\)},
            {"70.88021757611811`", "5.44196755981056`", 
              "0.6543210827288416`", \(-0.6178827842508849`\), 
              "31.083109983222002`", 
              "0.6651002746898389`", \(-2.0588986716675994`\)},
            {"70.94612023597574`", "5.415898358729398`", 
              "0.6613531748409642`", \(-1.571726609251579`\), 
              "31.450249579921852`", 
              "0.6649271082819362`", \(-2.0827627961099204`\)},
            {"70.97912172475796`", "5.614622254662147`", 
              "0.5899789686413528`", \(-2.158785673133894`\), 
              "31.67490582832742`", 
              "0.6828851567890089`", \(-2.0972885148051`\)},
            {"70.98713839102183`", "5.804671016407954`", 
              "0.5225935714459449`", \(-2.2656579234960015`\), 
              "31.715074694354687`", 
              "0.6992460672050599`", \(-2.099843049969027`\)},
            {"70.98759743671074`", "5.84774599514823`", 
              "0.5073778083281724`", \(-2.2129778560235196`\), 
              "31.694658205454438`", 
              "0.7028773118915637`", \(-2.098508383817929`\)},
            {"70.98760669240917`", "5.8500085318459565`", 
              "0.506578551906823`", \(-2.1977191008894525`\), 
              "31.688791679221644`", 
              "0.7030629210375299`", \(-2.098127915041671`\)},
            {"70.98760672909387`", "5.849811452732074`", 
              "0.5066461376707909`", \(-2.1967441942674477`\), 
              "31.688419003824684`", 
              "0.7030480192829497`", \(-2.098103906446469`\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"Likelihood", 
          "THETA"}}]]]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[GridBox[{
              {"\<\"\"\>", "\<\"THETA\"\>", "\<\"SCORE\"\>"},
              {"1", "5.849811452732074`", "5.705927677144147`*^-6"},
              {"2", "0.5066461376707909`", "0.0000790577847355249`"},
              {"3", \(-2.1967441942674477`\), "4.341308008893013`*^-6"},
              {"4", "31.688419003824684`", "5.718118032184487`*^-6"},
              {"5", "0.7030480192829497`", "0.00011123179612264791`"},
              {"6", \(-2.098103906446469`\), "0.000015454395112742615`"}
              },
            RowSpacings->0,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ 
            BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "SCORE"}}, 
              TableDirections -> {Column, Row}, TableSpacing -> {0, 1}]]], 
        "\[InvisibleSpace]", "\<\"   Likelihood = \"\>", "\[InvisibleSpace]", 
        "70.98760672909387`"}],
      SequenceForm[ 
        TableForm[ {{5.8498114527320739, 5.7059276771441466*^-06}, {
          0.50664613767079092, 7.9057784735524905*^-05}, {-2.1967441942674477,
           4.3413080088930129*^-06}, {31.688419003824684, 
          5.7181180321844869*^-06}, {0.70304801928294969, 
          0.00011123179612264791}, {-2.098103906446469, 
          1.5454395112742615*^-05}}, TableHeadings -> {Automatic, {"THETA", 
          "SCORE"}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          1}], "   Likelihood = ", 70.987606729093869],
      Editable->False]], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("WALD-TEST:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"CHI \"\>", "\<\"U \"\>", "\<\"PROB \"\>", \
"\<\"ALPHA \"\>"},
          {"1", "28132.577951130304`", "6", "0", "0.05`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"CHI ", "U ", "PROB ", 
          "ALPHA "}}, TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("NULLHYPOTHESE THETA = 0 ABLEHNEN"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("BONFERRONI-KONFIDENZINTERVALLE:"\)], "Print"],

Cell[BoxData[
    \("------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("QUANTIL Z(1-ALPHA/2U) = \
"\[InvisibleSpace]2.6382572734767504`\),
      SequenceForm[ "QUANTIL Z(1-ALPHA/2U) = ", 2.6382572734767504],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"THETA\"\>", "\<\"GRENZE\"\>", "\<\"STD\"\>"},
          {"1", "5.849811452732074`", "5.931172400468798`", 
            "2.2481402629291627`"},
          {"2", "0.5066461376707909`", "2.4363040630728903`", 
            "0.9234520406958939`"},
          {"3", \(-2.1967441942674477`\), "10.288134357240251`", 
            "3.8995948047486415`"},
          {"4", "31.688419003824684`", "4.032384622755191`", 
            "1.5284273688142744`"},
          {"5", "0.7030480192829497`", "0.9197360508561181`", 
            "0.3486149967641597`"},
          {"6", \(-2.098103906446469`\), "0.28677351516446015`", 
            "0.10869808568235047`"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"THETA", "GRENZE", "STD"}}, 
          TableDirections -> {Column, Row}, TableSpacing -> {0, 
          2}]]]], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("Korrelation der ML-Sch\[ADoubleDot]tzer"\)], "Print"],

Cell[BoxData[
    \("-------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9999999999999999`", \(-0.9732038267408688`\), 
              "0.018171064210049694`", \(-0.016843946753203647`\), 
              "0.8676453711000416`", "0.014343917342731058`"},
            {\(-0.9732038267408654`\), 
              "1.0000000000000002`", \(-0.016610337742573297`\), 
              "0.015248521359211616`", \(-0.9522533126329844`\), \
\(-0.012710769550846409`\)},
            {"0.01817106421031169`", \(-0.016610337742861133`\), 
              "1.`", \(-0.9848256982818201`\), "0.013539697117686307`", 
              "0.9035916318115373`"},
            {\(-0.016843946753460532`\), 
              "0.015248521359493911`", \(-0.9848256982818199`\), 
              "0.9999999999999999`", \(-0.012317845720684562`\), \
\(-0.9543432874289656`\)},
            {"0.8676453711000339`", \(-0.95225331263298`\), 
              "0.013539697117388423`", \(-0.012317845720392332`\), 
              "0.9999999999999999`", "0.010020045613004595`"},
            {"0.014343917342965636`", \(-0.012710769551104301`\), 
              "0.9035916318115391`", \(-0.9543432874289673`\), 
              "0.010020045613271682`", "1.`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE"\)], \
"Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"5.054134641803204`", \(-2.0204195257530793`\), 
              "0.1593027415042802`", \(-0.05787780727250804`\), 
              "0.6800044010757395`", "0.003505202180891531`"},
            {\(-2.020419525753072`\), 
              "0.852763671465411`", \(-0.05981530088230983`\), 
              "0.021522210937961184`", \(-0.30655817587139234`\), \
\(-0.00127587487710411`\)},
            {"0.15930274150657706`", \(-0.05981530088334635`\), 
              "15.206839641222595`", \(-5.869804834093545`\), 
              "0.018406639141884548`", "0.3830130566613904`"},
            {\(-0.05787780727339073`\), 
              "0.021522210938359623`", \(-5.869804834093543`\), 
              "2.3360902217405264`", \(-0.006563351021046987`\), \
\(-0.15855185394417343`\)},
            {"0.6800044010757335`", \(-0.3065581758713909`\), 
              "0.01840663914147959`", \(-0.006563351020891278`\), 
              "0.12153241596887505`", "0.0003796974319892865`"},
            {"0.003505202180948855`", \(-0.0012758748771299966`\), 
              "0.3830130566613911`", \(-0.15855185394417373`\), 
              "0.0003796974319994074`", "0.011815273831007604`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({0.0005253166330861109`, 0.0019943948911808527`, 0.06265201373858373`, 
      0.06329375940289787`, 5.960284610877913`, 
      17.494425770491254`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"12.83622435833006`", "49.27609024631356`", 
              "0.0033249411144932743`", "0.008430603248573473`", 
              "52.47453648169803`", \(-0.1679767128467962`\)},
            {"49.27609024631356`", "201.74488103494335`", 
              "0.046660274635165984`", "0.10895191158216651`", 
              "233.17716234862826`", \(-0.37706872874178415`\)},
            {"0.0033249411144932743`", "0.046660274635165984`", 
              "4.2772719607435254`", "14.980395311015885`", 
              "0.06543145180234561`", "62.37193365039314`"},
            {"0.008430603248573473`", "0.10895191158216651`", 
              "14.980395311015885`", "57.264147475733346`", 
              "0.16772469907336984`", "282.8284447688789`"},
            {"52.47453648169803`", "233.17716234862826`", 
              "0.06543145180234561`", "0.16772469907336984`", 
              "302.79445773690645`", "0.011231838584167651`"},
            {\(-0.1679767128467962`\), \(-0.37706872874178415`\), 
              "62.37193365039314`", "282.8284447688789`", 
              "0.011231838584167651`", "1858.0875109675112`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    \({1903.613815015216`, 501.40521539739524`, 15.96117890436071`, 
      15.799345929738145`, 0.1677772229492085`, 
      0.05716106450814472`}\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    \("KOMPENSIERTE LIKELIHOOD"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("U =  "\[InvisibleSpace]6\[InvisibleSpace]"  Nue = "\
\[InvisibleSpace]101\),
      SequenceForm[ "U =  ", 6, "  Nue = ", 101],
      Editable->False]], "Print"],

Cell[BoxData[
    \("AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE \
(A/D)"\)], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"LIK\"\>", "\<\"AIC\"\>", "\<\"SIC/RISS\"\>", \
"\<\"A/D\"\>"},
          {"\<\"Kompensator\"\>", "0", "6", "13.84536155052378`", 
            "32.148213714835514`"},
          {"\<\"komp. Lik.\"\>", "70.98760672909387`", "64.98760672909387`", 
            "57.14224517857009`", "38.839393014258356`"}
          },
        RowSpacings->0,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"Kompensator", "komp. Lik."}, {"LIK", 
          "AIC", "SIC/RISS", "A/D"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {0, 1}]]]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Filtering and smoothing (true parameter values)", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
ZM//Dimensions
X//Dimensions\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"],

Cell[BoxData[
    \({10, 101, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theta", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({10.`, \(-1.`\), 2.`, 30.`, 1.`, \(-2.`\)}\)], "Output"]
}, Open  ]],

Cell["first panel unit n=1: ZM[[1]]", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "{YG,PG,YF,PF,lik}=\n\tMNonLinGlatt[mue,sigma,ZM[[",
  StyleBox["n=1",
    FontColor->RGBColor[1, 0, 0]],
  "]],X[[1]],{drift,diffusion,Jacobif,h,R,Jacobih},\n\t\t\t  \
Theta,dt,Nonlin,miss];"
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("{k,p,T} = "\[InvisibleSpace]{2, 2, 100}\),
      SequenceForm[ "{k,p,T} = ", {2, 2, 100}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["YG//Dimensions", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \({101, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["z=Quantile[NormalDistribution[0,1],.995]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(2.5758293035489004`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
stdF=Map[VecDiag,PF]//Sqrt;
hpdF=YF~ii~(YF+z stdF)~ii~(YF-z stdF);

stdG=Map[VecDiag,PG]//Sqrt;
hpdG=YG~ii~(YG+z stdG)~ii~(YG-z stdG);\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(stdG\)\" is similar to \
existing symbol \"\!\(stdF\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(hpdG\)\" is similar to \
existing symbol \"\!\(hpdF\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["stdF//AddTimeAxis//plot1", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 3}\),
      SequenceForm[ "Dimension der Daten  ", {101, 3}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.0841076 4.49302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00575 -24 -4.5 ]
[-0.0125 .00575 0 4.5 ]
[-0.0125 .09561 -24 -4.5 ]
[-0.0125 .09561 0 4.5 ]
[-0.0125 .18547 -24 -4.5 ]
[-0.0125 .18547 0 4.5 ]
[-0.0125 .27533 -24 -4.5 ]
[-0.0125 .27533 0 4.5 ]
[-0.0125 .36519 -18 -4.5 ]
[-0.0125 .36519 0 4.5 ]
[-0.0125 .45506 -24 -4.5 ]
[-0.0125 .45506 0 4.5 ]
[-0.0125 .54492 -24 -4.5 ]
[-0.0125 .54492 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.97619 .04762 -5 -6 ]
[.97619 .04762 5 6 ]
[.97619 .05466 -5 -6 ]
[.97619 .05466 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00575 m
.00625 .00575 L
s
[(0.02)] -0.0125 .00575 1 0 Mshowa
0 .09561 m
.00625 .09561 L
s
[(0.04)] -0.0125 .09561 1 0 Mshowa
0 .18547 m
.00625 .18547 L
s
[(0.06)] -0.0125 .18547 1 0 Mshowa
0 .27533 m
.00625 .27533 L
s
[(0.08)] -0.0125 .27533 1 0 Mshowa
0 .36519 m
.00625 .36519 L
s
[(0.1)] -0.0125 .36519 1 0 Mshowa
0 .45506 m
.00625 .45506 L
s
[(0.12)] -0.0125 .45506 1 0 Mshowa
0 .54492 m
.00625 .54492 L
s
[(0.14)] -0.0125 .54492 1 0 Mshowa
.125 Mabswid
0 .02822 m
.00375 .02822 L
s
0 .05068 m
.00375 .05068 L
s
0 .07315 m
.00375 .07315 L
s
0 .11808 m
.00375 .11808 L
s
0 .14054 m
.00375 .14054 L
s
0 .16301 m
.00375 .16301 L
s
0 .20794 m
.00375 .20794 L
s
0 .2304 m
.00375 .2304 L
s
0 .25287 m
.00375 .25287 L
s
0 .2978 m
.00375 .2978 L
s
0 .32026 m
.00375 .32026 L
s
0 .34273 m
.00375 .34273 L
s
0 .38766 m
.00375 .38766 L
s
0 .41012 m
.00375 .41012 L
s
0 .43259 m
.00375 .43259 L
s
0 .47752 m
.00375 .47752 L
s
0 .49999 m
.00375 .49999 L
s
0 .52245 m
.00375 .52245 L
s
0 .56738 m
.00375 .56738 L
s
0 .58985 m
.00375 .58985 L
s
0 .61231 m
.00375 .61231 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00575 m
1 .00575 L
s
.99375 .09561 m
1 .09561 L
s
.99375 .18547 m
1 .18547 L
s
.99375 .27533 m
1 .27533 L
s
.99375 .36519 m
1 .36519 L
s
.99375 .45506 m
1 .45506 L
s
.99375 .54492 m
1 .54492 L
s
.125 Mabswid
.99625 .02822 m
1 .02822 L
s
.99625 .05068 m
1 .05068 L
s
.99625 .07315 m
1 .07315 L
s
.99625 .11808 m
1 .11808 L
s
.99625 .14054 m
1 .14054 L
s
.99625 .16301 m
1 .16301 L
s
.99625 .20794 m
1 .20794 L
s
.99625 .2304 m
1 .2304 L
s
.99625 .25287 m
1 .25287 L
s
.99625 .2978 m
1 .2978 L
s
.99625 .32026 m
1 .32026 L
s
.99625 .34273 m
1 .34273 L
s
.99625 .38766 m
1 .38766 L
s
.99625 .41012 m
1 .41012 L
s
.99625 .43259 m
1 .43259 L
s
.99625 .47752 m
1 .47752 L
s
.99625 .49999 m
1 .49999 L
s
.99625 .52245 m
1 .52245 L
s
.99625 .56738 m
1 .56738 L
s
.99625 .58985 m
1 .58985 L
s
.99625 .61231 m
1 .61231 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 1 r
gsave
.97619 .04762 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .05797 m
.03333 .0594 L
.04286 .06085 L
.05238 .06236 L
.0619 .06393 L
.07143 .06557 L
.08095 .06731 L
.09048 .06915 L
.1 .07111 L
.10952 .0732 L
.11905 .02199 L
.12857 .0241 L
.1381 .02641 L
.14762 .02894 L
.15714 .0317 L
.16667 .0347 L
.17619 .03794 L
.18571 .04143 L
.19524 .04517 L
.20476 .04917 L
.21429 .01472 L
.22381 .01986 L
.23333 .02527 L
.24286 .03093 L
.25238 .03684 L
.2619 .043 L
.27143 .0494 L
.28095 .05604 L
.29048 .06291 L
.3 .07002 L
.30952 .02256 L
.31905 .03205 L
.32857 .04154 L
.3381 .05107 L
.34762 .06068 L
.35714 .07036 L
.36667 .08016 L
.37619 .09007 L
.38571 .10012 L
.39524 .11031 L
.40476 .12065 L
.41429 .13116 L
.42381 .14183 L
.43333 .15269 L
.44286 .16372 L
.45238 .17495 L
.4619 .18638 L
.47143 .198 L
.48095 .20984 L
.49048 .22189 L
Mistroke
.5 .04563 L
.50952 .06552 L
.51905 .08418 L
.52857 .10203 L
.5381 .11933 L
.54762 .13625 L
.55714 .15292 L
.56667 .16942 L
.57619 .18584 L
.58571 .20222 L
.59524 .04451 L
.60476 .07192 L
.61429 .09657 L
.62381 .11954 L
.63333 .14139 L
.64286 .16247 L
.65238 .18301 L
.6619 .20318 L
.67143 .2231 L
.68095 .24286 L
.69048 .04736 L
.7 .08253 L
.70952 .11313 L
.71905 .1411 L
.72857 .16738 L
.7381 .19252 L
.74762 .21685 L
.75714 .24063 L
.76667 .26402 L
.77619 .28714 L
.78571 .04956 L
.79524 .09319 L
.80476 .12997 L
.81429 .16305 L
.82381 .19383 L
.83333 .04485 L
.84286 .09432 L
.85238 .13489 L
.8619 .17095 L
.87143 .20426 L
.88095 .04574 L
.89048 .0999 L
.9 .14367 L
.90952 .18231 L
.91905 .2179 L
.92857 .04673 L
.9381 .10566 L
.94762 .15262 L
.95714 .19386 L
.96667 .23172 L
Mistroke
.97619 .04762 L
Mfstroke
0 .98 .604 r
gsave
.97619 .05466 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05797 m
.03333 .06224 L
.04286 .06663 L
.05238 .07119 L
.0619 .07599 L
.07143 .08105 L
.08095 .08644 L
.09048 .09218 L
.1 .09831 L
.10952 .10486 L
.11905 .03092 L
.12857 .03751 L
.1381 .04474 L
.14762 .05262 L
.15714 .06114 L
.16667 .07031 L
.17619 .08011 L
.18571 .09053 L
.19524 .10157 L
.20476 .11322 L
.21429 .0335 L
.22381 .04927 L
.23333 .06516 L
.24286 .08125 L
.25238 .09761 L
.2619 .11428 L
.27143 .13129 L
.28095 .14867 L
.29048 .16644 L
.3 .1846 L
.30952 .04325 L
.31905 .0717 L
.32857 .09811 L
.3381 .1234 L
.34762 .14804 L
.35714 .17232 L
.36667 .19644 L
.37619 .22053 L
.38571 .24468 L
.39524 .26896 L
.40476 .29343 L
.41429 .31813 L
.42381 .34309 L
.43333 .36834 L
.44286 .3939 L
.45238 .41979 L
.4619 .44602 L
.47143 .47261 L
.48095 .49956 L
.49048 .52688 L
Mistroke
.5 .05458 L
.50952 .11639 L
.51905 .16651 L
.52857 .21107 L
.5381 .25238 L
.54762 .29161 L
.55714 .32942 L
.56667 .36625 L
.57619 .40238 L
.58571 .43802 L
.59524 .05357 L
.60476 .1366 L
.61429 .19964 L
.62381 .25414 L
.63333 .3038 L
.64286 .35037 L
.65238 .39481 L
.6619 .43772 L
.67143 .47951 L
.68095 .52047 L
.69048 .05465 L
.7 .1597 L
.70952 .23533 L
.71905 .29944 L
.72857 .35715 L
.7381 .41075 L
.74762 .46152 L
.75714 .51022 L
.76667 .55737 L
.77619 .60332 L
.78571 .05537 L
.79524 .18363 L
.80476 .27178 L
.81429 .34533 L
.82381 .41089 L
.83333 .05354 L
.84286 .19479 L
.85238 .2894 L
.8619 .36774 L
.87143 .43723 L
.88095 .05396 L
.89048 .20732 L
.9 .30808 L
.90952 .39102 L
.91905 .46431 L
.92857 .05433 L
.9381 .21997 L
.94762 .32686 L
.95714 .41436 L
.96667 .49141 L
Mistroke
.97619 .05466 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{281.438, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00803oool2000002P0oooo1@00
00030?ooo`800000:03oool3000000<0oooo0P00000W0?ooo`<00000103oool2000002H0oooo0`00
00040?ooo`800000903oool3000000@0oooo0P0000040?ooo`8000000`3oool001l0oooo00@00000
0?ooo`3oool00000:03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000002@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo000O0?ooo`040000003oool0oooo
000002T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`D000000P3o
ool010000000oooo0?ooo`00000U0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000T0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000009@3oool4000000<0oooo00@000000?ooo`3oool000009@3oool3000000<0oooo
00@000000?ooo`3oool00000903oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool001l0oooo00@000000?ooo`3oool000009`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000009P3oool00`000000oooo
000000030?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`00000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
000T0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`007`3oool010000000oooo0?ooo`00000W0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000W0?ooo`8000000`3oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000903oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000008`3oool2000000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`00803oool2000002T0oooo0`000004
0?ooo`800000:@3oool00`000000oooo0?ooo`020?ooo`800000:03oool2000000@0oooo0P00000V
0?ooo`<00000103oool2000002D0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000003
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`000P3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool200000080oooo1@00003o0?ooo`<0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oooo/0
00000`3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`3oool3000000<0oooo00001@3oool000000?ooo`3oool0
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?L0oooo00<000000?ooo`3oool00@3oool000050?ooo`000000oooo0?ooo`000000203o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0a0?ooo`<0003o``3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0340oooo10000?o20?ooo`030000003oool0oooo0040oooo00020?oo
o`8000002P3oool2000000<0oooo0`0000050?ooo`030000003oool0oooo01T0oooo10000?lD0?oo
o`H0003o4P3oool20000oj`0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3o
ool06@3oool90000o`h0oooo0`000?l00`3oool0003o0000o`020000oa40oooo0P000?n/0?ooo`03
0000003oool0oooo0040oooo000K0?ooo`8000006P3oool20000o`030?ooo`000?l0003o00H0003o
303oool20000o`@0oooo0`000?l@0?ooo`<0003oZP3oool2000000<0oooo000K0?ooo`030000003o
ool0oooo01T0oooo1000nYX40?ooo`P0003o1`3oool00`000?l00?ZJ003jVP040?ooo`D0003o3@3o
ool50000ojT0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0603oool0
0`000?l00?ZJ003jVP03003jVPD0oooo20000?l50?ooo`030000o`00nYX00?ZJ00D0oooo1@000?l;
0?ooo`L0003oZ03oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0H0?oo
o`040000o`00nYX00?ZJ0?ooo`<00?ZJ2@3oool50000o`<0oooo00@0003o003jVP00nYX00?ZJ1`3o
ool30000o`X0oooo0P000?l30?ooo`<0003oY`3oool00`000000oooo0?ooo`010?ooo`006`3oool0
0`000000oooo0?ooo`0H0?ooo`030000o`00nYX00?ZJ0080oooo1000nYX90?ooo`L0003o1000nYX7
0?ooo`D0003o1`3oool00`000?l00?ZJ003jVP030?ooo`80003o:@3oool20000oaH0oooo0P000?li
0?ooo`80003o2P3oool20000o`X0oooo0P000?lA0?ooo`030000003oool0oooo0040oooo000K0?oo
o`8000006@3oool00`000?l00?ZJ003jVP030?ooo`@00?ZJ2P3oool50000o`D00?ZJ1`3oool50000
o`H0oooo00<0003o003jVP00nYX00`3oool30000obP0oooo0P000?lF0?ooo`80003o5@3oool20000
oaH0oooo0P000?l:0?ooo`80003o2P3oool20000o`X0oooo0P000?l:0?ooo`80003o103oool20000
00<0oooo000K0?ooo`030000003oool0oooo01P0oooo0`00nYX50?ooo`<00?ZJ303oool20000o`80
0?ZJ00<0oooo003jVP00nYX02P3oool30000o`D0oooo00<0003o003jVP00nYX0103oool40000obH0
oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`800?ZJ5@3oool2003jVQH0oooo0P000?l:0?ooo`80
0?ZJ2P3oool2003jVPX0oooo0P00nYX:0?ooo`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`<00?ZJ4`3oool2003jVPL0oooo0`00nYX<0?ooo`<00?ZJ
00@0oooo003jVP00nYX00?ZJ2P3oool30000o`@0oooo00@0003o003jVP00nYX00?ZJ103oool40000
obD0oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`800?ZJ00<0003o0?ooo`3oool04P3oool2003j
VP030000o`3oool0oooo01<0oooo0P00nYX:0?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003j
VPX0oooo0P00nYX:0?ooo`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`D00?ZJ1@000?l<0?ooo`800?ZJ203oool3003jVP/0oooo0P00nYX30?ooo`80
0?ZJ2`3oool30000o`80oooo0P000?l3003jVPH0oooo0`000?lT0?ooo`800?ZJ00<0003o0?ooo`3o
ool04`3oool2003jVP030000o`3oool0oooo0180oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`80
0?ZJ00<0003o0?ooo`3oool01`3oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0
oooo0?ooo`070?ooo`800?ZJ2P3oool2003jVPD0oooo00<000000?ooo`3oool00@3oool001/0oooo
00<000000?ooo`3oool0103oool5003jVPP0003o1P3oool00`000?l00?ZJ003jVP090?ooo`<00?ZJ
2P3oool2003jVP<0oooo0`00nYX;0?ooo`H0003o0`00nYX70?ooo`<0003o8`3oool2003jVP80003o
503oool2003jVP030000o`3oool0oooo0180oooo0P00nYX00`000?l0oooo0?ooo`0C0?ooo`800?ZJ
00<0003o0?ooo`3oool01`3oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0oooo
0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVPD0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool01P3oool4003jVP030?ooo`000?l0003o00T0003o00@0
oooo0000o`00nYX00?ZJ2P3oool3003jVPT0oooo0P00nYX40?ooo`800?ZJ303oool50000o`@00?ZJ
1`3oool30000ob80oooo0P00nYX20000oa@0oooo0P00nYX20000oa<0oooo0P00nYX20000oa@0oooo
0P00nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVP030000
o`3oool0oooo00L0oooo0P00nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ1@3oool00`000000oooo
0?ooo`010?ooo`006`3oool2000000T0oooo1000nYX40?ooo`P0003o0P00nYX;0?ooo`<00?ZJ203o
ool2003jVP@0oooo0`00nYX>0?ooo`80003o1000nYX80?ooo`80003o8P3oool3003jVP80003o4P3o
ool00`000?l00?ZJ003jVP020000oa<0oooo0`00nYX00`000?l0oooo0?ooo`0B0?ooo`800?ZJ0P00
0?l80?ooo`800?ZJ0P000?l80?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVP030000o`3o
ool0oooo00L0oooo0P00nYX40?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool02@3oool6
003jVPH0oooo0`000?l2003jVP`0oooo0`00nYX70?ooo`800?ZJ1@3oool2003jVQ00oooo1000nYX8
0?ooo`<0003o803oool010000?l00?ZJ003jVP00nYX30000oa40oooo00D0003o003jVP00nYX00?ZJ
0000o`0C0?ooo`<00?ZJ00<0003o0?ooo`3oool04P3oool2003jVP80003o203oool2003jVP80003o
203oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0oooo0?ooo`070?ooo`800?ZJ
1@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`H00?ZJ1`3o
ool2003jVPd0oooo0`00nYX60?ooo`800?ZJ1@3oool3003jVPl0oooo1@00nYX80?ooo`@0003o7P3o
ool01@000?l00?ZJ003jVP00nYX0oooo0080003o4@3oool010000?l00?ZJ003jVP00nYX20000oa80
oooo0`00nYX20000oa<0oooo0`00nYX00`000?l0oooo0?ooo`060?ooo`<00?ZJ00<0003o0?ooo`3o
ool01P3oool2003jVP030000o`3oool0oooo00L0oooo0P00nYX00`000?l0oooo0?ooo`070?ooo`80
0?ZJ1@3oool00`000000oooo0?ooo`010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo00h0oooo1000nYX60?ooo`800?ZJ
3P3oool3003jVPD0oooo0P00nYX60?ooo`800?ZJ3P3oool3003jVP030?ooo`00nYX00?ZJ00T0oooo
10000?lM0?ooo`050000o`00nYX00?ZJ003jVP3oool00`000?l@0?ooo`040000o`00nYX00?ZJ003j
VP80003o4P3oool3003jVP80003o4`3oool3003jVP030000o`3oool0oooo00D0oooo00D0003o003j
VP00nYX00?ZJ0000o`080?ooo`800?ZJ00<0003o0?ooo`3oool01`3oool2003jVP030000o`3oool0
oooo00L0oooo0P00nYX50?ooo`030000003oool0oooo0040oooo00001@3oool000000?ooo`3oool0
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0100oooo0`00nYX40?ooo`<00?ZJ3`3oool3003jVP@0oooo0P00nYX60?ooo`<00?ZJ3@3o
ool2003jVP80oooo0`00nYX:0?ooo`<0003o703oool010000?l00?ZJ003jVP00nYX20?ooo`80003o
403oool010000?l00?ZJ003jVP00nYX20000oa80oooo0`00nYX20000oa<0oooo0`00nYX20000o`H0
oooo00@0003o003jVP00nYX00?ZJ0P000?l60?ooo`030000o`00nYX00?ZJ0080003o203oool2003j
VP030000o`3oool0oooo00L0oooo0P00nYX50?ooo`030000003oool0oooo0040oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00D000000?ooo`3oool000000?ooo`05000000@0oooo00<00000
0?ooo`3oool04@3oool5003jVP030?ooo`00nYX00?ZJ0140oooo0P00nYX40?ooo`800?ZJ1`3oool3
003jVP`0oooo0P00nYX30?ooo`800?ZJ2`3oool20000oa`0oooo00@0003o003jVP00nYX00?ZJ0P3o
ool30000o`l0oooo00@0003o003jVP00nYX00?ZJ0`000?lA0?ooo`<00?ZJ0`000?lB0?ooo`<00?ZJ
0P000?l60?ooo`040000o`00nYX00?ZJ003jVP80003o1P3oool00`000?l00?ZJ003jVP020000o`L0
oooo00<0003o003jVP00nYX00P000?l80?ooo`800?ZJ1@3oool00`000000oooo0?ooo`010?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`030?ooo`8000004`3oool7003jVQ40oooo0`00nYX20?ooo`<00?ZJ203oool3
003jVP/0oooo0P00nYX30?ooo`<00?ZJ2P3oool30000oa/0oooo00@0003o003jVP00nYX00?ZJ0`3o
ool20000o`l0oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000oa40oooo0`00nYX00`3oool0003o
0000o`0B0?ooo`<00?ZJ0P000?l60?ooo`040000o`00nYX00?ZJ003jVP80003o1P3oool01@000?l0
0?ZJ003jVP00nYX0003o00L0oooo00D0003o003jVP00nYX00?ZJ0000o`070?ooo`030000o`00nYX0
0?ZJ00<0oooo0`0000030?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0E0?ooo`@00?ZJ4P3o
ool3003jVP030?ooo`00nYX00?ZJ00X0oooo0P00nYX;0?ooo`800?ZJ103oool2003jVP/0oooo1000
0?lI0?ooo`040000o`00nYX00?ZJ003jVP<0oooo0`000?l>0?ooo`050000o`00nYX00?ZJ003jVP3o
ool00P000?l@0?ooo`050000o`00nYX00?ZJ003jVP3oool00P000?lB0?ooo`<00?ZJ0P000?l60?oo
o`040000o`00nYX00?ZJ003jVP80003o1P3oool01@000?l00?ZJ003jVP00nYX0003o00L0oooo00D0
003o003jVP00nYX00?ZJ0000o`070?ooo`030000o`00nYX00?ZJ00D0oooo00<000000?ooo`3oool0
0@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`80
00001@3oool00`000000oooo0?ooo`0F0?ooo`<00?ZJ4`3oool5003jVPX0oooo0`00nYX:0?ooo`80
0?ZJ103oool2003jVP`0oooo10000?lH0?ooo`030000o`00nYX00?ZJ00800?ZJ0`3oool20000o`h0
oooo00D0003o003jVP00nYX00?ZJ0?ooo`030000o`l0oooo00D0003o003jVP00nYX00?ZJ0?ooo`02
0000oa80oooo0`00nYX30000o`D0oooo00@0003o003jVP00nYX00?ZJ0P000?l60?ooo`050000o`00
nYX00?ZJ003jVP000?l01`3oool01@000?l00?ZJ003jVP00nYX0003o00L0oooo00<0003o003jVP00
nYX01@3oool00`000000oooo0?ooo`010?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool2003jVQ@0oooo1000nYX;0?ooo`800?ZJ
2P3oool2003jVP@0oooo0`00nYX=0?ooo`<0003o5`3oool00`000?l00?ZJ003jVP02003jVP<0oooo
0`000?l=0?ooo`040000o`00nYX00?ZJ003jVP80oooo0P000?l?0?ooo`030000o`00nYX00?ZJ0080
0?ZJ0`000?lA0?ooo`<00?ZJ00<0oooo0000o`000?l01@3oool010000?l00?ZJ003jVP00nYX30000
o`D0oooo00D0003o003jVP00nYX00?ZJ0000o`070?ooo`050000o`00nYX00?ZJ003jVP000?l01`3o
ool00`000?l00?ZJ003jVP050?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo02h0oooo0`00nYX;0?ooo`<00?ZJ2@3oool2003jVPD0oooo0P00nYX>0?ooo`80003o5`3oool0
0`000?l00?ZJ003jVP02003jVP@0oooo0P000?l=0?ooo`040000o`00nYX00?ZJ003jVP80oooo0`00
0?l>0?ooo`030000o`00nYX00?ZJ00800?ZJ00<0oooo0000o`000?l0403oool01@000?l00?ZJ003j
VP00nYX0oooo0080003o1@3oool01@000?l00?ZJ003jVP00nYX0oooo0080003o1@3oool010000?l0
0?ZJ003jVP00nYX20000o`H0oooo00D0003o003jVP00nYX00?ZJ0000o`070?ooo`030000o`00nYX0
0?ZJ00D0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00000`0?ooo`800?ZJ303oool2003j
VPT0oooo0P00nYX50?ooo`800?ZJ3P3oool30000oaH0oooo00<0003o003jVP00nYX00P00nYX40?oo
o`80003o3@3oool010000?l00?ZJ003jVP00nYX30?ooo`80003o3P3oool00`000?l00?ZJ003jVP02
003jVP030?ooo`000?l0003o0100oooo00D0003o003jVP00nYX00?ZJ0?ooo`020000o`D0oooo00D0
003o003jVP00nYX00?ZJ0?ooo`020000o`D0oooo00@0003o003jVP00nYX00?ZJ0P000?l60?ooo`04
0000o`00nYX00?ZJ003jVP80003o1P3oool00`000?l00?ZJ003jVP040?ooo`8000000`3oool001/0
oooo00<000000?ooo`3oool0?@3oool3003jVPP0oooo0P00nYX50?ooo`<00?ZJ3P3oool30000oaD0
oooo00<0003o003jVP00nYX00P00nYX40?ooo`<0003o303oool5003jVP80oooo0`000?l=0?ooo`03
0000o`00nYX00?ZJ00800?ZJ00@0oooo0000o`000?l0003o3`3oool01@000?l00?ZJ003jVP00nYX0
oooo0080003o1@3oool01@000?l00?ZJ003jVP00nYX0oooo0080003o1@3oool010000?l00?ZJ003j
VP00nYX20000o`H0oooo00@0003o003jVP00nYX00?ZJ0P000?l60?ooo`030000o`00nYX00?ZJ00D0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0?P3oool3003jVPL0oooo
0P00nYX60?ooo`800?ZJ3`3oool20000oaD0oooo00<0003o003jVP00nYX00P00nYX50?ooo`80003o
2`3oool010000?l00?ZJ003jVP3oool2003jVP<0oooo0P000?l=0?ooo`030000o`00nYX00?ZJ0080
0?ZJ0P3oool20000o`l0oooo00<0003o003jVP00nYX00P00nYX30000o`@0oooo00D0003o003jVP00
nYX00?ZJ0?ooo`020000o`D0oooo00@0003o003jVP00nYX00?ZJ0`000?l50?ooo`040000o`00nYX0
0?ZJ003jVP80003o1P3oool00`000?l00?ZJ003jVP050?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo03l0oooo0P00nYX70?ooo`800?ZJ1P3oool2003jVPl0oooo0`000?lD
0?ooo`030000o`00nYX00?ZJ00<00?ZJ103oool30000o`X0oooo00@0003o003jVP00nYX0oooo0P00
nYX30?ooo`<0003o303oool00`000?l00?ZJ003jVP02003jVP80oooo0`000?l>0?ooo`030000o`00
nYX00?ZJ00800?ZJ00<0oooo0000o`000?l0103oool00`000?l00?ZJ003jVP02003jVP<0003o103o
ool01@000?l00?ZJ003jVP00nYX0oooo0080003o1@3oool010000?l00?ZJ003jVP00nYX20000o`H0
oooo00<0003o003jVP00nYX01@3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo
0?ooo`0o0?ooo`<00?ZJ1P3oool2003jVPH0oooo0`00nYX?0?ooo`@0003o4P3oool010000?l00?ZJ
003jVP3oool2003jVPD0oooo0`000?l90?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000
o``0oooo00<0003o003jVP00nYX00P00nYX30?ooo`80003o3P3oool00`000?l00?ZJ003jVP02003j
VP030?ooo`000?l0003o00@0oooo00<0003o003jVP00nYX00P00nYX00`3oool0003o0000o`040?oo
o`050000o`00nYX00?ZJ003jVP3oool00P000?l50?ooo`040000o`00nYX00?ZJ003jVP<0003o1@3o
ool00`000?l00?ZJ003jVP050?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo0400oooo0P00nYX60?ooo`800?ZJ1`3oool2003jVQ00oooo10000?l@0?ooo`050000o`00nYX0
0?ZJ003jVP3oool00P00nYX60?ooo`<0003o203oool010000?l00?ZJ003jVP3oool2003jVP@0oooo
0P000?l<0?ooo`030000o`00nYX00?ZJ00800?ZJ0`3oool20000o`h0oooo00<0003o003jVP00nYX0
0P00nYX00`3oool0003o0000o`040?ooo`030000o`00nYX00?ZJ00800?ZJ00<0oooo0000o`000?l0
103oool01@000?l00?ZJ003jVP00nYX0oooo0080003o1@3oool01@000?l00?ZJ003jVP00nYX0oooo
0080003o1@3oool00`000?l00?ZJ003jVP050?ooo`030000003oool0oooo0040oooo000K0?ooo`80
0000@@3oool3003jVPD0oooo0P00nYX70?ooo`<00?ZJ4@3oool30000o`l0oooo00<0003o003jVP00
nYX00P3oool2003jVPL0oooo0P000?l80?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool30000
o`/0oooo00<0003o003jVP00nYX00P00nYX30?ooo`<0003o3@3oool00`000?l00?ZJ003jVP02003j
VP040?ooo`000?l0003o0000o`<0oooo00<0003o003jVP00nYX00P00nYX00`3oool0003o0000o`04
0?ooo`050000o`00nYX00?ZJ003jVP3oool00`000?l40?ooo`050000o`00nYX00?ZJ003jVP3oool0
0P000?l50?ooo`030000o`00nYX00?ZJ00@0oooo0P0000030?ooo`006`3oool00`000000oooo0?oo
o`110?ooo`800?ZJ1@3oool2003jVPP0oooo0P00nYXB0?ooo`80003o3`3oool00`000?l00?ZJ003j
VP020?ooo`<00?ZJ1P3oool30000o`L0oooo00@0003o003jVP00nYX0oooo0P00nYX50?ooo`80003o
2`3oool00`000?l00?ZJ003jVP03003jVP<0oooo0P000?l=0?ooo`030000o`00nYX00?ZJ00800?ZJ
0P3oool20000o`<0oooo1@00nYX00`3oool0003o0000o`040?ooo`040000o`00nYX00?ZJ003jVP80
oooo0P000?l40?ooo`050000o`00nYX00?ZJ003jVP3oool00P000?l50?ooo`030000o`00nYX00?ZJ
00D0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0@@3oool3003jVP@0
oooo0P00nYX80?ooo`<00?ZJ4@3oool30000o`h0oooo00<0003o003jVP00nYX00`3oool2003jVPL0
oooo0P000?l70?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ1@3oool30000o`X0oooo00@0003o003j
VP00nYX0oooo0P00nYX30?ooo`80003o3@3oool00`000?l00?ZJ003jVP02003jVP80oooo0P000?l3
0?ooo`800?ZJ00@0oooo003jVP00nYX0oooo0`000?l30?ooo`040000o`00nYX00?ZJ003jVP80oooo
0P000?l40?ooo`050000o`00nYX00?ZJ003jVP3oool00`000?l40?ooo`030000o`00nYX00?ZJ00D0
oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0@P3oool2003jVP<0oooo
0`00nYX90?ooo`800?ZJ4P3oool30000o`d0oooo00<0003o003jVP00nYX00`3oool2003jVPL0oooo
0`000?l60?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ1P3oool30000o`T0oooo00@0003o003jVP00
nYX0oooo0P00nYX30?ooo`<0003o303oool00`000?l00?ZJ003jVP02003jVP80oooo0P000?l30?oo
o`800?ZJ00<0oooo003jVP00nYX00P3oool20000o`<0oooo1000nYX20?ooo`80003o103oool01000
0?l00?ZJ003jVP00nYX20?ooo`80003o103oool00`000?l00?ZJ003jVP050?ooo`030000003oool0
oooo0040oooo000K0?ooo`030000003oool0oooo0480oooo0`00nYX20?ooo`800?ZJ2P3oool3003j
VQ80oooo0P000?l=0?ooo`030000o`00nYX00?ZJ00<0oooo0P00nYX80?ooo`80003o1P3oool01000
0?l00?ZJ003jVP3oool3003jVPH0oooo0P000?l90?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103o
ool20000o``0oooo00<0003o003jVP00nYX00P00nYX20?ooo`80003o0`3oool2003jVP030?ooo`00
nYX00?ZJ0080oooo0P000?l30?ooo`@00?ZJ0P3oool30000o`<0oooo00@0003o003jVP00nYX00?ZJ
0P3oool20000o`@0oooo00<0003o003jVP00nYX01@3oool00`000000oooo0?ooo`010?ooo`006`3o
ool00`000000oooo0?ooo`130?ooo`800?ZJ0P3oool2003jVP/0oooo0P00nYXB0?ooo`<0003o303o
ool00`000?l00?ZJ003jVP030?ooo`<00?ZJ1`3oool30000o`D0oooo00<0003o003jVP00nYX00P3o
ool2003jVPH0oooo0`000?l80?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000o``0oooo
00<0003o003jVP00nYX00P00nYX20?ooo`<0003o00D0oooo0000o`00nYX00?ZJ0?ooo`02003jVP80
oooo0P000?l30?ooo`@00?ZJ0`3oool20000o`<0oooo1000nYX20?ooo`80003o103oool00`000?l0
0?ZJ003jVP050?ooo`030000003oool0oooo0040oooo000K0?ooo`800000A03oool3003jVP030?oo
o`00nYX00?ZJ00/0oooo0P00nYXC0?ooo`<0003o2`3oool00`000?l00?ZJ003jVP040?ooo`800?ZJ
203oool20000o`D0oooo00<0003o003jVP00nYX00P3oool2003jVPL0oooo0P000?l80?ooo`040000
o`00nYX00?ZJ0?ooo`800?ZJ103oool30000o`/0oooo00<0003o003jVP00nYX00P00nYX30?ooo`80
003o00D0oooo0000o`00nYX00?ZJ0?ooo`02003jVP80oooo0P000?l30?ooo`@00?ZJ0`3oool20000
o`<0oooo1000nYX20?ooo`<0003o0`3oool3003jVP@0oooo0P0000030?ooo`006`3oool00`000000
oooo0?ooo`140?ooo`800?ZJ00<0oooo003jVP00nYX02`3oool3003jVQ<0oooo0`000?l:0?ooo`03
0000o`00nYX00?ZJ00@0oooo0P00nYX80?ooo`<0003o103oool00`000?l00?ZJ003jVP020?ooo`80
0?ZJ1`3oool30000o`L0oooo00@0003o003jVP00nYX0oooo0P00nYX50?ooo`80003o2`3oool00`00
0?l00?ZJ003jVP03003jVP80oooo0P000?l01@3oool0003o003jVP00nYX0oooo00800?ZJ0P3oool3
0000o`030?ooo`000?l00?ZJ00<00?ZJ0`3oool20000o`<0oooo1000nYX30?ooo`80003o0`3oool2
003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0A03oool5003j
VP`0oooo0P00nYXD0?ooo`<0003o2@3oool00`000?l00?ZJ003jVP040?ooo`800?ZJ2@3oool20000
o`@0oooo00<0003o003jVP00nYX00P3oool2003jVPP0oooo0P000?l70?ooo`<00?ZJ00<0oooo003j
VP00nYX01@3oool20000o`/0oooo00@0003o003jVP00nYX0oooo0P00nYX20?ooo`@0003o0P00nYX0
0`3oool00?ZJ003jVP030?ooo`80003o00<0oooo0000o`00nYX01000nYX20?ooo`80003o0`3oool4
003jVP<0oooo0P000?l30?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`000P3oool20000
00@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000050?ooo`030000003oool0oooo
04D0oooo1000nYX<0?ooo`800?ZJ5@3oool30000o`P0oooo00<0003o003jVP00nYX0103oool2003j
VPT0oooo0`000?l20?ooo`80003o0P00nYX20?ooo`800?ZJ203oool20000o`L0oooo0P00nYX20?oo
o`800?ZJ1@3oool30000o`X0oooo00@0003o003jVP00nYX0oooo0P00nYX30?ooo`<0003o0P00nYX0
103oool00?ZJ003jVP00nYX20?ooo`80003o00D0oooo0000o`00nYX00?ZJ0?ooo`02003jVP80oooo
0`000?l00`3oool0003o003jVP03003jVP<0oooo0P000?l30?ooo`800?ZJ1P3oool00`000000oooo
0?ooo`010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04H0oooo0`00nYX<0?oo
o`<00?ZJ5@3oool30000o`L0oooo00<0003o003jVP00nYX0103oool3003jVPT0oooo0`000?l00`3o
ool0003o0000o`02003jVP80oooo0P00nYX80?ooo`<0003o1P3oool2003jVP80oooo0P00nYX60?oo
o`80003o2P3oool010000?l00?ZJ003jVP3oool2003jVP<0oooo0`000?l2003jVP80oooo0P00nYX2
0?ooo`@0003o0P00nYX00`3oool00?ZJ003jVP030?ooo`80003o00<0oooo0000o`00nYX01000nYX2
0?ooo`80003o0`3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool000050?ooo`000000oooo
0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
0P3oool2000004L0oooo0`00nYX=0?ooo`800?ZJ5P3oool30000o`H0oooo00<0003o003jVP00nYX0
1@3oool2003jVPX0oooo1@000?l2003jVP80oooo0P00nYX90?ooo`80003o1P3oool2003jVP80oooo
0`00nYX50?ooo`80003o2P3oool010000?l00?ZJ003jVP3oool2003jVP@0oooo0P000?l2003jVP80
oooo0P00nYX30?ooo`<0003o0P00nYX00`3oool00?ZJ003jVP030?ooo`80003o00D0oooo0000o`00
nYX00?ZJ0?ooo`02003jVP80oooo0`000?l20?ooo`800?ZJ103oool3000000<0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo00<00000
0?ooo`3oool0A`3oool2003jVPd0oooo0P00nYXG0?ooo`<0003o1@3oool00`000?l00?ZJ003jVP05
0?ooo`800?ZJ2`3oool40000o`800?ZJ0P3oool3003jVPP0oooo0P000?l60?ooo`800?ZJ0`3oool2
003jVPD0oooo0`000?l90?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000o`800?ZJ0P3o
ool2003jVP<0oooo0`000?l2003jVP030?ooo`00nYX00?ZJ00<0oooo10000?l2003jVP030?ooo`00
nYX00?ZJ00<0oooo0P000?l0103oool0003o003jVP00nYX60?ooo`030000003oool0oooo0040oooo
00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000080?oo
o`030000003oool0oooo05H0oooo0`00nYXG0?ooo`<0003o103oool00`000?l00?ZJ003jVP050?oo
o`800?ZJ2`3oool40000o`800?ZJ0`3oool2003jVPP0oooo0`000?l50?ooo`800?ZJ0`3oool2003j
VPH0oooo0P000?l90?ooo`040000o`00nYX00?ZJ0?ooo`800?ZJ103oool20000o`800?ZJ0P3oool2
003jVP<0oooo0`000?l2003jVP030?ooo`00nYX00?ZJ00@0oooo0`000?l2003jVP030?ooo`00nYX0
0?ZJ00<0oooo0P000?l0103oool0003o003jVP00nYX60?ooo`030000003oool0oooo0040oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo05L0oooo0P00nYXH0?ooo`<0003o0P3oool20000o`800?ZJ
1@3oool2003jVP`0oooo0`000?l2003jVP<0oooo0P00nYX90?ooo`80003o1@3oool2003jVP<0oooo
0P00nYX60?ooo`80003o2@3oool3003jVP030?ooo`00nYX00?ZJ00D0oooo00<0003o003jVP00nYX0
0P3oool2003jVP@0oooo0P000?l2003jVP030?ooo`00nYX00?ZJ00@0oooo0`000?l2003jVP030?oo
o`00nYX00?ZJ00<0oooo0P000?l0103oool0003o003jVP00nYX60?ooo`030000003oool0oooo0040
oooo00020?ooo`8000002P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05L0oooo
0P00nYXI0?ooo`80003o0P3oool20000o`800?ZJ1@3oool2003jVP`0oooo0`000?l2003jVP<0oooo
0P00nYX90?ooo`80003o103oool00`000?l00?ZJ003jVP030?ooo`800?ZJ1P3oool30000o`P0oooo
0P00nYX20?ooo`800?ZJ1P3oool2003jVP80oooo0P00nYX40?ooo`80003o0P00nYX00`3oool00?ZJ
003jVP040?ooo`<0003o0P00nYX00`3oool00?ZJ003jVP030?ooo`80003o00@0oooo0000o`00nYX0
0?ZJ1P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1G0?ooo`<00?ZJ
603oool30000o`030?ooo`000?l0003o00800?ZJ1@3oool3003jVP`0oooo0P000?l2003jVP<0oooo
0P00nYX90?ooo`<0003o0`3oool00`000?l00?ZJ003jVP030?ooo`800?ZJ1`3oool20000o`P0oooo
0P00nYX20?ooo`800?ZJ1P3oool2003jVP80oooo0P00nYX40?ooo`80003o0P00nYX00`3oool00?ZJ
003jVP050?ooo`80003o0P00nYX00`3oool00?ZJ003jVP030?ooo`@0003o0P00nYX60?ooo`030000
003oool0oooo0040oooo000K0?ooo`800000F@3oool2003jVQT0oooo1@000?l2003jVPH0oooo0P00
nYX>0?ooo`800?ZJ0`3oool2003jVPX0oooo0P000?l30?ooo`030000o`00nYX00?ZJ00<0oooo0P00
nYX70?ooo`<0003o1`3oool2003jVP80oooo0`00nYX50?ooo`800?ZJ0P3oool2003jVPD0oooo00@0
003o003jVP00nYX0oooo0P00nYX50?ooo`80003o0P00nYX00`3oool00?ZJ003jVP040?ooo`<0003o
0P00nYX50?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool0F03oool3003jVQT0oooo1000
0?l2003jVPH0oooo0P00nYX>0?ooo`800?ZJ0`3oool3003jVPT0oooo0`000?l20?ooo`030000o`00
nYX00?ZJ00<0oooo0P00nYX80?ooo`80003o1`3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3o
ool2003jVPH0oooo0P00nYX00`3oool00?ZJ003jVP050?ooo`80003o0P00nYX00`3oool00?ZJ003j
VP040?ooo`<0003o0P00nYX60?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo05T0oooo0P00nYXI0?ooo`@0003o0P00nYX60?ooo`800?ZJ3P3oool2003jVP@0oooo0P00nYX:
0?ooo`<0003o00@0oooo0000o`00nYX00?ZJ0`3oool2003jVPP0oooo0`000?l60?ooo`800?ZJ0`3o
ool2003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo00@0
003o003jVP00nYX0oooo0P00nYX40?ooo`<0003o0P00nYX60?ooo`030000003oool0oooo0040oooo
000K0?ooo`030000003oool0oooo05T0oooo0`00nYXI0?ooo`<0003o0P00nYX60?ooo`800?ZJ3P3o
ool2003jVP@0oooo0P00nYX;0?ooo`80003o00@0oooo0000o`00nYX00?ZJ0`3oool3003jVPP0oooo
0P000?l60?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3oool2003jVP030?oo
o`00nYX00?ZJ00H0oooo00@0003o003jVP00nYX0oooo0P00nYX50?ooo`80003o0P00nYX60?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo05X0oooo0P00nYXJ0?ooo`80003o
0P00nYX60?ooo`<00?ZJ3@3oool2003jVP@0oooo0P00nYX;0?ooo`@0003o0P00nYX40?ooo`800?ZJ
203oool30000o`D0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP80oooo0`00nYX50?ooo`800?ZJ
00<0oooo003jVP00nYX01`3oool2003jVP030?ooo`00nYX00?ZJ00D0oooo0P000?l2003jVPH0oooo
00<000000?ooo`3oool00@3oool001/0oooo0P00001K0?ooo`<00?ZJ6`3oool2003jVPL0oooo0P00
nYX=0?ooo`800?ZJ103oool3003jVP/0oooo0`000?l2003jVP@0oooo0P00nYX90?ooo`80003o1@3o
ool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX0103oool00?ZJ003j
VP00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01@3oool20000o`800?ZJ1@3oool2000000<0oooo
000K0?ooo`030000003oool0oooo05/0oooo0P00nYXK0?ooo`800?ZJ1`3oool2003jVPd0oooo0P00
nYX50?ooo`800?ZJ2`3oool30000o`800?ZJ103oool2003jVPT0oooo0P000?l40?ooo`030000o`00
nYX00?ZJ00<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3o
ool2003jVP030?ooo`00nYX00?ZJ00H0oooo00<0003o003jVP00nYX01P3oool00`000000oooo0?oo
o`010?ooo`006`3oool00`000000oooo0?ooo`1K0?ooo`800?ZJ6`3oool2003jVPL0oooo0P00nYX=
0?ooo`800?ZJ1@3oool2003jVP`0oooo0P000?l2003jVP@0oooo0P00nYX90?ooo`<0003o0`3oool0
0`000?l00?ZJ003jVP030?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3oool2
003jVPH0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`030000o`00nYX00?ZJ00H0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0F`3oool3003jVQX0oooo0P00nYX70?oo
o`800?ZJ3@3oool2003jVPD0oooo0P00nYX<0?ooo`80003o0P00nYX40?ooo`800?ZJ2P3oool20000
o`<0oooo00<0003o003jVP00nYX00`3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ1@3oool2003j
VP80oooo0P00nYX60?ooo`800?ZJ00@0oooo003jVP00nYX00?ZJ1P3oool2003jVPH0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0G03oool2003jVQX0oooo0P00nYX70?oo
o`<00?ZJ303oool2003jVPD0oooo0P00nYX<0?ooo`80003o0P00nYX40?ooo`800?ZJ2P3oool20000
o`<0oooo00<0003o003jVP00nYX00`3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ1@3oool2003j
VP80oooo0P00nYX60?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX60?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo05`0oooo0P00nYXJ0?ooo`800?ZJ203oool2003jVP/0
oooo0`00nYX50?ooo`<00?ZJ303oool00`000?l00?ZJ003jVP040?ooo`800?ZJ2P3oool30000o`80
oooo00<0003o003jVP00nYX00`3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP80
oooo0P00nYX60?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX60?ooo`030000003oool0oooo0040
oooo000K0?ooo`800000G@3oool3003jVQT0oooo0P00nYX80?ooo`800?ZJ2`3oool2003jVPL0oooo
0P00nYX=0?ooo`800?ZJ103oool3003jVPX0oooo0P000?l20?ooo`030000o`00nYX00?ZJ00<0oooo
0`00nYX40?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3oool2003jVP80oooo
0P00nYX60?ooo`800?ZJ1@3oool2000000<0oooo000K0?ooo`030000003oool0oooo05d0oooo0P00
nYXI0?ooo`800?ZJ203oool2003jVP/0oooo0P00nYX70?ooo`800?ZJ3@3oool2003jVPD0oooo0P00
nYX:0?ooo`<0003o00@0oooo0000o`00nYX00?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`800?ZJ
1@3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX60?ooo`030000
003oool0oooo0040oooo000K0?ooo`030000003oool0oooo05d0oooo0`00nYXH0?ooo`800?ZJ203o
ool2003jVP/0oooo0P00nYX70?ooo`800?ZJ3@3oool2003jVPD0oooo0P00nYX;0?ooo`80003o00@0
oooo0000o`00nYX00?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP80oooo
0`00nYX50?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo
00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<0
00000?ooo`3oool0GP3oool2003jVQP0oooo0P00nYX80?ooo`<00?ZJ2P3oool2003jVPL0oooo0P00
nYX=0?ooo`800?ZJ1@3oool2003jVP/0oooo10000?l2003jVP@0oooo0P00nYX40?ooo`800?ZJ0`3o
ool2003jVPD0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP80oooo0P00nYX60?ooo`800?ZJ1P3o
ool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0
oooo0`00nYXG0?ooo`800?ZJ2@3oool2003jVPX0oooo0P00nYX70?ooo`<00?ZJ303oool2003jVPD0
oooo0P00nYX<0?ooo`<0003o0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0`00nYX40?ooo`80
0?ZJ0`3oool2003jVPD0oooo0P00nYX20?ooo`800?ZJ1P3oool2003jVPH0oooo00<000000?ooo`3o
ool00@3oool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1O0?ooo`800?ZJ5`3oool2
003jVPT0oooo0P00nYX:0?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX50?ooo`<00?ZJ2`3oool3
0000o`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0P00nYX5
0?ooo`800?ZJ0P3oool2003jVPH0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo00001@3o
ool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool3000000D0oooo0P00
001P0?ooo`<00?ZJ5P3oool2003jVPT0oooo0`00nYX90?ooo`800?ZJ203oool2003jVP`0oooo0P00
nYX60?ooo`800?ZJ303oool20000o`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103o
ool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0P3oool3003jVPD0oooo0P00nYX40?ooo`<000000`3o
ool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1P0?ooo`800?ZJ5P3oool2003jVPX0
oooo0P00nYX90?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX60?ooo`800?ZJ303oool20000o`80
0?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0P00nYX50?ooo`80
0?ZJ0`3oool2003jVPD0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo00001@3oool00000
0?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0H03oool2003jVQH0oooo0P00nYX:0?ooo`800?ZJ2@3oool2
003jVPP0oooo0P00nYX<0?ooo`800?ZJ1P3oool2003jVP`0oooo0P000?l2003jVP@0oooo0P00nYX4
0?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX5
0?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`000P3oool2000000X0oooo0P0000030?oo
o`<000001@3oool00`000000oooo0?ooo`1P0?ooo`<00?ZJ5@3oool2003jVPX0oooo0`00nYX80?oo
o`800?ZJ203oool2003jVP`0oooo0P00nYX60?ooo`800?ZJ3@3oool00`000?l00?ZJ003jVP040?oo
o`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX30?oo
o`800?ZJ1@3oool2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3o
ool0H@3oool2003jVQ@0oooo0`00nYX;0?ooo`800?ZJ203oool2003jVPP0oooo0P00nYX<0?ooo`80
0?ZJ1P3oool3003jVP`0oooo00<0003o003jVP00nYX0103oool3003jVP<0oooo0P00nYX40?ooo`80
0?ZJ103oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPD0oooo0P00nYX60?ooo`03
0000003oool0oooo0040oooo000K0?ooo`800000HP3oool2003jVQ@0oooo0P00nYX<0?ooo`800?ZJ
203oool2003jVPP0oooo0`00nYX;0?ooo`800?ZJ1`3oool2003jVPd0oooo0P00nYX50?ooo`800?ZJ
0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ0`3oool3003jVP@0oooo0P00nYX30?ooo`800?ZJ
1@3oool2003jVPD0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1Q0?ooo`<00?ZJ4`3o
ool2003jVP`0oooo0P00nYX80?ooo`800?ZJ2@3oool2003jVP/0oooo0P00nYX70?ooo`800?ZJ3@3o
ool2003jVPD0oooo0P00nYX30?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103o
ool2003jVP<0oooo0P00nYX50?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`006`3oool0
0`000000oooo0?ooo`1R0?ooo`800?ZJ4`3oool2003jVP`0oooo0`00nYX70?ooo`800?ZJ2@3oool2
003jVP/0oooo0P00nYX70?ooo`800?ZJ3@3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ103oool2
003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ1P3oool0
0`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1R0?ooo`800?ZJ4`3oool2003j
VPd0oooo0P00nYX70?ooo`800?ZJ2@3oool2003jVP/0oooo0P00nYX70?ooo`800?ZJ3@3oool2003j
VPD0oooo0P00nYX30?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003j
VP<0oooo0P00nYX50?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`1R0?ooo`<00?ZJ4P3oool2003jVPd0oooo0P00nYX70?ooo`800?ZJ2@3oool2003jVP/0
oooo0P00nYX70?ooo`800?ZJ3@3oool2003jVPD0oooo0P00nYX30?ooo`800?ZJ103oool3003jVP<0
oooo0P00nYX40?ooo`800?ZJ103oool2003jVP<0oooo0`00nYX40?ooo`800?ZJ1P3oool00`000000
oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1S0?ooo`800?ZJ4P3oool2003jVPd0oooo
0P00nYX70?ooo`800?ZJ2@3oool3003jVPX0oooo0P00nYX70?ooo`<00?ZJ303oool2003jVPD0oooo
0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX40?ooo`800?ZJ103oool2003jVP@0oooo
0P00nYX40?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`006`3oool2000006@0oooo0P00
nYXB0?ooo`800?ZJ3@3oool2003jVPL0oooo0P00nYX:0?ooo`800?ZJ2P3oool2003jVPP0oooo0P00
nYX<0?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0P00
nYX40?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX50?ooo`8000000`3oool001/0oooo00<00000
0?ooo`3oool0H`3oool3003jVQ40oooo0P00nYX=0?ooo`<00?ZJ1P3oool2003jVPX0oooo0P00nYX:
0?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX50?ooo`800?ZJ0P3oool3003jVPD0oooo0P00nYX3
0?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ103oool2003jVPH0oooo00<00000
0?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0I03oool2003jVQ40oooo0P00nYX>0?oo
o`800?ZJ1P3oool2003jVPX0oooo0`00nYX90?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX50?oo
o`<00?ZJ00<0oooo003jVP00nYX01P3oool2003jVP<0oooo0P00nYX40?ooo`800?ZJ103oool2003j
VP@0oooo0P00nYX40?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000
oooo0?ooo`1T0?ooo`<00?ZJ403oool2003jVPh0oooo0P00nYX60?ooo`800?ZJ2`3oool2003jVPT0
oooo0P00nYX80?ooo`800?ZJ303oool2003jVPH0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`80
0?ZJ0`3oool2003jVP@0oooo0`00nYX30?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX60?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06D0oooo0P00nYX@0?ooo`800?ZJ
3P3oool2003jVPH0oooo0P00nYX;0?ooo`800?ZJ2@3oool2003jVPP0oooo0P00nYX<0?ooo`800?ZJ
1P3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo
0P00nYX40?ooo`800?ZJ103oool2003jVPH0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0I@3oool2003jVQ00oooo0P00nYX>0?ooo`<00?ZJ1@3oool2003jVP/0oooo0P00
nYX90?ooo`800?ZJ203oool2003jVP`0oooo0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01P3o
ool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVP@0oooo0P00nYX40?ooo`800?ZJ1P3o
ool00`000000oooo0?ooo`010?ooo`006`3oool2000006H0oooo0`00nYX?0?ooo`800?ZJ3`3oool2
003jVPD0oooo0P00nYX;0?ooo`<00?ZJ203oool2003jVPP0oooo0`00nYX;0?ooo`800?ZJ1P3oool2
003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX20?ooo`<00?ZJ1@3oool2003jVP<0oooo0P00nYX4
0?ooo`800?ZJ103oool2003jVPD0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`1V0?oo
o`800?ZJ3`3oool2003jVPl0oooo0P00nYX50?ooo`800?ZJ303oool2003jVPP0oooo0P00nYX90?oo
o`800?ZJ2`3oool2003jVPH0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ0P3oool2003j
VPH0oooo0P00nYX30?ooo`800?ZJ103oool2003jVP@0oooo0P00nYX60?ooo`030000003oool0oooo
0040oooo000K0?ooo`030000003oool0oooo06H0oooo0`00nYX>0?ooo`800?ZJ3`3oool2003jVPD0
oooo0P00nYX<0?ooo`800?ZJ203oool2003jVPT0oooo0P00nYX;0?ooo`800?ZJ1P3oool2003jVP03
0?ooo`00nYX00?ZJ00H0oooo0`00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ0`3oool2003jVP@0
oooo0`00nYX30?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`00203oool2000000@0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0I`3oool2003jVPh0oooo
0P00nYX?0?ooo`800?ZJ1@3oool2003jVP`0oooo0P00nYX80?ooo`800?ZJ2@3oool2003jVP/0oooo
0P00nYX60?ooo`800?ZJ00<0oooo003jVP00nYX01`3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo
0P00nYX30?ooo`800?ZJ1@3oool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1W0?ooo`800?ZJ3P3oool2003jVPl0oooo0`00nYX40?ooo`800?ZJ303oool2003jVPP0oooo
0P00nYX90?ooo`800?ZJ2`3oool2003jVPH0oooo1@00nYX70?ooo`800?ZJ00<0oooo003jVP00nYX0
1P3oool2003jVP<0oooo0P00nYX50?ooo`800?ZJ0`3oool2003jVPH0oooo00<000000?ooo`3oool0
0@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000
J03oool3003jVPd0oooo0P00nYX@0?ooo`800?ZJ103oool2003jVP`0oooo0`00nYX70?ooo`800?ZJ
2@3oool2003jVP/0oooo0P00nYX70?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo
0P00nYX20?ooo`<00?ZJ1@3oool2003jVP<0oooo0P00nYX40?ooo`<000000`3oool000L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo
0P00nYX=0?ooo`800?ZJ403oool2003jVP@0oooo0P00nYX=0?ooo`800?ZJ1`3oool2003jVPT0oooo
0P00nYX;0?ooo`800?ZJ1`3oool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ
0P3oool2003jVPH0oooo0P00nYX30?ooo`800?ZJ1P3oool00`000000oooo0?ooo`010?ooo`001`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
J03oool2003jVPd0oooo0P00nYX@0?ooo`<00?ZJ0`3oool2003jVPd0oooo0P00nYX70?ooo`800?ZJ
2@3oool3003jVPX0oooo0P00nYX70?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo
0P00nYX20?ooo`800?ZJ1P3oool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo
00070?ooo`040000003oool0oooo000000P0oooo0P0000060?ooo`030000003oool0oooo06P0oooo
0`00nYX<0?ooo`800?ZJ4@3oool2003jVP80oooo0`00nYX=0?ooo`800?ZJ1`3oool2003jVPX0oooo
0P00nYX:0?ooo`800?ZJ1`3oool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`<00?ZJ
00<0oooo003jVP00nYX01P3oool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo
00080?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo0P00
nYX<0?ooo`800?ZJ4@3oool2003jVP80oooo0P00nYX>0?ooo`800?ZJ1`3oool2003jVPX0oooo0P00
nYX:0?ooo`800?ZJ1`3oool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP070?ooo`800?ZJ00<0
oooo003jVP00nYX01P3oool2003jVP<0oooo0P00nYX60?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo06T0oooo0P00nYX<0?ooo`800?ZJ4@3oool3003jVP030?ooo`00nYX0
0?ZJ00h0oooo0P00nYX70?ooo`800?ZJ2P3oool2003jVPX0oooo0P00nYX80?ooo`<00?ZJ1`3oool5
003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP060?ooo`800?ZJ0P3oool3003jVPH0oooo00<00000
0?ooo`3oool00@3oool001/0oooo0P00001Z0?ooo`<00?ZJ2`3oool2003jVQ80oooo0P00nYX00`3o
ool00?ZJ003jVP0>0?ooo`<00?ZJ1P3oool2003jVPX0oooo0P00nYX:0?ooo`800?ZJ203oool3003j
VPP0oooo1000nYX70?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool2003jVP80oooo0P00nYX60?oo
o`8000000`3oool001/0oooo00<000000?ooo`3oool0JP3oool2003jVP/0oooo0P00nYXB0?ooo`80
0?ZJ00<0oooo003jVP00nYX03`3oool2003jVPH0oooo0P00nYX:0?ooo`800?ZJ2P3oool2003jVPP0
oooo0`00nYX80?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00H0oooo0P00nYX20?ooo`80
0?ZJ1`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1Z0?ooo`800?ZJ
2`3oool2003jVQ80oooo1@00nYX?0?ooo`800?ZJ1P3oool2003jVPX0oooo0P00nYX:0?ooo`800?ZJ
203oool3003jVPP0oooo1000nYX70?ooo`800?ZJ00<0oooo003jVP00nYX01P3oool3003jVP030?oo
o`00nYX00?ZJ00L0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0JP3o
ool3003jVPX0oooo0P00nYXC0?ooo`@00?ZJ3`3oool2003jVPH0oooo0P00nYX:0?ooo`<00?ZJ2@3o
ool2003jVPP0oooo0`00nYX80?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00L0oooo0P00
nYX00`3oool00?ZJ003jVP070?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
oooo06/0oooo0P00nYX:0?ooo`800?ZJ4`3oool4003jVPl0oooo0P00nYX60?ooo`800?ZJ2`3oool2
003jVPT0oooo0P00nYX80?ooo`<00?ZJ203oool4003jVPL0oooo0P00nYX00`3oool00?ZJ003jVP07
0?ooo`800?ZJ00<0oooo003jVP00nYX01`3oool00`000000oooo0?ooo`010?ooo`006`3oool20000
06`0oooo0`00nYX90?ooo`800?ZJ4`3oool4003jVPl0oooo0`00nYX40?ooo`<00?ZJ2`3oool2003j
VPT0oooo0P00nYX90?ooo`800?ZJ2@3oool3003jVPL0oooo1@00nYX70?ooo`800?ZJ00<0oooo003j
VP00nYX01P3oool2000000<0oooo000K0?ooo`030000003oool0oooo06`0oooo0P00nYX90?ooo`80
0?ZJ4`3oool4003jVQ00oooo0P00nYX40?ooo`800?ZJ303oool2003jVPT0oooo0P00nYX90?ooo`80
0?ZJ2@3oool3003jVPP0oooo1000nYX70?ooo`800?ZJ00<0oooo003jVP00nYX01`3oool00`000000
oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`1/0?ooo`800?ZJ2@3oool2003jVQ@0oooo
0`00nYX@0?ooo`800?ZJ103oool2003jVP`0oooo0P00nYX90?ooo`800?ZJ2@3oool2003jVPT0oooo
0`00nYX80?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX00?ZJ00L0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool0K03oool3003jVPP0oooo0P00nYXD0?ooo`<00?ZJ403o
ool2003jVP@0oooo0P00nYX<0?ooo`800?ZJ2@3oool2003jVQ@0oooo0`00nYX80?ooo`@00?ZJ1`3o
ool2003jVP030?ooo`00nYX00?ZJ00L0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0K@3oool2003jVPP0oooo0P00nYXD0?ooo`<00?ZJ403oool2003jVP@0oooo0P00nYX<
0?ooo`<00?ZJ203oool2003jVQ@0oooo0`00nYX80?ooo`@00?ZJ1`3oool2003jVP030?ooo`00nYX0
0?ZJ00L0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0K@3oool3003j
VPL0oooo0P00nYXD0?ooo`<00?ZJ403oool3003jVP<0oooo0P00nYX=0?ooo`800?ZJ203oool2003j
VQ@0oooo0`00nYX80?ooo`@00?ZJ1`3oool5003jVPL0oooo00<000000?ooo`3oool00@3oool001/0
oooo0P00001_0?ooo`800?ZJ1`3oool2003jVQ@0oooo0`00nYXA0?ooo`800?ZJ0`3oool2003jVPd0
oooo0P00nYX80?ooo`800?ZJ5@3oool2003jVPP0oooo1000nYX80?ooo`@00?ZJ1P3oool2000000<0
oooo000K0?ooo`030000003oool0oooo06h0oooo0P00nYX70?ooo`800?ZJ5@3oool2003jVQ40oooo
0P00nYX30?ooo`800?ZJ3@3oool2003jVPP0oooo0P00nYXE0?ooo`800?ZJ2@3oool3003jVPP0oooo
1000nYX70?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo06h0oooo0`00
nYX60?ooo`800?ZJ5@3oool2003jVQ40oooo0P00nYX30?ooo`800?ZJ3@3oool3003jVPL0oooo0P00
nYXE0?ooo`800?ZJ2@3oool3003jVPP0oooo1000nYX70?ooo`030000003oool0oooo0040oooo0002
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000000P3oool5000000@0oooo00<00000
0?ooo`3oool0K`3oool2003jVPH0oooo0P00nYXX0?ooo`800?ZJ0`3oool2003jVPh0oooo0P00nYX7
0?ooo`800?ZJ803oool3003jVPP0oooo1000nYX70?ooo`030000003oool0oooo0040oooo00001@3o
ool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo06l0oooo0P00nYX60?ooo`800?ZJ:03oool3003jVP80oooo0P00
nYX>0?ooo`800?ZJ1`3oool2003jVR00oooo0`00nYX80?ooo`@00?ZJ1`3oool00`000000oooo0?oo
o`010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1_0?ooo`<00?ZJ103oool3003jVRT0oooo0P00
nYX20?ooo`800?ZJ3P3oool2003jVPL0oooo0P00nYXP0?ooo`<00?ZJ203oool4003jVPL0oooo00<0
00000?ooo`3oool00@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo0P00001a0?ooo`800?ZJ103oool2003jVRX0oooo0P00
nYX20?ooo`800?ZJ3P3oool3003jVPH0oooo0P00nYXP0?ooo`<00?ZJ203oool4003jVPD0oooo0`00
00030?ooo`0000D0oooo0000003oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo0`00nYX30?ooo`800?ZJ
:P3oool3003jVP030?ooo`00nYX00?ZJ00l0oooo0P00nYX60?ooo`800?ZJ8@3oool2003jVPT0oooo
0`00nYX70?ooo`030000003oool0oooo0040oooo00001@3oool000000?ooo`3oool0000000P0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1a0?ooo`80
0?ZJ0`3oool2003jVR/0oooo0P00nYX00`3oool00?ZJ003jVP0?0?ooo`800?ZJ1P3oool2003jVR40
oooo0P00nYX90?ooo`<00?ZJ1`3oool00`000000oooo0?ooo`010?ooo`000P3oool2000000X0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0L@3oool2003jVP<0oooo
0P00nYX[0?ooo`800?ZJ00<0oooo003jVP00nYX03`3oool2003jVPH0oooo0P00nYXQ0?ooo`800?ZJ
2@3oool3003jVPL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0L@3o
ool3003jVP80oooo0P00nYX[0?ooo`800?ZJ00<0oooo003jVP00nYX03`3oool2003jVPD0oooo0`00
nYX/0?ooo`<00?ZJ1`3oool00`000000oooo0?ooo`010?ooo`006`3oool2000007<0oooo0P00nYX2
0?ooo`800?ZJ:`3oool5003jVPl0oooo0`00nYX40?ooo`800?ZJ;@3oool3003jVPH0oooo0P000003
0?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`800?ZJ0P3oool2003jVR`0oooo1000nYX@0?oo
o`800?ZJ103oool2003jVRd0oooo0`00nYX70?ooo`030000003oool0oooo0040oooo000K0?ooo`03
0000003oool0oooo0780oooo0`00nYX00`3oool00?ZJ003jVP0/0?ooo`@00?ZJ403oool2003jVP@0
oooo0P00nYX]0?ooo`<00?ZJ1`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo
0?ooo`1c0?ooo`800?ZJ00<0oooo003jVP00nYX0;03oool4003jVQ00oooo0P00nYX40?ooo`800?ZJ
;P3oool2003jVPL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0L`3o
ool2003jVP030?ooo`00nYX00?ZJ02`0oooo1000nYX@0?ooo`800?ZJ103oool2003jVRh0oooo0P00
nYX70?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo07<0oooo1@00nYX]
0?ooo`<00?ZJ403oool2003jVP@0oooo0P00nYX^0?ooo`800?ZJ1`3oool00`000000oooo0?ooo`01
0?ooo`006`3oool2000007D0oooo1000nYX]0?ooo`<00?ZJ403oool3003jVP<0oooo0P00nYXf0?oo
o`8000000`3oool001/0oooo00<000000?ooo`3oool0M03oool4003jVRd0oooo0`00nYXA0?ooo`80
0?ZJ0`3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0
M03oool4003jVRd0oooo0`00nYXA0?ooo`800?ZJ0`3oool2003jVSL0oooo00<000000?ooo`3oool0
0@3oool001/0oooo00<000000?ooo`3oool0M03oool4003jVRd0oooo0`00nYXA0?ooo`800?ZJ0`3o
ool2003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?ooo`3oool0M@3oool3
003jVRh0oooo0P00nYXA0?ooo`800?ZJ0`3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool0
01/0oooo00<000000?ooo`3oool0M@3oool3003jVRh0oooo0P00nYXA0?ooo`<00?ZJ0P3oool2003j
VSL0oooo00<000000?ooo`3oool00@3oool001/0oooo0P00001f0?ooo`<00?ZJ;P3oool2003jVQ80
oooo0P00nYX20?ooo`800?ZJ=P3oool2000000<0oooo000K0?ooo`030000003oool0oooo07H0oooo
0P00nYY20?ooo`800?ZJ0P3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0MP3oool2003jVT80oooo0P00nYX20?ooo`800?ZJ=`3oool00`000000oooo0?oo
o`010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`000004
0?ooo`030000003oool0oooo0;X0oooo0`00nYX00`3oool00?ZJ003jVP0g0?ooo`030000003oool0
oooo0040oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0;/0oooo0P00nYX00`3oool00?ZJ003jVP0g
0?ooo`030000003oool0oooo0040oooo00001@3oool000000?ooo`3oool0000000T0oooo00@00000
0?ooo`3oool0oooo1@0000040?ooo`800000_03oool2003jVP030?ooo`00nYX00?ZJ03D0oooo0`00
00030?ooo`0000D0oooo0000003oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;/0oooo0P00nYX00`3oool00?ZJ
003jVP0g0?ooo`030000003oool0oooo0040oooo00001@3oool000000?ooo`3oool0000000T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo0;/0oooo
1@00nYXg0?ooo`030000003oool0oooo0040oooo00001@3oool000000?ooo`3oool0000000P0oooo
0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`2l0?ooo`@00?ZJ=`3oool00`000000oooo
0?ooo`010?ooo`000P3oool2000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0;`0oooo1000nYXg0?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo0;`0oooo1000nYXg0?ooo`030000003oool0oooo0040oooo000K0?oo
o`800000_@3oool4003jVSH0oooo0P0000030?ooo`006`3oool00`000000oooo0?ooo`2l0?ooo`@0
0?ZJ=`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2m0?ooo`<00?ZJ
=`3oool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2m0?ooo`<00?ZJ=`3o
ool00`000000oooo0?ooo`010?ooo`006`3oool00`000000oooo0?ooo`2m0?ooo`<00?ZJ=`3oool0
0`000000oooo0?ooo`010?ooo`006`3oool200000;h0oooo0`00nYXf0?ooo`8000000`3oool001/0
oooo00<000000?ooo`3oool0_@3oool3003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo
00<000000?ooo`3oool0_@3oool3003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<0
00000?ooo`3oool0_P3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<00000
0?ooo`3oool0_P3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo00<000000?oo
o`3oool0_P3oool2003jVSL0oooo00<000000?ooo`3oool00@3oool001/0oooo0P0000040?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`80
00000`3oool001/0oooon`0000030?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 280.438}, {172.875, 0}} -> {-13.8823, 0.00523223, \
0.419554, 0.000889325}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["time = AddTimeAxis[#,{0,10,dt}]&", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \(AddTimeAxis[#1, {0, 10, dt}] &\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZM // Dimensions\)], "Input"],

Cell[BoxData[
    \({10, 101, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
m1={PointSize[ps=.02],Map[Point[#]&,{(tau-1)dt,ZM[[n,tau,1]]}//\
Transpose]};
m2={PointSize[ps    ],Map[Point[#]&,{(tau-1)dt,ZM[[n,tau,2]]}//Transpose]};\
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
DisplayTogetherArray[

{{plot1[Column[hpdF,{1,3,5}]//time,color->{1,2,2},Epilog->m1,PlotLabel->\"\
filtered, 1st component\"],
  plot1[Column[hpdG,{1,3,5}]//time,color->{1,2,2},Epilog->m1,PlotLabel->\"\
smoothed, 1st component\"]},
 {plot1[Column[hpdF,{2,4,6}]//time,color->{1,2,2},Epilog->m2,PlotLabel->\"\
filtered, 2nd component\"],
  plot1[Column[hpdG,{2,4,6}]//time,color->{1,2,2},Epilog->m2,PlotLabel->\"\
smoothed, 2nd component\"]}}
]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Dimension der Daten  "\[InvisibleSpace]{101, 4}\),
      SequenceForm[ "Dimension der Daten  ", {101, 4}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.5 0.309017 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.0676389 0.0413307 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01502 -6 -4.5 ]
[-0.0125 .01502 0 4.5 ]
[-0.0125 .09768 -6 -4.5 ]
[-0.0125 .09768 0 4.5 ]
[-0.0125 .18035 -6 -4.5 ]
[-0.0125 .18035 0 4.5 ]
[-0.0125 .26301 -6 -4.5 ]
[-0.0125 .26301 0 4.5 ]
[-0.0125 .34567 -12 -4.5 ]
[-0.0125 .34567 0 4.5 ]
[-0.0125 .42833 -12 -4.5 ]
[-0.0125 .42833 0 4.5 ]
[-0.0125 .51099 -12 -4.5 ]
[-0.0125 .51099 0 4.5 ]
[-0.0125 .59365 -12 -4.5 ]
[-0.0125 .59365 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .60003 -5 -6 ]
[.97619 .60003 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .59674 -5 -6 ]
[.97619 .59674 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01502 m
.00625 .01502 L
s
[(2)] -0.0125 .01502 1 0 Mshowa
0 .09768 m
.00625 .09768 L
s
[(4)] -0.0125 .09768 1 0 Mshowa
0 .18035 m
.00625 .18035 L
s
[(6)] -0.0125 .18035 1 0 Mshowa
0 .26301 m
.00625 .26301 L
s
[(8)] -0.0125 .26301 1 0 Mshowa
0 .34567 m
.00625 .34567 L
s
[(10)] -0.0125 .34567 1 0 Mshowa
0 .42833 m
.00625 .42833 L
s
[(12)] -0.0125 .42833 1 0 Mshowa
0 .51099 m
.00625 .51099 L
s
[(14)] -0.0125 .51099 1 0 Mshowa
0 .59365 m
.00625 .59365 L
s
[(16)] -0.0125 .59365 1 0 Mshowa
.125 Mabswid
0 .03569 m
.00375 .03569 L
s
0 .05635 m
.00375 .05635 L
s
0 .07702 m
.00375 .07702 L
s
0 .11835 m
.00375 .11835 L
s
0 .13901 m
.00375 .13901 L
s
0 .15968 m
.00375 .15968 L
s
0 .20101 m
.00375 .20101 L
s
0 .22168 m
.00375 .22168 L
s
0 .24234 m
.00375 .24234 L
s
0 .28367 m
.00375 .28367 L
s
0 .30434 m
.00375 .30434 L
s
0 .325 m
.00375 .325 L
s
0 .36633 m
.00375 .36633 L
s
0 .387 m
.00375 .387 L
s
0 .40766 m
.00375 .40766 L
s
0 .44899 m
.00375 .44899 L
s
0 .46966 m
.00375 .46966 L
s
0 .49033 m
.00375 .49033 L
s
0 .53166 m
.00375 .53166 L
s
0 .55232 m
.00375 .55232 L
s
0 .57299 m
.00375 .57299 L
s
0 .61432 m
.00375 .61432 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01502 m
1 .01502 L
s
.99375 .09768 m
1 .09768 L
s
.99375 .18035 m
1 .18035 L
s
.99375 .26301 m
1 .26301 L
s
.99375 .34567 m
1 .34567 L
s
.99375 .42833 m
1 .42833 L
s
.99375 .51099 m
1 .51099 L
s
.99375 .59365 m
1 .59365 L
s
.125 Mabswid
.99625 .03569 m
1 .03569 L
s
.99625 .05635 m
1 .05635 L
s
.99625 .07702 m
1 .07702 L
s
.99625 .11835 m
1 .11835 L
s
.99625 .13901 m
1 .13901 L
s
.99625 .15968 m
1 .15968 L
s
.99625 .20101 m
1 .20101 L
s
.99625 .22168 m
1 .22168 L
s
.99625 .24234 m
1 .24234 L
s
.99625 .28367 m
1 .28367 L
s
.99625 .30434 m
1 .30434 L
s
.99625 .325 m
1 .325 L
s
.99625 .36633 m
1 .36633 L
s
.99625 .387 m
1 .387 L
s
.99625 .40766 m
1 .40766 L
s
.99625 .44899 m
1 .44899 L
s
.99625 .46966 m
1 .46966 L
s
.99625 .49033 m
1 .49033 L
s
.99625 .53166 m
1 .53166 L
s
.99625 .55232 m
1 .55232 L
s
.99625 .57299 m
1 .57299 L
s
.99625 .61432 m
1 .61432 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(filtered) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(2) show
129.000 13.000 moveto
(nd) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .60003 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .01808 m
.03333 .02073 L
.04286 .02345 L
.05238 .02623 L
.0619 .02907 L
.07143 .03198 L
.08095 .03495 L
.09048 .03799 L
.1 .0411 L
.10952 .04428 L
.11905 .04444 L
.12857 .04767 L
.1381 .05097 L
.14762 .05433 L
.15714 .05776 L
.16667 .06127 L
.17619 .06484 L
.18571 .06848 L
.19524 .0722 L
.20476 .07598 L
.21429 .07726 L
.22381 .08112 L
.23333 .08505 L
.24286 .08906 L
.25238 .09314 L
.2619 .09729 L
.27143 .10151 L
.28095 .10581 L
.29048 .11018 L
.3 .11462 L
.30952 .11809 L
.31905 .12266 L
.32857 .1273 L
.3381 .13201 L
.34762 .13679 L
.35714 .14164 L
.36667 .14657 L
.37619 .15157 L
.38571 .15663 L
.39524 .16177 L
.40476 .16698 L
.41429 .17226 L
.42381 .17761 L
.43333 .18303 L
.44286 .18852 L
.45238 .19407 L
.4619 .19969 L
.47143 .20538 L
.48095 .21113 L
.49048 .21694 L
Mistroke
.5 .22653 L
.50952 .23256 L
.51905 .23864 L
.52857 .24478 L
.5381 .25099 L
.54762 .25725 L
.55714 .26357 L
.56667 .26995 L
.57619 .27638 L
.58571 .28286 L
.59524 .29609 L
.60476 .3028 L
.61429 .30955 L
.62381 .31635 L
.63333 .32319 L
.64286 .33008 L
.65238 .33701 L
.6619 .34398 L
.67143 .35098 L
.68095 .35802 L
.69048 .36536 L
.7 .37247 L
.70952 .37961 L
.71905 .38678 L
.72857 .39396 L
.7381 .40117 L
.74762 .4084 L
.75714 .41564 L
.76667 .42289 L
.77619 .43016 L
.78571 .43934 L
.79524 .44664 L
.80476 .45395 L
.81429 .46126 L
.82381 .46856 L
.83333 .48226 L
.84286 .48962 L
.85238 .49697 L
.8619 .5043 L
.87143 .51162 L
.88095 .51749 L
.89048 .52474 L
.9 .53197 L
.90952 .53917 L
.91905 .54633 L
.92857 .5557 L
.9381 .56282 L
.94762 .56989 L
.95714 .57691 L
.96667 .58388 L
Mistroke
.97619 .60003 L
Mfstroke
0 .98 .604 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02145 m
.03333 .0242 L
.04286 .02702 L
.05238 .02991 L
.0619 .03287 L
.07143 .03589 L
.08095 .039 L
.09048 .04217 L
.1 .04542 L
.10952 .04875 L
.11905 .04717 L
.12857 .05055 L
.1381 .05402 L
.14762 .05757 L
.15714 .06121 L
.16667 .06493 L
.17619 .06873 L
.18571 .07262 L
.19524 .0766 L
.20476 .08066 L
.21429 .08004 L
.22381 .08428 L
.23333 .08859 L
.24286 .09298 L
.25238 .09745 L
.2619 .10199 L
.27143 .10662 L
.28095 .11133 L
.29048 .11612 L
.3 .12099 L
.30952 .12111 L
.31905 .12635 L
.32857 .13161 L
.3381 .13692 L
.34762 .14229 L
.35714 .14772 L
.36667 .15322 L
.37619 .15878 L
.38571 .16442 L
.39524 .17014 L
.40476 .17593 L
.41429 .18179 L
.42381 .18774 L
.43333 .19375 L
.44286 .19984 L
.45238 .20601 L
.4619 .21225 L
.47143 .21857 L
.48095 .22496 L
.49048 .23142 L
Mistroke
.5 .22982 L
.50952 .23731 L
.51905 .24458 L
.52857 .25178 L
.5381 .25896 L
.54762 .26615 L
.55714 .27337 L
.56667 .28062 L
.57619 .2879 L
.58571 .29523 L
.59524 .29935 L
.60476 .30802 L
.61429 .31627 L
.62381 .32436 L
.63333 .33238 L
.64286 .34038 L
.65238 .34836 L
.6619 .35634 L
.67143 .36434 L
.68095 .37234 L
.69048 .36865 L
.7 .37825 L
.70952 .38718 L
.71905 .39586 L
.72857 .40442 L
.7381 .4129 L
.74762 .42133 L
.75714 .42972 L
.76667 .43809 L
.77619 .44645 L
.78571 .44264 L
.79524 .45299 L
.80476 .46238 L
.81429 .47143 L
.82381 .48029 L
.83333 .48553 L
.84286 .49623 L
.85238 .50582 L
.8619 .51501 L
.87143 .52397 L
.88095 .52076 L
.89048 .53165 L
.9 .54127 L
.90952 .55043 L
.91905 .55933 L
.92857 .55898 L
.9381 .57002 L
.94762 .57962 L
.95714 .58872 L
.96667 .59752 L
Mistroke
.97619 .60332 L
Mfstroke
gsave
.97619 .59674 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01727 L
.04286 .01988 L
.05238 .02255 L
.0619 .02528 L
.07143 .02807 L
.08095 .03091 L
.09048 .03382 L
.1 .03678 L
.10952 .0398 L
.11905 .04172 L
.12857 .04479 L
.1381 .04791 L
.14762 .05109 L
.15714 .05432 L
.16667 .05761 L
.17619 .06095 L
.18571 .06435 L
.19524 .0678 L
.20476 .07131 L
.21429 .07447 L
.22381 .07796 L
.23333 .08152 L
.24286 .08514 L
.25238 .08883 L
.2619 .09259 L
.27143 .09641 L
.28095 .1003 L
.29048 .10424 L
.3 .10826 L
.30952 .11508 L
.31905 .11897 L
.32857 .12298 L
.3381 .12709 L
.34762 .13129 L
.35714 .13557 L
.36667 .13992 L
.37619 .14435 L
.38571 .14884 L
.39524 .15341 L
.40476 .15804 L
.41429 .16273 L
.42381 .16749 L
.43333 .17231 L
.44286 .17719 L
.45238 .18213 L
.4619 .18713 L
.47143 .19219 L
.48095 .1973 L
.49048 .20247 L
Mistroke
.5 .22325 L
.50952 .2278 L
.51905 .2327 L
.52857 .23779 L
.5381 .24302 L
.54762 .24835 L
.55714 .25377 L
.56667 .25928 L
.57619 .26485 L
.58571 .27048 L
.59524 .29283 L
.60476 .29757 L
.61429 .30283 L
.62381 .30833 L
.63333 .314 L
.64286 .31979 L
.65238 .32566 L
.6619 .33161 L
.67143 .33763 L
.68095 .34369 L
.69048 .36208 L
.7 .3667 L
.70952 .37204 L
.71905 .37769 L
.72857 .38351 L
.7381 .38945 L
.74762 .39547 L
.75714 .40156 L
.76667 .40769 L
.77619 .41387 L
.78571 .43603 L
.79524 .4403 L
.80476 .44552 L
.81429 .45108 L
.82381 .45683 L
.83333 .479 L
.84286 .48302 L
.85238 .48812 L
.8619 .4936 L
.87143 .49926 L
.88095 .51422 L
.89048 .51784 L
.9 .52268 L
.90952 .52791 L
.91905 .53334 L
.92857 .55242 L
.9381 .55561 L
.94762 .56015 L
.95714 .5651 L
.96667 .57025 L
Mistroke
.97619 .59674 L
Mfstroke
0 g
.02 w
.02381 .01808 Mdot
.11905 .04283 Mdot
.21429 .07607 Mdot
.30952 .11784 Mdot
.5 .22672 Mdot
.59524 .29653 Mdot
.69048 .36538 Mdot
.78571 .43941 Mdot
.83333 .48268 Mdot
.88095 .51741 Mdot
.92857 .55582 Mdot
.97619 .60048 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0147151 0.97619 0.309017 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.0661746 0.0412405 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01631 -6 -4.5 ]
[-0.0125 .01631 0 4.5 ]
[-0.0125 .09879 -6 -4.5 ]
[-0.0125 .09879 0 4.5 ]
[-0.0125 .18127 -6 -4.5 ]
[-0.0125 .18127 0 4.5 ]
[-0.0125 .26375 -6 -4.5 ]
[-0.0125 .26375 0 4.5 ]
[-0.0125 .34623 -12 -4.5 ]
[-0.0125 .34623 0 4.5 ]
[-0.0125 .42871 -12 -4.5 ]
[-0.0125 .42871 0 4.5 ]
[-0.0125 .51119 -12 -4.5 ]
[-0.0125 .51119 0 4.5 ]
[-0.0125 .59367 -12 -4.5 ]
[-0.0125 .59367 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .60004 -5 -6 ]
[.97619 .60004 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .59676 -5 -6 ]
[.97619 .59676 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01631 m
.00625 .01631 L
s
[(2)] -0.0125 .01631 1 0 Mshowa
0 .09879 m
.00625 .09879 L
s
[(4)] -0.0125 .09879 1 0 Mshowa
0 .18127 m
.00625 .18127 L
s
[(6)] -0.0125 .18127 1 0 Mshowa
0 .26375 m
.00625 .26375 L
s
[(8)] -0.0125 .26375 1 0 Mshowa
0 .34623 m
.00625 .34623 L
s
[(10)] -0.0125 .34623 1 0 Mshowa
0 .42871 m
.00625 .42871 L
s
[(12)] -0.0125 .42871 1 0 Mshowa
0 .51119 m
.00625 .51119 L
s
[(14)] -0.0125 .51119 1 0 Mshowa
0 .59367 m
.00625 .59367 L
s
[(16)] -0.0125 .59367 1 0 Mshowa
.125 Mabswid
0 .03693 m
.00375 .03693 L
s
0 .05755 m
.00375 .05755 L
s
0 .07817 m
.00375 .07817 L
s
0 .11941 m
.00375 .11941 L
s
0 .14003 m
.00375 .14003 L
s
0 .16065 m
.00375 .16065 L
s
0 .20189 m
.00375 .20189 L
s
0 .22251 m
.00375 .22251 L
s
0 .24313 m
.00375 .24313 L
s
0 .28437 m
.00375 .28437 L
s
0 .30499 m
.00375 .30499 L
s
0 .32561 m
.00375 .32561 L
s
0 .36685 m
.00375 .36685 L
s
0 .38747 m
.00375 .38747 L
s
0 .40809 m
.00375 .40809 L
s
0 .44933 m
.00375 .44933 L
s
0 .46995 m
.00375 .46995 L
s
0 .49057 m
.00375 .49057 L
s
0 .53181 m
.00375 .53181 L
s
0 .55243 m
.00375 .55243 L
s
0 .57305 m
.00375 .57305 L
s
0 .61429 m
.00375 .61429 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01631 m
1 .01631 L
s
.99375 .09879 m
1 .09879 L
s
.99375 .18127 m
1 .18127 L
s
.99375 .26375 m
1 .26375 L
s
.99375 .34623 m
1 .34623 L
s
.99375 .42871 m
1 .42871 L
s
.99375 .51119 m
1 .51119 L
s
.99375 .59367 m
1 .59367 L
s
.125 Mabswid
.99625 .03693 m
1 .03693 L
s
.99625 .05755 m
1 .05755 L
s
.99625 .07817 m
1 .07817 L
s
.99625 .11941 m
1 .11941 L
s
.99625 .14003 m
1 .14003 L
s
.99625 .16065 m
1 .16065 L
s
.99625 .20189 m
1 .20189 L
s
.99625 .22251 m
1 .22251 L
s
.99625 .24313 m
1 .24313 L
s
.99625 .28437 m
1 .28437 L
s
.99625 .30499 m
1 .30499 L
s
.99625 .32561 m
1 .32561 L
s
.99625 .36685 m
1 .36685 L
s
.99625 .38747 m
1 .38747 L
s
.99625 .40809 m
1 .40809 L
s
.99625 .44933 m
1 .44933 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .49057 m
1 .49057 L
s
.99625 .53181 m
1 .53181 L
s
.99625 .55243 m
1 .55243 L
s
.99625 .57305 m
1 .57305 L
s
.99625 .61429 m
1 .61429 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(smoothed) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(2) show
129.000 13.000 moveto
(nd) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .60004 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .01644 m
.03333 .019 L
.04286 .02162 L
.05238 .0243 L
.0619 .02703 L
.07143 .02982 L
.08095 .03267 L
.09048 .03557 L
.1 .03852 L
.10952 .04152 L
.11905 .04457 L
.12857 .0477 L
.1381 .05088 L
.14762 .05411 L
.15714 .0574 L
.16667 .06074 L
.17619 .06413 L
.18571 .06757 L
.19524 .07107 L
.20476 .07462 L
.21429 .07822 L
.22381 .08203 L
.23333 .08591 L
.24286 .08986 L
.25238 .09387 L
.2619 .09796 L
.27143 .10211 L
.28095 .10633 L
.29048 .11061 L
.3 .11497 L
.30952 .11939 L
.31905 .12406 L
.32857 .12881 L
.3381 .13364 L
.34762 .13855 L
.35714 .14354 L
.36667 .14861 L
.37619 .15376 L
.38571 .15899 L
.39524 .1643 L
.40476 .16969 L
.41429 .17516 L
.42381 .18071 L
.43333 .18633 L
.44286 .19204 L
.45238 .19782 L
.4619 .20367 L
.47143 .20961 L
.48095 .21561 L
.49048 .2217 L
Mistroke
.5 .22785 L
.50952 .23438 L
.51905 .241 L
.52857 .2477 L
.5381 .25448 L
.54762 .26133 L
.55714 .26827 L
.56667 .27528 L
.57619 .28237 L
.58571 .28954 L
.59524 .29678 L
.60476 .30349 L
.61429 .31026 L
.62381 .31708 L
.63333 .32394 L
.64286 .33084 L
.65238 .33779 L
.6619 .34478 L
.67143 .35181 L
.68095 .35888 L
.69048 .36598 L
.7 .37327 L
.70952 .3806 L
.71905 .38796 L
.72857 .39535 L
.7381 .40276 L
.74762 .4102 L
.75714 .41765 L
.76667 .42513 L
.77619 .43262 L
.78571 .44013 L
.79524 .44854 L
.80476 .45699 L
.81429 .46545 L
.82381 .47394 L
.83333 .48245 L
.84286 .48956 L
.85238 .49665 L
.8619 .50373 L
.87143 .51078 L
.88095 .51782 L
.89048 .52554 L
.9 .53325 L
.90952 .54094 L
.91905 .54861 L
.92857 .55625 L
.9381 .56504 L
.94762 .57381 L
.95714 .58257 L
.96667 .59132 L
Mistroke
.97619 .60004 L
Mfstroke
0 .98 .604 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01816 m
.03333 .02078 L
.04286 .02345 L
.05238 .02618 L
.0619 .02896 L
.07143 .0318 L
.08095 .03469 L
.09048 .03763 L
.1 .04061 L
.10952 .04363 L
.11905 .0467 L
.12857 .0499 L
.1381 .05316 L
.14762 .05647 L
.15714 .05983 L
.16667 .06323 L
.17619 .06667 L
.18571 .07014 L
.19524 .07364 L
.20476 .07715 L
.21429 .08067 L
.22381 .08472 L
.23333 .0888 L
.24286 .09293 L
.25238 .09709 L
.2619 .10127 L
.27143 .10548 L
.28095 .1097 L
.29048 .11392 L
.3 .11812 L
.30952 .12227 L
.31905 .1275 L
.32857 .13274 L
.3381 .138 L
.34762 .1433 L
.35714 .14864 L
.36667 .15402 L
.37619 .15945 L
.38571 .16491 L
.39524 .17041 L
.40476 .17596 L
.41429 .18153 L
.42381 .18713 L
.43333 .19275 L
.44286 .19838 L
.45238 .204 L
.4619 .20961 L
.47143 .21518 L
.48095 .22067 L
.49048 .226 L
Mistroke
.5 .23099 L
.50952 .2387 L
.51905 .24611 L
.52857 .25335 L
.5381 .26049 L
.54762 .26752 L
.55714 .27445 L
.56667 .28125 L
.57619 .28787 L
.58571 .2942 L
.59524 .29993 L
.60476 .3083 L
.61429 .3161 L
.62381 .32361 L
.63333 .33091 L
.64286 .33802 L
.65238 .34495 L
.6619 .35165 L
.67143 .35808 L
.68095 .36408 L
.69048 .36918 L
.7 .37862 L
.70952 .38722 L
.71905 .39541 L
.72857 .40331 L
.7381 .41095 L
.74762 .41834 L
.75714 .42544 L
.76667 .43217 L
.77619 .43836 L
.78571 .44331 L
.79524 .45405 L
.80476 .4634 L
.81429 .47193 L
.82381 .47958 L
.83333 .4856 L
.84286 .49531 L
.85238 .5034 L
.8619 .51054 L
.87143 .51669 L
.88095 .52099 L
.89048 .53157 L
.9 .54035 L
.90952 .5481 L
.91905 .55479 L
.92857 .55944 L
.9381 .57135 L
.94762 .58127 L
.95714 .5901 L
.96667 .5978 L
Mistroke
.97619 .60332 L
Mfstroke
gsave
.97619 .59676 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01722 L
.04286 .01979 L
.05238 .02242 L
.0619 .0251 L
.07143 .02784 L
.08095 .03065 L
.09048 .03351 L
.1 .03642 L
.10952 .0394 L
.11905 .04245 L
.12857 .04549 L
.1381 .04859 L
.14762 .05175 L
.15714 .05497 L
.16667 .05824 L
.17619 .06159 L
.18571 .06501 L
.19524 .06851 L
.20476 .07209 L
.21429 .07578 L
.22381 .07935 L
.23333 .08302 L
.24286 .08679 L
.25238 .09066 L
.2619 .09464 L
.27143 .09873 L
.28095 .10295 L
.29048 .1073 L
.3 .11182 L
.30952 .11652 L
.31905 .12063 L
.32857 .12489 L
.3381 .12928 L
.34762 .1338 L
.35714 .13844 L
.36667 .1432 L
.37619 .14808 L
.38571 .15308 L
.39524 .15819 L
.40476 .16343 L
.41429 .16879 L
.42381 .17429 L
.43333 .17992 L
.44286 .1857 L
.45238 .19163 L
.4619 .19773 L
.47143 .20403 L
.48095 .21056 L
.49048 .2174 L
Mistroke
.5 .22472 L
.50952 .23007 L
.51905 .23589 L
.52857 .24204 L
.5381 .24846 L
.54762 .25515 L
.55714 .26209 L
.56667 .26932 L
.57619 .27688 L
.58571 .28488 L
.59524 .29362 L
.60476 .29869 L
.61429 .30442 L
.62381 .31054 L
.63333 .31696 L
.64286 .32367 L
.65238 .33064 L
.6619 .33792 L
.67143 .34555 L
.68095 .35368 L
.69048 .36278 L
.7 .36793 L
.70952 .37399 L
.71905 .38051 L
.72857 .38739 L
.7381 .39457 L
.74762 .40205 L
.75714 .40987 L
.76667 .41809 L
.77619 .42688 L
.78571 .43694 L
.79524 .44304 L
.80476 .45057 L
.81429 .45898 L
.82381 .46831 L
.83333 .47929 L
.84286 .4838 L
.85238 .4899 L
.8619 .49691 L
.87143 .50488 L
.88095 .51464 L
.89048 .51951 L
.9 .52615 L
.90952 .53377 L
.91905 .54242 L
.92857 .55306 L
.9381 .55873 L
.94762 .56635 L
.95714 .57504 L
.96667 .58483 L
Mistroke
.97619 .59676 L
Mfstroke
0 g
.02 w
.02381 .01936 Mdot
.11905 .04405 Mdot
.21429 .07722 Mdot
.30952 .1189 Mdot
.5 .22754 Mdot
.59524 .2972 Mdot
.69048 .3659 Mdot
.78571 .43977 Mdot
.83333 .48295 Mdot
.88095 .51759 Mdot
.92857 .55592 Mdot
.97619 .60048 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.309017 0.5 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.190614 0.227159 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03655 -6 -4.5 ]
[-0.0125 .03655 0 4.5 ]
[-0.0125 .15013 -18 -4.5 ]
[-0.0125 .15013 0 4.5 ]
[-0.0125 .2637 -6 -4.5 ]
[-0.0125 .2637 0 4.5 ]
[-0.0125 .37728 -18 -4.5 ]
[-0.0125 .37728 0 4.5 ]
[-0.0125 .49086 -6 -4.5 ]
[-0.0125 .49086 0 4.5 ]
[-0.0125 .60444 -18 -4.5 ]
[-0.0125 .60444 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .5614 -5 -6 ]
[.97619 .5614 5 6 ]
[.97619 .57855 -5 -6 ]
[.97619 .57855 5 6 ]
[.97619 .54424 -5 -6 ]
[.97619 .54424 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03655 m
.00625 .03655 L
s
[(1)] -0.0125 .03655 1 0 Mshowa
0 .15013 m
.00625 .15013 L
s
[(1.5)] -0.0125 .15013 1 0 Mshowa
0 .2637 m
.00625 .2637 L
s
[(2)] -0.0125 .2637 1 0 Mshowa
0 .37728 m
.00625 .37728 L
s
[(2.5)] -0.0125 .37728 1 0 Mshowa
0 .49086 m
.00625 .49086 L
s
[(3)] -0.0125 .49086 1 0 Mshowa
0 .60444 m
.00625 .60444 L
s
[(3.5)] -0.0125 .60444 1 0 Mshowa
.125 Mabswid
0 .05926 m
.00375 .05926 L
s
0 .08198 m
.00375 .08198 L
s
0 .10469 m
.00375 .10469 L
s
0 .12741 m
.00375 .12741 L
s
0 .17284 m
.00375 .17284 L
s
0 .19556 m
.00375 .19556 L
s
0 .21827 m
.00375 .21827 L
s
0 .24099 m
.00375 .24099 L
s
0 .28642 m
.00375 .28642 L
s
0 .30914 m
.00375 .30914 L
s
0 .33185 m
.00375 .33185 L
s
0 .35457 m
.00375 .35457 L
s
0 .4 m
.00375 .4 L
s
0 .42272 m
.00375 .42272 L
s
0 .44543 m
.00375 .44543 L
s
0 .46815 m
.00375 .46815 L
s
0 .51358 m
.00375 .51358 L
s
0 .5363 m
.00375 .5363 L
s
0 .55901 m
.00375 .55901 L
s
0 .58173 m
.00375 .58173 L
s
0 .01383 m
.00375 .01383 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03655 m
1 .03655 L
s
.99375 .15013 m
1 .15013 L
s
.99375 .2637 m
1 .2637 L
s
.99375 .37728 m
1 .37728 L
s
.99375 .49086 m
1 .49086 L
s
.99375 .60444 m
1 .60444 L
s
.125 Mabswid
.99625 .05926 m
1 .05926 L
s
.99625 .08198 m
1 .08198 L
s
.99625 .10469 m
1 .10469 L
s
.99625 .12741 m
1 .12741 L
s
.99625 .17284 m
1 .17284 L
s
.99625 .19556 m
1 .19556 L
s
.99625 .21827 m
1 .21827 L
s
.99625 .24099 m
1 .24099 L
s
.99625 .28642 m
1 .28642 L
s
.99625 .30914 m
1 .30914 L
s
.99625 .33185 m
1 .33185 L
s
.99625 .35457 m
1 .35457 L
s
.99625 .4 m
1 .4 L
s
.99625 .42272 m
1 .42272 L
s
.99625 .44543 m
1 .44543 L
s
.99625 .46815 m
1 .46815 L
s
.99625 .51358 m
1 .51358 L
s
.99625 .5363 m
1 .5363 L
s
.99625 .55901 m
1 .55901 L
s
.99625 .58173 m
1 .58173 L
s
.99625 .01383 m
1 .01383 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(filtered) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(1) show
129.000 13.000 moveto
(st) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .5614 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .03322 m
.03333 .03499 L
.04286 .03678 L
.05238 .0386 L
.0619 .04044 L
.07143 .04231 L
.08095 .04421 L
.09048 .04614 L
.1 .04809 L
.10952 .05007 L
.11905 .05323 L
.12857 .0553 L
.1381 .05739 L
.14762 .05952 L
.15714 .06168 L
.16667 .06386 L
.17619 .06608 L
.18571 .06833 L
.19524 .07061 L
.20476 .07293 L
.21429 .07353 L
.22381 .0759 L
.23333 .07831 L
.24286 .08075 L
.25238 .08322 L
.2619 .08574 L
.27143 .08828 L
.28095 .09087 L
.29048 .09349 L
.3 .09615 L
.30952 .10422 L
.31905 .10703 L
.32857 .10989 L
.3381 .11278 L
.34762 .11572 L
.35714 .1187 L
.36667 .12173 L
.37619 .1248 L
.38571 .12791 L
.39524 .13108 L
.40476 .13429 L
.41429 .13754 L
.42381 .14085 L
.43333 .14421 L
.44286 .14762 L
.45238 .15109 L
.4619 .1546 L
.47143 .15817 L
.48095 .1618 L
.49048 .16548 L
Mistroke
.5 .19116 L
.50952 .19527 L
.51905 .19945 L
.52857 .20369 L
.5381 .20801 L
.54762 .2124 L
.55714 .21686 L
.56667 .22139 L
.57619 .22601 L
.58571 .2307 L
.59524 .24338 L
.60476 .24833 L
.61429 .25336 L
.62381 .25848 L
.63333 .26369 L
.64286 .26899 L
.65238 .27439 L
.6619 .27988 L
.67143 .28548 L
.68095 .29118 L
.69048 .31034 L
.7 .31648 L
.70952 .32273 L
.71905 .3291 L
.72857 .33559 L
.7381 .34221 L
.74762 .34896 L
.75714 .35584 L
.76667 .36286 L
.77619 .37001 L
.78571 .37919 L
.79524 .38666 L
.80476 .39428 L
.81429 .40206 L
.82381 .41 L
.83333 .39163 L
.84286 .39938 L
.85238 .40729 L
.8619 .41537 L
.87143 .42362 L
.88095 .45416 L
.89048 .46319 L
.9 .47242 L
.90952 .48186 L
.91905 .4915 L
.92857 .51909 L
.9381 .52951 L
.94762 .54015 L
.95714 .55105 L
.96667 .56219 L
Mistroke
.97619 .5614 L
Mfstroke
0 .98 .604 r
gsave
.97619 .57855 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05172 m
.03333 .05367 L
.04286 .05566 L
.05238 .05767 L
.0619 .05972 L
.07143 .06181 L
.08095 .06393 L
.09048 .0661 L
.1 .0683 L
.10952 .07056 L
.11905 .06705 L
.12857 .06939 L
.1381 .07179 L
.14762 .07424 L
.15714 .07676 L
.16667 .07934 L
.17619 .08198 L
.18571 .08468 L
.19524 .08745 L
.20476 .09028 L
.21429 .0864 L
.22381 .08944 L
.23333 .09255 L
.24286 .09573 L
.25238 .09898 L
.2619 .10229 L
.27143 .10567 L
.28095 .10912 L
.29048 .11264 L
.3 .11622 L
.30952 .11811 L
.31905 .12216 L
.32857 .12625 L
.3381 .13039 L
.34762 .13457 L
.35714 .13882 L
.36667 .14312 L
.37619 .14748 L
.38571 .1519 L
.39524 .15639 L
.40476 .16095 L
.41429 .16558 L
.42381 .17028 L
.43333 .17505 L
.44286 .1799 L
.45238 .18482 L
.4619 .18983 L
.47143 .19491 L
.48095 .20008 L
.49048 .20533 L
Mistroke
.5 .20806 L
.50952 .21476 L
.51905 .22136 L
.52857 .22793 L
.5381 .2345 L
.54762 .24109 L
.55714 .24772 L
.56667 .25441 L
.57619 .26116 L
.58571 .26799 L
.59524 .26013 L
.60476 .26865 L
.61429 .27689 L
.62381 .285 L
.63333 .29305 L
.64286 .3011 L
.65238 .30917 L
.6619 .3173 L
.67143 .32549 L
.68095 .33376 L
.69048 .32746 L
.7 .33818 L
.70952 .34841 L
.71905 .35843 L
.72857 .36834 L
.7381 .37824 L
.74762 .38815 L
.75714 .39813 L
.76667 .40819 L
.77619 .41836 L
.78571 .3966 L
.79524 .40975 L
.80476 .42216 L
.81429 .43425 L
.82381 .44619 L
.83333 .40843 L
.84286 .42262 L
.85238 .43581 L
.8619 .44859 L
.87143 .46117 L
.88095 .47107 L
.89048 .48715 L
.9 .50209 L
.90952 .51655 L
.91905 .53083 L
.92857 .53613 L
.9381 .55422 L
.94762 .57098 L
.95714 .58725 L
.96667 .60332 L
Mistroke
.97619 .57855 L
Mfstroke
gsave
.97619 .54424 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .0163 L
.04286 .0179 L
.05238 .01952 L
.0619 .02116 L
.07143 .02282 L
.08095 .02449 L
.09048 .02618 L
.1 .02788 L
.10952 .02958 L
.11905 .03942 L
.12857 .04121 L
.1381 .043 L
.14762 .0448 L
.15714 .0466 L
.16667 .04839 L
.17619 .05019 L
.18571 .05198 L
.19524 .05378 L
.20476 .05557 L
.21429 .06066 L
.22381 .06236 L
.23333 .06406 L
.24286 .06577 L
.25238 .06747 L
.2619 .06918 L
.27143 .0709 L
.28095 .07262 L
.29048 .07434 L
.3 .07608 L
.30952 .09033 L
.31905 .09191 L
.32857 .09352 L
.3381 .09518 L
.34762 .09686 L
.35714 .09858 L
.36667 .10033 L
.37619 .10211 L
.38571 .10392 L
.39524 .10576 L
.40476 .10762 L
.41429 .10951 L
.42381 .11143 L
.43333 .11337 L
.44286 .11535 L
.45238 .11735 L
.4619 .11938 L
.47143 .12143 L
.48095 .12352 L
.49048 .12563 L
Mistroke
.5 .17426 L
.50952 .17578 L
.51905 .17753 L
.52857 .17945 L
.5381 .18151 L
.54762 .1837 L
.55714 .18599 L
.56667 .18837 L
.57619 .19085 L
.58571 .19341 L
.59524 .22663 L
.60476 .22801 L
.61429 .22983 L
.62381 .23196 L
.63333 .23432 L
.64286 .23688 L
.65238 .2396 L
.6619 .24247 L
.67143 .24547 L
.68095 .24859 L
.69048 .29322 L
.7 .29477 L
.70952 .29704 L
.71905 .29977 L
.72857 .30284 L
.7381 .30619 L
.74762 .30977 L
.75714 .31355 L
.76667 .31752 L
.77619 .32166 L
.78571 .36178 L
.79524 .36357 L
.80476 .3664 L
.81429 .36987 L
.82381 .3738 L
.83333 .37484 L
.84286 .37615 L
.85238 .37877 L
.8619 .38215 L
.87143 .38607 L
.88095 .43725 L
.89048 .43923 L
.9 .44276 L
.90952 .44716 L
.91905 .45217 L
.92857 .50205 L
.9381 .50479 L
.94762 .50933 L
.95714 .51485 L
.96667 .52106 L
Mistroke
.97619 .54424 L
Mfstroke
0 g
.02 w
.02381 .03322 Mdot
.11905 .05422 Mdot
.21429 .07169 Mdot
.30952 .10838 Mdot
.5 .19555 Mdot
.59524 .24514 Mdot
.69048 .31258 Mdot
.78571 .37944 Mdot
.83333 .38597 Mdot
.88095 .45852 Mdot
.92857 .52227 Mdot
.97619 .55941 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.309017 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.215983 0.241966 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02598 -6 -4.5 ]
[-0.0125 .02598 0 4.5 ]
[-0.0125 .14697 -18 -4.5 ]
[-0.0125 .14697 0 4.5 ]
[-0.0125 .26795 -6 -4.5 ]
[-0.0125 .26795 0 4.5 ]
[-0.0125 .38893 -18 -4.5 ]
[-0.0125 .38893 0 4.5 ]
[-0.0125 .50992 -6 -4.5 ]
[-0.0125 .50992 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[.97619 .58505 -5 -6 ]
[.97619 .58505 5 6 ]
[.97619 .60332 -5 -6 ]
[.97619 .60332 5 6 ]
[.97619 .56677 -5 -6 ]
[.97619 .56677 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02598 m
.00625 .02598 L
s
[(1)] -0.0125 .02598 1 0 Mshowa
0 .14697 m
.00625 .14697 L
s
[(1.5)] -0.0125 .14697 1 0 Mshowa
0 .26795 m
.00625 .26795 L
s
[(2)] -0.0125 .26795 1 0 Mshowa
0 .38893 m
.00625 .38893 L
s
[(2.5)] -0.0125 .38893 1 0 Mshowa
0 .50992 m
.00625 .50992 L
s
[(3)] -0.0125 .50992 1 0 Mshowa
.125 Mabswid
0 .05018 m
.00375 .05018 L
s
0 .07438 m
.00375 .07438 L
s
0 .09857 m
.00375 .09857 L
s
0 .12277 m
.00375 .12277 L
s
0 .17116 m
.00375 .17116 L
s
0 .19536 m
.00375 .19536 L
s
0 .21956 m
.00375 .21956 L
s
0 .24375 m
.00375 .24375 L
s
0 .29215 m
.00375 .29215 L
s
0 .31634 m
.00375 .31634 L
s
0 .34054 m
.00375 .34054 L
s
0 .36474 m
.00375 .36474 L
s
0 .41313 m
.00375 .41313 L
s
0 .43733 m
.00375 .43733 L
s
0 .46152 m
.00375 .46152 L
s
0 .48572 m
.00375 .48572 L
s
0 .00179 m
.00375 .00179 L
s
0 .53411 m
.00375 .53411 L
s
0 .55831 m
.00375 .55831 L
s
0 .58251 m
.00375 .58251 L
s
0 .6067 m
.00375 .6067 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02598 m
1 .02598 L
s
.99375 .14697 m
1 .14697 L
s
.99375 .26795 m
1 .26795 L
s
.99375 .38893 m
1 .38893 L
s
.99375 .50992 m
1 .50992 L
s
.125 Mabswid
.99625 .05018 m
1 .05018 L
s
.99625 .07438 m
1 .07438 L
s
.99625 .09857 m
1 .09857 L
s
.99625 .12277 m
1 .12277 L
s
.99625 .17116 m
1 .17116 L
s
.99625 .19536 m
1 .19536 L
s
.99625 .21956 m
1 .21956 L
s
.99625 .24375 m
1 .24375 L
s
.99625 .29215 m
1 .29215 L
s
.99625 .31634 m
1 .31634 L
s
.99625 .34054 m
1 .34054 L
s
.99625 .36474 m
1 .36474 L
s
.99625 .41313 m
1 .41313 L
s
.99625 .43733 m
1 .43733 L
s
.99625 .46152 m
1 .46152 L
s
.99625 .48572 m
1 .48572 L
s
.99625 .00179 m
1 .00179 L
s
.99625 .53411 m
1 .53411 L
s
.99625 .55831 m
1 .55831 L
s
.99625 .58251 m
1 .58251 L
s
.99625 .6067 m
1 .6067 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(smoothed) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(,) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
(1) show
129.000 13.000 moveto
(st) show
147.000 13.000 moveto
(component) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.200 0.200 0.200 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.97619 .58505 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.02381 .02454 m
.03333 .02646 L
.04286 .02841 L
.05238 .03038 L
.0619 .03239 L
.07143 .03443 L
.08095 .0365 L
.09048 .03861 L
.1 .04075 L
.10952 .04292 L
.11905 .04513 L
.12857 .04737 L
.1381 .04966 L
.14762 .05198 L
.15714 .05435 L
.16667 .05675 L
.17619 .0592 L
.18571 .06169 L
.19524 .06422 L
.20476 .0668 L
.21429 .06942 L
.22381 .07233 L
.23333 .07531 L
.24286 .07836 L
.25238 .08149 L
.2619 .08469 L
.27143 .08798 L
.28095 .09134 L
.29048 .09479 L
.3 .09832 L
.30952 .10193 L
.31905 .10558 L
.32857 .10932 L
.3381 .11315 L
.34762 .11706 L
.35714 .12106 L
.36667 .12515 L
.37619 .12934 L
.38571 .13362 L
.39524 .138 L
.40476 .14247 L
.41429 .14705 L
.42381 .15172 L
.43333 .1565 L
.44286 .16139 L
.45238 .16638 L
.4619 .17149 L
.47143 .1767 L
.48095 .18202 L
.49048 .18747 L
Mistroke
.5 .19302 L
.50952 .19813 L
.51905 .20332 L
.52857 .20862 L
.5381 .21401 L
.54762 .21951 L
.55714 .2251 L
.56667 .2308 L
.57619 .23661 L
.58571 .24253 L
.59524 .24855 L
.60476 .25483 L
.61429 .26123 L
.62381 .26776 L
.63333 .27442 L
.64286 .28121 L
.65238 .28814 L
.6619 .2952 L
.67143 .30241 L
.68095 .30976 L
.69048 .31726 L
.7 .32359 L
.70952 .33003 L
.71905 .33659 L
.72857 .34327 L
.7381 .35008 L
.74762 .35701 L
.75714 .36408 L
.76667 .37129 L
.77619 .37863 L
.78571 .38612 L
.79524 .39054 L
.80476 .39503 L
.81429 .39959 L
.82381 .40421 L
.83333 .40891 L
.84286 .42129 L
.85238 .43395 L
.8619 .44688 L
.87143 .4601 L
.88095 .47361 L
.89048 .48595 L
.9 .49855 L
.90952 .51143 L
.91905 .52459 L
.92857 .53803 L
.9381 .54704 L
.94762 .55623 L
.95714 .56563 L
.96667 .57523 L
Mistroke
.97619 .58505 L
Mfstroke
0 .98 .604 r
gsave
.97619 .60332 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03436 m
.03333 .03638 L
.04286 .03843 L
.05238 .0405 L
.0619 .04261 L
.07143 .04474 L
.08095 .04689 L
.09048 .04907 L
.1 .05128 L
.10952 .0535 L
.11905 .05575 L
.12857 .05812 L
.1381 .06052 L
.14762 .06297 L
.15714 .06544 L
.16667 .06795 L
.17619 .07049 L
.18571 .07306 L
.19524 .07564 L
.20476 .07824 L
.21429 .08084 L
.22381 .08413 L
.23333 .08747 L
.24286 .09087 L
.25238 .09431 L
.2619 .09779 L
.27143 .1013 L
.28095 .10483 L
.29048 .10837 L
.3 .1119 L
.30952 .11541 L
.31905 .12003 L
.32857 .12468 L
.3381 .12936 L
.34762 .13408 L
.35714 .13883 L
.36667 .14361 L
.37619 .14842 L
.38571 .15325 L
.39524 .1581 L
.40476 .16297 L
.41429 .16784 L
.42381 .1727 L
.43333 .17755 L
.44286 .18237 L
.45238 .18714 L
.4619 .19184 L
.47143 .19643 L
.48095 .20087 L
.49048 .2051 L
Mistroke
.5 .209 L
.50952 .21581 L
.51905 .22234 L
.52857 .22863 L
.5381 .2347 L
.54762 .24055 L
.55714 .24615 L
.56667 .25147 L
.57619 .25644 L
.58571 .26097 L
.59524 .26484 L
.60476 .27372 L
.61429 .28205 L
.62381 .28998 L
.63333 .29757 L
.64286 .30482 L
.65238 .31173 L
.6619 .31825 L
.67143 .3243 L
.68095 .32971 L
.69048 .33415 L
.7 .34398 L
.70952 .35292 L
.71905 .36122 L
.72857 .36901 L
.7381 .37632 L
.74762 .38313 L
.75714 .38939 L
.76667 .39497 L
.77619 .39963 L
.78571 .40277 L
.79524 .4107 L
.80476 .41681 L
.81429 .42143 L
.82381 .42444 L
.83333 .42522 L
.84286 .44184 L
.85238 .45645 L
.8619 .46954 L
.87143 .48102 L
.88095 .49015 L
.89048 .50723 L
.9 .522 L
.90952 .53503 L
.91905 .54627 L
.92857 .55481 L
.9381 .56917 L
.94762 .58084 L
.95714 .59057 L
.96667 .59834 L
Mistroke
.97619 .60332 L
Mfstroke
gsave
.97619 .56677 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.980 0.604 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03333 .01654 L
.04286 .01839 L
.05238 .02027 L
.0619 .02218 L
.07143 .02413 L
.08095 .02612 L
.09048 .02814 L
.1 .03022 L
.10952 .03234 L
.11905 .03451 L
.12857 .03663 L
.1381 .0388 L
.14762 .041 L
.15714 .04325 L
.16667 .04555 L
.17619 .0479 L
.18571 .05031 L
.19524 .0528 L
.20476 .05536 L
.21429 .058 L
.22381 .06053 L
.23333 .06315 L
.24286 .06586 L
.25238 .06867 L
.2619 .0716 L
.27143 .07466 L
.28095 .07785 L
.29048 .0812 L
.3 .08473 L
.30952 .08845 L
.31905 .09114 L
.32857 .09397 L
.3381 .09693 L
.34762 .10004 L
.35714 .10329 L
.36667 .1067 L
.37619 .11026 L
.38571 .11399 L
.39524 .11789 L
.40476 .12198 L
.41429 .12626 L
.42381 .13074 L
.43333 .13546 L
.44286 .14041 L
.45238 .14563 L
.4619 .15113 L
.47143 .15697 L
.48095 .16318 L
.49048 .16983 L
Mistroke
.5 .17705 L
.50952 .18044 L
.51905 .1843 L
.52857 .1886 L
.5381 .19332 L
.54762 .19846 L
.55714 .20406 L
.56667 .21014 L
.57619 .21678 L
.58571 .22409 L
.59524 .23227 L
.60476 .23594 L
.61429 .24041 L
.62381 .24553 L
.63333 .25127 L
.64286 .2576 L
.65238 .26454 L
.6619 .27215 L
.67143 .28052 L
.68095 .28981 L
.69048 .30038 L
.7 .30319 L
.70952 .30714 L
.71905 .31195 L
.72857 .31753 L
.7381 .32384 L
.74762 .3309 L
.75714 .33878 L
.76667 .3476 L
.77619 .35763 L
.78571 .36947 L
.79524 .37039 L
.80476 .37325 L
.81429 .37775 L
.82381 .38398 L
.83333 .3926 L
.84286 .40075 L
.85238 .41145 L
.8619 .42423 L
.87143 .43919 L
.88095 .45708 L
.89048 .46466 L
.9 .47511 L
.90952 .48782 L
.91905 .50291 L
.92857 .52124 L
.9381 .5249 L
.94762 .53163 L
.95714 .54069 L
.96667 .55213 L
Mistroke
.97619 .56677 L
Mfstroke
0 g
.02 w
.02381 .02244 Mdot
.11905 .04481 Mdot
.21429 .06342 Mdot
.30952 .1025 Mdot
.5 .19535 Mdot
.59524 .24817 Mdot
.69048 .32002 Mdot
.78571 .39122 Mdot
.83333 .39819 Mdot
.88095 .47546 Mdot
.92857 .54337 Mdot
.97619 .58293 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{690.25, 426.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:b0001ZR000`400?l00000o`00003oo`3ooooo
0?oook@0oooo003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo
003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0
oooo]03oool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool0
03@0oooo0P00000b0?ooo`D00000<`3oool300000380oooo0`00000c0?ooo`<00000;`3oool30000
00@0oooo0P00000f0?ooo`800000<P3oool5000003<0oooo0`00000b0?ooo`<00000<P3oool30000
0300oooo0`0000040?ooo`800000903oool003<0oooo00@000000?ooo`3oool00000<P3oool01000
0000oooo0?ooo`00000d0?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo0000
000a0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000003@0oooo00@000000?ooo`3oool00000<P3oool010000000oooo0?ooo`00000d
0?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo0000000`0?ooo`050000003o
ool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002<0
oooo000c0?ooo`040000003oool0oooo000003<0oooo00<000000?ooo`3oool0<@3oool500000340
oooo00D000000?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000;`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000
<`3oool00`000000oooo0?ooo`0a0?ooo`D00000<@3oool01@000000oooo0?ooo`3oool000000300
oooo00D000000?ooo`3oool0oooo0000000`0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000008`3oool003<0oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?ooo`0`
0?ooo`040000003oool0oooo00000380oooo1000000c0?ooo`<00000<03oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000=03oool00`000000
oooo0?ooo`0`0?ooo`040000003oool0oooo00000380oooo1000000b0?ooo`<00000<@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000002<0oooo000c0?ooo`040000003oool0oooo
00000340oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool000000380oooo00<0
00000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0000002l0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000d0?ooo`040000003oool0oooo00000340oooo00D000000?oo
o`3oool0oooo0000000b0?ooo`030000003oool000000380oooo00<000000?ooo`3oool0<P3oool0
1@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000S0?ooo`00<`3oool010000000oooo0?ooo`00000a0?ooo`050000003oool0oooo0?ooo`00
0000<`3oool2000003<0oooo00<000000?ooo`3oool0<P3oool01@000000oooo0?ooo`3oool00000
02h0oooo0P0000040?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000<@3o
ool01@000000oooo0?ooo`3oool0000003<0oooo0P00000c0?ooo`030000003oool0oooo0340oooo
00D000000?ooo`3oool0oooo0000000_0?ooo`800000103oool010000000oooo0?ooo`00000S0?oo
o`00=03oool2000003<0oooo0`00000e0?ooo`030000003oool0oooo0380oooo0P00000c0?ooo`<0
0000<03oool00`000000oooo0?ooo`030?ooo`800000=P3oool2000003<0oooo0`00000e0?ooo`03
0000003oool0oooo0380oooo0P00000b0?ooo`<00000<@3oool00`000000oooo0?ooo`030?ooo`80
0000903oool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool0
0?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo000_0?ooool000007000000]0?ooool00000
7000000P0?ooo`009@3oool5000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool002H0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool08@3o
ool5000000D0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo01h0oooo000W
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool300000?l0oooo4`3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3o
ool300000?l0oooo4`3oool00`000000oooo0?ooo`0N0?ooo`00:03oool00`000000oooo0?ooo`04
0?ooo`8000000P3oool5000000<00?ZJo`3oool=0?ooo`<000009@3oool00`000000oooo0?ooo`05
0?ooo`8000000P3oool5000000<00?ZJo`3oool=0?ooo`<00000803oool002D0oooo00D000000?oo
o`3oool0oooo000000050?ooo`040000003oool0oooo0?ooo`D000001@00nY[o0?ooo`d0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`D00000
1@00nY[o0?ooo`d0oooo00<000000?ooo`3oool07P3oool002D0oooo00D000000?ooo`3oool0oooo
000000050?ooo`040000003oool0oooo0?ooo`D000002000nY[o0?ooo`X0oooo00<000000?ooo`3o
ool08@3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool0oooo1@000008
003jV_l0oooo2P3oool00`000000oooo0?ooo`0N0?ooo`009P3oool3000000H0oooo00<000000?oo
o`3oool00P3oool3000000`00?ZJo`3oool70?ooo`030000003oool0oooo0240oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo0`0000030?ooo`/00?ZJo`3oool5
0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo00P0oooo3P00nY[o0?oo
o`80oooo00<000000?ooo`3oool08P3oool3000000H0oooo00<000000?ooo`3oool02P3oool<003j
V_l0oooo0P3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`0:0?ooo`l0
0?ZJoP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00d0oooo3000nY[n0?ooo`03
0000003oool0oooo01h0oooo000_0?ooo`8000003P3oool6003jVP80003o1`00nYX0103oool00000
00000000003f0?ooo`800000;@3oool200000140oooo3000nYX0103oool0000000000000003f0?oo
o`800000803oool002l0oooo00<000000?ooo`3oool0403oool6003jVP80003o1000nYX500000?H0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0E0?ooo`L00?ZJ1@00003f0?ooo`03
0000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0180oooo2P00nYX5000000<00?ZJ
l`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo1000nYX5000000<00?ZJ
l`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`0E0?ooo`L00?ZJ1@00
0005003jV_40oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0K0?ooo`03003jVP00
0000000000<000001@00nY[a0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0
oooo01/0oooo0P00nYX3000000T00?ZJkP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo01d0oooo0`000009003jV^h0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?oo
o`3oool0803oool<003jV^/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0P0?oo
o``00?ZJj`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool2000002@0oooo2`00nY[X0?ooo`80
0000;@3oool2000002@0oooo2`00nY[X0?ooo`800000803oool002l0oooo00<000000?ooo`3oool0
9@3oool<003jV^H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0U0?ooo``00?ZJ
iP3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`0X0?ooo``00?ZJh`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo2@00nY[S0?ooo`030000003o
ool0oooo01h0oooo000_0?ooo`030000003oool0oooo02/0oooo2`00nYX20?ooo`<00000g03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02d0oooo2@00nY[Q0?ooo`030000003oool0
oooo01h0oooo000_0?ooo`030000003oool0oooo02d0oooo2P00nYX500000=/0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0`0?ooo`P00?ZJ0`00003L0?ooo`030000003oool0oooo
01h0oooo000_0?ooo`800000<@3oool7003jVPD00000fP3oool2000002d0oooo00<000000?ooo`3o
ool0<`3oool4003jVPD00000f`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo
0?ooo`0c0?ooo`@00?ZJ1@000003003jV]P0oooo00<000000?ooo`3oool0:`3oool2000003H0oooo
0P00nYX5000000800?ZJf03oool200000200oooo000_0?ooo`030000003oool0oooo03D0oooo0`00
nYX3000000H00?ZJeP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03L0oooo1@00
0005003jV]H0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0>`3oool9
003jV]<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0h0?ooo`<000002@00nY[C
0?ooo`030000003oool0oooo01h0oooo000W0?ooo`<000001@3oool00`000000oooo0?ooo`0m0?oo
o`X00?ZJd03oool00`000000oooo0?ooo`0S0?ooo`<000001@3oool00`000000oooo0?ooo`0k0?oo
o``00?ZJd03oool00`000000oooo0?ooo`0N0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03h0oooo2`00nY[>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0m0?ooo``00?ZJcP3oool00`000000oooo0?ooo`0N0?ooo`00
9@3oool5000000D0oooo0P0000110?ooo``00?ZJb@3oool3000002<0oooo1@0000050?ooo`800000
@@3oool;003jV/X0oooo0`00000P0?ooo`009@3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo04<0oooo3000nY[80?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`130?ooo`T00?ZJb`3oool00`000000oooo0?ooo`0N0?ooo`00
9P3oool00`000000oooo000000060?ooo`030000003oool0oooo04H0oooo0`00nYX20000o`H00?ZJ
aP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
AP3oool9003jV/P0oooo00<000000?ooo`3oool07P3oool002L0oooo0P0000060?ooo`030000003o
ool0oooo04L0oooo1@00nYX20000o`D00?ZJa03oool00`000000oooo0?ooo`0S0?ooo`8000001P3o
ool00`000000oooo0?ooo`180?ooo`T00?ZJaP3oool00`000000oooo0?ooo`0N0?ooo`00:03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo04P0oooo1`00nYX010000?l00?ZJ003jVP00
nYX300000<40oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04X0oooo2@00nYX300000<40oooo00<000000?ooo`3oool07P3oool002l0oooo00<00000
0?ooo`3oool0B`3oool5003jVP80003o1@0000300?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0B`3oool7003jVPD00000`03oool00`000000oooo0?ooo`0N0?ooo`00;`3oool20000
04l0oooo0`00nYX00`000?l0000000000003000000800?ZJ_@3oool2000002d0oooo0P00001?0?oo
o`@00?ZJ1@00002o0?ooo`800000803oool002l0oooo00<000000?ooo`3oool0C`3oool3003jVPD0
00001@00nYZk0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0D03oool2003jVPD0
00000P00nYZn0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0500oooo
0`00nYX3000000P00?ZJ^@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05<0oooo
0`000006003jV[/0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0EP3o
ool3003jVP80003o1000nYZh0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0E@3o
ool:003jV[P0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0E`3oool5
003jVP030000o`00nYX00?ZJ00800?ZJ]P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo05H0oooo2P00nYZg0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo
05P0oooo3000nYZc0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0F03oool4003j
VP80003o0`00nYZf0?ooo`030000003oool0oooo01h0oooo000_0?ooo`800000G03oool4003jVP03
0000o`00nYX00?ZJ00D00?ZJ[`3oool2000002d0oooo0P00001K0?ooo`X00?ZJ/P3oool200000200
oooo000_0?ooo`030000003oool0oooo05d0oooo1000nYX20000o`H00?ZJ[P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo05/0oooo3000nYZ`0?ooo`030000003oool0oooo01h0oooo
000_0?ooo`030000003oool0oooo05h0oooo1@00nYX30000o`@00?ZJ[@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo05h0oooo0`00nYX20000o`H00?ZJ[P3oool00`000000oooo0?oo
o`0N0?ooo`00;`3oool00`000000oooo0?ooo`1P0?ooo`@00?ZJ10000?l4003jVZ/0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1O0?ooo`D00?ZJ0P000?l4003jVZd0oooo00<00000
0?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0HP3oool5003jVP80003o1P00nYZX0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0H03oool6003jVP80003o1000nYZ[0?oo
o`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo06<0oooo1P00nYX20000o`H0
0?ZJYP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo06<0oooo1000nYX20000o`D0
0?ZJZ@3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool2000006L0oooo1000nYX40000o`@00?ZJ
Y03oool2000002d0oooo0P00001V0?ooo`D00?ZJ00<0003o003jVP00nYX00P00nYZW0?ooo`800000
803oool002l0oooo00<000000?ooo`3oool0J03oool3003jVP@0003o00<0oooo003jVP00nYX00P00
nYZS0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0IP3oool5003jVP80003o1@00
nYZU0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo06T0oooo0`00nYX0
0`3oool0003o0000o`020000o`H00?ZJX03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo06T0oooo0`00nYX20000o`D00?ZJY03oool00`000000oooo0?ooo`0N0?ooo`009P3oool30000
00H0oooo00<000000?ooo`3oool0JP3oool5003jVP@0003o1P00nYZN0?ooo`030000003oool0oooo
0280oooo0`0000060?ooo`030000003oool0oooo06X0oooo1@00nYX20000o`<00?ZJX`3oool00`00
0000oooo0?ooo`0N0?ooo`009@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool0J`3oool6003jVP<0003o0P3oool4003jVYd0oooo00<000000?ooo`3oool08@3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0J`3oool6003jVP030000o`00nYX0
0?ZJ00<00?ZJX03oool00`000000oooo0?ooo`0N0?ooo`009@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0KP3oool4003jVPD0003o00<0oooo003jVP00nYX00P00nYZK
0?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo06h0oooo1000nYX00`000?l00?ZJ003jVP04003jVYh0oooo00<000000?ooo`3oool07P3o
ool002D0oooo100000060?ooo`800000L@3oool3003jVPH0003o1P00nYZF0?ooo`<000008`3oool4
000000H0oooo0P00001a0?ooo`@00?ZJ0P000?l4003jVY/0oooo0`00000P0?ooo`009@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0740oooo0`00nYX20?ooo`@0003o00<0oooo003j
VP00nYX01000nYZF0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1a0?ooo`D00?ZJ0P000?l3003jVY`0oooo00<000000?ooo`3oool07P3oool002H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1b0?ooo`D00?ZJ00<0oooo0000o`00
0?l00P000?l20?ooo`@00?ZJU@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0L`3oool4003jVP80003o0`00nYZK0?ooo`030000003oool0oooo01h0
oooo000W0?ooo`8000001P3oool00`000000oooo0?ooo`1c0?ooo`H00?ZJ1@000?l20?ooo`@00?ZJ
T`3oool00`000000oooo0?ooo`0S0?ooo`8000001P3oool00`000000oooo0?ooo`1e0?ooo`@00?ZJ
00<0003o003jVP00nYX00`00nYZH0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003o
ool0oooo07H0oooo1000nYX00`3oool0003o0000o`020000o`80oooo1@00nYZA0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0MP3oool4003jVP030000o`00nYX00?ZJ00@00?ZJUP3o
ool00`000000oooo0?ooo`0N0?ooo`00;`3oool2000007T0oooo0`00nYX20?ooo`@0003o0P3oool4
003jVXl0oooo0P00000]0?ooo`030000003oool0oooo07P0oooo1000nYX20000o`@00?ZJU@3oool0
0`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`1i0?ooo`<00?ZJ0P3oool40000
o`<0oooo0`00nYZ?0?ooo`030000003oool0oooo02/0oooo0P00001j0?ooo`D00?ZJ0P000?l3003j
VY<0oooo0P00000P0?ooo`00;`3oool00`000000oooo0?ooo`1j0?ooo`@00?ZJ0P3oool40000o`80
oooo0P00nYZ?0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0N`3oool4003jVP80
003o0`00nYZC0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo07/0oooo
1000nYX20?ooo`D0003o0`00nYZ>0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
O@3oool9003jVY40oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0O@3o
ool5003jVP030?ooo`000?l0003o0080003o0P00nYZ>0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0OP3oool9003jVY00oooo00<000000?ooo`3oool07P3oool002l0oooo00<00000
0?ooo`3oool0OP3oool5003jVP80oooo0P000?l3003jVXd0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`210?ooo`<00?ZJ00<0003o003jVP00nYX00P00nYZ>0?ooo`030000003oool0
oooo01h0oooo000_0?ooo`800000PP3oool3003jVP80oooo0P000?l01000nYX0000000000000002:
0?ooo`800000;@3oool2000008<0oooo1P00nYX3000008/0oooo0P00000P0?ooo`00;`3oool00`00
0000oooo0?ooo`220?ooo`@00?ZJ00<0oooo0000o`0000001000002:0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0P`3oool4003jVPD00000R`3oool00`000000oooo0?ooo`0N0?oo
o`00;`3oool00`000000oooo0?ooo`230?ooo`@00?ZJ00<0oooo0000000000000`000002003jVXP0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`260?ooo`03003jVP000000000000<0
0000R`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`250?ooo`<00?ZJ
1@000004003jVXH0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`270?ooo`D00000
0`00nYZ80?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo08H0oooo0`00
nYX300000003003jVP000?l00?ZJ00<00?ZJQ@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo08P0oooo0`000006003jVXH0oooo00<000000?ooo`3oool07P3oool002l0oooo00<00000
0?ooo`3oool0R`3oool3003jVP80003o1@00nYZ20?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0RP3oool8003jVXD0oooo00<000000?ooo`3oool07P3oool002l0oooo0P00002=0?oo
o`<00?ZJ0P000?l5003jVX00oooo0P00000]0?ooo`800000S03oool4003jVP030000o`00nYX00?ZJ
00800?ZJPP3oool200000200oooo000_0?ooo`030000003oool0oooo08d0oooo1000nYX30000o`<0
0?ZJP03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08d0oooo2000nYZ20?ooo`03
0000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo08h0oooo1000nYX30000o`D00?ZJ
O@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08h0oooo1000nYX010000?l00?ZJ
003jVP00nYZ10?ooo`030000003oool0oooo01h0oooo000V0?ooo`<000001P3oool00`000000oooo
0?ooo`2@0?ooo`@00?ZJ0P000?l6003jVW/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`2@0?ooo`L00?ZJP03oool00`000000oooo0?ooo`0N0?ooo`009@3oool01@000000oooo0?oo
o`3oool0000000D0oooo00<000000?ooo`3oool0T@3oool4003jVP@0003o1000nYYj0?ooo`030000
003oool0oooo0280oooo0`0000060?ooo`030000003oool0oooo0940oooo2000nYYn0?ooo`030000
003oool0oooo01h0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`2C0?ooo`<00?ZJ10000?l00`3oool00?ZJ003jVP02003jVWP0oooo00<000000?ooo`3oool0
8@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0T`3oool7003jVWd0
oooo00<000000?ooo`3oool07P3oool002H0oooo0`0000060?ooo`800000U@3oool3003jVP030?oo
o`000?l0003o0080003o1@00nYYd0?ooo`<000008`3oool01@000000oooo0?ooo`3oool0000000D0
oooo0P00002E0?ooo`<00?ZJ00<0003o003jVP00nYX00P00nYYi0?ooo`<00000803oool002D0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo09D0oooo1000nYX40000o`03
0?ooo`00nYX00?ZJ00800?ZJM@3oool00`000000oooo0?ooo`0R0?ooo`<000001P3oool00`000000
oooo0?ooo`2E0?ooo`P00?ZJNP3oool00`000000oooo0?ooo`0N0?ooo`009@3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0UP3oool4003jVP040?ooo`000?l0003o0000
o`80oooo0`00nYYd0?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo09H0oooo1000nYX010000?l00?ZJ003jVP00nYYi0?ooo`030000003o
ool0oooo01h0oooo000V0?ooo`<000001P3oool00`000000oooo0?ooo`2H0?ooo`@00?ZJ0`000?l2
0?ooo`800?ZJM03oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`2H0?ooo`L00?ZJN03oool00`000000oooo0?ooo`0N0?ooo`00;`3oool0
0`000000oooo0?ooo`2I0?ooo`@00?ZJ10000?l3003jVW<0oooo00<000000?ooo`3oool08P3oool3
000000H0oooo00<000000?ooo`3oool0V@3oool8003jVWH0oooo00<000000?ooo`3oool07P3oool0
02l0oooo00<000000?ooo`3oool0V`3oool3003jVP@0003o0P00nYYc0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0V`3oool7003jVWD0oooo00<000000?ooo`3oool07P3oool002l0
oooo0P00002M0?ooo`<00?ZJ0P3oool010000?l00?ZJ003jVP00nYYa0?ooo`800000;@3oool20000
09d0oooo0`00nYX010000?l00?ZJ003jVP00nYYc0?ooo`800000803oool002l0oooo00<000000?oo
o`3oool0W@3oool4003jVP80003o0P00nYYb0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0W@3oool7003jVW<0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3o
ool0WP3oool4003jVP040000o`000000000000000740oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`2N0?ooo`D00?ZJ0`00001a0?ooo`030000003oool0oooo01h0oooo000_0?ooo`03
0000003oool0oooo0:00oooo0P00nYX500000700oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`2P0?ooo`800?ZJ1@00001`0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000
003oool0oooo0:40oooo00<00?ZJ0000000000000`000003003jVVd0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`2Q0?ooo`03003jVP000000000000<000000P00nYY^0?ooo`030000
003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0:80oooo1@000005003jVV/0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`2R0?ooo`D000000`00nYY]0?ooo`030000003o
ool0oooo01h0oooo000_0?ooo`800000Y03oool300000003003jVP000?l0003o00@00?ZJJ@3oool2
000002d0oooo0P00002T0?ooo`<0000000<00?ZJ0000o`00nYX01000nYYY0?ooo`800000803oool0
02l0oooo00<000000?ooo`3oool0Y@3oool4003jVP80003o1000nYYX0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0Y@3oool9003jVVT0oooo00<000000?ooo`3oool07P3oool002l0
oooo00<000000?ooo`3oool0YP3oool4003jVP80003o1@00nYYV0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0YP3oool4003jVP80003o0`00nYYX0?ooo`030000003oool0oooo01h0
oooo000_0?ooo`030000003oool0oooo0:P0oooo1000nYX20000o`@00?ZJI@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0:P0oooo1000nYX00`000?l00?ZJ003jVP02003jVVH0oooo
00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0Z@3oool4003jVP80003o00<0
oooo003jVP00nYX00P00nYYS0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0Z@3o
ool4003jVP030000o`00nYX00?ZJ00800?ZJI@3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool2
00000:`0oooo0`00nYX30000o`@00?ZJH@3oool2000002d0oooo00<000000?ooo`3oool0Z`3oool3
003jVP80003o1000nYYS0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo
0:`0oooo0`00nYX30000o`030?ooo`00nYX00?ZJ00<00?ZJG`3oool00`000000oooo0?ooo`0[0?oo
o`800000[@3oool3003jVP80003o1000nYYQ0?ooo`800000803oool002l0oooo00<000000?ooo`3o
ool0[@3oool3003jVP@0003o1@00nYYN0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0[@3oool4003jVP80003o1000nYYP0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000
003oool0oooo0:h0oooo0`00nYX40000o`80oooo0`00nYYM0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0[P3oool4003jVP80003o1000nYYO0?ooo`030000003oool0oooo01h0oooo
000P0?ooo`<00000103oool2000000H0oooo00<000000?ooo`3oool0[`3oool3003jVP030?ooo`00
0?l0003o0080003o00<0oooo003jVP00nYX00P00nYYK0?ooo`030000003oool0oooo01`0oooo0`00
00040?ooo`8000001P3oool00`000000oooo0?ooo`2`0?ooo`@00?ZJ0P000?l3003jVUh0oooo00<0
00000?ooo`3oool07P3oool00240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0;00oooo1000nYX40000o`030?ooo`00nYX00?ZJ00800?ZJFP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`2a0?ooo`@00?ZJ0P000?l3003jVUd0oooo00<000000?ooo`3oool0
7P3oool00240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`800000
/P3oool4003jVP040?ooo`000?l0003o0000o`80oooo0`00nYYG0?ooo`<000007`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo0P00002d0?ooo`@00?ZJ00<0003o003j
VP00nYX00P00nYYI0?ooo`<00000803oool00240oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0;<0oooo1000nYX30000o`80oooo0P00nYYI0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0;@0oooo1000nYX00`000?l00?ZJ003jVP02003jVUX0oooo00<00000
0?ooo`3oool07P3oool00240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0;@0oooo1000nYX40000o`<00?ZJF03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`2f0?ooo`<00?ZJ0P000?l3003jVUT0oooo00<000000?ooo`3oool07P3oool00200oooo0P000004
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0]P3oool3003jVP@0003o0`00
nYYG0?ooo`030000003oool0oooo01`0oooo0P0000040?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0]`3oool3003jVP80003o0`00nYYH0?ooo`030000003oool0oooo01h0oooo
000Q0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo0;L0oooo0`00
nYX0103oool0003o0000o`000?l3000005H0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`2h0?ooo`H00?ZJ0`00001F0?ooo`030000
003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0;P0oooo0`00nYX00`3oool0003o0000
0004000005D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2i0?ooo`@00?ZJ1@00
001E0?ooo`030000003oool0oooo01h0oooo000_0?ooo`800000^P3oool3003jVP030?ooo`000000
000000<000000P00nYYB0?ooo`800000;@3oool200000;d0oooo00<00?ZJ0000000000000`00001D
0?ooo`800000803oool002l0oooo00<000000?ooo`3oool0^P3oool3003jVPD000000`00nYYB0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0_@3oool5000000<00?ZJDP3oool00`00
0000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`2k0?ooo`<00?ZJ0`0000000`00nYX0
003o003jVP04003jVTl0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2n0?ooo`<0
00001P00nYY@0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0;`0oooo
0`00nYX01@3oool00?ZJ003jVP00nYX0003o00D00?ZJCP3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0;l0oooo0`00nYX20000o`@00?ZJC`3oool00`000000oooo0?ooo`0N0?ooo`00
;`3oool00`000000oooo0?ooo`310?ooo`<00?ZJ0`000?l3003jVTd0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`300?ooo`@00?ZJ0P000?l3003jVTh0oooo00<000000?ooo`3oool0
7P3oool002l0oooo00<000000?ooo`3oool0`P3oool3003jVP<0003o1000nYY;0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0`@3oool4003jVP80003o0`00nYY=0?ooo`030000003o
ool0oooo01h0oooo000_0?ooo`800000a03oool4003jVP80003o1000nYY90?ooo`800000;@3oool2
00000<@0oooo1000nYX00`000?l00?ZJ003jVP02003jVTX0oooo0P00000P0?ooo`00;`3oool00`00
0000oooo0?ooo`340?ooo`@00?ZJ0P000?l00`3oool00?ZJ003jVP03003jVTL0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`340?ooo`@00?ZJ00<0003o003jVP00nYX00P00nYY:0?oo
o`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0<H0oooo0`00nYX30000o`D0
0?ZJAP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0<H0oooo0`00nYX20000o`@0
0?ZJB03oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`370?ooo`800?ZJ
10000?l20?ooo`<00?ZJA@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0<L0oooo
0P00nYX30000o`@00?ZJA`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?oo
o`370?ooo`<00?ZJ00<0oooo0000o`000?l00P000?l00`3oool00?ZJ003jVP02003jVT<0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`370?ooo`<00?ZJ00@0oooo0000o`000?l0003o
0`00nYY60?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0<P0oooo1000
nYX40000o`030?ooo`00nYX00?ZJ00800?ZJ@P3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0<P0oooo1000nYX30000o`<00?ZJA@3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool2
00000<X0oooo1000nYX0103oool0003o0000o`000?l20?ooo`D00?ZJ?P3oool2000002d0oooo0P00
003:0?ooo`@00?ZJ00<0oooo0000o`000?l00`00nYY30?ooo`800000803oool002l0oooo00<00000
0?ooo`3oool0b`3oool3003jVP040?ooo`000?l0003o0000o`80oooo1@00nYXn0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0b`3oool4003jVP80003o0`00nYY30?ooo`030000003o
ool0oooo01h0oooo000_0?ooo`030000003oool0oooo0<`0oooo0`00nYX00`3oool0003o0000o`02
0000o`<0oooo0P00nYXn0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0c03oool4
003jVP80003o0`00nYY20?ooo`030000003oool0oooo01h0oooo000P0?ooo`<000000P3oool50000
00D0oooo00<000000?ooo`3oool0c@3oool3003jVP030?ooo`000?l0003o0080003o0P3oool3003j
VSd0oooo00<000000?ooo`3oool0703oool300000080oooo1@0000050?ooo`030000003oool0oooo
0<h0oooo0`00nYX20000o`@00?ZJ@03oool00`000000oooo0?ooo`0N0?ooo`008@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0cP3oool3003j
VP80oooo10000?l00`3oool00?ZJ003jVP0m0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0<l0oooo0`00nYX2
0000o`@00?ZJ?`3oool00`000000oooo0?ooo`0N0?ooo`008@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0c`3oool3003jVP80oooo10000?l3003j
VS`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0d03oool4003jVP80003o0`00nYXn0?ooo`030000003oool0oooo
01h0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool200000=40
oooo1000nYX20?ooo`<0003o0P00nYXj0?ooo`<000007`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo0P00003B0?ooo`@00?ZJ0P000?l2003jVS`0oooo0`00000P0?ooo`00
8@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`3A0?ooo`@00?ZJ0P3oool20000o`<00000>`3oool00`000000oooo0?ooo`0M0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0=<0oooo1P00nYX3000003/0oooo00<000000?ooo`3oool07P3oool00200oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3C0?ooo`<00?ZJ0P3oool50000
03X0oooo00<000000?ooo`3oool0703oool2000000<0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo0=@0oooo1000nYX5000003X0oooo00<000000?ooo`3oool07P3oool0
0240oooo00<000000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0e03oool3003j
VP030?ooo`000000000000<000000`00nYXg0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0e`3oool00`00nYX00000000000030000
03X0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0e@3oool3003jVPD0
00001@00nYXe0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0f03oool500000080
0?ZJ>03oool00`000000oooo0?ooo`0N0?ooo`00;`3oool200000=L0oooo0`00nYX3000000<0003o
1000nYXc0?ooo`800000;@3oool00`000000oooo0?ooo`3I0?ooo`<000001000nYXg0?ooo`030000
003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0=L0oooo1P00nYX30000o`040?ooo`00
nYX00?ZJ003jVS<0oooo00<000000?ooo`3oool0:`3oool200000=/0oooo0`00nYX00`000?l00?ZJ
003jVP02003jVS@0oooo0P00000P0?ooo`00;`3oool00`000000oooo0?ooo`3K0?ooo`@00?ZJ0`00
0?l3003jVS80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3K0?ooo`P00?ZJ=03o
ool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`3L0?ooo`@00?ZJ0`000?l3
003jVS40oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3L0?ooo`@00?ZJ00@0003o
003jVP00nYX00?ZJ<`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`3N
0?ooo`<00?ZJ0`000?l2003jVS40oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3N
0?ooo`<00?ZJ00<0003o003jVP00nYX0<`3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`00
0000oooo0?ooo`3O0?ooo`<00?ZJ0P000?l3003jVS00oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`3O0?ooo`H00?ZJ<P3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool200000>40
oooo0`00nYX20000o`800?ZJ;`3oool2000002d0oooo0P00003Q0?ooo`H00?ZJ<03oool200000200
oooo000_0?ooo`030000003oool0oooo0>40oooo0`00nYX010000?l00?ZJ003jVP00nYX_0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0h@3oool6003jVS00oooo00<000000?ooo`3o
ool07P3oool002l0oooo00<000000?ooo`3oool0hP3oool3003jVP030000o`00nYX0000000800000
;@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0>80oooo1@00nYX3000002d0oooo
00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0h`3oool3003jVPD00000;03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0><0oooo0`00nYX5000002`0oooo00<0
00000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0i03oool2003jVPD000000P00nYXZ
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0i03oool2003jVPD0000000<00?ZJ
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`3V0?oo
o`D000001000nYXX0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0iP3oool50000
00800?ZJ:P3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool200000>P0oooo0`0000020000o`@0
0?ZJ9P3oool2000002d0oooo0P00003X0?ooo`<000001@00nYXW0?ooo`800000803oool002l0oooo
00<000000?ooo`3oool0j03oool3003jVP80003o00<0oooo003jVP00nYX00P00nYXU0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0j@3oool7003jVRL0oooo00<000000?ooo`3oool0
7P3oool002l0oooo00<000000?ooo`3oool0j@3oool3003jVP<0003o1000nYXT0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0jP3oool2003jVP80003o1000nYXU0?ooo`030000003o
ool0oooo01h0oooo000P0?ooo`<00000103oool3000000D0oooo00<000000?ooo`3oool0jP3oool3
003jVP<0003o00@0oooo003jVP00nYX00?ZJ8`3oool00`000000oooo0?ooo`0L0?ooo`<00000103o
ool3000000D0oooo00<000000?ooo`3oool0jP3oool3003jVP80003o1000nYXT0?ooo`030000003o
ool0oooo01h0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3[0?ooo`<00?ZJ10000?l2003jVR<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0j`3oool4
003jVP80003o0`00nYXS0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`040000003oool0oooo
0?ooo`D000001@3oool00`000000oooo0?ooo`3/0?ooo`<00?ZJ0`000?l3003jVR80oooo00<00000
0?ooo`3oool07@3oool010000000oooo0?ooo`3oool5000000D0oooo00<000000?ooo`3oool0k03o
ool4003jVP80003o0P00nYXS0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`800000kP3oool3003jVP040?ooo`00
0?l0003o003jVP<000007P3oool3000001l0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00@0oooo0P00003_0?ooo`H00?ZJ0`00000N0?ooo`<00000803oool00240oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003oool0oooo0>h0oooo
0`00nYX00`3oool0003o00000004000001l0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0k`3oool4003jVPD00000
7`3oool00`000000oooo0?ooo`0N0?ooo`00803oool2000000D0oooo0P0000060?ooo`030000003o
ool0oooo0>l0oooo0`00nYX00`3oool0000000000003000000<00?ZJ703oool00`000000oooo0?oo
o`0L0?ooo`8000001@3oool2000000H0oooo00<000000?ooo`3oool0l@3oool2003jVPD000000P00
nYXM0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3`0?ooo`<00?ZJ1@000004003jVQ/0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0lP3oool00`00nYX0000000000003000000<00?ZJ703oool00`000000oooo0?ooo`0N
0?ooo`00;`3oool00`000000oooo0?ooo`3a0?ooo`<00?ZJ0`0000030000o`<00?ZJ6P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0?@0oooo0`0000020000o`<00?ZJ6`3oool00`00
0000oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`3b0?ooo`800?ZJ00@0oooo003jVP00
nYX00?ZJ0`000?l5003jVQL0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3e0?oo
o`<00?ZJ0P000?l3003jVQX0oooo00<000000?ooo`3oool07P3oool002l0oooo0P00003g0?ooo`@0
0?ZJ0P000?l5003jVQD0oooo0P00000]0?ooo`800000m`3oool4003jVP040000o`00nYX00?ZJ003j
VQP0oooo0P00000P0?ooo`00;`3oool00`000000oooo0?ooo`3g0?ooo`@00?ZJ0P000?l20?ooo`80
0?ZJ5P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?L0oooo1000nYX010000?l0
0?ZJ003jVP00nYXH0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0?T0
oooo0`00nYX30000o`<00?ZJ5@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?T0
oooo0`00nYX010000?l00?ZJ003jVP00nYXG0?ooo`030000003oool0oooo01h0oooo000_0?ooo`03
0000003oool0oooo0?X0oooo0P00nYX40000o`800?ZJ5@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0?X0oooo0`00nYX010000?l00?ZJ003jVP00nYXF0?ooo`030000003oool0oooo
01h0oooo000_0?ooo`030000003oool0oooo0?X0oooo0`00nYX00`3oool0003o0000o`03003jVQ@0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3k0?ooo`L00?ZJ5@3oool00`000000
oooo0?ooo`0N0?ooo`00;`3oool00`000000oooo0?ooo`3k0?ooo`<00?ZJ00@0oooo0000o`000?l0
0?ZJ0`00000B0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o03oool6003jVP<0
00004P3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool200000?d0oooo0`00nYX00`3oool0003o
0000000400000100oooo0P00000]0?ooo`800000o`3oool3003jVPD00000403oool200000200oooo
000_0?ooo`030000003oool0oooo0?d0oooo0`00nYX00`3oool0000000000003000000800?ZJ3`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo0P00nYX500000003003jVP3o
ool0oooo00h0oooo00<000000?ooo`3oool07P3oool002l0oooo00<000000?ooo`3oool0oP3oool3
003jVPD000001@00nYX<0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`D0000000<00?ZJ0?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool00`00
0000oooo0?ooo`3o0?ooo`<00?ZJ0`0000020000o`H00?ZJ2P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0?l0oooo0`3oool3000000<00?ZJ3`3oool00`000000oooo0?ooo`0N0?oo
o`00;`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0`00nYX20000o`80oooo1000nYX90?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool40?ooo`L00?ZJ3@3oool00`000000
oooo0?ooo`0N0?ooo`00;`3oool200000?l0oooo1P3oool3003jVP<0003o0P3oool3003jVPL0oooo
0P00000]0?ooo`800000o`3oool60?ooo`L00?ZJ2`3oool200000200oooo000_0?ooo`030000003o
ool0oooo0?l0oooo1P3oool3003jVP<0003o0P3oool2003jVPP0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`3o0?ooo`H0oooo0P00nYX20000o`<00?ZJ2`3oool00`000000oooo0?oo
o`0N0?ooo`00;`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0`00nYX40000o`800?ZJ203oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo1P3oool3003jVP80003o0`00nYX:
0?ooo`030000003oool0oooo01h0oooo000_0?ooo`030000003oool0oooo0?l0oooo203oool3003j
VP<0003o0`00nYX70?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool70?oo
o`@00?ZJ00@0003o003jVP00nYX00?ZJ2@3oool00`000000oooo0?ooo`0N0?ooo`00803oool30000
00<0oooo0`0000060?ooo`030000003oool0oooo0?l0oooo2@3oool3003jVP030?ooo`000?l0003o
00800?ZJ1`3oool00`000000oooo0?ooo`0L0?ooo`<000000`3oool3000000H0oooo00<000000?oo
o`3oool0o`3oool80?ooo`@00?ZJ00@0003o003jVP00nYX00?ZJ203oool00`000000oooo0?ooo`0N
0?ooo`008@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo1000nYX00`000?l00?ZJ003jVP070?ooo`030000003oool0
oooo01d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`H00?ZJ203oool00`000000oooo0?ooo`0N0?ooo`008@3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool200000?l0oooo303o
ool7003jVP@0oooo0`00000O0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`800000o`3oool<0?ooo`H00?ZJ1@3oool300000200oooo000Q0?ooo`040000003o
ool0oooo0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0`00nYX3000000D0oooo
00<000000?ooo`3oool07@3oool010000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`<00?ZJ0`0000050?ooo`030000003oool0oooo01h0oooo000Q0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<00?ZJ00000000
00000`0000040?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo0?l0oooo3P3oool00`00nYX0000000000003000000@0oooo00<000000?oo
o`3oool07P3oool00200oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`D00000103oool00`000000oooo0?ooo`0L0?ooo`800000103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo3`3oool5000000@0oooo00<000000?ooo`3o
ool07P3oool00240oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0
o`3oool?0?ooo`D00000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo
0P0000060?ooo`030000003oool0oooo0?l0oooo3`3oool5000000@0oooo00<000000?ooo`3oool0
7P3oool002l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0340oooo0`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo0`0000050?ooo`030000003o
ool0oooo01h0oooo000_0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool2000002d0oooo0P0000040?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`800000803oool0
02l0ooooo`00000L000002d0ooooo`00000L00000200oooo003o0?ooool0oooo]03oool00?l0oooo
o`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?oo
o`00Z@3oool00`0c<c<0oooo0?ooo`0a0?ooo`<0<c<co`3ooolB0?ooo`0303<c<`3oool0oooo0340
oooo0`0c<c>:0?ooo`00ZP3oool00`0c<c<0oooo0?ooo`0a0?ooo`0303<c<`3oool0oooo0?l0oooo
4P3oool00`0c<c<0oooo0?ooo`0a0?ooo`0303<c<`3oool0oooo08T0oooo001g0?ooo`D0<c<c00<0
oooo03<c<`0c<c<00`0c<c<00`3oool0<c<c03<c<`0303<c<`<0oooo0P0c<c<30?ooo`<0<c<c0P3o
ool303<c<`@0oooo0`0c<c<30?ooo`@0<c<c103oool00`0c<c<0oooo0?ooo`060?ooo`D0<c<c00D0
oooo03<c<`0c<c<0<c<c0?ooo`0203<c<`030?ooo`0c<c<0<c<c0080<c<c203oool303<c<`<0oooo
0`0c<c<20?ooo`0503<c<`3oool0<c<c0?ooo`0c<c<00P3oool303<c<`<0oooo0`0c<c<20?ooo`<0
<c<c00@0oooo03<c<`0c<c<0oooo0`0c<c<20?ooo`<0<c<c00<0oooo03<c<`0c<c<00P3oool203<c
<l00oooo100c<c<20?ooo`0503<c<`3oool0<c<c0?ooo`0c<c<00P3oool303<c<`<0oooo0`0c<c<4
0?ooo`80<c<c0P3oool603<c<`040?ooo`0c<c<0<c<c03<c<`<0oooo100c<c<40?ooo`0303<c<`3o
ool0oooo00H0oooo1@0c<c<01@3oool0<c<c03<c<`0c<c<0oooo0080<c<c00<0oooo03<c<`0c<c<0
0P0c<c<80?ooo`<0<c<c0`3oool303<c<`80oooo00D0<c<c0?ooo`0c<c<0oooo03<c<`020?ooo`<0
<c<c0`3oool303<c<`80oooo0`0c<c<0103oool0<c<c03<c<`3oool303<c<`80oooo0`0c<c<00`3o
ool0<c<c03<c<`020?ooo`80<c<cJ`3oool007T0oooo00<0<c<c0?ooo`3oool00`3oool00`0c<c<0
oooo0?ooo`030?ooo`0303<c<`3oool0oooo0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<6
0?ooo`0303<c<`3oool0oooo0080oooo00<0<c<c0?ooo`3oool00`3oool0100c<c<0oooo0?ooo`0c
<c<?0?ooo`0403<c<`3oool0oooo03<c<`80oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<20?oo
o`0303<c<`3oool0oooo00H0oooo00L0<c<c0?ooo`3oool0oooo03<c<`3oool0<c<c00<0oooo00L0
<c<c0?ooo`0c<c<0oooo03<c<`3oool0<c<c0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<3
0?ooo`0403<c<`3oool0oooo03<c<`80oooo00<0<c<c0?ooo`0c<c<01P3oool0100c<c<0oooo0?oo
o`0c<c<20?ooo`0403<c<`3oool0oooo03<c<l<0oooo00T0<c<c0?ooo`0c<c<0oooo03<c<`3oool0
<c<c0?ooo`0c<c<00`3oool00`0c<c<0oooo03<c<`030?ooo`0403<c<`3oool0oooo03<c<`80oooo
00@0<c<c0?ooo`3oool0<c<c0P3oool00`0c<c<0oooo03<c<`050?ooo`0403<c<`3oool0oooo03<c
<`l0oooo00@0<c<c0?ooo`3oool0<c<c0P3oool01P0c<c<0oooo0?ooo`0c<c<0oooo03<c<`80oooo
00<0<c<c0?ooo`3oool01P3oool01`0c<c<0oooo0?ooo`3oool0<c<c0?ooo`0c<c<00`3oool01`0c
<c<0oooo03<c<`3oool0<c<c0?ooo`0c<c<00P3oool01P0c<c<0oooo0?ooo`0c<c<0oooo03<c<`<0
oooo00@0<c<c0?ooo`3oool0<c<c0P3oool00`0c<c<0oooo03<c<`060?ooo`0403<c<`3oool0oooo
03<c<`80oooo00@0<c<c0?ooo`3oool0<c<cJP3oool007T0oooo00<0<c<c0?ooo`3oool00`3oool0
0`0c<c<0oooo0?ooo`030?ooo`0303<c<`3oool0oooo0080oooo00<0<c<c0?ooo`3oool00P3oool5
03<c<`80oooo00<0<c<c0?ooo`3oool00P3oool503<c<`050?ooo`0c<c<0oooo0?ooo`0c<c<0403o
ool00`0c<c<0oooo0?ooo`020?ooo`0603<c<`3oool0oooo03<c<`3oool0<c<c0P3oool00`0c<c<0
oooo0?ooo`060?ooo`0303<c<`3oool0oooo00<0oooo00/0<c<c0?ooo`3oool0oooo03<c<`3oool0
<c<c0?ooo`0c<c<0oooo03<c<`020?ooo`0603<c<`3oool0oooo03<c<`3oool0<c<c0`3oool0100c
<c<0oooo0?ooo`0c<c<20?ooo`0303<c<`3oool0<c<c00@0<c<c0P3oool0100c<c<0oooo0?ooo`0c
<c<20?ooo`0303<c<`3oool0oooo0<40oooo0`0c<c<20?ooo`0703<c<`3oool0<c<c0?ooo`0c<c<0
oooo03<c<`030?ooo`0303<c<`3oool0<c<c00<0oooo00@0<c<c0?ooo`3oool0<c<c1@3oool01@0c
<c<0oooo0?ooo`0c<c<0oooo00D0<c<c00D0oooo03<c<`3oool0oooo03<c<`0@0?ooo`0303<c<`3o
ool0oooo0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<20?ooo`0303<c<`3oool0oooo00H0
oooo00<0<c<c0?ooo`3oool00`3oool02`0c<c<0oooo0?ooo`3oool0<c<c0?ooo`0c<c<0oooo03<c
<`3oool0<c<c0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<30?ooo`0403<c<`3oool0oooo
03<c<`80oooo00<0<c<c0?ooo`0c<c<0100c<c<20?ooo`0403<c<`3oool0oooo03<c<`80oooo00<0
<c<c0?ooo`3oool0J`3oool007T0oooo00<0<c<c0?ooo`3oool00`3oool00`0c<c<0oooo0?ooo`03
0?ooo`0303<c<`3oool0oooo0080oooo00<0<c<c0?ooo`3oool00P3oool01@0c<c<0oooo0?ooo`3o
ool0<c<c0080oooo0P0c<c<30?ooo`0703<c<`3oool0oooo0?ooo`0c<c<0oooo03<c<`020?ooo`03
03<c<`3oool0oooo00l0oooo00D0<c<c0?ooo`3oool0oooo03<c<`020?ooo`0303<c<`3oool0<c<c
0080oooo00<0<c<c0?ooo`3oool01P3oool01`0c<c<0oooo0?ooo`3oool0<c<c0?ooo`0c<c<00`3o
ool01`0c<c<0oooo03<c<`3oool0<c<c0?ooo`0c<c<00P3oool01P0c<c<0oooo0?ooo`0c<c<0oooo
03<c<`<0oooo00@0<c<c0?ooo`3oool0<c<c0P3oool00`0c<c<0oooo03<c<`030?ooo`0403<c<`3o
ool0oooo03<c<`80oooo00@0<c<c0?ooo`3oool0<c<c`P3oool00`0c<c<0oooo0?ooo`030?ooo`07
03<c<`3oool0<c<c0?ooo`0c<c<0oooo03<c<`030?ooo`0303<c<`3oool0<c<c00<0oooo00@0<c<c
0?ooo`3oool0<c<c1@3oool01P0c<c<0oooo0?ooo`0c<c<0oooo03<c<`<0oooo00<0<c<c0?ooo`0c
<c<00P3oool00`0c<c<0oooo0?ooo`0?0?ooo`0503<c<`3oool0oooo0?ooo`0c<c<00P3oool00`0c
<c<0oooo03<c<`020?ooo`0303<c<`3oool0oooo00H0oooo00L0<c<c0?ooo`3oool0oooo03<c<`3o
ool0<c<c00<0oooo00L0<c<c0?ooo`0c<c<0oooo03<c<`3oool0<c<c0080oooo00H0<c<c0?ooo`3o
ool0<c<c0?ooo`0c<c<30?ooo`0403<c<`3oool0oooo03<c<`80oooo00<0<c<c0?ooo`0c<c<00`3o
ool0100c<c<0oooo0?ooo`0c<c<20?ooo`0403<c<`3oool0oooo03<c<fd0oooo001h0?ooo`@0<c<c
00@0oooo03<c<`0c<c<0<c<c1@3oool0100c<c<0oooo0?ooo`3oool403<c<`<0oooo0`0c<c<20?oo
o`80<c<c00<0oooo03<c<`0c<c<00P3oool303<c<`<0oooo0`0c<c<>0?ooo`0603<c<`3oool0oooo
0?ooo`0c<c<0oooo100c<c<30?ooo`<0<c<c2@3oool303<c<`<0oooo0`0c<c<20?ooo`80<c<c00@0
oooo03<c<`3oool0oooo100c<c<30?ooo`<0<c<c0P3oool403<c<`<0oooo0`0c<c<20?ooo`@0<c<c
0P3oool403<c<l40oooo100c<c<01@3oool0<c<c03<c<`3oool0<c<c00<0oooo0`0c<c<30?ooo`<0
<c<c0P3oool403<c<`<0oooo0`0c<c<30?ooo`<0<c<c0`3oool303<c<`h0oooo00H0<c<c0?ooo`3o
ool0oooo03<c<`3oool403<c<`<0oooo0`0c<c<90?ooo`<0<c<c0`3oool303<c<`80oooo0P0c<c<0
103oool0<c<c0?ooo`3oool403<c<`<0oooo0`0c<c<20?ooo`@0<c<c0`3oool303<c<`80oooo100c
<c<20?ooo`@0<c<cJ`3oool007T0oooo00<0<c<c0?ooo`3oool02@3oool00`0c<c<0oooo0?ooo`02
0?ooo`0303<c<`3oool0oooo01L0oooo00<0<c<c0?ooo`3oool0303oool01@0c<c<0oooo0?ooo`3o
ool0<c<c00X0oooo00<0<c<c0?ooo`3oool0=`3oool00`0c<c<0oooo0?ooo`3I0?ooo`0303<c<`3o
ool0oooo00<0oooo00<0<c<c0?ooo`3oool02`3oool00`0c<c<0oooo0?ooo`0<0?ooo`0503<c<`3o
ool0oooo0?ooo`0c<c<02P3oool00`0c<c<0oooo0?ooo`0g0?ooo`0303<c<`3oool0oooo06/0oooo
001j0?ooo`80<c<c0`3oool0100c<c<0oooo0?ooo`3oool303<c<`@0oooo00<0<c<c0?ooo`3oool0
5P3oool203<c<`l0oooo0`0c<c<:0?ooo`80<c<c>@3oool00`0c<c<0oooo0?ooo`3I0?ooo`0303<c
<`3oool0oooo0080oooo0P0c<c<<0?ooo`80<c<c3`3oool303<c<`X0oooo0P0c<c<i0?ooo`0303<c
<`3oool0oooo06/0oooo003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?ooo`00=`3oool20000
0380oooo1@00000c0?ooo`<00000<P3oool3000003<0oooo0`00000_0?ooo`<00000103oool20000
03H0oooo0P00000b0?ooo`D00000<`3oool300000380oooo0`00000c0?ooo`<00000;`3oool30000
00@0oooo0P00000Q0?ooo`00=P3oool010000000oooo0?ooo`00000b0?ooo`040000003oool0oooo
000003@0oooo00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool000000340oooo00D0
00000?ooo`3oool0oooo0000000_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000=03oool010000000oooo0?ooo`00000b0?ooo`040000003oool0oooo000003@0oooo00<00000
0?ooo`3oool0<03oool01@000000oooo0?ooo`3oool000000340oooo00D000000?ooo`3oool0oooo
0000000_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000803oool003H0oooo
00@000000?ooo`3oool00000<`3oool00`000000oooo0?ooo`0a0?ooo`D00000<@3oool01@000000
oooo0?ooo`3oool000000340oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000c0?ooo`030000
003oool0oooo0340oooo1@00000a0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@000000
oooo0?ooo`3oool0000002l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000P
0?ooo`00=P3oool010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo0300oooo00@00000
0?ooo`3oool00000<P3oool4000003<0oooo0`00000`0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000=03oool010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo0300
oooo00@000000?ooo`3oool00000<P3oool4000003<0oooo0`00000`0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000803oool003H0oooo00@000000?ooo`3oool00000<@3oool0
1@000000oooo0?ooo`3oool000000380oooo00<000000?ooo`000000<P3oool00`000000oooo0?oo
o`0c0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000003@0oooo00@000000?ooo`3oool00000<@3oool01@000000oooo0?ooo`3oool0
00000380oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0c0?ooo`050000003oool0
oooo0?ooo`000000;`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000200oooo
000f0?ooo`040000003oool0oooo00000340oooo00D000000?ooo`3oool0oooo0000000c0?ooo`80
0000<`3oool00`000000oooo0?ooo`0b0?ooo`050000003oool0oooo0?ooo`000000;P3oool20000
00@0oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000a0?ooo`050000003o
ool0oooo0?ooo`000000<`3oool2000003<0oooo00<000000?ooo`3oool0<P3oool01@000000oooo
0?ooo`3oool0000002h0oooo0P0000040?ooo`040000003oool0oooo00000200oooo000g0?ooo`80
0000<`3oool3000003D0oooo00<000000?ooo`3oool0<P3oool2000003<0oooo0`00000`0?ooo`03
0000003oool0oooo00<0oooo0P00000f0?ooo`800000<`3oool3000003D0oooo00<000000?ooo`3o
ool0<P3oool2000003<0oooo0`00000`0?ooo`030000003oool0oooo00<0oooo0P00000Q0?ooo`00
o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oo
ok@0oooo000b0?ooool000007000000]0?ooool000007000000M0?ooo`00<P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02/0oooo0P0000040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`8000007@3oool00380oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo01/0oooo000b0?oo
o`8000000`3oool4003jV_l0oooo4@3oool2000002d0oooo00<000000?ooo`3oool00P3oool4003j
V_l0oooo4P3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`T0
0?ZJo`3oool=0?ooo`030000003oool0oooo0280oooo0`0000060?ooo`030000003oool0oooo0080
oooo0`000006003jV_l0oooo3@3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo
0?ooo`050?ooo``00?ZJo`3oool70?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`3oool5000000/00?ZJo`3oool70?ooo`030000003oool0oooo01/0
oooo000b0?ooo`030000003oool0oooo00X0oooo3000nY[o0?ooo`80oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`D00000103oool9003jV_l0
oooo1@3oool00`000000oooo0?ooo`0K0?ooo`00:@3oool3000000H0oooo00<000000?ooo`3oool0
0P3oool3000000/0oooo3000nY[k0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
1@3oool200000080oooo1@0000050000o`D0oooo2@00nY[l0?ooo`<000007@3oool002X0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`3oool5000000l0oooo2000nY[j0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`<00000
30000?l00`3oool00?ZJ003jVP0:003jV_T0oooo00<000000?ooo`3oool06`3oool002X0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`3oool5000000<0003o4P3oool3003jV_T0oooo
00<000000?ooo`3oool08P3oool2000000L0oooo00<000000?ooo`3oool00P3oool7003jVP030?oo
o`000?l0003o00L0003o1@3oool9003jV_H0oooo00<000000?ooo`3oool06`3oool002X0oooo00<0
00000?ooo`3oool01@3oool200000080oooo1@0000080000o`h0oooo1@00nY[d0?ooo`<000009@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo2@00nYX50?ooo`T0003o103o
ool3000000H00?ZJl@3oool00`000000oooo0?ooo`0K0?ooo`00:P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`/0003o2P3oool9003jV_40oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`T00?ZJ00<0oooo0000o`000?l020000?l5
000000/00?ZJj`3oool00`000000oooo0?ooo`0K0?ooo`00:@3oool2000000L0oooo00<000000?oo
o`3oool03@3oool<0000o`L0oooo3000nY[[0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool02P3oool<003jVP80oooo10000?l5000000@0oooo2@00nY[Y0?ooo`030000003oool0oooo
01/0oooo000Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool;0000o`<0
00001@3oool<003jV^H0oooo00<000000?ooo`3oool0:`3oool200000140oooo2@00nYX30?ooo`D0
00001@000?l50?ooo`T00?ZJhP3oool2000001d0oooo000b0?ooo`030000003oool0oooo0080oooo
1`00nYX?0?ooo`@0003o1@00000:0?ooo`/00?ZJh@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo01D0oooo2000nYX3000000T0003o103oool9003jV^40oooo00<000000?ooo`3oool0
6`3oool00380oooo00<000000?ooo`3oool00P3oool9003jVQ40oooo1@0000050000o`X0oooo2@00
nY[N0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0603oool9003jVP@0oooo2@00
0?l50?ooo`D00?ZJ0`00003L0?ooo`030000003oool0oooo01/0oooo000b0?ooo`8000002@3oool9
003jVP/0oooo1@0000080000o``0oooo1`00nY[J0?ooo`800000;@3oool00`000000oooo0?ooo`0M
0?ooo`T00?ZJ0P3oool90000o`@0oooo0P00nYX5000000800?ZJf@3oool00`000000oooo0?ooo`0K
0?ooo`00<P3oool00`000000oooo0?ooo`0:0?ooo``00?ZJ1`3oool3000000D0oooo2@000?l:0?oo
o`T00?ZJeP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0200oooo2@00nYX40?oo
o`T0003o00<0oooo0000000000000`000005003jV]H0oooo00<000000?ooo`3oool06`3oool00380
oooo00<000000?ooo`3oool0403oool9003jVP<0oooo1@00nYX70?ooo`T0003o1`3oool3000000`0
0?ZJd03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02D0oooo2@00nYX20?ooo`L0
003o1@0000000`3oool00?ZJ003jVP05003jV]<0oooo00<000000?ooo`3oool06`3oool00380oooo
00<000000?ooo`3oool05@3oool?003jVPT0oooo2@000?l00`3oool0000000000003000000@0oooo
3000nY[;0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:03oool9003jVP@0oooo
0`000?l3000000030000o`3oool0oooo0080oooo2@00nY[>0?ooo`030000003oool0oooo01/0oooo
000b0?ooo`030000003oool0oooo01P0oooo1@00nYX30?ooo`T00?ZJ1`3oool70000o`D000002P3o
ool;003jV/H0oooo00<000000?ooo`3oool0:`3oool2000002h0oooo1`00nYX40?ooo`T0003o0P3o
ool9003jV/X0oooo0P00000M0?ooo`00<P3oool00`000000oooo0?ooo`0S0?ooo`T00?ZJ2@3oool2
0000o`D000001@000?l:0?ooo`L00?ZJa@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0300oooo2@00nYX20?ooo`T0003o103oool7003jV/P0oooo00<000000?ooo`3oool06`3oool0
0380oooo0P00000Y0?ooo`T00?ZJ1`3oool3000000T0003o303oool2003jV/@0oooo0P00000]0?oo
o`030000003oool0oooo03<0oooo2@00nYX40?ooo`L0003o103oool6003jV/H0oooo00<000000?oo
o`3oool06`3oool00380oooo00<000000?ooo`3oool0:`3oool9003jVP`0oooo2@000?l70?ooo`<0
0?ZJa03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03P0oooo1P00nYX50?ooo`H0
003o1@3oool6003jV/<0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0
<03oool6003jVP030?ooo`00nYX00?ZJ00D00?ZJ1@3oool90000o`D0oooo0`00nY[30?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0>`3oool6003jVPD0oooo1P000?l40?ooo`L00?ZJ
`03oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`0c0?ooo`h00?ZJ1`3o
ool70000o`<0oooo1`00nYZn0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0?@3o
ool7003jVP@0oooo1`000?l40?ooo`H00?ZJ_P3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool0
0`000000oooo0?ooo`0e0?ooo`<00?ZJ1@3oool7003jVPL0oooo1`000?l00`3oool00?ZJ003jVP0:
003jV[P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`100?ooo`L00?ZJ103oool6
0000o`80oooo0`000006003jV[/0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?oo
o`3oool0@03oool7003jVPL0oooo1@000?l50?ooo``00?ZJ/`3oool00`000000oooo0?ooo`0[0?oo
o`800000A03oool6003jVPD0oooo10000?l5000000030?ooo`00nYX00?ZJ00L00?ZJ]@3oool20000
01d0oooo000b0?ooo`030000003oool0oooo04<0oooo1P00nYX80?ooo`80003o0`0000080?ooo``0
0?ZJ[@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04H0oooo1P00nYX40?ooo`80
003o1@0000040?ooo`T00?ZJ/`3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool2000004L0oooo
1P00nYX60?ooo`D000000P000?l:0?ooo``00?ZJY`3oool2000002d0oooo00<000000?ooo`3oool0
B03oool7003jVP<0oooo1@0000020000o`L0oooo1`00nYZ`0?ooo`030000003oool0oooo01/0oooo
000b0?ooo`030000003oool0oooo04P0oooo1`00nYX30?ooo`D000001@000?l=0?ooo`/00?ZJX`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04/0oooo1P00nYX20?ooo`<000001P00
0?l70?ooo`L00?ZJ[@3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`1;
0?ooo`H00?ZJ00<0oooo0000000000000`0000000`3oool0003o0000o`050000o`l0oooo3000nYZM
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0CP3oool6003jVP@0oooo1`000?l7
0?ooo`D00?ZJ[03oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`1>0?oo
o`D00?ZJ0`0000050?ooo`H0003o4P3oool<003jVYP0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`1@0?ooo`L00?ZJ103oool60000o`P0oooo0`00nYZ[0?ooo`030000003oool0oooo
01/0oooo000b0?ooo`030000003oool0oooo0500oooo1`00nYX70?ooo`H0003o5@3oool9003jVYD0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1C0?ooo`H00?ZJ1@3oool50000o`L0
oooo1@00nYZX0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo05<0oooo
1P00nYX70?ooo`X0003o503oool9003jVY00oooo00<000000?ooo`3oool0:`3oool2000005L0oooo
1@00nYX50?ooo`@0003o1`3oool7003jVZ@0oooo0P00000M0?ooo`00<P3oool2000005L0oooo1P00
nYX70?ooo`T0003o5@3oool7003jVXh0oooo0P00000]0?ooo`030000003oool0oooo05P0oooo1000
nYX60?ooo`D0003o1`3oool6003jVZ<0oooo00<000000?ooo`3oool06`3oool00380oooo00<00000
0?ooo`3oool0F03oool7003jVPX0oooo1P000?lG0?ooo`800?ZJS`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo05X0oooo1@00nYX40?ooo`L0003o1`3oool6003jVZ00oooo00<00000
0?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0F`3oool6003jVPX0oooo1`000?lD0?oo
o`800?ZJS`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05/0oooo1P00nYX50?oo
o`H0003o1`3oool6003jVYh0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3o
ool0GP3oool5003jVP/0oooo1P000?lB0?ooo`<00?ZJSP3oool00`000000oooo0?ooo`0F0?ooo`<0
0000103oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`1N0?ooo`D0
0?ZJ1P3oool60000o`L0oooo1000nYZM0?ooo`030000003oool0oooo01/0oooo000M0?ooo`<00000
103oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`1P0?ooo`@00?ZJ
3@3oool60000oa00oooo0P00nYZ>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0H03oool4003jVPL0
oooo1P000?l70?ooo`@00?ZJV`3oool00`000000oooo0?ooo`0K0?ooo`007P3oool00`000000oooo
0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1R0?ooo`D0
0?ZJ303oool70000o`d0oooo0P00nYZ>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0680oooo1@00nYX70?ooo`@0
003o1`3oool5003jVYT0oooo00<000000?ooo`3oool06`3oool001h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06<0oooo1`00nYX<0?ooo`H0003o
2`3oool2003jVXh0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo0P00001T0?ooo`H00?ZJ1`3oool40000o`L0oooo1000nYZF0?ooo`<00000
7@3oool001h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`800000I`3o
ool6003jVPd0oooo1P000?l80?ooo`<00?ZJR`3oool3000001T0oooo00<000000?ooo`3oool01`3o
ool4000000H0oooo00<000000?ooo`3oool0IP3oool4003jVPL0oooo1P000?l60?ooo`@00?ZJUP3o
ool00`000000oooo0?ooo`0K0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`@000001P3oool0
0`000000oooo0?ooo`1Y0?ooo`D00?ZJ3@3oool70000o`H0oooo0P00nYZ=0?ooo`030000003oool0
oooo01H0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0J03oool4
003jVPL0oooo1P000?l50?ooo`@00?ZJU@3oool00`000000oooo0?ooo`0K0?ooo`007@3oool20000
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1[0?ooo`@00?ZJ3`3oool60000
o`@0oooo0P00nYZ=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3oool50000
00D0oooo00<000000?ooo`3oool0J@3oool6003jVPL0oooo10000?l60?ooo`@00?ZJT`3oool00`00
0000oooo0?ooo`0K0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`D000001@3oool00`000000
oooo0?ooo`1]0?ooo`D00?ZJ3`3oool60000o`030?ooo`00nYX00?ZJ08d0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`1[0?ooo`H00?ZJ1`3oool40000o`D0oooo1@00nYZA0?ooo`03
0000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo06h0oooo1P00nYX?0?ooo`D0003o
0P00nYZ=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0KP3oool4003jVPL0oooo
1@000?l50?ooo`@00?ZJT03oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?oo
o`1a0?ooo`D00?ZJ403oool20000o`<00?ZJS03oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0700oooo1000nYX70?ooo`@0003o1P3oool4003jVXh0oooo00<000000?ooo`3oool06`3o
ool00380oooo0P00001d0?ooo`@00?ZJ3`3oool30000o`@00?ZJR@3oool2000002d0oooo0P00001b
0?ooo`H00?ZJ1P3oool50000o`@0oooo1000nYZ<0?ooo`8000007@3oool00380oooo00<000000?oo
o`3oool0M@3oool5003jVPd0oooo0P000?l9003jVXD0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`1c0?ooo`H00?ZJ1@3oool50000o`D0oooo1000nYZ;0?ooo`030000003oool0oooo
01/0oooo000b0?ooo`030000003oool0oooo07H0oooo1P00nYX;0?ooo`<0003o0P3oool9003jVX80
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1f0?ooo`@00?ZJ1`3oool30000o`D0
oooo1P00nYZ80?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo07T0oooo
1@00nYX:0?ooo`80003o1`3oool9003jVWd0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`1h0?ooo`@00?ZJ1P3oool50000o`@0oooo1P00nYZ60?ooo`030000003oool0oooo01/0oooo
000b0?ooo`030000003oool0oooo07/0oooo1000nYX90?ooo`80003o2P3oool;003jVWP0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`1i0?ooo`H00?ZJ103oool60000o`D0oooo1000
nYZ50?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo07d0oooo1@00nYX6
0?ooo`050000o`0000000000000000000?l0303oool9003jVWD0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1k0?ooo`H00?ZJ1@3oool20000o`<000001@3oool5003jVX80oooo00<0
00000?ooo`3oool06`3oool00380oooo0P00001o0?ooo`D00?ZJ1@3oool5000000030000o`3oool0
oooo00h0oooo1@00nYYc0?ooo`800000;@3oool2000007l0oooo1000nYX50?ooo`D000001@3oool6
003jVWl0oooo0P00000M0?ooo`00<P3oool00`000000oooo0?ooo`210?ooo`<00?ZJ103oool50000
0080003o4P3oool2003jVW@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`200?oo
o`@00?ZJ0`3oool500000080003o1P3oool5003jVWh0oooo00<000000?ooo`3oool06`3oool00380
oooo00<000000?ooo`3oool0PP3oool5003jVP030?ooo`000000000000<000001@000?l?0?ooo`<0
0?ZJL`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0840oooo1P00nYX5000000<0
003o1`3oool4003jVWd0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0
P`3oool6003jVP<000000P3oool70000o`d0oooo0P00nYYc0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0P`3oool5003jVP<000000P3oool50000o`H0oooo1000nYYk0?ooo`030000
003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo08H0oooo1P00nYX50?ooo`H0003o2`3o
ool2003jVW<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`260?ooo`D00?ZJ0`3o
ool60000o`D0oooo1000nYYj0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0
oooo08T0oooo1000nYX70?ooo`H0003o203oool3003jVW80oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`290?ooo`<00?ZJ1@3oool40000o`H0oooo1000nYYh0?ooo`030000003oool0
oooo01/0oooo000b0?ooo`030000003oool0oooo08/0oooo0`00nYX80?ooo`H0003o1`3oool2003j
VW80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2:0?ooo`@00?ZJ1@3oool40000
o`D0oooo1000nYYg0?ooo`030000003oool0oooo01/0oooo000b0?ooo`800000S@3oool3003jVPX0
oooo10000?l60?ooo`800?ZJL@3oool2000002d0oooo0P00002<0?ooo`@00?ZJ1@3oool50000o`D0
oooo0`00nYYe0?ooo`8000007@3oool00380oooo00<000000?ooo`3oool0S@3oool4003jVPX0oooo
10000?l40?ooo`<00?ZJL@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08d0oooo
1000nYX50?ooo`@0003o1@3oool3003jVWD0oooo00<000000?ooo`3oool06`3oool00380oooo00<0
00000?ooo`3oool0SP3oool4003jVPX0oooo1P000?l20?ooo`<00?ZJL03oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo08h0oooo1000nYX60?ooo`D0003o0`3oool4003jVW<0oooo00<0
00000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0T03oool5003jVPT0oooo1@000?l0
0`3oool00?ZJ003jVP07003jVVX0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2@
0?ooo`@00?ZJ1@3oool50000o`<0oooo1000nYYb0?ooo`030000003oool0oooo01/0oooo000b0?oo
o`030000003oool0oooo0940oooo1@00nYX;0?ooo`80003o0`3oool<003jVVD0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`2A0?ooo`@00?ZJ1`3oool30000o`@0oooo1000nYY`0?oo
o`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo09@0oooo0`00nYX:0?ooo`<0
003o203oool9003jVV80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2C0?ooo`@0
0?ZJ1P3oool40000o`<0oooo1P00nYY]0?ooo`030000003oool0oooo01/0oooo000b0?ooo`800000
UP3oool4003jVPT0oooo00@0003o00000000000000002`3oool7003jVUh0oooo0P00000]0?ooo`03
0000003oool0oooo09@0oooo1@00nYX50?ooo`@0003o103oool6003jVV/0oooo00<000000?ooo`3o
ool06`3oool00380oooo00<000000?ooo`3oool0UP3oool4003jVPP0oooo1@00000=0?ooo`H00?ZJ
G@3oool00`000000oooo0?ooo`0[0?ooo`800000U`3oool4003jVPH0oooo0`000?l3000000<0oooo
1000nYYY0?ooo`8000007@3oool00380oooo00<000000?ooo`3oool0V03oool4003jVPH0oooo1@00
00020000o`h0oooo1`00nYYI0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0V03o
ool5003jVP@0oooo00<0003o0000000000000`0000040?ooo`@00?ZJJ03oool00`000000oooo0?oo
o`0K0?ooo`00<P3oool00`000000oooo0?ooo`2I0?ooo`@00?ZJ1@3oool5000000<0003o3`3oool5
003jVUT0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2I0?ooo`D00?ZJ103oool5
000000D0oooo1@00nYYV0?ooo`030000003oool0oooo01/0oooo000X0?ooo`D000001@3oool00`00
0000oooo0?ooo`2K0?ooo`<00?ZJ1@3oool300000080oooo1@000?l?0?ooo`800?ZJF@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo09`0oooo0`00nYX30?ooo`D000000P000?l50?oo
o`@00?ZJI@3oool00`000000oooo0?ooo`0K0?ooo`00:@3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo09`0oooo0`00nYX:0?ooo`H0003o3@3oool3003jVUP0oooo00<000000?oo
o`3oool08@3oool5000000D0oooo00<000000?ooo`3oool0W@3oool5003jVP040?ooo`0000000000
000000@0003o1P3oool4003jVV<0oooo00<000000?ooo`3oool06`3oool002X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2M0?ooo`@00?ZJ0P3oool3003jVPH0oooo10000?l=0?oo
o`800?ZJF03oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0WP3oool7003jVP<0oooo10000?l50?ooo`@00?ZJHP3oool00`000000oooo0?ooo`0K
0?ooo`00:`3oool00`000000oooo0?ooo`040?ooo`800000W`3oool9003jVPL0oooo10000?l;0?oo
o`800?ZJEP3oool3000002D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2Q0?oo
o`D00?ZJ0`3oool40000o`H0oooo1000nYYP0?ooo`030000003oool0oooo01/0oooo000X0?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2P0?ooo`@00?ZJ00<0oooo003j
VP00nYX00P00nYX60?ooo`D0003o2@3oool2003jVUP0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`040?ooo`800000Y@3oool2003jVPD0oooo0`000?l60?ooo`@00?ZJG@3oool30000
01d0oooo000X0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2Q0?oo
o`800?ZJ0`3oool4003jVPL0oooo10000?l80?ooo`<00?ZJE`3oool00`000000oooo0?ooo`0Q0?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`2T0?ooo`<00?ZJ1@3oool3
0000o`L0oooo0`00nYYN0?ooo`030000003oool0oooo01/0oooo000Y0?ooo`<000001P3oool00`00
0000oooo0?ooo`2X0?ooo`<00?ZJ203oool50000o`H0oooo0P00nYYG0?ooo`030000003oool0oooo
0240oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0:D0oooo1000nYX4
0?ooo`@0003o1P3oool3003jVUd0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?oo
o`3oool0Z@3oool3003jVPP0oooo1@000?l50?ooo`800?ZJE`3oool00`000000oooo0?ooo`0R0?oo
o`<000001P3oool00`000000oooo0?ooo`2V0?ooo`@00?ZJ103oool40000o`H0oooo0`00nYYL0?oo
o`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0:X0oooo0`00nYX:0?ooo`<0
003o103oool2003jVUL0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2X0?ooo`@0
0?ZJ103oool40000o`D0oooo0`00nYYK0?ooo`030000003oool0oooo01/0oooo000b0?ooo`800000
[03oool4003jVPT0oooo1@000?l00`3oool00?ZJ003jVP1F0?ooo`800000;@3oool00`000000oooo
0?ooo`2Y0?ooo`@00?ZJ103oool40000o`D0oooo0`00nYYJ0?ooo`030000003oool0oooo01/0oooo
000b0?ooo`030000003oool0oooo0:`0oooo1000nYX90?ooo`D0003o0`00nYYF0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0Z`3oool3003jVPD0oooo10000?l40?ooo`<00?ZJF@3o
ool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`2^0?ooo`<00?ZJ2`3oool2
0000o`040?ooo`00nYX00?ZJ003jVUD0oooo00<000000?ooo`3oool0:`3oool200000:d0oooo0`00
nYX50?ooo`@0003o103oool3003jVUL0oooo0P00000M0?ooo`00<P3oool00`000000oooo0?ooo`2_
0?ooo`<00?ZJ2P3oool30000o`T00?ZJC`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0:d0oooo1000nYX50?ooo`<0003o103oool3003jVUL0oooo00<000000?ooo`3oool06`3oool0
0380oooo00<000000?ooo`3oool0/03oool3003jVPX0oooo0P000?l20?ooo`T00?ZJC@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0:h0oooo1000nYX50?ooo`<0003o103oool4003j
VUD0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0/@3oool3003jVPT0
oooo0`000?l70?ooo`H00?ZJBP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;00
oooo1000nYX40?ooo`@0003o0`3oool6003jVU80oooo00<000000?ooo`3oool06`3oool00380oooo
00<000000?ooo`3oool0/P3oool3003jVPT0oooo0`0000080?ooo`L00?ZJA`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0;40oooo1000nYX40?ooo`@0003o103oool7003jVTl0oooo
00<000000?ooo`3oool06`3oool00380oooo0P00002d0?ooo`@00?ZJ1P3oool5000000X0oooo1P00
nYY40?ooo`800000;@3oool00`000000oooo0?ooo`2c0?ooo`@00?ZJ103oool40000o`D0oooo1@00
nYY>0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0;@0oooo1000nYX5
0?ooo`D000003@3oool6003jVT80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2d
0?ooo`@00?ZJ103oool20000o`<000001P3oool3003jVTd0oooo00<000000?ooo`3oool06`3oool0
0380oooo00<000000?ooo`3oool0]P3oool3003jVP@0oooo1@0000030000o``0oooo1`00nYXo0?oo
o`030000003oool0oooo02/0oooo0P00002g0?ooo`<00?ZJ103oool5000000H0oooo1000nYY:0?oo
o`8000007@3oool00380oooo00<000000?ooo`3oool0]`3oool3003jVP@0oooo0`0000060000o`d0
oooo1@00nYXn0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0]`3oool3003jVP<0
oooo1@0000070?ooo`@00?ZJBP3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo
0?ooo`2h0?ooo`<00?ZJ2@3oool40000o`l0oooo0P00nYXn0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0^03oool5003jVPD000000`000?l60?ooo`@00?ZJB03oool00`000000oooo
0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`2i0?ooo`<00?ZJ0P3oool3003jVPD0oooo0`00
0?l>0?ooo`800?ZJ?P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;T0oooo1@00
nYX3000000H0003o1@3oool4003jVTL0oooo00<000000?ooo`3oool06`3oool00380oooo0P00002k
0?ooo`L00?ZJ1P3oool30000o`d0oooo0`00nYXl0?ooo`800000;@3oool00`000000oooo0?ooo`2l
0?ooo`@00?ZJ103oool40000o`H0oooo0`00nYY60?ooo`030000003oool0oooo01/0oooo000b0?oo
o`030000003oool0oooo0;/0oooo1`00nYX60?ooo`@0003o303oool2003jVSd0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`2n0?ooo`<00?ZJ1@3oool30000o`H0oooo0`00nYY50?oo
o`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0;`0oooo0P00nYX20?ooo`<0
0?ZJ1P3oool40000o`/0oooo0P00nYXm0?ooo`030000003oool0oooo02/0oooo0P0000300?ooo`<0
0?ZJ1@3oool30000o`H0oooo1000nYY20?ooo`8000007@3oool00380oooo00<000000?ooo`3oool0
`@3oool3003jVPL0oooo10000?l90?ooo`<00?ZJ?03oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0<00oooo0`00nYX50?ooo`@0003o1@3oool4003jVT80oooo00<000000?ooo`3oool0
6`3oool00380oooo00<000000?ooo`3oool0`P3oool3003jVPL0oooo10000?l90?ooo`800?ZJ?03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0<40oooo0`00nYX50?ooo`@0003o1P3o
ool3003jVT40oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0``3oool4
003jVPL0oooo0`000?l80?ooo`800?ZJ?03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0<80oooo0`00nYX60?ooo`@0003o1@3oool3003jVT00oooo00<000000?ooo`3oool06`3oool0
0380oooo0P0000350?ooo`@00?ZJ1`3oool30000o`L0oooo0P00nYXk0?ooo`800000;@3oool00`00
0000oooo0?ooo`330?ooo`@00?ZJ1@3oool40000o`D0oooo0`00nYXo0?ooo`030000003oool0oooo
01/0oooo000b0?ooo`030000003oool0oooo0<H0oooo0`00nYX70?ooo`@0003o1@3oool3003jVS/0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`340?ooo`@00?ZJ1P3oool30000o`D0
oooo0`00nYXn0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0<L0oooo
0P00nYX80?ooo`@0003o1@3oool3003jVSX0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`360?ooo`<00?ZJ1P3oool30000o`D0oooo0P00nYXn0?ooo`030000003oool0oooo01/0oooo
000b0?ooo`030000003oool0oooo0<L0oooo0`00nYX90?ooo`@0003o0`3oool6003jVSL0oooo00<0
00000?ooo`3oool0:`3oool200000<P0oooo0`00nYX60?ooo`@0003o0`3oool3003jVS`0oooo0P00
000M0?ooo`00703oool5000000<0oooo00<000000?ooo`3oool00P3oool3000000H0oooo00<00000
0?ooo`3oool0b03oool3003jVPT0oooo10000?l40?ooo`L00?ZJ=03oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0<P0oooo0`00nYX60?ooo`@0003o0`3oool3003jVS`0oooo00<00000
0?ooo`3oool06`3oool001d0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0b@3oool3003jVPX0oooo10000?l50?ooo`H00?ZJ<P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0<T0oooo0`00nYX70?ooo`@0003o0P3o
ool7003jVSL0oooo00<000000?ooo`3oool06`3oool001h0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0<X0oooo0`00nYX:0?ooo`80003o0`000006
0?ooo`/00?ZJ:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0<X0oooo0`00nYX7
0?ooo`@0003o0P3oool9003jVS@0oooo00<000000?ooo`3oool06`3oool001l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`800000c03oool3003jVPX0oooo1@0000070?oo
o``00?ZJ9@3oool3000002d0oooo00<000000?ooo`3oool0b`3oool5003jVPH0oooo10000?l50?oo
o`D00?ZJ<`3oool00`000000oooo0?ooo`0K0?ooo`00703oool01@000000oooo0?ooo`3oool00000
00L0oooo100000060?ooo`030000003oool0oooo0<`0oooo0`00nYX90?ooo`D000002P3oool30000
0080oooo1`00nYXT0?ooo`030000003oool0oooo01D0oooo1@0000030?ooo`030000003oool0oooo
0080oooo0`0000060?ooo`030000003oool0oooo0<`0oooo1@00nYX60?ooo`@0003o1`3oool3003j
VS80oooo00<000000?ooo`3oool06`3oool001`0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0c@3oool3003jVPP0oooo1@0000000`00
0?l0oooo0?ooo`060?ooo`D00000103oool5003jVR<0oooo00<000000?ooo`3oool05P3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`3?0?ooo`<00?ZJ1`3oool3000000L0oooo1000nYX`0?ooo`030000003oool0oooo01/0oooo000M
0?ooo`<00000203oool5000000D0oooo00<000000?ooo`3oool0cP3oool3003jVPP0oooo0`000003
0000o`L0oooo1@0000070?ooo`800?ZJ8`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool200000=40oooo1000nYX40?ooo`D000001`3oool4
003jVRd0oooo0`00000M0?ooo`00<P3oool00`000000oooo0?ooo`3?0?ooo`800?ZJ303oool30000
o`H0oooo1@0000070?ooo`800?ZJ8`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3A0?ooo`@00?ZJ0`3oool50000
00<0003o1P3oool01000nYX0000000000000000]0?ooo`030000003oool0oooo01/0oooo000b0?oo
o`030000003oool0oooo0<l0oooo0`00nYX80?ooo`800?ZJ0P3oool40000o`D0oooo0`0000000`00
0?l0oooo0?ooo`050?ooo`800?ZJ8`3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo
0?ooo`0000001`3oool4000000H0oooo00<000000?ooo`3oool0d`3oool5003jVPD000001P000?l3
0?ooo`D00000;03oool00`000000oooo0?ooo`0K0?ooo`00<P3oool200000=40oooo0`00nYX70?oo
o`800?ZJ0`3oool40000o`<0oooo1P000?l60?ooo`800?ZJ8P3oool2000001L0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0e03oool5
003jVP<000000`3oool60000o`030?ooo`000000000000<0000000<00?ZJ0?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3A0?ooo`<00?ZJ1@3oool4003j
VP@0oooo0`000?l0103oool0003o0000o`000?l20?ooo`<0003o1@3oool3003jVR80oooo00<00000
0?ooo`3oool05P3oool3000000P0oooo1@0000050?ooo`030000003oool0oooo0=L0oooo1@00nYX6
0?ooo`@0003o1@0000000`00nYX0oooo0?ooo`0Y0?ooo`030000003oool0oooo01/0oooo000b0?oo
o`030000003oool0oooo0=80oooo0`00nYX40?ooo`@00?ZJ1@3oool50000o`@0oooo0`000?l50?oo
o`800?ZJ8P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0=X0oooo0`00nYX70?oo
o`<0003o0`000003003jVRX0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3o
ool0d`3oool4003jVP030?ooo`00nYX00?ZJ00@00?ZJ1@3oool40000o`800?ZJ0`3oool30000o`@0
oooo0P00nYXR0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0f`3oool4003jVPL0
oooo0`000?l20?ooo`<00?ZJ:@3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo
0?ooo`3D0?ooo`H00?ZJ0P3oool3003jVPD0oooo0P000?l00`3oool00?ZJ003jVP040?ooo`<0003o
0`3oool2003jVR80oooo00<000000?ooo`3oool0:`3oool200000=d0oooo1000nYX70?ooo`<0003o
0P3oool2003jVRP0oooo0P00000M0?ooo`00<P3oool00`000000oooo0?ooo`3F0?ooo`@00?ZJ0`3o
ool3003jVPL0oooo0`00nYX40?ooo`@0003o00<0oooo003jVP00nYX08P3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0=h0oooo1@00nYX50?ooo`<0003o00@0oooo003jVP00nYX00?ZJ
:03oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3G0?ooo`800?ZJ1@3o
ool3003jVPD0oooo1@00nYX40?ooo`@0003o0P00nYXR0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0g`3oool6003jVP@0oooo0`000?l0103oool00?ZJ003jVP00nYXW0?ooo`030000
003oool0oooo01/0oooo000b0?ooo`800000h03oool2003jVPD0oooo0P00nYX0103oool00?ZJ003j
VP00nYX50?ooo`80003o0P00nYXQ0?ooo`800000;@3oool00`000000oooo0?ooo`3R0?ooo`L00?ZJ
00<0oooo0000o`000?l00P3oool3003jVRH0oooo00<000000?ooo`3oool06`3oool00380oooo00<0
00000?ooo`3oool0g`3oool3003jVP@0oooo0P00nYX20?ooo`800?ZJ1P3oool010000?l00?ZJ003j
VP00nYXQ0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0i03oool5003jVP040?oo
o`000?l0003o0000o`80oooo0P00nYXV0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000
003oool0oooo0>00oooo0`00nYX20?ooo`<00?ZJ0P3oool3003jVPD0oooo0P000?l2003jVR40oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3W0?ooo`<00?ZJ00<0oooo0000o`000?l0
0P3oool3003jVRD0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0h@3o
ool3003jVP030?ooo`00nYX00?ZJ00@0oooo0`00nYX40?ooo`80003o0P00nYXQ0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0j03oool3003jVP<0003o0P3oool3003jVR@0oooo00<0
00000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0hP3oool2003jVP030?ooo`00nYX0
0?ZJ00D0oooo0P00nYX50?ooo`030000o`00nYX00?ZJ00D00?ZJ703oool00`000000oooo0?ooo`0[
0?ooo`800000jP3oool2003jVP040?ooo`000?l0003o0000o`80oooo0`00nYXR0?ooo`8000007@3o
ool00380oooo00<000000?ooo`3oool0hP3oool5003jVPD0oooo0`00nYX40?ooo`030000o`00nYX0
0?ZJ00L00?ZJ6P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0>T0oooo0`00nYX0
103oool0003o0000o`000?l20?ooo`800?ZJ8`3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool2
00000>@0oooo0`00nYX70?ooo`<00?ZJ0`3oool20000o`D0oooo1000nYXH0?ooo`800000;@3oool0
0`000000oooo0?ooo`3Z0?ooo`800?ZJ0P3oool30000o`040?ooo`00nYX00?ZJ003jVR80oooo00<0
00000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0i03oool2003jVPP0oooo0`00nYX2
0?ooo`80003o1`3oool4003jVQL0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3Z
0?ooo`<00?ZJ0P3oool20000o`80oooo0P00nYXR0?ooo`030000003oool0oooo01/0oooo000b0?oo
o`030000003oool0oooo0>l0oooo0P00nYX20?ooo`040000o`0000000000000000H0oooo1000nYXF
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0j`3oool2003jVP80oooo0`000?l0
0`3oool00?ZJ003jVP0R0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo
0>l0oooo0`00nYX00`3oool0000000000003000000L0oooo0P00nYXF0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0j`3oool3003jVP80oooo0`000?l3003jVR40oooo00<000000?oo
o`3oool06`3oool00380oooo00<000000?ooo`3oool0l03oool3003jVPD000001`3oool2003jVQH0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3/0?ooo`800?ZJ0`3oool30000o`<0
0?ZJ803oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3a0?ooo`800?ZJ
1@0000000`000?l0oooo0?ooo`040?ooo`<00?ZJ5@3oool00`000000oooo0?ooo`0[0?ooo`800000
k@3oool3003jVP<0oooo0P000?l0103oool00?ZJ003jVP00nYXN0?ooo`8000007@3oool00380oooo
0P00003c0?ooo`800?ZJ0`0000030000o`H0oooo0P00nYXD0?ooo`800000;@3oool00`000000oooo
0?ooo`3]0?ooo`<00?ZJ0P3oool30000o`030?ooo`00nYX00?ZJ00800?ZJ7@3oool00`000000oooo
0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3c0?ooo`<00?ZJ0P3oool30000o`D0oooo0P00
nYXE0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0kP3oool3003jVP80oooo00@0
003o00000000000000001000nYXL0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003o
ool0oooo0?@0oooo0P00nYX30?ooo`@0003o0`3oool2003jVQD0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`3_0?ooo`<00?ZJ00<0oooo0000000000000`000000103oool00?ZJ003j
VP00nYXK0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0?@0oooo0`00
nYX30?ooo`@0003o0P3oool2003jVQD0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`3`0?ooo`<00?ZJ1@0000020?ooo`800?ZJ6`3oool00`000000oooo0?ooo`0K0?ooo`00:@3oool3
000000H0oooo00<000000?ooo`3oool0m@3oool3003jVP@0oooo0`000?l0103oool00?ZJ003jVP00
nYXD0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0l@3oool2003jVPD000000P3o
ool3003jVQX0oooo00<000000?ooo`3oool06`3oool002P0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo0?H0oooo0P00nYX50?ooo`80003o0P3oool2003jVQ@0oooo00<0
00000?ooo`3oool0:`3oool200000?<0oooo0P00nYX3000000040000o`3oool0oooo0?ooo`<00?ZJ
603oool2000001d0oooo000/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0mP3o
ool3003jVP@0oooo0`000?l00`3oool00?ZJ003jVP0D0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0lP3oool3003jVP040?ooo`000?l0003o0000o`<0oooo0`00nYXH0?ooo`030000
003oool0oooo01/0oooo000Z0?ooo`8000001P3oool200000?P0oooo0P00nYX50?ooo`<0003o0P00
nYXB0?ooo`<00000;@3oool00`000000oooo0?ooo`3c0?ooo`<00?ZJ00@0oooo0000o`000?l0003o
0`3oool2003jVQP0oooo00<000000?ooo`3oool06`3oool002`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3g0?ooo`<00?ZJ1@3oool20000o`800?ZJ503oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0?@0oooo0P00nYX20?ooo`<0003o0P3oool3003jVQL0oooo00<0
00000?ooo`3oool06`3oool002P0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0?P0oooo0`00nYX40?ooo`80003o0`00nYXC0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0m03oool3003jVP80oooo0`000?l20?ooo`800?ZJ5`3oool00`000000oooo0?oo
o`0K0?ooo`00:@3oool3000000H0oooo00<000000?ooo`3oool0n@3oool3003jVP@0oooo0P000?l4
003jVQ40oooo00<000000?ooo`3oool08P3oool3000000H0oooo00<000000?ooo`3oool0m@3oool3
003jVP80oooo0P000?l20?ooo`<00?ZJ5P3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool00`00
0000oooo0?ooo`3j0?ooo`800?ZJ103oool20000o`H00?ZJ3`3oool00`000000oooo0?ooo`0Q0?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3f0?ooo`800?ZJ0P3oool3
0000o`80oooo0P00nYXF0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo
0?X0oooo0`00nYX30?ooo`<0003o0P3oool5003jVPd0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`030?ooo`800000m`3oool3003jVP80oooo0`000?l0103oool00?ZJ003jVP00nYXC
0?ooo`<000007@3oool00380oooo0P00003l0?ooo`<00?ZJ0`3oool20000o`@0oooo1000nYX;0?oo
o`8000009@3oool2000000H0oooo00<000000?ooo`3oool0m`3oool2003jVP<0oooo0`000?l0103o
ool00?ZJ003jVP00nYXD0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo
0?`0oooo0`00nYX20?ooo`040000o`0000000000000000@0oooo1@00nYX90?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3g0?ooo`<00?ZJ0`3oool2
0000o`80oooo0P00nYXD0?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo
0?d0oooo0P00nYX20?ooo`D00000103oool5003jVPP0oooo00<000000?ooo`3oool08@3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0n03oool3003jVP80oooo0`000?l0
0`3oool00?ZJ003jVP02003jVQ80oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?oo
o`3oool0o@3oool3003jVP030?ooo`000000000000<000001`3oool2003jVPP0oooo00<000000?oo
o`3oool08P3oool3000000H0oooo00<000000?ooo`3oool0n@3oool3003jVP80oooo0`000?l00`3o
ool00?ZJ003jVP02003jVQ40oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3o
ool0oP3oool2003jVP030?ooo`000000000000<000001`3oool2003jVPP0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`3j0?ooo`<00?ZJ0P3oool20000o`<0oooo1000nYX?0?ooo`03
0000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0?h0oooo1000nYX300000080003o
1P3oool3003jVPL0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3k0?ooo`<00?ZJ
00@0oooo0000o`000?l0003o0`3oool4003jVPh0oooo00<000000?ooo`3oool06`3oool00380oooo
00<000000?ooo`3oool0o`3oool4003jVP80oooo0P000?l70?ooo`800?ZJ1`3oool00`000000oooo
0?ooo`0[0?ooo`800000o@3oool3003jVP040?ooo`000?l0003o0000o`@0oooo0`00nYX<0?ooo`80
00007@3oool00380oooo0P00003o0?ooo`<0oooo0`00nYX0103oool0003o0000o`000?l60?ooo`80
0?ZJ1P3oool2000002d0oooo00<000000?ooo`3oool0o@3oool2003jVP80oooo00@0003o00000000
000000000`3oool3003jVP`0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3o
ool0o`3oool30?ooo`800?ZJ0P3oool30000o`D0oooo0`00nYX60?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0o@3oool3003jVP030?ooo`000000000000<000000`3oool3003jVP/0
oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0o`3oool30?ooo`<00?ZJ
0P3oool30000o`D0oooo0P00nYX60?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
oP3oool2003jVP030?ooo`000000000000<00000103oool3003jVPX0oooo00<000000?ooo`3oool0
6`3oool00380oooo00<000000?ooo`3oool0o`3oool40?ooo`<00?ZJ0P3oool30000o`@0oooo0P00
nYX60?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0oP3oool3003jVPD0000000<0
003o0?ooo`3oool00P3oool3003jVPT0oooo00<000000?ooo`3oool06`3oool00380oooo00<00000
0?ooo`3oool0o`3oool50?ooo`800?ZJ0`3oool30000o`/0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`3o0?ooo`<00?ZJ0`0000030000o`@0oooo0`00nYX80?ooo`030000003oool0
oooo01/0oooo000b0?ooo`030000003oool0oooo0?l0oooo1@3oool3003jVP<0oooo0`000?l20?oo
o`<000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo0P3oool3003j
VP80oooo0`000?l40?ooo`800?ZJ203oool00`000000oooo0?ooo`0K0?ooo`00<P3oool200000?l0
oooo1`3oool2003jVP@0oooo0`000?l5000000<0oooo0P00000]0?ooo`800000o`3oool40?ooo`80
0?ZJ0`3oool30000o`<0oooo0`00nYX60?ooo`8000007@3oool00380oooo00<000000?ooo`3oool0
o`3oool60?ooo`<00?ZJ103oool20000o`D00000103oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0?l0oooo0`3oool3003jVP<0oooo0`000?l30?ooo`800?ZJ1`3oool00`000000oooo
0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0P00nYX50?ooo`030000o`00
0000000000<00000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo103o
ool3003jVP<0oooo0`000?l20?ooo`<00?ZJ1P3oool00`000000oooo0?ooo`0K0?ooo`00<P3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo0P00nYX70?ooo`<000001@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0?l0oooo1@3oool3003jVP<0oooo0`000?l20?ooo`800?ZJ1P3oool0
0`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0`00nYX>0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool60?ooo`800?ZJ103oool30000
o`T0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0o`3oool80?ooo`80
0?ZJ3P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo1P3oool3003jVP@0
oooo0`000?l3000000D0oooo00<000000?ooo`3oool06`3oool00380oooo00<000000?ooo`3oool0
o`3oool80?ooo`<00?ZJ1@3oool2003jVPH0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo0`00nYX40?ooo`030000o`000000000000<00000103oool00`000000oooo
0?ooo`0K0?ooo`00<P3oool200000?l0oooo2P3oool3003jVP@0oooo0P00nYX50?ooo`800000;@3o
ool200000?l0oooo2@3oool3003jVP<0oooo00<0003o0000000000000`0000030?ooo`8000007@3o
ool00380oooo00<000000?ooo`3oool0o`3oool:0?ooo`<00?ZJ0`3oool2003jVPH0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0`00nYX30?ooo`D00000103oool0
0`000000oooo0?ooo`0K0?ooo`00<P3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0P00nYX20?oo
o`<00?ZJ1P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo2P3oool4003j
VP80oooo0`0000050?ooo`030000003oool0oooo01/0oooo000b0?ooo`030000003oool0oooo0?l0
oooo2`3oool3003jVP030?ooo`00nYX00?ZJ00L0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo1000nYX90?ooo`030000003oool0oooo01/0oooo000M0?ooo`<00000
103oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooo``0oooo
1@00nYX70?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3oool=0?ooo`<00?ZJ
203oool00`000000oooo0?ooo`0K0?ooo`00703oool01@000000oooo0?ooo`3oool0000000L0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0?l0oooo3@3oool4003jVPL0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0`00nYX70?ooo`03
0000003oool0oooo01/0oooo000P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool200000?l0oooo3P3oool3003jVPH0oooo0`00000]0?ooo`030000003oool0oooo0?l0oooo
3`3oool3003jVPH0oooo00<000000?ooo`3oool06`3oool001h0oooo0P00000<0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0o`3oool>0?ooo`800?ZJ203oool00`000000oooo0?oo
o`0[0?ooo`800000o`3ooolA0?ooo`800?ZJ1@3oool2000001d0oooo000P0?ooo`030000003oool0
oooo00D0oooo100000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo000L0?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo000M0?oo
o`<00000203oool5000000D0ooooo`00000L000002d0ooooo`00000L000001d0oooo003o0?ooool0
oooo]03oool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool0
0:`0oooo00<0<c<c0?ooo`3oool0<@3oool303<c<ol0oooo4P3oool00`0c<c<0oooo0?ooo`0a0?oo
o`<0<c<cQ`3oool00:d0oooo00<0<c<c0?ooo`3oool0<@3oool00`0c<c<0oooo0?ooo`3o0?oooa80
oooo00<0<c<c0?ooo`3oool0<@3oool00`0c<c<0oooo0?ooo`260?ooo`00NP3oool503<c<`030?oo
o`0c<c<0<c<c00<0<c<c00<0oooo03<c<`0c<c<00`0c<c<30?ooo`80<c<c0`3oool303<c<`80oooo
0`0c<c<40?ooo`<0<c<c0`3oool403<c<`@0oooo00<0<c<c0?ooo`3oool01`3oool303<c<`80oooo
100c<c<40?ooo`80<c<c2@3oool303<c<`<0oooo0`0c<c<20?ooo`0503<c<`3oool0<c<c0?ooo`0c
<c<00P3oool303<c<`<0oooo0`0c<c<20?ooo`<0<c<c00@0oooo03<c<`0c<c<0oooo0`0c<c<20?oo
o`<0<c<c00<0oooo03<c<`0c<c<00P3oool203<c<l00oooo100c<c<20?ooo`0503<c<`3oool0<c<c
0?ooo`0c<c<00P3oool303<c<`<0oooo0`0c<c<40?ooo`80<c<c0P3oool603<c<`040?ooo`0c<c<0
<c<c03<c<`<0oooo100c<c<40?ooo`0303<c<`3oool0oooo00L0oooo0`0c<c<20?ooo`@0<c<c103o
ool203<c<`T0oooo0`0c<c<30?ooo`<0<c<c0P3oool01@0c<c<0oooo03<c<`3oool0<c<c0080oooo
0`0c<c<30?ooo`<0<c<c0P3oool303<c<`040?ooo`0c<c<0<c<c0?ooo`<0<c<c0P3oool303<c<`03
0?ooo`0c<c<0<c<c0080oooo0P0c<c=X0?ooo`00O03oool00`0c<c<0oooo0?ooo`030?ooo`0303<c
<`3oool0oooo00<0oooo00<0<c<c0?ooo`3oool00P3oool01P0c<c<0oooo0?ooo`0c<c<0oooo03<c
<`H0oooo00<0<c<c0?ooo`3oool00P3oool00`0c<c<0oooo0?ooo`030?ooo`0403<c<`3oool0oooo
03<c<a00oooo00<0<c<c0?ooo`3oool01@3oool0100c<c<0oooo0?ooo`0c<c<20?ooo`0303<c<`3o
ool0oooo00D0oooo00L0<c<c0?ooo`3oool0oooo03<c<`3oool0<c<c00<0oooo00L0<c<c0?ooo`0c
<c<0oooo03<c<`3oool0<c<c0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<30?ooo`0403<c
<`3oool0oooo03<c<`80oooo00<0<c<c0?ooo`0c<c<01P3oool0100c<c<0oooo0?ooo`0c<c<20?oo
o`0403<c<`3oool0oooo03<c<l<0oooo00T0<c<c0?ooo`0c<c<0oooo03<c<`3oool0<c<c0?ooo`0c
<c<00`3oool00`0c<c<0oooo03<c<`030?ooo`0403<c<`3oool0oooo03<c<`80oooo00@0<c<c0?oo
o`3oool0<c<c0P3oool00`0c<c<0oooo03<c<`050?ooo`0403<c<`3oool0oooo03<c<a00oooo00<0
<c<c0?ooo`3oool01@3oool0100c<c<0oooo0?ooo`0c<c<20?ooo`0303<c<`3oool0oooo00D0oooo
00L0<c<c0?ooo`3oool0oooo03<c<`3oool0<c<c00<0oooo00L0<c<c0?ooo`0c<c<0oooo03<c<`3o
ool0<c<c0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<30?ooo`0403<c<`3oool0oooo03<c
<`80oooo00<0<c<c0?ooo`0c<c<01P3oool0100c<c<0oooo0?ooo`0c<c<20?ooo`0403<c<`3oool0
oooo03<c<fL0oooo001l0?ooo`0303<c<`3oool0oooo00<0oooo00<0<c<c0?ooo`3oool00`3oool0
0`0c<c<0oooo0?ooo`020?ooo`0303<c<`3oool0oooo0080oooo1@0c<c<20?ooo`0303<c<`3oool0
oooo0080oooo1@0c<c<01@3oool0<c<c0?ooo`3oool0<c<c0100oooo00<0<c<c0?ooo`3oool00P3o
ool303<c<`<0oooo00<0<c<c0?ooo`3oool0203oool00`0c<c<0oooo0?ooo`030?ooo`0;03<c<`3o
ool0oooo0?ooo`0c<c<0oooo03<c<`3oool0<c<c0?ooo`0c<c<00P3oool01P0c<c<0oooo0?ooo`0c
<c<0oooo03<c<`<0oooo00@0<c<c0?ooo`3oool0<c<c0P3oool00`0c<c<0oooo03<c<`0403<c<`80
oooo00@0<c<c0?ooo`3oool0<c<c0P3oool00`0c<c<0oooo0?ooo`310?ooo`<0<c<c0P3oool01`0c
<c<0oooo03<c<`3oool0<c<c0?ooo`0c<c<00`3oool00`0c<c<0oooo03<c<`030?ooo`0403<c<`3o
ool0oooo03<c<`D0oooo00D0<c<c0?ooo`3oool0<c<c0?ooo`0503<c<`050?ooo`0c<c<0oooo0?oo
o`0c<c<0403oool00`0c<c<0oooo0?ooo`020?ooo`<0<c<c0`3oool00`0c<c<0oooo0?ooo`080?oo
o`0303<c<`3oool0oooo00<0oooo00/0<c<c0?ooo`3oool0oooo03<c<`3oool0<c<c0?ooo`0c<c<0
oooo03<c<`020?ooo`0603<c<`3oool0oooo03<c<`3oool0<c<c0`3oool0100c<c<0oooo0?ooo`0c
<c<20?ooo`0303<c<`3oool0<c<c00@0<c<c0P3oool0100c<c<0oooo0?ooo`0c<c<20?ooo`0303<c
<`3oool0oooo06P0oooo001l0?ooo`0303<c<`3oool0oooo00<0oooo00<0<c<c0?ooo`3oool00`3o
ool00`0c<c<0oooo0?ooo`020?ooo`0303<c<`3oool0oooo0080oooo00D0<c<c0?ooo`3oool0oooo
03<c<`020?ooo`80<c<c0`3oool01`0c<c<0oooo0?ooo`3oool0<c<c0?ooo`0c<c<00P3oool00`0c
<c<0oooo0?ooo`0>0?ooo`0503<c<`3oool0oooo0?ooo`0c<c<01P3oool00`0c<c<0oooo0?ooo`08
0?ooo`0703<c<`3oool0oooo0?ooo`0c<c<0oooo03<c<`030?ooo`0703<c<`3oool0<c<c0?ooo`0c
<c<0oooo03<c<`020?ooo`0603<c<`3oool0oooo03<c<`3oool0<c<c0`3oool0100c<c<0oooo0?oo
o`0c<c<20?ooo`0303<c<`3oool0<c<c00<0oooo00@0<c<c0?ooo`3oool0<c<c0P3oool0100c<c<0
oooo0?ooo`0c<c?20?ooo`0303<c<`3oool0oooo00<0oooo00L0<c<c0?ooo`0c<c<0oooo03<c<`3o
ool0<c<c00<0oooo00<0<c<c0?ooo`0c<c<00`3oool0100c<c<0oooo0?ooo`0c<c<50?ooo`0603<c
<`3oool0oooo03<c<`3oool0<c<c0`3oool00`0c<c<0oooo03<c<`020?ooo`0303<c<`3oool0oooo
00h0oooo00D0<c<c0?ooo`3oool0oooo03<c<`060?ooo`0303<c<`3oool0oooo00P0oooo00L0<c<c
0?ooo`3oool0oooo03<c<`3oool0<c<c00<0oooo00L0<c<c0?ooo`0c<c<0oooo03<c<`3oool0<c<c
0080oooo00H0<c<c0?ooo`3oool0<c<c0?ooo`0c<c<30?ooo`0403<c<`3oool0oooo03<c<`80oooo
00<0<c<c0?ooo`0c<c<00`3oool0100c<c<0oooo0?ooo`0c<c<20?ooo`0403<c<`3oool0oooo03<c
<fX0oooo001k0?ooo`@0<c<c00@0oooo03<c<`0c<c<0<c<c1@3oool0100c<c<0oooo0?ooo`3oool4
03<c<`<0oooo0`0c<c<20?ooo`80<c<c00<0oooo03<c<`0c<c<00P3oool303<c<`<0oooo0`0c<c<@
0?ooo`0303<c<`3oool0oooo0080oooo100c<c<00`3oool0<c<c03<c<`0203<c<`T0oooo0`0c<c<3
0?ooo`<0<c<c0P3oool203<c<`040?ooo`0c<c<0oooo0?ooo`@0<c<c0`3oool303<c<`80oooo100c
<c<30?ooo`<0<c<c0P3oool403<c<`80oooo100c<c?10?ooo`@0<c<c00D0oooo03<c<`0c<c<0oooo
03<c<`030?ooo`<0<c<c0`3oool303<c<`80oooo100c<c<30?ooo`<0<c<c0`3oool303<c<`<0oooo
0`0c<c<@0?ooo`0303<c<`3oool0oooo0080oooo100c<c<00`3oool0<c<c03<c<`0203<c<`T0oooo
0`0c<c<30?ooo`<0<c<c0P3oool203<c<`040?ooo`0c<c<0oooo0?ooo`@0<c<c0`3oool303<c<`80
oooo100c<c<30?ooo`<0<c<c0P3oool403<c<`80oooo100c<c=X0?ooo`00O03oool00`0c<c<0oooo
0?ooo`090?ooo`0303<c<`3oool0oooo0080oooo00<0<c<c0?ooo`3oool05`3oool00`0c<c<0oooo
0?ooo`0=0?ooo`80<c<c2P3oool00`0c<c<0oooo0?ooo`0i0?ooo`0303<c<`3oool0oooo0=T0oooo
00<0<c<c0?ooo`3oool00`3oool00`0c<c<0oooo0?ooo`0;0?ooo`0303<c<`3oool0oooo00d0oooo
0P0c<c<:0?ooo`0303<c<`3oool0oooo03T0oooo00<0<c<c0?ooo`3oool0J03oool007d0oooo0P0c
<c<30?ooo`0403<c<`3oool0oooo0?ooo`<0<c<c103oool00`0c<c<0oooo0?ooo`0F0?ooo`80<c<c
403oool00`0c<c<0oooo0?ooo`080?ooo`0303<c<`3oool0oooo03T0oooo00<0<c<c0?ooo`3oool0
f@3oool00`0c<c<0oooo0?ooo`020?ooo`80<c<c303oool203<c<a00oooo00<0<c<c0?ooo`3oool0
203oool00`0c<c<0oooo0?ooo`0i0?ooo`0303<c<`3oool0oooo06P0oooo003o0?ooool0oooo]03o
ool00?l0ooooo`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool00?l0oooo
o`3ooond0?ooo`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?oo
o`00o`3ooooo0?oook@0oooo003o0?ooool0oooo]03oool00?l0ooooo`3ooond0?ooo`00o`3ooooo
0?oook@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 689.25}, {425.625, 0}} -> {-0.0508793, -0.0309082, \
0.00304934, 0.00304934}, {{16.625, 344.625}, {415.438, 212.812}} -> \
{-2.00106, -0.309623, 0.0371749, 0.0856618}, {{344.625, 672.562}, {415.438, \
212.812}} -> {-14.1932, -0.345806, 0.0371749, 0.0858492}, {{16.625, 344.625}, \
{212.812, 10.125}} -> {-2.11016, -2.67186, 0.0371621, 0.0155805}, {{344.625, \
672.562}, {212.812, 10.125}} -> {-14.2982, -2.40351, 0.0371621, 0.014627}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowToolbars->"EditBar",
Evaluator->"Local",
WindowSize->{994, 669},
WindowMargins->{{29, Automatic}, {Automatic, 6}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
0000001804P000000bd2=_oaoo43?095o`85N@?NW0002008ool000001@050001
0000I24A4R060`410@000BL?0040000000000000000004E3<34100;o00000001
000A0S<R<3`00Q3400018NOWinOWia4A\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 74, 1, 56, "Section"],
Cell[1853, 56, 1312, 22, 331, "Input"],

Cell[CellGroupData[{
Cell[3190, 82, 69, 1, 46, "Subsection"],
Cell[3262, 85, 64, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[3351, 90, 56, 1, 39, "Input"],
Cell[3410, 93, 1196, 18, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4655, 117, 82, 1, 46, "Subsection"],
Cell[4740, 120, 67, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[4832, 125, 129, 4, 54, "Input"],
Cell[4964, 131, 189, 3, 70, "Message"],
Cell[5156, 136, 107, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5300, 143, 188, 5, 54, "Input"],
Cell[5491, 150, 181, 3, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5709, 158, 69, 1, 39, "Input"],
Cell[5781, 161, 146, 2, 70, "Output"]
}, Open  ]],
Cell[5942, 166, 93, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[6060, 171, 94, 1, 39, "Input"],
Cell[6157, 174, 380, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6574, 188, 190, 6, 84, "Input"],
Cell[6767, 196, 175, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6979, 204, 137, 4, 54, "Input"],
Cell[7119, 210, 175, 3, 70, "Output"]
}, Open  ]],
Cell[7309, 216, 93, 1, 30, "Text"],
Cell[7405, 219, 194, 7, 99, "Input"],

Cell[CellGroupData[{
Cell[7624, 230, 132, 4, 39, "Input"],
Cell[7759, 236, 64, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7860, 242, 256, 7, 99, "Input"],
Cell[8119, 251, 146, 2, 70, "Output"]
}, Open  ]],
Cell[8280, 256, 137, 5, 69, "Input"],

Cell[CellGroupData[{
Cell[8442, 265, 63, 1, 39, "Input"],
Cell[8508, 268, 66, 1, 70, "Output"]
}, Open  ]],
Cell[8589, 272, 104, 4, 54, "Input"],

Cell[CellGroupData[{
Cell[8718, 280, 124, 4, 54, "Input"],
Cell[8845, 286, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8932, 292, 117, 4, 54, "Input"],
Cell[9052, 298, 60, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9161, 305, 66, 1, 30, "Subsection"],

Cell[CellGroupData[{
Cell[9252, 310, 333, 15, 219, "Input"],
Cell[9588, 327, 123, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9748, 334, 64, 1, 39, "Input"],
Cell[9815, 337, 46, 1, 70, "Output"]
}, Open  ]],
Cell[9876, 341, 26, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[9927, 345, 203, 8, 99, "Input"],
Cell[10133, 355, 69, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10239, 361, 144, 4, 54, "Input"],
Cell[10386, 367, 181, 3, 70, "Print"],
Cell[10570, 372, 83317, 3604, 70, 57237, 3278, "GraphicsData", "PostScript", \
"Graphics"],
Cell[93890, 3978, 130, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[94069, 3987, 41, 0, 30, "Subsection"],
Cell[94113, 3989, 148, 5, 39, "Input"],

Cell[CellGroupData[{
Cell[94286, 3998, 52, 1, 39, "Input"],
Cell[94341, 4001, 185, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94563, 4009, 87, 4, 54, "Input"],
Cell[94653, 4015, 171, 3, 70, "Output"],
Cell[94827, 4020, 375, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95239, 4031, 97, 1, 39, "Input"],
Cell[95339, 4034, 92, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95468, 4040, 194, 6, 84, "Input"],
Cell[95665, 4048, 21185, 712, 70, 6710, 529, "GraphicsData", "PostScript", \
"Graphics"],
Cell[116853, 4762, 130, 3, 70, "Output"],
Cell[116986, 4767, 24381, 888, 70, 9252, 697, "GraphicsData", "PostScript", \
"Graphics"],
Cell[141370, 5657, 130, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[141549, 5666, 83, 1, 30, "Subsection"],

Cell[CellGroupData[{
Cell[141657, 5671, 359, 18, 264, "Input"],
Cell[142019, 5691, 123, 2, 38, "Output"]
}, Open  ]],
Cell[142157, 5696, 78, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[142260, 5701, 209, 5, 54, "Input"],
Cell[142472, 5708, 69, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142578, 5714, 109, 2, 39, "Input"],
Cell[142690, 5718, 46, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142773, 5724, 141, 4, 39, "Input"],
Cell[142917, 5730, 181, 3, 22, "Print"],
Cell[143101, 5735, 83317, 3604, 182, 57237, 3278, "GraphicsData", \
"PostScript", "Graphics"],
Cell[226421, 9341, 130, 3, 38, "Output"]
}, Open  ]],
Cell[226566, 9347, 80, 1, 30, "Text"],
Cell[226649, 9350, 216, 7, 84, "Input"],

Cell[CellGroupData[{
Cell[226890, 9361, 65, 1, 39, "Input"],
Cell[226958, 9364, 46, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[227041, 9370, 74, 4, 54, "Input"],
Cell[227118, 9376, 2307, 34, 173, "Output"],
Cell[229428, 9412, 2306, 34, 173, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231771, 9451, 62, 1, 39, "Input"],
Cell[231836, 9454, 38, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231911, 9460, 298, 10, 144, "Input"],
Cell[232212, 9472, 99, 2, 22, "Print"],
Cell[232314, 9476, 99, 2, 22, "Print"],
Cell[232416, 9480, 99, 2, 22, "Print"],
Cell[232518, 9484, 51, 1, 22, "Print"],
Cell[232572, 9487, 921, 18, 33, "Print"],
Cell[233496, 9507, 45, 1, 22, "Print"],
Cell[233544, 9510, 244, 5, 22, "Print"],
Cell[233791, 9517, 102, 2, 22, "Print"],
Cell[233896, 9521, 173, 3, 22, "Print"],
Cell[234072, 9526, 577, 10, 22, "Print"],
Cell[234652, 9538, 831, 18, 22, "Print"],
Cell[235486, 9558, 830, 18, 22, "Print"],
Cell[236319, 9578, 830, 18, 22, "Print"],
Cell[237152, 9598, 830, 18, 22, "Print"],
Cell[237985, 9618, 828, 18, 22, "Print"],
Cell[238816, 9638, 828, 18, 22, "Print"],
Cell[239647, 9658, 760, 17, 22, "Print"],
Cell[240410, 9677, 412, 10, 22, "Print"],
Cell[240825, 9689, 45, 1, 22, "Print"],
Cell[240873, 9692, 1139, 25, 117, "Print"],
Cell[242015, 9719, 46, 1, 22, "Print"],
Cell[242064, 9722, 4312, 121, 101, "Print"],
Cell[246379, 9845, 268, 5, 22, "Print"],
Cell[246650, 9852, 102, 2, 22, "Print"],
Cell[246755, 9856, 173, 3, 22, "Print"],
Cell[246931, 9861, 806, 14, 37, "Print"],
Cell[247740, 9877, 830, 18, 22, "Print"],
Cell[248573, 9897, 830, 18, 22, "Print"],
Cell[249406, 9917, 830, 18, 22, "Print"],
Cell[250239, 9937, 830, 18, 22, "Print"],
Cell[251072, 9957, 828, 18, 22, "Print"],
Cell[251903, 9977, 828, 18, 22, "Print"],
Cell[252734, 9997, 760, 17, 22, "Print"],
Cell[253497, 10016, 414, 10, 22, "Print"],
Cell[253914, 10028, 45, 1, 22, "Print"],
Cell[253962, 10031, 1258, 28, 117, "Print"],
Cell[255223, 10061, 46, 1, 22, "Print"],
Cell[255272, 10064, 4957, 121, 101, "Print"],
Cell[260232, 10187, 257, 4, 22, "Print"],
Cell[260492, 10193, 102, 2, 22, "Print"],
Cell[260597, 10197, 173, 3, 22, "Print"],
Cell[260773, 10202, 811, 14, 37, "Print"],
Cell[261587, 10218, 828, 18, 22, "Print"],
Cell[262418, 10238, 828, 18, 22, "Print"],
Cell[263249, 10258, 760, 17, 22, "Print"],
Cell[264012, 10277, 414, 10, 22, "Print"],
Cell[264429, 10289, 45, 1, 22, "Print"],
Cell[264477, 10292, 1260, 28, 117, "Print"],
Cell[265740, 10322, 46, 1, 22, "Print"],
Cell[265789, 10325, 5015, 121, 101, "Print"],
Cell[270807, 10448, 268, 5, 22, "Print"],
Cell[271078, 10455, 102, 2, 22, "Print"],
Cell[271183, 10459, 173, 3, 22, "Print"],
Cell[271359, 10464, 813, 14, 37, "Print"],
Cell[272175, 10480, 760, 17, 22, "Print"],
Cell[272938, 10499, 410, 10, 22, "Print"],
Cell[273351, 10511, 45, 1, 22, "Print"],
Cell[273399, 10514, 1263, 28, 117, "Print"],
Cell[274665, 10544, 46, 1, 22, "Print"],
Cell[274714, 10547, 4984, 121, 101, "Print"],
Cell[279701, 10670, 267, 5, 22, "Print"],
Cell[279971, 10677, 102, 2, 22, "Print"],
Cell[280076, 10681, 173, 3, 22, "Print"],
Cell[280252, 10686, 815, 14, 37, "Print"],
Cell[281070, 10702, 828, 18, 22, "Print"],
Cell[281901, 10722, 760, 17, 22, "Print"],
Cell[282664, 10741, 414, 10, 22, "Print"],
Cell[283081, 10753, 45, 1, 22, "Print"],
Cell[283129, 10756, 1272, 29, 117, "Print"],
Cell[284404, 10787, 46, 1, 22, "Print"],
Cell[284453, 10790, 4983, 121, 101, "Print"],
Cell[289439, 10913, 265, 5, 22, "Print"],
Cell[289707, 10920, 102, 2, 22, "Print"],
Cell[289812, 10924, 173, 3, 22, "Print"],
Cell[289988, 10929, 814, 14, 37, "Print"],
Cell[290805, 10945, 760, 17, 22, "Print"],
Cell[291568, 10964, 414, 10, 22, "Print"],
Cell[291985, 10976, 45, 1, 22, "Print"],
Cell[292033, 10979, 1263, 28, 117, "Print"],
Cell[293299, 11009, 46, 1, 22, "Print"],
Cell[293348, 11012, 4972, 121, 101, "Print"],
Cell[298323, 11135, 267, 5, 22, "Print"],
Cell[298593, 11142, 102, 2, 22, "Print"],
Cell[298698, 11146, 173, 3, 22, "Print"],
Cell[298874, 11151, 814, 14, 37, "Print"],
Cell[299691, 11167, 760, 17, 22, "Print"],
Cell[300454, 11186, 412, 10, 22, "Print"],
Cell[300869, 11198, 45, 1, 22, "Print"],
Cell[300917, 11201, 1265, 28, 117, "Print"],
Cell[302185, 11231, 46, 1, 22, "Print"],
Cell[302234, 11234, 4973, 121, 101, "Print"],
Cell[307210, 11357, 268, 5, 22, "Print"],
Cell[307481, 11364, 102, 2, 22, "Print"],
Cell[307586, 11368, 173, 3, 22, "Print"],
Cell[307762, 11373, 807, 14, 37, "Print"],
Cell[308572, 11389, 760, 17, 22, "Print"],
Cell[309335, 11408, 414, 10, 22, "Print"],
Cell[309752, 11420, 45, 1, 22, "Print"],
Cell[309800, 11423, 1263, 28, 117, "Print"],
Cell[311066, 11453, 46, 1, 22, "Print"],
Cell[311115, 11456, 4990, 121, 101, "Print"],
Cell[316108, 11579, 265, 5, 22, "Print"],
Cell[316376, 11586, 102, 2, 22, "Print"],
Cell[316481, 11590, 173, 3, 22, "Print"],
Cell[316657, 11595, 811, 14, 37, "Print"],
Cell[317471, 11611, 760, 17, 22, "Print"],
Cell[318234, 11630, 416, 10, 22, "Print"],
Cell[318653, 11642, 45, 1, 22, "Print"],
Cell[318701, 11645, 1276, 29, 117, "Print"],
Cell[319980, 11676, 46, 1, 22, "Print"],
Cell[320029, 11679, 4970, 121, 101, "Print"],
Cell[325002, 11802, 265, 5, 22, "Print"],
Cell[325270, 11809, 102, 2, 22, "Print"],
Cell[325375, 11813, 175, 3, 22, "Print"],
Cell[325553, 11818, 816, 14, 37, "Print"],
Cell[326372, 11834, 760, 17, 22, "Print"],
Cell[327135, 11853, 416, 10, 22, "Print"],
Cell[327554, 11865, 45, 1, 22, "Print"],
Cell[327602, 11868, 1275, 29, 117, "Print"],
Cell[328880, 11899, 46, 1, 22, "Print"],
Cell[328929, 11902, 4964, 121, 101, "Print"],
Cell[333896, 12025, 265, 5, 22, "Print"],
Cell[334164, 12032, 102, 2, 22, "Print"],
Cell[334269, 12036, 175, 3, 22, "Print"],
Cell[334447, 12041, 815, 14, 37, "Print"],
Cell[335265, 12057, 760, 17, 22, "Print"],
Cell[336028, 12076, 416, 10, 22, "Print"],
Cell[336447, 12088, 45, 1, 22, "Print"],
Cell[336495, 12091, 1276, 29, 117, "Print"],
Cell[337774, 12122, 46, 1, 22, "Print"],
Cell[337823, 12125, 4968, 121, 101, "Print"],
Cell[342794, 12248, 265, 5, 22, "Print"],
Cell[343062, 12255, 102, 2, 22, "Print"],
Cell[343167, 12259, 175, 3, 22, "Print"],
Cell[343345, 12264, 811, 14, 37, "Print"],
Cell[344159, 12280, 758, 17, 22, "Print"],
Cell[344920, 12299, 416, 10, 22, "Print"],
Cell[345339, 12311, 45, 1, 22, "Print"],
Cell[345387, 12314, 1261, 28, 117, "Print"],
Cell[346651, 12344, 46, 1, 22, "Print"],
Cell[346700, 12347, 4970, 121, 101, "Print"],
Cell[351673, 12470, 266, 5, 22, "Print"],
Cell[351942, 12477, 102, 2, 22, "Print"],
Cell[352047, 12481, 175, 3, 22, "Print"],
Cell[352225, 12486, 809, 14, 37, "Print"],
Cell[353037, 12502, 756, 17, 22, "Print"],
Cell[353796, 12521, 418, 10, 22, "Print"],
Cell[354217, 12533, 45, 1, 22, "Print"],
Cell[354265, 12536, 1266, 28, 117, "Print"],
Cell[355534, 12566, 46, 1, 22, "Print"],
Cell[355583, 12569, 4977, 121, 101, "Print"],
Cell[360563, 12692, 264, 5, 22, "Print"],
Cell[360830, 12699, 102, 2, 22, "Print"],
Cell[360935, 12703, 175, 3, 22, "Print"],
Cell[361113, 12708, 813, 14, 37, "Print"],
Cell[361929, 12724, 758, 17, 22, "Print"],
Cell[362690, 12743, 420, 10, 22, "Print"],
Cell[363113, 12755, 45, 1, 22, "Print"],
Cell[363161, 12758, 1269, 27, 117, "Print"],
Cell[364433, 12787, 46, 1, 22, "Print"],
Cell[364482, 12790, 4976, 121, 101, "Print"],
Cell[369461, 12913, 266, 5, 22, "Print"],
Cell[369730, 12920, 102, 2, 22, "Print"],
Cell[369835, 12924, 175, 3, 22, "Print"],
Cell[370013, 12929, 815, 14, 37, "Print"],
Cell[370831, 12945, 760, 17, 22, "Print"],
Cell[371594, 12964, 432, 10, 24, "Print"],
Cell[372029, 12976, 45, 1, 22, "Print"],
Cell[372077, 12979, 1288, 27, 117, "Print"],
Cell[373368, 13008, 46, 1, 22, "Print"],
Cell[373417, 13011, 4978, 121, 101, "Print"],
Cell[378398, 13134, 264, 5, 22, "Print"],
Cell[378665, 13141, 102, 2, 22, "Print"],
Cell[378770, 13145, 175, 3, 22, "Print"],
Cell[378948, 13150, 815, 14, 37, "Print"],
Cell[379766, 13166, 760, 17, 22, "Print"],
Cell[380529, 13185, 434, 10, 24, "Print"],
Cell[380966, 13197, 45, 1, 22, "Print"],
Cell[381014, 13200, 1319, 28, 117, "Print"],
Cell[382336, 13230, 46, 1, 22, "Print"],
Cell[382385, 13233, 4972, 121, 101, "Print"],
Cell[387360, 13356, 263, 4, 24, "Print"],
Cell[387626, 13362, 249, 4, 22, "Print"],
Cell[387878, 13368, 3896, 72, 277, "Print"],
Cell[391777, 13442, 91, 1, 22, "Print"],
Cell[391871, 13445, 80, 1, 22, "Print"],
Cell[391954, 13448, 91, 1, 22, "Print"],
Cell[392048, 13451, 1622, 31, 89, "Print"],
Cell[393673, 13484, 89, 1, 22, "Print"],
Cell[393765, 13487, 45, 1, 22, "Print"],
Cell[393813, 13490, 89, 1, 22, "Print"],
Cell[393905, 13493, 542, 14, 31, "Print"],
Cell[394450, 13509, 67, 1, 22, "Print"],
Cell[394520, 13512, 89, 1, 22, "Print"],
Cell[394612, 13515, 66, 1, 22, "Print"],
Cell[394681, 13518, 89, 1, 22, "Print"],
Cell[394773, 13521, 89, 1, 22, "Print"],
Cell[394865, 13524, 208, 4, 22, "Print"],
Cell[395076, 13530, 1057, 24, 81, "Print"],
Cell[396136, 13556, 90, 1, 22, "Print"],
Cell[396229, 13559, 74, 1, 22, "Print"],
Cell[396306, 13562, 90, 1, 22, "Print"],
Cell[396399, 13565, 1323, 25, 101, "Print"],
Cell[397725, 13592, 91, 1, 22, "Print"],
Cell[397819, 13595, 97, 2, 22, "Print"],
Cell[397919, 13599, 91, 1, 22, "Print"],
Cell[398013, 13602, 1353, 25, 101, "Print"],
Cell[399369, 13629, 45, 1, 22, "Print"],
Cell[399417, 13632, 180, 3, 22, "Print"],
Cell[399600, 13637, 91, 1, 22, "Print"],
Cell[399694, 13640, 108, 2, 22, "Print"],
Cell[399805, 13644, 91, 1, 22, "Print"],
Cell[399899, 13647, 1299, 23, 101, "Print"],
Cell[401201, 13672, 45, 1, 22, "Print"],
Cell[401249, 13675, 172, 3, 22, "Print"],
Cell[401424, 13680, 91, 1, 22, "Print"],
Cell[401518, 13683, 58, 1, 22, "Print"],
Cell[401579, 13686, 91, 1, 22, "Print"],
Cell[401673, 13689, 199, 4, 22, "Print"],
Cell[401875, 13695, 109, 2, 22, "Print"],
Cell[401987, 13699, 742, 17, 41, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[402778, 13722, 103, 1, 30, "Subsection"],

Cell[CellGroupData[{
Cell[402906, 13727, 87, 4, 54, "Input"],
Cell[402996, 13733, 46, 1, 38, "Output"],
Cell[403045, 13736, 46, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403128, 13742, 56, 1, 39, "Input"],
Cell[403187, 13745, 76, 1, 38, "Output"]
}, Open  ]],
Cell[403278, 13749, 45, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[403348, 13753, 257, 7, 69, "Input"],
Cell[403608, 13762, 163, 3, 22, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403808, 13770, 65, 1, 39, "Input"],
Cell[403876, 13773, 42, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403955, 13779, 91, 1, 39, "Input"],
Cell[404049, 13782, 53, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[404139, 13788, 193, 7, 99, "Input"],
Cell[404335, 13797, 181, 3, 21, "Message"],
Cell[404519, 13802, 181, 3, 21, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[404737, 13810, 75, 1, 39, "Input"],
Cell[404815, 13813, 179, 3, 22, "Print"],
Cell[404997, 13818, 56687, 1263, 182, 10097, 683, "GraphicsData", \
"PostScript", "Graphics"],
Cell[461687, 15083, 130, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[461854, 15091, 83, 1, 39, "Input"],
Cell[461940, 15094, 64, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[462041, 15100, 49, 1, 39, "Input"],
Cell[462093, 15103, 46, 1, 38, "Output"]
}, Open  ]],
Cell[462154, 15107, 214, 6, 54, "Input"],

Cell[CellGroupData[{
Cell[462393, 15117, 501, 13, 129, "Input"],
Cell[462897, 15132, 179, 3, 22, "Print"],
Cell[463079, 15137, 179, 3, 22, "Print"],
Cell[463261, 15142, 179, 3, 22, "Print"],
Cell[463443, 15147, 179, 3, 22, "Print"],
Cell[463625, 15152, 152204, 4787, 435, 58589, 3627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[615832, 19941, 135, 3, 38, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

