(************** Content-type: application/mathematica **************
                     CreatedBy='%s'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30138,        961]*)
(*NotebookOutlinePosition[     31222,        997]*)
(*  CellTagsIndexPosition[     31178,        993]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["ML Implementierung", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Expintegral//Clear
Expintegral[v_,St_,X_,Theta_,dt_]:=
\tExp[dt Apply[Plus,MapThread[v[#1,#2,Theta]&,
\t\t{Drop[St,-1],Drop[X,-1]} ]]];
\t\t
FeynmanKacFokker//Clear
FeynmanKacFokker[x_,y_,s_,t_,f_,g_,v_,h_,X_,Theta_,Prozess_,n_,T_]:=
\t(*allgemeiner Fall*) 
\tModule[{c,dt},
\t
\tdt  = (t-s)/T //N;
\tPrint[\"{n,T,dt} = \", {n,T,dt}];
\tSt = Table[RungeKutta[f,g,x,X,T,dt,Theta,Prozess,EulerStep],{nn,1,n}];
\tx1 = Map[Expintegral[v,#,X,Theta,dt]&,St];
\tST = Map[Last,St,{1}];
\tx2 = Map[h[#-y,X//Last,Theta]&,ST];
\txx = x1 x2;
\tc = Apply[Plus,xx]/n //N;
\tc]
\t

FeynmanKacFokker[x_,y_,f_,g_,{v_,0},h_,X_,Theta_,Prozess_,n_,dt_]:=
\t(*v = 0*) 
\tModule[{T},
\tT = Length[X]-1;
\t
\tSt = Table[RungeKutta[f,g,x,X,T,dt,Theta,Prozess,EulerStep],{nn,1,n}];
\tST = Map[Last,St,{1}];
\tsm = smoothQuickAndDirty[ST];
\tPrint[\"FeynmanKacFokker {n,T,dt,sm} = \", {n,T,dt,N[sm,12]}];
\t(*ST//Print;*)
\tx2 = Map[h[#-y,X//Last,{Theta,sm}//Flatten]&,ST];
\tApply[Plus,x2]/n //N
\t]\t  \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\

FeynmanKacFokker1[x_,y_,f_,g_,{v_,0},h_,X_,Theta_,$dw$_,dt_]:=
\t(*mit gegebenen Zufallszahlen dw*) 
\tModule[{T},
\tn = $dw$//Length;
\tT = Length[X]-1;
\t
\tSt = Map[RungeKutta1[f,g,x,{X,#},T,dt,Theta,EulerStep1]&,$dw$];
\tST = Map[Last,St,{1}];
\t(*ST//Print;*)
\tsm = smoothQuickAndDirty[ST];
\tsm//Print;
\t(*Print[\"FeynmanKacFokker1 {n,T,dt,sm} = \", {n,T,dt,N[sm,12]}];*)
\t
\t(*St//Dimensions//Print;*)
\t(*plot1[flatten[St//Transpose,{2,3}]//AddTimeAxis];*)
\t
\tx2 = Map[h[#-y,X//Last,{Theta,sm}//Flatten]&,ST];
\tApply[Plus,x2]/n //N
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LikelihoodFokker//Clear
LikelihoodFokker[Theta_,Y_,time_,dt_,f_,g_,X_,$dw$_]:= 
(***************************************************************)
Module[{th,smooth,lik},
\tPrint[\"*LikelihoodFokker, mit $dw$\" ];
\t
\tti = time/dt + 1;
\tXi = Map[Take[X,#]&,Delta[ti,ti,List,-1]];
\t
\tdichte = 
\t\tMapThread[
\t\t\tFeynmanKacFokker1[#1,#2,f,g,{v,0},h,#3,Theta,$dw$,dt]&,
\t\t\t\t{Drop[Y,-1],Drop[Y,1],Xi}];
\t\t\t
\tlik = Apply[Plus,Log[dichte]]; 
\tlik
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[" ", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LikelihoodFokkeralt[Theta_,Y_,time_,dt_,f_,g_,X_,seed_,ns_,Prozess_]:= 
(***************************************************************)
Module[{th,smooth,lik},
\tPrint[\"*LikelihoodFokkeralt, seed = \",seed,\"  Prozess = \",Prozess];
\tsmooth = .1;
\tth = {Theta,smooth}//Flatten;
\tSeedRandom[seed];
\tti = time/dt + 1;
\tXi = Map[Take[X,#]&,Delta[ti,ti,List,-1]];
\tdichte = 
\t\tMapThread[
\t\t\tFeynmanKacFokker[#1,#2,f,g,{v,0},h,#3,th,Prozess,ns,dt]&,
\t\t\t\t{Drop[Y,-1],Drop[Y,1],Xi}];
\tlik = Apply[Plus,Log[dichte]];
\tlik
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)\t\
\t\t 
ScoreFokker[Theta_,Y_,time_,dt_,f_,g_,X_,dw_]:=
(***************************************************************)\t\t\t 
(* NUMERISCHER SCORE *)
Module[{INC = $MachineEpsilon//Sqrt,i,u,LIK,LIKI,INC1,SNUM,Thetai},
(*INC = 10.^-2;*)
Print[\"*ScoreFokker INC = \",INC];
LIK = LikelihoodFokker[Theta,Y,time,dt,f,g,X,dw];
INC = INC Abs[Theta];
INC1=1/INC;
SNUM = {};
Do[ 
    Thetai=Theta//Flatten;
    Thetai[[i]]=Thetai[[i]]+INC[[i]];
    
    LIKI = LikelihoodFokker[Thetai,Y,time,dt,f,g,X,dw];
    SNUM = Append[SNUM,(LIKI-LIK)*INC1[[i]]]
    
  ,{i,Length[Theta]} ];
  
{SNUM,LIK}
]\
\>", "Input",
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)\t\
\t\t 
ScoreFokker2[Theta_,Y_,time_,dt_,f_,g_,X_,dw_]:=
(***************************************************************)\t\t\t 
(* NUMERISCHER SCORE  2-seitig*)
Module[{INC = $MachineEpsilon^(1/3),i,u,LIK,LIKI,INC1,SNUM,
\t\tThetaiup,Thetaido},

LIK = LikelihoodFokker[Theta,Y,time,dt,f,g,X,dw];
INC = INC Abs[Theta];
INC1=1/(2INC);
SNUM = {};
Do[ 
    Thetaiup=Theta//Flatten;
    Thetaido=Theta//Flatten;
    Thetaiup[[i]]=Thetaiup[[i]]+INC[[i]];
    Thetaido[[i]]=Thetaido[[i]]-INC[[i]];
    
    LIKIup = LikelihoodFokker[Thetaiup,Y,time,dt,f,g,X,dw];
\tLIKIdo = LikelihoodFokker[Thetaido,Y,time,dt,f,g,X,dw];
    SNUM = Append[SNUM,(LIKIup-LIKIdo)*INC1[[i]]]
    
  ,{i,Length[Theta]} ];
  
{SNUM,LIK}
]\
\>", "Input",
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
GRIDIJ[PSI_,I_,J_,HI_,HJ_]:= Module[{OUT},
(***************************************************************)
OUT = PSI;
OUT[[I]] = OUT[[I]] + HI[[I]];
OUT[[J]] = OUT[[J]] + HJ[[J]];
OUT
]\
\>", "Input",
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
GRIDI[PSI_,I_,HI_]:= Module[{OUT},
(***************************************************************)
OUT = PSI;
OUT[[I]] = OUT[[I]] + HI[[I]];
OUT
]\
\>", "Input",
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["GRIDI[{1,2,3},2,{.1,.2,.4}]", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1, 2.2, 3}\
\>", "\<\
{1, 2.2, 3}\
\>"], "Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["GRIDIJ[{1,2,3},2,3,{.1,.2,.4},{.1,.2,.1}]", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1, 2.2, 3.1}\
\>", "\<\
{1, 2.2, 3.1}\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}]}, Open]],

Cell["\<\
(***************************************************************)
HesseFokker[Theta_,Y_,time_,dt_,f_,g_,X_,dw_]:=
(***************************************************************)
(* NUMERISCHE HESSE-MATRIX MIT NUMERISCHEM SCORE:*)
(* ZENTRALE DIFFERENZEN *)


Module[{LIK,L2,INC = $MachineEpsilon^(1/3),INK,INK2,H4,H,
\t\tLIJ,LIMJ,LIJM,LIMJM,L2I,LM2I,I,J},

U    = Length[Theta];
LIK  = LikelihoodFokker[Theta,Y,time,dt,f,g,X,dw];
L2   = 2 LIK;
INK  = INC Abs[Theta];
INK2 = 2 INK;
H4   = .25/Outer[Times,INK,INK];

H = Shape[0,{U,U}];

Do[ 

{LIJ,LIMJ,LIJM,LIMJM} = 
\tMap[LikelihoodFokker[#,Y,time,dt,f,g,X,dw]&,
\t\t\t{GRIDIJ[Theta ,I,J,  INK,  INK],
\t\t\t GRIDIJ[Theta ,I,J,  INK, -INK],
\t\t\t GRIDIJ[Theta ,I,J, -INK,  INK],
\t\t\t GRIDIJ[Theta ,I,J, -INK, -INK]
\t\t\t }];
\t
    H[[I,J]] = LIJ - LIMJ - LIJM + LIMJM;
    
,{I,1,U},{J,I+1,U}];

H = H + Transpose[H];

Do[ 

{L2I,LM2I} = 
\tMap[LikelihoodFokker[#,Y,time,dt,f,g,X,dw]&,
\t\t\t{GRIDI[Theta ,I, INK2],
\t\t\t GRIDI[Theta ,I,-INK2]
\t\t\t }];
    H[[I,I]] = L2I - L2 + LM2I;
    
,{I,1,U}];

H = H H4;
{H,LIK}
]
\
\>", "Input",
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\


(***************************************************************)\t\t\t 
BFGSUP[F_,SNEU_,S_,STEP_] := Module[{ETA,MACHEPS2,Y,FSTEP,A,B,Fup},
(***************************************************************)\t\t\t 
ETA = 10^-4; (*NOISE LEVEL*)
MACHEPS2 = 10.^-8;
Y = -SNEU+S;
FSTEP = F.STEP;
A = Y.STEP;
If[ A < MACHEPS2 Max[Abs[STEP]] Max[Abs[Y]], Return[F]  ];
If[ Max[Abs[Y-FSTEP]] < ETA, Return[F]  ];
A=1/A;
B = 1/(STEP.FSTEP);
Print[\"*BFGSUP \", A,\"  \", B];
Fup = F + Outer[Times, A Y ,Y] - Outer[Times,B FSTEP,FSTEP];
(*Fup=.5 (F+Transpose[Fup] *)
Fup
]\
\>", "Input",
  CellMargins->{{3, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{1, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
MatPrint[F_]:=
(***************************************************************)
  Print[NumberForm[F//MatrixForm,4,NumberSigns->{\"-\",\" \"}]];\
\>", "Input",\

  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LikTest[LIKNEU_]:=
(***************************************************************)
\tIf[(LIKNEU//NumberQ//Not)||(Im[LIKNEU]!=0)||(LIKNEU>10.^10),
\t \tPrint[\"LIKNEU = \",LIKNEU,\" reset to -10.^10\"]; -10.^10,
\t \t\tLIKNEU]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)\t\
\t\t 
BFGSFokker//Clear
BFGSFokker[THETA0_,F0_,KMAX_,EPS_,Y_,time_,dt_,X_,P_,Q_,T_,
\t\t\tOPTION_,mue_,sigma_,
\t\t\tf_,g_,PRINT_,seed_,$n$_]:= 
(***************************************************************)\t\t\t 
Module[{INC,MAXSTEP,MINSTEP,BOUND,ALPHA,u,THETA,F,
        S,LIKALT,LIKI,psii,STEPL,STEP,
        LIKNEU,SNEU,likpsi,COV,k,LIKELI,TT},
INC=10.^-5;
MAXSTEP=10.^-1;
MINSTEP=10.^-10;
BOUND=10.^-6;
ALPHA=10.^-4;
stepreduce = 3;

{p,r} = g[ Y[[1]],X[[1]],THETA0 ]//Dimensions;
SeedRandom[seed];
TT = Max[Delta[time]]/dt + 1//Ceiling;
dw = Table[UniC[],{nn,$n$},{tt,TT},{rr,r}] Sqrt[dt];

(*Kern-Funktion*)
h[S_,t_,Theta_] := GaussDichte[S,{0,Theta//Last} ]//N;

If[PRINT[[1]] == 1,
Print[\"***********************LSDE1**********************************\"];
Print[\"***********************MODUL: BFGSFokker *********************\"];
Print[\"**************************************************************\"];
Print[\"Technical Output\"];
VecPrint[{KMAX,EPS,P,Q,T,OPTION,MAXSTEP,
\t\t  MINSTEP,BOUND,stepreduce}//Spalte,
         {\"KMAX\",\"EPS\",\"P\",\"Q\",\"T\",\"OPTION\",\"MAXSTEP\",
         \"MINSTEP\",\"BOUND\",\"stepreduce\"}];
Print[ \"\"];
Print[ \"STARTWERT THETA0 = \", THETA0]
];

u = Length[THETA0];

THETA=THETA0;
F=F0;
If[OPTION == 1, F = SHIFT[F,BOUND] ];

{S,LIKALT} = ScoreFokker[THETA0,Y,time,dt,f,g,X,dw]; 
LIKI = {}; psii = {};

DoUntil[{KK,KMAX}, Max[Abs[S]]<EPS && Max[Abs[STEP]]<EPS,
 \t
\tIf[PRINT[[2]] == 1,
\tPrint[\"-----------------------------------------------------------------\"]\
;
    Print[\"BFGSFokker: Iteration = \",KK];
    ];
    
    LIKI=Append[LIKI,LIKALT];
    psii=Append[psii,THETA];
    
 \tSTEP=LinearSolve[F,S];

    (*BEGRENZUNG DER SCHRITTL\[CapitalADoubleDot]NGE*)
    STEPL=Max[Abs[STEP]];
    STEP=STEP*Min[1,MAXSTEP/STEPL];

    (*STEP-Reduction*)
   
    THETA1 = THETA + STEP;   (*VOLLER NEWTON-STEP*)
    
  \tLIKNEU = LikelihoodFokker[THETA1,Y,time,dt,f,g,X,dw];
\t\t\t  \t\t\t
   \tLIKNEU = LikTest[LIKNEU];
   \t 
    DoWhile[{half,100}, (LIKNEU<LIKALT+ALPHA*(S.STEP) &&
          \t\t\t\t Max[Abs[STEP]]>MINSTEP),
         STEP=STEP/stepreduce;
         THETA1 = THETA + STEP; 
         
         LIKNEU = LikelihoodFokker[THETA1,Y,time,dt,f,g,X,dw];
\t\t\t  \t\t
\t\t LIKNEU = LikTest[LIKNEU];
\t  \t\t
\t\t If[PRINT[[3]] == 1,
         Print[\"STEP-HALVING:  \",half,
         \t\t\t\"  LIKNEU  \", PaddedForm[LIKNEU,{20,15}],
         \t\t\t\"  LIKALT  \", PaddedForm[LIKALT,{20,15}]];
         ];
     ]; (*End DoWhile*)
     
\t
\tIf[PRINT[[4]] == 1,
    Print[\"LIKNEU  \", PaddedForm[LIKNEU,{20,15}],\"      \",
          \"LIKALT  \", PaddedForm[LIKALT,{20,15}] ];
    Print[\"LIKNEU - LIKALT  \",PaddedForm[LIKNEU-LIKALT,{20,15}] ];
    ];
    Print[\"\"];
  
    If[PRINT[[5]] == 1, 
    Print[MatrixForm[{THETA1,THETA,STEP,S}//Transpose,
    \t  TableHeadings->{Automatic,{\"THETA1\",\"THETA\",\"STEP\",\"SCORE\"}}]
    \t  ]];
    
    If[PRINT[[6]] == 1,
    Print[\"\"];
    MatPrint[F];
    ];
       
    {SNEU,LIKALT} = ScoreFokker[THETA1,Y,time,dt,f,g,X,dw];
    (* BFGS-UPDATE *)
    F = BFGSUP[F,SNEU,S,STEP];
    S = SNEU;
    
    THETA = THETA1;
    k = KK;

];

If[PRINT[[7]] == 1,
Print[ \"BFGSFokker:  ENDE DER ITERATION  \",k,\"  \",KMAX] ];

LIKI = Append[LIKI,LIKALT]; psii = Append[psii,THETA];
likpsi = Spalte[LIKI]~ii~psii;

If[PRINT[[8]] == 1,
Print[MatrixForm[likpsi,
\t\tTableHeadings->{Automatic,{\"Likelihood\",\"THETA\"}} ]];
];
\t\t\t\t\t

If[Fisher,

\t{F,LIKELI} = HesseFokker[THETA,Y,time,dt,f,g,X,dw];\t
\tF=-F;
\t
\tCOV = OUTPUT[THETA,F,.05,S,LIKELI];
\tLKOMP[LIKELI,u,(T+1)];
\t
,(* else *)
\tCOV = Inverse[F]; (* BFGS-UPDATE!!*)
];

{THETA,COV,likpsi,k}

]\
\>", "Input",
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
FeynmanKacFokkerDemo//Clear
FeynmanKacFokkerDemo[x_,y_,s_,t_,f_,g_,{v_,0},h_,X_,Theta_,Prozess_,n_,T_]:=
\t(*allgemeiner Fall*) 
\tModule[{c,dt,yy,traj,dens},
\t
\tdt  = (t-s)/T //N;
\tPrint[\"{n,T,dt} = \", {n,T,dt}];
\tSt = Table[RungeKutta[f,g,x,X,T,dt,Theta,Prozess,EulerStep],{nn,1,n}];
\tST = Map[Last,St,{1}];
\tx2 = Map[h[yy-#1,X//Last,Theta]&,ST];
\tx2 = Apply[Plus,x2]/n //N;
\tsm = smoothQuickAndDirty[ST];sm//Print;
\t
\tdens = Plot[x2/.smooth->sm//Evaluate,{yy,-6,6},
\t\t\tPlotRange->{All,{0,.7}},
\t\t\tDisplayFunction->Identity];
\t\t
\ttraj = plot1[flatten[St//Transpose,{2,3}]//AddTimeAxis[#,{s,t,dt}]&,
\t\t\tDisplayFunction->Identity,
\t\t\tfarbmodell->Hue,
\t\t\tdicke->.001,
\t\t\tPlotRange->{All,{-6,6}}];
\t\t\t
\t{dens,traj}
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
(***************************************************************)
LikelihoodFokkerDemo//Clear
LikelihoodFokkerDemo[Theta_,Y_,time_,f_,g_,h_,X_,ns_,Ts_,Prozess_]:= 
(***************************************************************)
Module[{th,dens,traj,data},
\tPrint[\"*LikelihoodFokker\"];
\t
\tsmooth//Clear;
\tth = {Theta,smooth}//Flatten;
\t
\tgg = 
\tMapThread[
\tFeynmanKacFokkerDemo[#1,#2,#3,#4,f,g,{v,0},h,X,th,Prozess,ns,Ts]&,
\t{Drop[Y,-1],Drop[Y,1],Drop[time,-1],Drop[time,1]}];
\t
\t{dens,traj} = gg//Transpose;
\t
\tdata = plot1[Spalte[time]~ii~Y,PlotJoined->False,
\t\t\tdicke ->.01,color->{10},DisplayFunction->Identity];
\t\t\t
\tShow[traj,data,DisplayFunction->$DisplayFunction];
\tfill = {Indeterminate};
\tShow[GraphicsArray[Partition[{dens,fill}//Flatten,2]],DisplayFunction->$\
DisplayFunction];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\


RungeKutta1//Clear
RungeKutta1[f_,g_,Y0_,{X_,dw_},T_,dt_,Theta_,Step_] :=
\tFoldList[ Step[f,g,#1,#2,Theta,dt]&,Y0,{Take[X,T],Take[dw,T]}//Transpose]
 

EulerStep1//Clear
EulerStep1[f_,g_,y_,{t_,dw_},Theta_,dt_] :=
      y + f[y,t,Theta] dt + g[y,t,Theta].dw\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
HeunStep1//Clear
HeunStep1[f_,g_,y_,{t_,dw_},Theta_,dt_] :=
\tModule[{f1,g1,t1,f2,g2},
\t\tf1 = f[y,t,Theta];
\t\tg1 = g[y,t,Theta];
\t
\t\ty1 = y + f1 dt + g1.dw; (* Euler-Pr\[ADoubleDot]diktor *)
\t\tt1 = t + dt;
\t\tf2 = f[y1,t1,Theta];
\t\tg2 = g[y1,t1,Theta];
\t\t
        y + 0.5 ( (f1 + f2) dt + (g1 + g2).dw )
 \t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
RungeKutta4Step1//Clear
RungeKutta4Step1[f_,g_,y_,{t_,dw_},Theta_,dt_]:=
\tModule[{f0,f1,f2,f3,g0,g1,g2,g3,t1,t3,dth,dwh,y1,y2,y3},
\t\tf0 = f[y,t,Theta];
\t\tg0 = g[y,t,Theta];
\t\tdwh = dw/2;
\t\tdth = dt/2;
\t\t
\t\tt1 = t + dth;
\t\ty1 = y + f0 dth + g0.dwh;
\t\tf1 = f[y1,t1,Theta];
\t\tg1 = g[y1,t1,Theta];
\t\t
\t\ty2 = y + f1 dth + g1.dwh;
\t\tf2 = f[y2,t1,Theta];
\t\tg2 = g[y2,t1,Theta];
\t\t
\t\ty3 = y + f2 dt + g2.dw;
\t\tt3 = t + dt;
\t\tf3 = f[y3,t3,Theta];
\t\tg3 = g[y3,t3,Theta];
\t\t
        y + (f0 + 2f1 + 2f2 + f3) dt/6. + (g0 + 2g1 + 2g2 + g3).dw/6. 
 \t] 
      \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
RungeKutta1Lik//Clear
RungeKutta1Lik[fg_,Y0_,{X_,dw_},T_,dt_,Theta_,Step_] :=
\tBlock[{y,l},
\t{y,l}=FoldList[ Step[fg,#1,#2,Theta,dt]&,{Y0,0},
\t                {Take[X,T],Take[dw,T]}//Transpose]//Transpose;
\t{y,l//Last}
\t]
 

EulerStep1Lik//Clear
EulerStep1Lik[fg_,{y_,l_},{t_,dw_},Theta_,dt_] := 
Module[{f,G,gdw,Omega,lik},
\t
\t{f,G} = fg[y,t,Theta];  
\tgdw = G.dw;
\tOmega = G.Transpose[G]*dt; 
\tlik = -.5(Log[Det[Omega]] + gdw.Inverse[Omega].gdw);
\t
    {y + f dt + gdw,l+lik}
    
    ]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
smoothQuickAndDirty[ST_]:= 
\t(Varianz[ST]//First//VecDiag//Max) Length[ST]^(-2/5) //N\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\

GaussDichte1[x_,{mue_,sigma_,sigma1_}]:= 
\tModule[{z = x-mue},
\t(*{GaussDichte1,x,mue}//Print; *)
\tDet[2 Pi sigma]^(-.5) Exp[-.5 z.sigma1.z]//N
\t];

EulerTransitionDensity//Clear
EulerTransitionDensity[y_,x_,f_,g_,t_,dt_,Theta_]:= 
\t Module[{gg,omega,sigma,sigma1},
\t gg = g[x,t,Theta];
\t omega = gg.Transpose[gg];
\t sigma = omega dt;
\t sigma1 = Inverse[sigma];
\t gg = GaussDichte1[y,{x + f[x,t,Theta]dt,sigma,sigma1}];
\t (*{gggg,y,x,sigma,sigma1}//Print;*)
\t gg
\t ];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell[TextData[{
  "\nLogEulerTransitionDensity//Clear\n\
LogEulerTransitionDensity[y_,x_,f_,g_,t_,dt_,Theta_]:= \n     (*Konstante \
-p/2 Log[2Pi] und Jacobi weggelassen\n       Jacobi f\[ADoubleDot]llt bei \
Likelihood-Quotient p1/p2 weg*)\n\t \
Module[{gg,omega,sigma,sigma1,out,y1,Jacobi,dy},\n\t gg = g[x,t,Theta];\n\t \
omega = gg.Transpose[gg];\n\t sigma = omega dt;\n\t sigma1 = Inverse[sigma];\n\
\t y1 = x + f[x,t,Theta]dt;\n\t dy = y-y1;\n\t \t(*Jacobi = Log[Det[sigma]]*)\
\n\t \t(*out = -.5(  Jacobi +  dy.sigma1.dy );*)\n\t \n\t out = -.5 \
dy.sigma1.dy;\n\t out\n\t ];\n\t \n\t \nEulerDensity//Clear\n",
  StyleBox["EulerDensity",
    FontColor->RGBColor[1, 0, 0]],
  "[Y_,f_,g_,time_,dt_,Theta_]:=\nModule[{p,out},\n p = \
EulerTransitionDensity[#1,#2,f,g,#3,dt,Theta]&;\n out = \
Apply[Times,MapThread[p,{Drop[Y,1],Drop[Y,-1],Drop[time,-1]}]];\n \
(*{Theta,out,Y}//Print;*)\n out\n ]\n\nLogEulerDensity//Clear\n",
  StyleBox["LogEulerDensity",
    FontColor->RGBColor[1, 0, 0]],
  "[Y_,f_,g_,time_,dt_,Theta_]:=\nModule[{p,out},\n p = \
LogEulerTransitionDensity[#1,#2,f,g,#3,dt,Theta]&;\n out = \
Apply[Plus,MapThread[p,{Drop[Y,1],Drop[Y,-1],Drop[time,-1]}]];\n out\n ]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \
\"Jacobi\" is similar to existing symbol \"JacobiP\".\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}]}, Open]],

Cell[TextData[{
  "loglikelihoodRatio//Clear\n",
  StyleBox["loglikelihoodRatio",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,x_,{f1_,f2_},g_,t_,dt_,Theta_]:=\n \
Module[{G,omega,omega1,out,Jacobi,dy,F1,F2,F12},\n\t G = g[x,t,Theta];\n\t \
omega = G.Transpose[G];\n\t omega1 = Inverse[omega];\n\t F1 = f1[x,t,Theta];\n\
\t F2 = f2[x,t,Theta];\n\t F12 = (F1-F2).omega1; \t\n\t dy = y-x;\n\t   \
(*F12.dy - .5 F12.(F1+F2) dt*)\n\t F12.( dy - (.5 dt)(F1+F2) )  \n\t \n\t ];\n\
\nloglikelihoodRatio1//Clear\n",
  StyleBox["loglikelihoodRatio1",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,x_,{f1_,f2_},g_,t_,dt_,Theta_]:=\n \
Module[{G,omega,omegaI,dy,dy1,dy2,F1,F2},\n\t G = g[x,t,Theta];\n\t omega = \
G.Transpose[G];\n\t omegaI = Inverse[omega];\n\t F1 = f1[x,t,Theta];\n\t F2 = \
f2[x,t,Theta]; \n\t dy = y-x;\n\t dy1 = dy - F1 dt;\n\t dy2 = dy - F2 dt;\n\t \
-(0.5/dt)(dy1.omegaI.dy1 - dy2.omegaI.dy2)  \n\t ];\n\t \n\
loglikelihoodRatio2//Clear\n",
  StyleBox["loglikelihoodRatio2",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,x_,{f1_,f2_},{g1_,g2_},t_,dt_,Theta_]:=\n \
Module[{G1,G2,omega1,omega2,omega1I,omega2I,dy,dy1,dy2,F1,F2},\n\t G1 = \
g1[x,t,Theta];\n\t omega1 = G1.Transpose[G1];\n\t omega1I = Inverse[omega1];\n\
\t G2 = g2[x,t,Theta];\n\t omega2 = G2.Transpose[G2];\n\t omega2I = \
Inverse[omega2];\n\t F1 = f1[x,t,Theta];\n\t F2 = f2[x,t,Theta];\n\t dy = \
y-x;\n\t dy1 = dy - F1 dt;\n\t dy2 = dy - F2 dt;\n\t -(0.5)(  (  \
dy1.omega1I.dy1     - dy2.omega2I.dy2)/dt \n\t           + \
Log[Det[omega1]/Det[omega2]] ) \n\t ];\n\n\nloglikelihood//Clear\n",
  StyleBox["loglikelihood",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,x_,f1_,g1_,t_,dt_,Theta_]:=\n Module[{G1,omega1,omega1I,dy,dy1,F1},\n\t\
 G1 = g1[x,t,Theta];\n\t omega1 = G1.Transpose[G1]*dt;\n\t omega1I = \
Inverse[omega1];\n\t \n\t F1 = f1[x,t,Theta];\n\t \n\t dy = y-x;\n\t dy1 = dy \
- F1 dt;\n\t \n\t -0.5*(  dy1.omega1I.dy1 + Log[Det[omega1]] ) \n\t ];\n\t \n\
\t \t \t \t \nLogLikelihoodRatio//Clear\n",
  StyleBox["LogLikelihoodRatio",
    FontColor->RGBColor[1, 0, 0]],
  "[Y_,{f1_,f2_},g_,time_,dt_,Theta_]:=\nModule[{p,out},\n p = \
loglikelihoodRatio1[#1,#2,{f1,f2},g,#3,dt,Theta]&;\n (* Y//Dimensions//Print; \
*)\n If[Length[Y]<=1, 0, (* else *)\n \
Apply[Plus,MapThread[p,{Drop[Y,1],Drop[Y,-1],Drop[time,-1]}]]\n ]\n ]\n \n\
LogLikelihoodRatio2//Clear\n",
  StyleBox["LogLikelihoodRatio2",
    FontColor->RGBColor[1, 0, 0]],
  "[Y_,{f1_,f2_},{g1_,g2_},time_,dt_,Theta_]:=\nModule[{p,out},\n p = \
loglikelihoodRatio2[#1,#2,{f1,f2},{g1,g2},#3,dt,Theta]&;\n \
Apply[Plus,MapThread[p,{Drop[Y,1],Drop[Y,-1],Drop[time,-1]}]]\n ]\n \n\
LogLikelihood//Clear\n",
  StyleBox["LogLikelihood",
    FontColor->RGBColor[1, 0, 0]],
  "[Y_,f1_,g1_,time_,dt_,Theta_]:=\nModule[{p,out},\n p = \
loglikelihood[#1,#2,f1,g1,#3,dt,Theta]&;\n \
Apply[Plus,MapThread[p,{Drop[Y,1],Drop[Y,-1],Drop[time,-1]}]]\n ]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
WienerDensity//Clear
WienerDensity[Y_,a_,G_,dt_]:=
Module[{p,omega,sigma,sigma1},
 omega = G.Transpose[G];
 sigma = omega dt;
 sigma1 = Inverse[sigma];
 p = GaussDichte[#,{a dt,sigma,sigma1}]&;
 Apply[Times,Map[p,Delta[Y]] ]
 ]   \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "\nImportanceSampler//Clear\n",
  StyleBox["ImportanceSampler",
    FontColor->RGBColor[1, 0, 0]],
  "[h_,p1_,p2_,Y2_,t_,{Theta1_,Theta2_,Theta3_},\n                  \
log_:False]:=\n\tModule[{m,s,n,y,F},\n\t\n\tIf[Not[log],\n\tF = \
If[(p1[#,t,Theta1]&) =!= (p2[#,t,Theta2]&),\n\t\n\t\t      \
Print[\"ImportanceSampler h p1/p2\"]; \n\t\t      h[#,t,Theta3] \
p1[#,t,Theta1]/p2[#,t,Theta2]&,\n\t\t      \n\t       \
Print[\"ImportanceSampler h\"]; \n\t       h[#,t,Theta3]&\n\t      ];\n\t     \
 \n\t,(*else*)     \n\tF = If[(p1[#,t,Theta1]&) =!= (p2[#,t,Theta2]&),\n\t\n\t\
\t      Print[\"ImportanceSampler h Exp(p1 - p2)\"]; \n\t\t      \
h[#,t,Theta3]* Exp[ p1[#,t,Theta1]- p2[#,t,Theta2] ]&,\n\t\t      \n\t       \
Print[\"ImportanceSampler h\"]; \n\t       h[#,t,Theta3]&\n\t      ]; \n\t];  \
        (*F//Print;*)\n\t \n\ty = Map[F,Y2];\n\t{m,s} = y//MS;\n\tn = \
Length[Y2];\n\t{m,s/Sqrt[n]} //N\n\t];\n\nWienerSampler//Clear\n",
  StyleBox["WienerSampler",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,y_,f_,g_,h_,X_,{Theta1_,Theta2_,Theta3_},$dw$_,dt_]:=\n\t(*mit \
gegebenen Zufallszahlen dw*)\n\t \n\tModule[{T},\n\tn = $dw$//Length;\n\tT = \
Length[X]-1;\n\n Clear[a,b,p1,p2];\n\n a[yy_,t_,Theta_] :=  Theta[[1]];\n \
b[yy_,t_,Theta_] :=  Theta[[2]];\n \n p1 = EulerDensity [#1,f,g,#2,dt,#3]&;\n \
p2 = WienerDensity[#1,Theta2[[1]],Theta2[[2]],dt]&; \n \n\t (*Y2 = \
Map[RungeKutta1[a,b,x,{X,#},T,dt,Theta2,EulerStep1]&,$dw$];*)\n\tY2 = \
Map[WienerProzess1[Theta2[[1]],Theta2[[2]],x,dt,#]&,$dw$];\n\n If[$SMOOTH$,sm \
= smoothQuickAndDirty[Y2//Transpose//Last],\n \t\t\t\t\t\t\t\t\t\t  sm = \
Indeterminate];\n \t\t\t\t\t\t\t\t\t\t  \n Print[\"WienerSampler {n,T,dt,sm} \
= \", {n,T,dt,N[sm,12]}];\n\n ImportanceSampler[h,",
  StyleBox["p1,p2",
    FontColor->RGBColor[1, 0, 0]],
  ",Y2,X,{Theta1,Theta2,Append[Theta3,sm]} ]\n \n\t]\t"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "EulerSampler//Clear\n",
  StyleBox["EulerSampler",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,y_,f_,g_,h_,X_,{Theta1_,Theta3_},$dw$_,dt_]:=\n\t(*mit gegebenen \
Zufallszahlen dw*)\n\t \n\tModule[{T},\n\tn = $dw$//Length;\n\tT = \
Length[X]-1;\n \n\tY1 = \
Map[RungeKutta1[f,g,x,{X,#},T,dt,Theta1,EulerStep1]&,$dw$];\n\t\n \
If[$SMOOTH$,sm = smoothQuickAndDirty[Y2//Transpose//Last],\n \t\t\t\t\t\t\t\t\
\t\t  sm = Indeterminate];\n \n Print[\"EulerSampler  {n,T,dt,sm} = \", \
{n,T,dt,N[sm,12]}];\n \n ImportanceSampler[h,",
  StyleBox["1,1",
    FontColor->RGBColor[1, 0, 0]],
  ",Y1,X,{_,_,Append[Theta3,sm]} ]\n\n\t]\t"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "ItoSampler//Clear\n\
ItoSampler[x_,y_,f_,g_,h_,X_,{Theta1_,Theta2_,Theta3_},$dw$_,dt_]:=\n\t(*mit \
gegebenen Zufallszahlen dw*)\n\t \n\tModule[{T},\n\t\n\tn = $dw$//Length;\n\t\
T = Length[X]-1;\n\n Clear[p1,p2];\n\n p1 = EulerDensity[#1,f,g,#2,dt,#3]&;\n \
p2 = EulerDensity[#1,f,g,#2,dt,#3]&;\n \n\tY2 = \
Map[RungeKutta1[f,g,x,{X,#},T,dt,Theta2,EulerStep1]&,$dw$];\n\t\n \
If[$SMOOTH$,sm = smoothQuickAndDirty[Y2//Transpose//Last],\n \t\t\t\t\t\t\t\t\
\t\t  sm = Indeterminate];\n \n Print[\"ItoSampler {n,T,dt,sm} = \", \
{n,T,dt,N[sm,12]}];\n \n ImportanceSampler[h,",
  StyleBox["p1,p2",
    FontColor->RGBColor[1, 0, 0]],
  ",Y2,X,{Theta1,Theta2,Append[Theta3,sm]} ]\n \n\t]\t "
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "LogItoSampler//Clear\n\
LogItoSampler[x_,y_,f_,g_,h_,X_,{Theta1_,Theta2_,Theta3_},$dw$_,dt_]:=\n\t\
(*mit gegebenen Zufallszahlen dw*)\n\t \n\tModule[{T},\n\t\n\tn = \
$dw$//Length;\n\tT = Length[X]-1;\n\n Clear[p1,p2];\n\n p1 = \
LogEulerDensity[#1,f,g,#2,dt,#3]&;\n p2 = LogEulerDensity[#1,f,g,#2,dt,#3]&;\n\
 \n\tY2 = Map[RungeKutta1[f,g,x,{X,#},T,dt,Theta2,EulerStep1]&,$dw$];\n\t\n \
If[$SMOOTH$,sm = smoothQuickAndDirty[Y2//Transpose//Last],\n \t\t\t\t\t\t\t\t\
\t\t  sm = Indeterminate];\n \n Print[\"LogItoSampler {n,T,dt,sm} = \", \
{n,T,dt,N[sm,12]}];\n \n ImportanceSampler[h,",
  StyleBox["p1,p2",
    FontColor->RGBColor[1, 0, 0]],
  ",Y2,X,{Theta1,Theta2,Append[Theta3,sm]},True]\n \n\t]\t "
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
WienerProzess1//Clear
WienerProzess1[a_,B_,x_,dt_,dW_]:= 
\tCumulativeSums[Join[{x},Map[a dt + Dot[B,#]&,dW]]]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
WienerProzess2//Clear
WienerProzess2[a_,B_,x_,dt_,dW_]:= 
    Module[{T = Length[dW]},
\tMap[Plus[x+a#]&,Range[0,T dt,dt]] + 
\t\tJoin[{0},CumulativeSums[Map[Dot[B,#]&,dW]]]]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["WienerProzess1[{1},{{.1}},x,dt,10//Range//Spalte]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
 {0.08333333333333331483*Second, {x, {0.3 + x}, {0.7 \
+ x}, {1.2 + x}, {1.8 + x}, {2.5 + x}, {3.3 + x}, {4.2 + x}, {5.2 + x}, 
  {6.3 + x}, {7.5 + x}}}\
\>", "\<\
 {0.0833333 Second, {x, {0.3 + x}, {0.7 + \
x}, {1.2 + x}, {1.8 + x}, {2.5 + x}, {3.3 + x}, {4.2 + x}, {5.2 + x}, {6.3 + \
x}, 
  {7.5 + x}}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["WienerProzess2[{1},{{.1}},x,dt,10//Range//Spalte]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
 {0.0999999999999999778*Second, {{x}, {0.3 + x}, \
{0.7 + x}, {1.2 + x}, {1.8 + x}, {2.5 + x}, {3.3 + x}, {4.2 + x}, {5.2 + x}, 
  {6.3 + x}, {7.5 + x}}}\
\>", "\<\
{0.1 Second, {{x}, {0.3 + x}, {0.7 + x}, \
{1.2 + x}, {1.8 + x}, {2.5 + x}, {3.3 + x}, {4.2 + x}, {5.2 + x}, {6.3 + x}, \
{7.5 + x}}}\
\>"], "Output",
  InitializationCell->True,
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]}, Open]]}, Open]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 626},
WindowMargins->{{137, Automatic}, {-8, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
0000001804P000000bd2=_oaoo43?095o`85N@?NW0002008ool000001@050001
0000I24A4R060`410@000BL?0040000000000000000004E3<34100;o00000001
000A0S<R<3`00Q3400018NOWinOWia4A\>"
]


(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1763, 53, 99, 2, 70, "Section",
  InitializationCell->True],
Cell[1865, 57, 1065, 37, 70, "Input",
  InitializationCell->True],
Cell[2933, 96, 637, 23, 70, "Input",
  InitializationCell->True],
Cell[3573, 121, 611, 21, 70, "Input",
  InitializationCell->True],
Cell[4187, 144, 80, 2, 70, "Input",
  InitializationCell->True],
Cell[4270, 148, 689, 20, 70, "Input",
  InitializationCell->True],
Cell[4962, 170, 863, 28, 70, "Input",
  InitializationCell->True],
Cell[5828, 200, 983, 31, 70, "Input",
  InitializationCell->True],
Cell[6814, 233, 459, 13, 70, "Input",
  InitializationCell->True],
Cell[7276, 248, 420, 12, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[7719, 262, 106, 2, 70, "Input",
  InitializationCell->True],
Cell[7828, 266, 138, 6, 70, "Output",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[7998, 274, 120, 2, 70, "Input",
  InitializationCell->True],
Cell[8121, 278, 144, 7, 70, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[8277, 287, 1289, 55, 70, "Input",
  InitializationCell->True],
Cell[9569, 344, 770, 24, 70, "Input",
  InitializationCell->True],
Cell[10342, 370, 300, 8, 70, "Input",
  InitializationCell->True],
Cell[10645, 380, 380, 9, 70, "Input",
  InitializationCell->True],
Cell[11028, 391, 3954, 148, 70, "Input",
  InitializationCell->True],
Cell[14985, 541, 840, 28, 70, "Input",
  InitializationCell->True],
Cell[15828, 571, 906, 29, 70, "Input",
  InitializationCell->True],
Cell[16737, 602, 347, 13, 70, "Input",
  InitializationCell->True],
Cell[17087, 617, 409, 16, 70, "Input",
  InitializationCell->True],
Cell[17499, 635, 673, 28, 70, "Input",
  InitializationCell->True],
Cell[18175, 665, 609, 25, 70, "Input",
  InitializationCell->True],
Cell[18787, 692, 173, 5, 70, "Input",
  InitializationCell->True],
Cell[18963, 699, 568, 21, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[19554, 722, 1262, 23, 70, "Input",
  InitializationCell->True],
Cell[20819, 747, 174, 4, 70, "Message"]
}, Open  ]],
Cell[21005, 753, 2972, 56, 70, "Input",
  InitializationCell->True],
Cell[23980, 811, 317, 12, 70, "Input",
  InitializationCell->True],
Cell[24300, 825, 1944, 33, 70, "Input",
  InitializationCell->True],
Cell[26247, 860, 715, 16, 70, "Input",
  InitializationCell->True],
Cell[26965, 878, 780, 15, 70, "Input",
  InitializationCell->True],
Cell[27748, 895, 799, 15, 70, "Input",
  InitializationCell->True],
Cell[28550, 912, 197, 6, 70, "Input",
  InitializationCell->True],
Cell[28750, 920, 261, 8, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[29034, 930, 108, 1, 70, "Input"],
Cell[29145, 933, 404, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29581, 946, 108, 1, 70, "Input"],
Cell[29692, 949, 425, 11, 70, "Output",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)
