(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    297545,      11145]*)
(*NotebookOutlinePosition[    308734,      11486]*)
(*  CellTagsIndexPosition[    306684,      11422]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
RESAMPLING = True;
FDIGITS = Round[-Log[10,$MachineEpsilon]];
TYP = 1;
YMAX = 10^8.;
ANALGRAD = False;
FACTOR = 1.0;
MAXSTEP=0.1;
CSEED=-999;
SCALING=1;
STEPREDUCE = 4;
FISHER=False;
PRINT={1,1,1,1,1,1,1,1}
OVERFLOW=False;
SHIFT$=10^-16;

\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    \({1, 1, 1, 1, 1, 1, 1, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
<<KernDichte.m
<<Feynman.Fokker.impl.ma
<<Momente.multi.m\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["Clear::wrsym: Symbol F is Protected.", "Message",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
SetDelayed::write: Tag F in F[mm_, {f_, Omega_}, Gauss_:True] is \
Protected.\
\>", "Message",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utilities", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["divers", "Subsubsection",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
box[cmin_,c_,cmax_] := 
\tMapThread[Flatten[List[#1+First[#2],#2,#3+Last[#2]]]&,{cmin,c,cmax}]

box1[cmin_,c_,cmax_] := 
\tMapThread[Flatten[List[#1,#2,#3]]&,{cmin,c,cmax}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
\t
cuts[S_,t_,Theta_] :=  (*geordnete cuts!!*)
\tModule[{c1},
\tc1 = Take[Theta,-5];
\tc1 = (c1//First) + FoldList[Plus,0,Abs[c1]//Rest];
\tbox[cmin,{c1},cmax]
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\

cutoffs1//Clear
cutoffs1[z_,c_]:= c[[{z,z+1}]]

cutoffs//Clear
cutoffs[z_,c_] := MapThread[cutoffs1[#1,#2]&,{z,c}]\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
messind//Clear
(***************************************************************)\t\t\t 
messind[ZM_,MISS_] := Locate[Map[any,unsameq[ZM,MISS]],True]
(***************************************************************)\t\t\t 

(***************************************************************)\t\t\t 
messind1[ZM_,MISS_] := Complement[ Range[Length[ZM]],
                       Locate[ Map[all,ZM~eq~MISS], True]
                       ]
(***************************************************************)

missings[z_,miss_,op_]:=Apply[op,Map[(#===miss)&,z]]
CaseDel[Z_,miss_]:=Select[Z,Not[missings[#,miss,Or]]&]
CaseDel1[X_,m_]:=X[[Locate[Map[(And@@#)&,Map[(#=!=m)&,X,{2}]]]]]\t
\t\t \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
smoothQuickAndDirty1[ST_]:= 
(***************************************************************)\t\t\t 
\tModule[{m,s,sm},
\t{m,s} =  ST//MS1;
\tsm = (s//Max)^2 Length[ST]^(-2/5) //N;
\t{sm,m,s}]
\t
(***************************************************************)\t\t\t 
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
Modus = \"Fix\"; (*Voreinstellung*)
AutomaticGrid//Clear
(***************************************************************)\t\t\t 
AutomaticGrid[Theta_,{m_,s_,nstd_},{Z_,Modus_},{y1_,y2_,dy_}]:= 
(***************************************************************)\t\t\t 
Module[{y1s,y2s,dys,c},
Which[  Modus == \"Ordinal\",

\t\tc = cuts[_,X,Theta]; 
\t\t{y1s,y2s} = cutoffs[Z,c]//Transpose//N;
\t\tdys = dy
\t\t 
\t\t,Modus == \"Automatic\",
\t
\t\ty1s = m-nstd s;
\t\ty2s = m+nstd s;
\t\tdys = dy
\t\t
\t\t,Modus == \"Fix\",
\t\t
\t\t{y1s,y2s,dys} = {y1,y2,dy} (*fixes Gitter*)
\t\t
  ];
\t\t
Print[\"Gitter:\",{Modus,y1s,y2s,dys,Z}];
{y1s,y2s,dys}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
chi[{Z_,Y_,X_},Theta_,{h_,R_}] := 
(***************************************************************)\t\t\t 
\tModule[{z = Z-h[Y,X,Theta]},
\tExp[- z.Inverse[R].z]
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
Over[y_,MAX_]:= 
(***************************************************************)\t\t\t 
Block[{ov,max,y1},
ov  = Position[y,Overflow[]];
max = Position[y,x_/;Abs[x]>MAX];
y1 = ReplacePart[y ,0,max];
y1 = ReplacePart[y1,0,ov];
If[y=!=y1, Print[\"Warnung: Overflow\", i]];
y1
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
Over[y_,MAX_,i_]:= 
(***************************************************************)\t\t\t 
Block[{ov,max,y1},
ov  = Position[y,Overflow[]];
max = Position[y,x_/;Abs[x]>MAX];
y1 = ReplacePart[y ,0,max];
y1 = ReplacePart[y1,0,ov];
If[y=!=y1, Print[\"Warnung: Overflow\", i];OVERFLOW=True];
{y1,OVERFLOW}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
InverseStepFunction[y_,yi_]:= 
(***************************************************************)\t\t\t 
\tModule[{out},
\tout = Position[le[yi,y],True];
\tout = If[out == {},0,out//Last//First]
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
CompressData[Z_,miss_]:= Module[{ti},
(***************************************************************)\t\t\t 
\tti  = messind[Z,miss];
\tti  = Union[ti,{1,Length[Z]}];
\t{Z[[ti]],ti}]

ExpandData//Clear
(***************************************************************)\t\t\t 
ExpandData[{Z_,ti_},miss_]:= Module[{Tc,k,T1,ZE},
(***************************************************************)\t\t\t 
\t{Tc,k} = Z//Dimensions;
\t T1    = ti//Last;
\t
\tZE = Shape[miss,{T1,k}];
\tMap[ (ZE[[ti[[#]] ]]=Z[[#]])&,Tc//Range];
\t
\tZE
\t
\t]\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
ExpandData[{Zi_,ti_,dt_},miss_]:=
(***************************************************************)\t\t\t 
Module[{Z},
(* voller Datensatz *)
\t{T1,k}=Zi//Dimensions;
\tIf[OrderedQ[ti]//Not,Print[\"ti not ordered \",ti];Return[{}]];
\tj =ti/dt;
\tj= j - Min[j] + 1//Rationalize;
\tZ = Shape[miss,{j//Last,k}];
\tDo[Z[[ j[[i]] ]]=Zi[[i]],{i,1,T1}];
\tZ]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
SampleData[Z_,select_,miss_]:=
(***************************************************************)\t\t\t 
Module[{ZM},
ZM = Shape[miss,Z//Dimensions];
Map[(ZM[[#]] = Z[[#]])&,select];
ZM
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["SampleData[{{{aa}},bb,{cc}},{2,3},-9]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{-9, bb, {cc}}\
\>", "\<\
{-9, bb, {cc}}\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
IdPlusA[A_] := Block[{out,p},
\t\tp = Length[A];
\t\tout = A; 
\t\tDo[out[[i,i]] = out[[i,i]]+1 ,{i,p}];
\t\tout]
\t\t
IdPlusA[vec_,A_] := Block[{out,p},
\t\tp = Length[A];
\t\tout = A; 
\t\tDo[out[[i,i]] = out[[i,i]]+vec[[i]] ,{i,p}];
\t\tout]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
Symmetrize[A_]:=0.5(A+Transpose[A]);
\t  \
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Symmetrize[{{1,2},{3,4}}]", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{{1., 2.5}, {2.5, 4.}}\
\>", "\<\
{{1., 2.5}, {2.5, \
4.}}\
\>"], "Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["UKF utilities", "Subsubsection",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
Shift[H_,BOUND_,Text_:\"\"] := Module[{H1,EIGEN,MINI,COND,minabs},
(***************************************************************)
EIGEN=Eigenvalues[H];
MINI=Min[EIGEN];

minabs=Min[Abs[EIGEN]];
COND=If[minabs=!=0,Max[Abs[EIGEN]]/minabs,Infinity];

If[MINI<BOUND,
Print[Text,i,\"Shift:Warnung:kleine EIGENWERTE der Kovarianz-MATRIX: \", 
\t\t\t\tEIGEN,\"  BOUND  \",BOUND//N];
H1=H+DiagonalMatrix[Array[(BOUND-MINI)&,{Length[H]}]], 
H1 = H ];
Return[H1]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Shift[I2,10^1]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{10, 0}, {0, 10}}\
\>", "\<\
{{10, 0}, {0, \
10}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "SigmaSample//Clear\n",
  StyleBox["SigmaSample",
    FontColor->RGBColor[1, 0, 0]],
  "[mue_, Sigma_, kappa_]:=\nModule[{Gamma,p,pk,pk2,alpha0,alpha,x1,x2},\n\n\
(*Print[\"",
  StyleBox["SigmaSample",
    FontColor->RGBColor[1, 0, 0]],
  "\",Sigma,\"Eigenwerte\",Sigma//Eigenvalues];*)\n\n\
Gamma=CholeskyDecomposition[Sigma]; (*Zeilen*)\np=mue//Length;\n\n\
pk=(p+kappa);\npk2=pk//Sqrt;\nalpha0=kappa/pk;\nalpha=1/(2 pk);\n\n\
x1=Map[(mue + pk2#)&,Gamma];\nx2=Map[(mue - pk2#)&,Gamma];\n\n\
{Join[{mue},x1,x2],{alpha0,Table[alpha,{i,2p}]}//Flatten}\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SigmaSample[{1, 2}, I2, 0] // N\)], "Input"],

Cell[BoxData[
    \({{{1.`, 2.`}, {2.414213562373095`, 2.`}, {1.`, 
          3.414213562373095`}, {\(-0.41421356237309515`\), 2.`}, {1.`, 
          0.5857864376269049`}}, {0.`, 0.25`, 0.25`, 0.25`, 
        0.25`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "SigmaSample2//Clear\n",
  StyleBox["SigmaSample2",
    FontColor->RGBColor[1, 0, 0]],
  "[mue_, Sigma_, kappa_,tau_]:=\n\
Module[{Gamma,p,pk,pk2,alpha0,alpha,alpha1,alpha2,x1,x2,x3,x4},\n\n\
Gamma=CholeskyDecomposition[Sigma]; (*Zeilen*)\np=mue//Length;\n\n\
pk=(p+kappa);\npk2=pk//Sqrt;\nalpha0= (2pk-p*(1+1/tau^2))/(2pk);\nalpha=1/(2 \
pk);\nalpha1=alpha/2;\nalpha2=alpha1/tau^2;\n\nx1=Map[(mue + pk2#)&,Gamma];\n\
x2=Map[(mue - pk2#)&,Gamma];\n\npk2=tau pk2;\nx3=Map[(mue + pk2#)&,Gamma];\n\
x4=Map[(mue - pk2#)&,Gamma];\n\n\
{Join[{mue},x1,x2,x3,x4],{alpha0,Table[alpha1,{i,2p}],Table[alpha2,{i,2p}]}//\
Flatten}\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "WeightedMean//Clear\n",
  StyleBox["WeightedMean",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,alpha_]:=Apply[Plus,x alpha];\n"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "WeightedVariance//Clear",
  StyleBox["\nWeightedVariance",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,alpha_]:=\nModule[{mean},\n\nmean=Apply[Plus,x alpha];\n\n\
Apply[Plus,alpha Map[Outer[Times,#,#]&,x]]- Outer[Times,mean,mean]\n\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "WeightedMeanAndVariance//Clear\n",
  StyleBox["WeightedMeanAndVariance",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,alpha_]:=\nModule[{mean,var,xx},\n\nmean=Apply[Plus,x alpha];\n\n\
(*xx=Map[Outer[Times,#,#]&,x];*)\n\
(*xx=Table[Outer[Times,x[[i]],x[[i]]],{i,x//Length}];*)\n\
xx=MapThread[Outer[Times,#1,#2]&,{x,x}];\n\nvar=Apply[Plus,alpha xx]- \
Outer[Times,mean,mean];\n\n(*xx//Clear;*)\n\n{mean,var}\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "WeightedMeanAndVariance1//Clear\n",
  StyleBox["WeightedMeanAndVariance1",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,alpha_]:=\nModule[{mean,var,xx},\n\nmean=alpha.x;\n\n\
(*xx=Map[Outer[Times,#,#]&,x];*)\n\
(*xx=Table[Outer[Times,x[[i]],x[[i]]],{i,x//Length}];*)\n\
xx=MapThread[Outer[Times,#1,#2]&,{x,x}];\n\nvar=alpha.xx- \
Outer[Times,mean,mean];\n\n(*xx//Clear;*)\n\n{mean,var}\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["WeightedMeanAndVariance",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,y_,alpha_]:=\nModule[{meanx,meany,covxy},\n\nmeanx=Apply[Plus,x \
alpha];\nmeany=Apply[Plus,y alpha];\ncovxy=Apply[Plus,alpha \
MapThread[Outer[Times,#1,#2]&,{x,y}]]\n                               - \
Outer[Times,meanx,meany];\n\n{meanx, meany, covxy}\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["WeightedMeanAndVarianceSpezial//Clear\n\
WeightedMeanAndVarianceSpezial",
    FontColor->RGBColor[1, 0, 0]],
  "[x_,meanx_,y_,alpha_]:=\nModule[{meany,covxy,covyy},\n\nmeany=Apply[Plus,y \
alpha];\ncovyy=Apply[Plus,alpha Map[Outer[Times,#,#]&,y]]\n                   \
      - Outer[Times,meany,meany];\n\ncovxy=Apply[Plus,alpha \
MapThread[Outer[Times,#1,#2]&,{x,y}]]\n                               - \
Outer[Times,meanx,meany];\n\n{meany, covyy, covxy}\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["Gauss-Hermite", "Subsubsection",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussIntegral//Clear
GaussIntegral[f_,{mue_,Sigma_},{a_,b_},Genau_]:=
(***************************************************************)
Module[{p=mue//Length,y,yy,iter,phi,i,z,Sigma1,int},

yy=Array[y,p];
iter=Apply[Sequence,Table[{y[i],a[[i]],b[[i]]},{i,p}]];
z=yy-mue;
Sigma1=Sigma//Inverse;
(*Print[Genau];*)
int=NIntegrate[f[yy]Exp[-0.5*z.Sigma1.z],iter//Evaluate,
\t\t\t\tMethod->GaussKronrod,
\t\t\t\tAccuracyGoal->Genau,
\t\t\t\tMaxPoints->Automatic];
    
int*GaussFaktor[Sigma]
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussIntegral1//Clear
GaussIntegral1[f_,{mue_,Sigma_},{a_,b_},Genau_]:=
(***************************************************************)
Module[{p=mue//Length,y,yy,iter,phi,i,z,Sigma1,int,Gamma},

zz=Array[z,p];
iter=Apply[Sequence,Table[{z[i],a,b},{i,p}]];

(*Print[Genau];*)
Gamma=Sigma//CholeskyDecomposition//Transpose;

int=NIntegrate[f[mue+Gamma.zz]Exp[-0.5*zz.zz],iter//Evaluate,
\t\t\t\tMethod->GaussKronrod,
\t\t\t\tAccuracyGoal->Genau,
\t\t\t\tMaxPoints->Automatic];
    
int*(2Pi)^(-p/2)
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermitePoints//Clear
GaussHermitePoints[m_]:=
(***************************************************************)
Module[{superdiag,null,JJ,vals,vecs,weight},

Print[\"Genauigkeit x^\",2m-1];

superdiag=Sqrt[Range[m-1]/2]//N;
null=Shape[0,m];
JJ=TridiagonalMatrix[{superdiag,null,superdiag}];
{vals,vecs}=JJ//Eigensystem;
weight=vecs[[All,1]]^2;

{vals,weight}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermitePoints1//Clear
GaussHermitePoints1[m_,text_:0]:=
(***************************************************************)
Module[{superdiag,null,JJ,vals,vecs,weight},

If[text===1,Print[\"Genauigkeit x^\",2m-1]];

superdiag=Sqrt[Range[m-1]]//N; (*ohne 1/2; Gewicht N(0,1)*)
null=Shape[0,m];
JJ=TridiagonalMatrix[{superdiag,null,superdiag}];
{vals,vecs}=JJ//Eigensystem;
weight=vecs[[All,1]]^2;

{vals,weight}//Transpose//Sort//Transpose
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["GaussHermitePoints1[5]\n",
  FontWeight->"Plain"]], "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["Genauigkeit x^9", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{{-2.8569700138728042, -1.355626179974266, 0., \
1.355626179974266, 2.8569700138728042}, {0.011257411327720688, \
0.22207592200561252, 0.5333333333333331, 0.22207592200561252, \
0.011257411327720694}}\
\>", "\<\
{{-2.85697, -1.35563, 0., 1.35563, \
2.85697}, {0.0112574, 0.222076, 0.533333, 0.222076, 0.0112574}}\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
(***************************************************************)
GaussHermitePointsMulti//Clear
GaussHermitePointsMulti[m_,{mue_,Sigma_}]:=
(***************************************************************)
Module[{Gamma,vals,weight,n},

n=mue//Length; 
(*n//Print;*)

{vals,weight}=GaussHermitePoints1[m];

vals  = Sequence@@Table[  vals,{i,n}];
weight= Sequence@@Table[weight,{i,n}];

Gamma = CholeskyDecomposition[Sigma]//Transpose;

vals  =Outer[(mue+Gamma.List[##])&,vals]; (*Transf. Stutzstellen*)
weight=Outer[Times,weight];

{vals,weight}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermitePointsMulti2//Clear
GaussHermitePointsMulti2[m_,n_,eps_:10.^-16,ksigma_:Infinity,text_:0]:=
(***************************************************************)
(* Gewicht N(0,1) !!*)
Module[{vals1,weight1,sel},

{vals1,weight1}=GaussHermitePoints1[m];

sel=Position[Map[(Abs[#]<ksigma)&,vals1],True]//Flatten;
vals1=vals1[[sel]];
weight1=weight1[[sel]];

vals1  = tupel[vals1,n];   
weight1= tupel[weight1,n,Times]; 
sel=Position[Map[(#>eps)&,weight1],True]//Flatten;


If[text===1,

Print[\"Genauigkeit x^\",2m-1,\"; \",
      \"Stuetzstellen: \",m^n,\"; weight > \",eps//N, 
      \" und |vals| < \", ksigma, \": \",sel//Length]
 ];
      
(*weight1//Print;*)

{vals1,weight1}={vals1[[sel]],weight1[[sel]]};

weight1=weight1/Plus@@weight1; (*Normierung auf 1*)

{vals1,weight1}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
{vals,weight}=GaussHermitePointsMulti2[100,1,10^-4];
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Genauigkeit x^199
Stuetzstellen:100; weight > 0.0001 und |vals| < Infinity: 24\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["plot1[{vals//Flatten,weight}//Transpose,PlotJoined->False]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["Dimension der Daten  {24, 2}", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.131412 0.0147151 4.76545 [
[.10576 -0.0125 -6 -9 ]
[.10576 -0.0125 6 0 ]
[.23718 -0.0125 -6 -9 ]
[.23718 -0.0125 6 0 ]
[.36859 -0.0125 -6 -9 ]
[.36859 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63141 -0.0125 -3 -9 ]
[.63141 -0.0125 3 0 ]
[.76282 -0.0125 -3 -9 ]
[.76282 -0.0125 3 0 ]
[.89424 -0.0125 -3 -9 ]
[.89424 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11002 -24 -4.5 ]
[-0.0125 .11002 0 4.5 ]
[-0.0125 .20533 -24 -4.5 ]
[-0.0125 .20533 0 4.5 ]
[-0.0125 .30064 -24 -4.5 ]
[-0.0125 .30064 0 4.5 ]
[-0.0125 .39595 -24 -4.5 ]
[-0.0125 .39595 0 4.5 ]
[-0.0125 .49126 -18 -4.5 ]
[-0.0125 .49126 0 4.5 ]
[-0.0125 .58657 -24 -4.5 ]
[-0.0125 .58657 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10576 0 m
.10576 .00625 L
s
[(-3)] .10576 -0.0125 0 1 Mshowa
.23718 0 m
.23718 .00625 L
s
[(-2)] .23718 -0.0125 0 1 Mshowa
.36859 0 m
.36859 .00625 L
s
[(-1)] .36859 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63141 0 m
.63141 .00625 L
s
[(1)] .63141 -0.0125 0 1 Mshowa
.76282 0 m
.76282 .00625 L
s
[(2)] .76282 -0.0125 0 1 Mshowa
.89424 0 m
.89424 .00625 L
s
[(3)] .89424 -0.0125 0 1 Mshowa
.125 Mabswid
.13205 0 m
.13205 .00375 L
s
.15833 0 m
.15833 .00375 L
s
.18461 0 m
.18461 .00375 L
s
.21089 0 m
.21089 .00375 L
s
.26346 0 m
.26346 .00375 L
s
.28974 0 m
.28974 .00375 L
s
.31602 0 m
.31602 .00375 L
s
.34231 0 m
.34231 .00375 L
s
.39487 0 m
.39487 .00375 L
s
.42115 0 m
.42115 .00375 L
s
.44744 0 m
.44744 .00375 L
s
.47372 0 m
.47372 .00375 L
s
.52628 0 m
.52628 .00375 L
s
.55256 0 m
.55256 .00375 L
s
.57885 0 m
.57885 .00375 L
s
.60513 0 m
.60513 .00375 L
s
.65769 0 m
.65769 .00375 L
s
.68398 0 m
.68398 .00375 L
s
.71026 0 m
.71026 .00375 L
s
.73654 0 m
.73654 .00375 L
s
.78911 0 m
.78911 .00375 L
s
.81539 0 m
.81539 .00375 L
s
.84167 0 m
.84167 .00375 L
s
.86795 0 m
.86795 .00375 L
s
.07948 0 m
.07948 .00375 L
s
.0532 0 m
.0532 .00375 L
s
.02692 0 m
.02692 .00375 L
s
.00063 0 m
.00063 .00375 L
s
.92052 0 m
.92052 .00375 L
s
.9468 0 m
.9468 .00375 L
s
.97308 0 m
.97308 .00375 L
s
.99937 0 m
.99937 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11002 m
.00625 .11002 L
s
[(0.02)] -0.0125 .11002 1 0 Mshowa
0 .20533 m
.00625 .20533 L
s
[(0.04)] -0.0125 .20533 1 0 Mshowa
0 .30064 m
.00625 .30064 L
s
[(0.06)] -0.0125 .30064 1 0 Mshowa
0 .39595 m
.00625 .39595 L
s
[(0.08)] -0.0125 .39595 1 0 Mshowa
0 .49126 m
.00625 .49126 L
s
[(0.1)] -0.0125 .49126 1 0 Mshowa
0 .58657 m
.00625 .58657 L
s
[(0.12)] -0.0125 .58657 1 0 Mshowa
.125 Mabswid
0 .03854 m
.00375 .03854 L
s
0 .06237 m
.00375 .06237 L
s
0 .0862 m
.00375 .0862 L
s
0 .13385 m
.00375 .13385 L
s
0 .15768 m
.00375 .15768 L
s
0 .18151 m
.00375 .18151 L
s
0 .22916 m
.00375 .22916 L
s
0 .25299 m
.00375 .25299 L
s
0 .27681 m
.00375 .27681 L
s
0 .32447 m
.00375 .32447 L
s
0 .3483 m
.00375 .3483 L
s
0 .37212 m
.00375 .37212 L
s
0 .41978 m
.00375 .41978 L
s
0 .44361 m
.00375 .44361 L
s
0 .46743 m
.00375 .46743 L
s
0 .51509 m
.00375 .51509 L
s
0 .53891 m
.00375 .53891 L
s
0 .56274 m
.00375 .56274 L
s
0 .6104 m
.00375 .6104 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10576 .61178 m
.10576 .61803 L
s
.23718 .61178 m
.23718 .61803 L
s
.36859 .61178 m
.36859 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63141 .61178 m
.63141 .61803 L
s
.76282 .61178 m
.76282 .61803 L
s
.89424 .61178 m
.89424 .61803 L
s
.125 Mabswid
.13205 .61428 m
.13205 .61803 L
s
.15833 .61428 m
.15833 .61803 L
s
.18461 .61428 m
.18461 .61803 L
s
.21089 .61428 m
.21089 .61803 L
s
.26346 .61428 m
.26346 .61803 L
s
.28974 .61428 m
.28974 .61803 L
s
.31602 .61428 m
.31602 .61803 L
s
.34231 .61428 m
.34231 .61803 L
s
.39487 .61428 m
.39487 .61803 L
s
.42115 .61428 m
.42115 .61803 L
s
.44744 .61428 m
.44744 .61803 L
s
.47372 .61428 m
.47372 .61803 L
s
.52628 .61428 m
.52628 .61803 L
s
.55256 .61428 m
.55256 .61803 L
s
.57885 .61428 m
.57885 .61803 L
s
.60513 .61428 m
.60513 .61803 L
s
.65769 .61428 m
.65769 .61803 L
s
.68398 .61428 m
.68398 .61803 L
s
.71026 .61428 m
.71026 .61803 L
s
.73654 .61428 m
.73654 .61803 L
s
.78911 .61428 m
.78911 .61803 L
s
.81539 .61428 m
.81539 .61803 L
s
.84167 .61428 m
.84167 .61803 L
s
.86795 .61428 m
.86795 .61803 L
s
.07948 .61428 m
.07948 .61803 L
s
.0532 .61428 m
.0532 .61803 L
s
.02692 .61428 m
.02692 .61803 L
s
.00063 .61428 m
.00063 .61803 L
s
.92052 .61428 m
.92052 .61803 L
s
.9468 .61428 m
.9468 .61803 L
s
.97308 .61428 m
.97308 .61803 L
s
.99937 .61428 m
.99937 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11002 m
1 .11002 L
s
.99375 .20533 m
1 .20533 L
s
.99375 .30064 m
1 .30064 L
s
.99375 .39595 m
1 .39595 L
s
.99375 .49126 m
1 .49126 L
s
.99375 .58657 m
1 .58657 L
s
.125 Mabswid
.99625 .03854 m
1 .03854 L
s
.99625 .06237 m
1 .06237 L
s
.99625 .0862 m
1 .0862 L
s
.99625 .13385 m
1 .13385 L
s
.99625 .15768 m
1 .15768 L
s
.99625 .18151 m
1 .18151 L
s
.99625 .22916 m
1 .22916 L
s
.99625 .25299 m
1 .25299 L
s
.99625 .27681 m
1 .27681 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .3483 m
1 .3483 L
s
.99625 .37212 m
1 .37212 L
s
.99625 .41978 m
1 .41978 L
s
.99625 .44361 m
1 .44361 L
s
.99625 .46743 m
1 .46743 L
s
.99625 .51509 m
1 .51509 L
s
.99625 .53891 m
1 .53891 L
s
.99625 .56274 m
1 .56274 L
s
.99625 .6104 m
1 .6104 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
[( )] .97619 .01557 0 0 Mshowa
.01 w
.02381 .01557 Mdot
.06562 .01728 Mdot
.10732 .02165 Mdot
.14892 .03166 Mdot
.19043 .05213 Mdot
.23186 .08941 Mdot
.27322 .14964 Mdot
.31453 .23535 Mdot
.35579 .34153 Mdot
.39702 .45337 Mdot
.43822 .54838 Mdot
.47941 .60332 Mdot
.52059 .60332 Mdot
.56178 .54838 Mdot
.60298 .45337 Mdot
.64421 .34153 Mdot
.68547 .23535 Mdot
.72678 .14964 Mdot
.76814 .08941 Mdot
.80957 .05213 Mdot
.85108 .03166 Mdot
.89268 .02165 Mdot
.93438 .01728 Mdot
.97619 .01557 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[R000`400?l00000o`00003ooooooolK
ooooo`00oooooolKooooo`00oooooolKooooo`00oooooolKooooo`00=oooool3o`0001gooooo1Ol0
000Mooooo`?o00007Oooool2o`0001kooooo0ol0000Mooooo`Go00007_ooool3o`0001_ooooo000f
ooooo`05o`000?ooooooooooooooool000007Oooool01?l0003oooooooooool0000Nooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`0Mooooo`04
o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`00000Jooooo`00<?ooool5o`00
00Gooooo00?o0000ooooooooool05?ooool5o`0000?ooooo00?o0000ooooooooool05_ooool5o`00
00?ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`00>?ooool2o`00
023ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0001kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o00006oooool0
03[ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01cooooo00Go
0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo01Sooooo000fooooo`05o`000?oo
ooooooooooooool000007?ooool01Ol0003ooooooooooooooooo000001gooooo0_l0000Mooooo`04
o`000?ooooooooooo`0001gooooo0_l0000Nooooo`05o`000?ooooooooooooooool000007Oooool0
1Ol0003ooooooooooooooooo000001[ooooo000gooooo`?o00007_ooool3o`0001oooooo00?o0000
ooooooooool07?ooool2o`0001oooooo00?o0000ooooooooool07Oooool3o`0001oooooo0ol0000K
ooooo`00oooooolKooooo`00oooooolKooooo`00oooooolKooooo`00oooooolKooooo`006oooooon
o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
0?[ooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`;o00000oooool2o`00
oo3ooooo0_l00?l3ooooo`;o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`02ooooo`;o003o2Oooool2o`00om[ooooo0_l00?l9ooooo`;o003o1?ooool1o`00
007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03Oooool2o`00
o`Sooooo0_l00?o5ooooo`;o003o2Oooool2o`00o`oooooo0Ol00001ooooo`004oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo01Oooooo0_l00?o5ooooo`;o003o6_ooool1o`00
007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0Rooooo`;o003o/?ooool2o`00obCo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`;o003o/?ooool2o`00obCooooo
0Ol00001ooooo`006oooool2o`000?[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`3j
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0/ooooo`;o003o
Voooool2o`00oboooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0/ooooo`;o003oVooo
ool2o`00oboooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool0
01_ooooo0_l0003jooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool2o`0003Sooooo0_l00?n6ooooo`;o
003o>?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo03Oooooo0_l00?n6ooooo`;o003o
>Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooo
oooo0?[ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3jooooo`7o0000
0Oooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0n_ooool1o`00007ooooo00001Ooooooo0000
oooooooooooo000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`;o0000n_ooool2o`00007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0n_oo
ool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0n_ooool1o`00007o
oooo0002ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?[ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0n_ooool1o`00007ooooo000Kooooo`;o0000n_ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0@Oooool2o`00og7ooooo0_l00?m4ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0@Oooool2o`00og7ooooo0_l00?m4ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`;o0000n_ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o
00000Oooool001_ooooo0_l0003jooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0n_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`000_ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo
0?[ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3jooooo`7o00000Oooool0
0005ooooool0003oooooooooool000002?ooool01Ol0003oooooooooool0003ooooo00Go00001?oo
ool00ol0003oooooooooo`3jooooo`7o00000Oooool00005ooooool0003oooooooooool000002?oo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool2o`000?[o
oooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`3jooooo`7o00000Oooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00003ooooo`;o00001Oooool0
0ol0003oooooooooo`3jooooo`7o00000Oooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo
000Kooooo`;o0000n_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo04cooooo0_l00?mL
ooooo`;o003oC_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04cooooo0_l00?mLoooo
o`;o003oC_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_oo
ool1o`00007ooooo000Kooooo`;o0000n_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
0?[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo0_l0003joooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo0?[ooooo0Ol00001ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`0000Goooooo`000?oooooo
ooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`;o0000n_ooool2o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03
o`000?oooooooooo0?[ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3joooo
o`7o00000Oooool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo0_l0003jooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0E_ooool2o`00odOooooo0_l00?mIooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0E_ooool2o`00odOooooo0_l00?mIooooo`7o00000Oooool001_ooooo0_l0003joooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
0?[ooooo0Ol00001ooooo`006oooool2o`000?[ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`000_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?[ooooo0Ol00001oooo
o`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`;o0000n_ooool2o`00007ooooo00001Ooooooo0000oooooooooooo000000So
oooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool0n_ooool1o`00
007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo0002ooooo`;o0000
2_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo0_l0003jooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001
ooooo`006oooool2o`000?[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0HOooool2o`00oc;ooooo0_l00?mSooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0HOooool2o`00oc;ooooo0_l00?mSooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
0?[ooooo0Ol00001ooooo`006oooool2o`000?[ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0n_ooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3joooo
o`7o00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04oooo
o`;o0000n_ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3jooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?[ooooo0Ol00001oooo
o`001oooool01?l0003oooooooooool00008ooooo`;o00001_ooool00ol0003oooooooooo`3joooo
o`7o00000Oooool000Sooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006ooo
ool2o`000?[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo0?[o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`;o0000n_ooool2o`00007ooooo000Koooo
o`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3jooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0Joooool2o`00oagooooo0_l00?m^ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0Joooool2o`00oagooooo0_l00?m^ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Kooooo`;o0000n_ooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`3jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo0002
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000Cooooo00?o0000
ooooooooool0n_ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?[ooooo0Ol0
0001ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool2o`000?[ooooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`00
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3jooooo`7o00000Oooool00005ooooool0003oooooooooool000002Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3jooooo`7o0000
0Oooool00005ooooool0003oooooooooool000002?ooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`000_ooool2o`0000[ooooo
00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0M_ooool2o`00o`Sooooo
0_l00?mhooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0M_ooool2o`00o`Sooooo0_l0
0?mhooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Koooo
o`;o00006Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Fooooo`;o00000Oooool001_oooooo_l00001ooooo`00
oooooolKooooo`00oooooolKooooo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-4.61986, -0.0148233, 0.0299946, \
0.00082713}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
(***************************************************************)
Shift[H_, BOUND_, Text_:\"\"] :=
(***************************************************************) 
Module[{H1, EIGEN, MINI, COND, minabs}, 
      EIGEN = Eigenvalues[H]; MINI = Min[EIGEN]; minabs = Min[Abs[EIGEN]]; 
      COND = If[minabs =!= 0, Max[Abs[EIGEN]]/minabs, Infinity]; 
      If[MINI < BOUND, 
      Print[Text, i, \"Shift:Warnung:kleine EIGENWERTE der Kovarianz-MATRIX: \
\", 
         EIGEN, \"  BOUND  \", N[BOUND]]; 
      H1 = H + DiagonalMatrix[Array[BOUND - MINI &, {Length[H]}]], 
      H1 = H]; 
      Return[H1]];\
\>", "Print",
  PageWidth->Infinity,
  Evaluatable->True,
  InitializationCell->True,
  GeneratedCell->False,
  CellAutoOverwrite->False,
  FontSize->14,
  CellTags->"Info3416806370-7050022"],

Cell["\<\
(***************************************************************)
TrafoMueSigma//Clear
TrafoMueSigma[vals_,{mue_,Sigma_},shift_:0]:=
(***************************************************************)
Module[{Gamma,vals1},

Gamma = If[shift==0,
           CholeskyDecomposition[Sigma//Symmetrize]//Transpose,
           CholeskyDecomposition[Shift[Sigma//Symmetrize,shift]]//Transpose];

vals1 = Map[(mue+Gamma.#)&,vals]; (*Transf. Stuetzstellen*)

vals1
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermite2//Clear
GaussHermite2[g_,{vals_,weight_}]:=weight.Map[g,vals]
(***************************************************************)\
\>", \
"Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermiteA//Clear
GaussHermiteA[g_,m_,{mue_,Sigma_}]:=
(***************************************************************)
Module[{Gamma,z,n,superdiag,null,JJ,vals,vecs,weight,g1},
n=mue//Length; 
(*n//Print;*)
Print[\"Genauigkeit x^\",2m-1];

superdiag=Sqrt[Range[m-1]]//N;
null=Shape[0,m];
JJ=TridiagonalMatrix[{superdiag,null,superdiag}];
{vals,vecs}=JJ//Eigensystem;
weight=vecs[[All,1]]^2;

weight=Sequence@@Table[weight,{i,n}];

Gamma = CholeskyDecomposition[Sigma]//Transpose;

g1//Clear;
g1[z_]:= g[mue+Gamma.(z)];
vals  = Sequence@@Table[vals,{i,n}];

Flatten[Outer[Times,weight]].Flatten[Outer[g1[List[##]]&,vals]]
(*Outer[Times,weight] Outer[g1[List[##]]&,vals]/.List->Plus*)

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermite//Clear
GaussHermite[g_,m_,{mue_,Sigma_},eps_:10^-16]:=
(***************************************************************)
Module[{Gamma,z,n,superdiag,null,JJ,vals,vecs,weight,g1},
n=mue//Length; 
(*n//Print;*)

superdiag=Sqrt[Range[m-1]]//N; (*ohne Sqrt[2]!!*)
null=Shape[0,m];
JJ=TridiagonalMatrix[{superdiag,null,superdiag}];
{vals,vecs}=JJ//Eigensystem;
weight=vecs[[All,1]]^2;

weight=tupel[weight,n,Times];

sel=Position[Map[(#>eps)&,weight],True]//Flatten;

(*
Print[\"Genauigkeit x^\",2m-1,\"  Stuetzstellen:\",weight//Length,
\t\t\"  groesser \",eps//N//AccountingForm, \" :\",sel//Length];*)

Gamma = CholeskyDecomposition[Sigma]//Transpose;

vals  = tupel[vals,n];

weight[[sel]].Map[g[mue+Gamma.#]&,vals[[sel]]]


]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
GaussHermite1//Clear
GaussHermite1[g_,{vals_,weight_},{mue_,Sigma_},eps_:10^-16]:=
(***************************************************************)
Module[{Gamma,z,n,g1,vals1,weight1},
n=mue//Length; 
(*n//Print;*)

vals1  = tupel[vals,n]; 
weight1= tupel[weight,n,Times]; 
sel=Position[Map[(#>eps)&,weight1],True]//Flatten;

Gamma = CholeskyDecomposition[Sigma]//Transpose;

g1//Clear;
g1[z_]:= g[mue+Gamma.z];

weight1[[sel]].Map[g1,vals1[[sel]]]

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
TrapezFormel//Clear
(***************************************************************)
TrapezFormel[n_,{x0_,x1_}]:=
(***************************************************************)
Module[{dx,x,vals,wx,weight},

dx=(x1-x0)/n;
x=Range[x0,x1,dx];

vals=tupel1[x];

wx=Map[Shape[1,#]&,n+1];
wx[[All, 1]]=.5;
wx[[All,-1]]=.5;

dx=Times@@dx;
weight=tupel1[wx,Times]dx;

{vals,weight}

]

Needs[\"NumericalMath`GaussianQuadrature`\"]

GaussFormel[n_, {x0_, x1_}] := 
Module[{X,vals,weight},
X=MapThread[(GaussianQuadratureWeights[#1, #2, \
#3]//Transpose)&,{n,x0,x1}]//Transpose;
vals  =tupel1[X[[1]]];
weight=tupel1[X[[2]],Times];
{vals,weight}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zufalls-Zahlen", "Section",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
RandomMultinomial//Clear
(***************************************************************)\t\t\t 
RandomMultinomial[xij_,pij_,n_]:= 
(***************************************************************)\t\t\t 
\tModule[{u,U,pos,pcum,z,out},
\tpcum = CumulativeSums[{0,pij}//Flatten];
\tz = Last[pcum]; 
\t(*Print[\"RandomMultinomial: Normierung  \",z];*)
    pcum = pcum/z;
    (*U = Table[Random[],{n}];*)
    
    out = 
    Table[
\tu = Random[];
\tPrint[u];
\tpos = Position[le[u,pcum],False]//Last;
\txij[[pos]]//Flatten,
\t{n}];
\tout
\t]
\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(RandomMultinomial\\) is Protected. \\!\\(\\*ButtonBox[\\\"Mehr\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::wrsym\\\"]\\)\"\>"}]], "Message",
  PageWidth->Infinity],

Cell[BoxData[
    RowBox[{\(SetDelayed::"write"\), \(\(:\)\(\ \)\), "\<\"Tag \
\\!\\(RandomMultinomial\\) in \\!\\(RandomMultinomial[\\(\\(xij_, pij_, n_\\)\
\\)]\\) is Protected. \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::write\\\"]\\)\"\>"}]], "Message",
  PageWidth->Infinity],

Cell[BoxData[
    \($Failed\)], "Output",
  PageWidth->Infinity]
}, Open  ]],

Cell["\<\
xijpos//Clear
(***************************************************************)\t\t\t 
xijpos[u_,xij_,pcum_]:= 
(***************************************************************)\t\t\t 
Module[{pos},
pos = Position[le[u,pcum],False]//Last;
xij[[pos]]//Flatten
]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
RandomMultinomial1//Clear
(***************************************************************)\t\t\t 
RandomMultinomial1[xij_,pij_,n_,quote_:1]:= 
(***************************************************************)\t\t\t 
\tModule[{u,U,pos,pcum,z,out,i,c},
\t(*quote = True: Quotenstichprobe*)
\t
\tpcum = CumulativeSums[{0,pij}//Flatten];
\tz = Last[pcum]; 
\t(*Print[\"RandomMultinomial: Normierung  \",z];*)
    pcum = pcum/z;
    c=0.5;
    
    U= If[quote==1, (Table[i,{i,n}]-c)/n,
       (*else*) 
       If[quote==2, Table[Random[],{n}]]
       ];
    
    (*U//Print;*)
    out = Map[xijpos[#,xij,pcum]&,U];
\tout
\t]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
RandomMultinomial1[xij_,pij_,n_,quote_,seed_]:= 
(***************************************************************)\t\t\t 
\tBlock[{u,U,pos,pcum,z,out,i,c},
\t(*quote = 1: Quotenstichprobe*)
\t
\tpcum = CumulativeSums[{0,pij}//Flatten];
\tz = Last[pcum]; 
\t(* Print[\"RandomMultinomial: Normierung  \",z]; *)
    pcum = pcum/z;
    c=0.5;
    
    U= If[quote==1, (Table[i,{i,n}]-c)/n,
       (*else*) 
       If[quote==2, cRandomC[n,1,seed]//Flatten,  
       (*else*) 
       If[quote==3, c=c+.5;(Table[i,{i,n}]+(cRandomC[n,1,seed]//Flatten)-c)/n
       ]]];
       
    (* U//Print; *)
    
    out = Map[xijpos[#,xij,pcum]&,U];
\tout
\t]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
RandomNumbers//Clear
(***************************************************************)\t\t\t 
RandomNumbers[{x1_,x2_,dx_},density_,n_]:= 
(***************************************************************)\t\t\t 
Module[{range,z,xij,pij},
range = MapThread[Range[##]&,{x1,x2,dx}];
xij = Flatten[Apply[Outer[List,##]&,range],Length[range]-1];
pij = Map[density[##]&,xij] Apply[Times,dx]//Chop;

(*
Print[\"xij  \",xij];
Print[\"pij  \",pij]; 
*)

z = Apply[Plus,pij];
Print[\"RandomNumbers: Normierung  \",z];
If[z == 0,Print[\"Warnung: Gleichverteilung benutzt\"];
\t\t  Print[\"pij  \",pij]; 
\t\t  pij = pij + 1./Length[pij]; z=1];

{z,RandomMultinomial[xij,pij/z,n]}
]
\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(RandomNumbers\\) is Protected. \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\
\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::wrsym\\\"]\\)\"\>"}]], "Message",
  PageWidth->Infinity],

Cell[BoxData[
    RowBox[{\(SetDelayed::"write"\), \(\(:\)\(\ \)\), "\<\"Tag \
\\!\\(RandomNumbers\\) in \\!\\(RandomNumbers[\\(\\(\\(\\({x1_, x2_, \
dx_}\\)\\), density_, n_\\)\\)]\\) is Protected. \\!\\(\\*ButtonBox[\\\"Mehr\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::write\\\"]\\)\"\>"}]], "Message",
  PageWidth->Infinity],

Cell[BoxData[
    \($Failed\)], "Output",
  PageWidth->Infinity]
}, Open  ]],

Cell["\<\
zufall//Clear
(***************************************************************)\t\t\t 
zufall[Generator_,n_,p_,seed_,anti_]:=
(***************************************************************)\t\t\t 
Block[{eps,n1},
SeedRandom[seed];
If[anti==1,n1=n/2,n1=n];
eps=If[Generator===cGaussC,

         (*Print[Generator,{n1,p,1.0,seed}]; *)
         
         cGaussC[n1,p,1.0,seed],
         
    (*else*)
         
         (*Print[Generator];*) 
         Table[Generator//ToExpression,{nn,n1},{pp,p}]
     ];
 If[anti==1,eps=Join[eps,-eps]];
 eps
  ]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
RandomKDE//Clear
(***************************************************************)\t\t\t 
RandomKDE[data_,Generator_,n_]:=
(***************************************************************)\t\t\t 
Module[{m,sm,Y},
(* Zufallszahlen aus KDE[data] *)

{m,p}= data//Dimensions;
sm = smoothQuickAndDirtyM[data,2];
sm//Print;
Y = RandomMultinomial[data,Shape[1/m,{m}],n];
eps = Table[Generator//ToExpression,{nn,n},{pp,p}];
Z = Y + sm eps
]

(***************************************************************)\t\t\t 
RandomKDE[data_,Gewichte_,Generator_,n_]:=
(***************************************************************)\t\t\t 
Module[{m,sm,Y},
(* Zufallszahlen aus KDE[data] *)

{m,p}= data//Dimensions;
sm = smoothQuickAndDirtyM[data,2];
Print[\"sm  \",sm];
Y = RandomMultinomial[data,Gewichte,n];
eps = Table[Generator//ToExpression,{nn,n},{pp,p}];
Z = Y + sm eps
]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomKDE[{1, 1, 1} // 
        Spalte, { .1,  .3,  .6}, {{{1}}, {{1}}, {{1}}}, \
"\<Random[NormalDistribution[0,1]]\>", 12345900, 5]\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{1.3265935027538982`}, {1.158865989799143`}, {0.5546619552023664`}, \
{0.7213289525913906`}, {0.8949452152448337`}}\)], "Output"]
}, Open  ]],

Cell["\<\
(***************************************************************)\t\
\t\t 
RandomKDE[data_,Gewichte_,Cov_,Generator_,seed_,n_]:=
(***************************************************************)\t\t\t 
Module[{m,p,mm,MM,eps,Std,Z,shift},
(* Zufallszahlen aus KDE[data] *)

{m,p}= data//Dimensions;
mm = m//Range;

\t(*MM = RandomMultinomial[mm,Gewichte,n]//Flatten//Sort;*)
\t(*MM = RandomMultinomial[mm,Gewichte,n]//Flatten;*)

    (*MM = RandomMultinomial1[mm,Gewichte,n]//Flatten//Sort;*)

MM = RandomMultinomial1[mm,Gewichte,n]//Flatten;

\t(*\"----------\"//Print;*)
\t(*Gewichte//Print;*)
\t(*MM//Print;*)
\t(*Column[data,2]//MS//Print;*)

shift = 10.^-14 * IdentityMatrix[p];(*falls Cov singul\[ADoubleDot]r*)

(*eps = Table[Generator[],{nn,n},{pp,p}];*)

SeedRandom[seed];
eps = If[Generator===cGaussC,

         (*Print[Generator,{n,p,1.0,seed}]; *)
         cGaussC[n,p,1.0,seed],
         
         (*else*)
         
         (*Print[Generator];*) 
         Table[Generator//ToExpression,{nn,n},{pp,p}]
        ];
        

Std = Map[Transpose[CholeskyDecomposition[#+shift]]&,Cov];
Z   = data[[MM]] + MapThread[Dot,{Std[[MM]],eps}];

\t    (*
\t    Print[\"Std \",Std];
\t\tPrint[\"Z     \",Z];
\t\tPrint[\"MM       \",MM];
\t\tPrint[\"data     \",data[[MM]] ];
\t\tPrint[\"eps      \",eps  ];
\t\tPrint[\"Std*eps  \",MapThread[Dot,{Std[[MM]],eps}] ];
\t\t*)

\t\t(* Column[Z,2]//MS//Print; *)

Z]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
RandomKDE1[data_,Gewichte_,Cov_,eps_,seed_,quote_]:=
(***************************************************************)\t
\t\t 
Module[{n,m,p,mm,MM,Std,Z,shift},
(* Zufallszahlen aus KDE[data] *)

{m,p}= data//Dimensions;  
mm = m//Range;

\t(*MM = RandomMultinomial[mm,Gewichte,n]//Flatten//Sort;*)
\t(*MM = RandomMultinomial[mm,Gewichte,n]//Flatten;*)

    (*MM = RandomMultinomial1[mm,Gewichte,n]//Flatten//Sort;*)

SeedRandom[seed];
MM = RandomMultinomial1[mm,Gewichte,n=Length[eps],quote,seed]//Flatten;


\t(*\"----------\"//Print;      *)
\t(*Gewichte//Print;          *)
\t(*MM//Print;                *)
\t(*Column[data,2]//MS//Print;*)

shift = 10.^-14 * IdentityMatrix[p];(*falls Cov singul\[ADoubleDot]r*)
       
Std = Map[Transpose[CholeskyDecomposition[Symmetrize[#+shift]]]&,Cov];
Z   = data[[MM]] + MapThread[Dot,{Std[[MM]],eps}];

\t    (*
\t    Print[\"Std \",Std];
\t\tPrint[\"Z     \",Z];
\t\tPrint[\"MM       \",MM];
\t\tPrint[\"data     \",data[[MM]] ];
\t\tPrint[\"eps      \",eps  ];
\t\tPrint[\"Std*eps  \",MapThread[Dot,{Std[[MM]],eps}] ];
\t\t*)

\t\t(* Column[Z,2]//MS//Print; *)

Z]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
RandomKDE2[data_,Gewichte_,Cov_,eps_,seed_,quote_]:=
(***************************************************************)\t
\t\t 
Module[{n,m,p,mm,MM,Std,Z,shift},
(* Zufallszahlen aus KDE[data] *)

{m,p}= data//Dimensions;
mm = m//Range;

\t(*MM = RandomMultinomial[mm,Gewichte,n]//Flatten//Sort;*)
\t(*MM = RandomMultinomial[mm,Gewichte,n]//Flatten;*)

    (*MM = RandomMultinomial1[mm,Gewichte,n]//Flatten//Sort;*)

SeedRandom[seed];
MM = RandomMultinomial1[mm,Gewichte,n=Length[eps],quote,seed]//Flatten;

\t(*\"----------\"//Print;*)
\t(*Gewichte//Print;*)
\t(*MM//Print;*)
\t(*Column[data,2]//MS//Print;*)

shift = 10.^-14 * IdentityMatrix[p];(*falls Cov singul\[ADoubleDot]r*)
       
Std = Map[Transpose[CholeskyDecomposition[Symmetrize[#+shift]]]&,Cov];
Z   = data[[MM]] + MapThread[Dot,{Std[[MM]],eps}];

\t    (*
\t    Print[\"Std \",Std];
\t\tPrint[\"Z     \",Z];
\t\tPrint[\"MM       \",MM];
\t\tPrint[\"data     \",data[[MM]] ];
\t\tPrint[\"eps      \",eps  ];
\t\tPrint[\"Std*eps  \",MapThread[Dot,{Std[[MM]],eps}] ];
\t\t*)

\t\t(* Column[Z,2]//MS//Print; *)

{Z,MM}]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
RandomGauss//Unprotect;
RandomGauss//Clear;
RandomGauss[X_,Theta_,{mue_,sigma_},n_?IntegerQ,Generator_:\"Gauss[]\"]:=
(***************************************************************)\t\t\t 
Module[{m,s,s2},
m =   mue[X,Theta];
s = sigma[X,Theta];
s2 = CholeskyDecomposition[s];
Map[Plus[m,#]&,Table[Generator//ToExpression,{n},{Length[m]}].s2]
]

(***************************************************************)\t\t\t 
RandomGauss[mue_,sigma_,n_?IntegerQ,Generator_:\"Gauss[]\",Anti_:0]:=
(***************************************************************)\t\t\t 
Module[{s2,z},
s2 = CholeskyDecomposition[sigma];

(*Print[Generator,\"  \",Anti];*)

If[Anti==0,
\tz=Table[Generator//ToExpression,{n},{Length[mue]}],
\t(*Anti==1*)
\tz=Table[Generator//ToExpression,{n/2},{Length[mue]}];
\tz=Join[z,-z]
];

Map[Plus[mue,#]&,z.s2]
]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Protect[RandomGauss]", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    \({"RandomGauss"}\)], "Output",
  PageWidth->Infinity]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(RandomGauss[{1}, {{1}}, 10, "\<Uni[]\>"]\), "\[IndentingNewLine]", 
    \(RandomGauss[{1}, {{1}}, 10, "\<Random[]\>"]\)}], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    \({{1.2366924817785436`}, {2.042729262134644`}, {1.8072218975246805`}, \
{2.2085501386789055`}, {1.2989736159397753`}, {1.6989342173090356`}, \
{2.3623821070171793`}, {0.9611578504383423`}, {1.3720786017171194`}, \
{0.6801569662477899`}}\)], "Output",
  PageWidth->Infinity],

Cell[BoxData[
    \({{1.116577033731075`}, {1.6163939296297003`}, {1.093365626468109`}, \
{1.3730343983067372`}, {1.5467413064615367`}, {1.8714526197609778`}, \
{1.6249011424639612`}, {1.6882684621715283`}, {1.1825630797345452`}, \
{1.7676503551811207`}}\)], "Output",
  PageWidth->Infinity]
}, Open  ]],

Cell["\<\
(***************************************************************)\t\
\t\t 
Quote[alpha_]:= 
(***************************************************************)\t\t\t 
\tModule[{factor,an,nn, n = Length[alpha]},
\t
\tfactor = Min[DeleteCases[alpha//Chop//N,0]];
\tfactor = 1/n //N;
\t(*factor//Print;*)
\tan = alpha n //Round;
\t
    nn = Apply[Plus,an];
  
    If[nn == n,Return[APLExpand[an,n//Range]//Flatten],
    (*else*)
    
\tDo[
    an = (alpha + factor Table[Random[]-.5,{n}]) n //Round;
    nn = Apply[Plus,an];
    nn//Print;
    If[nn == n,Break[]];
    ,{20}];
   
    Return[APLExpand[an,n//Range]//Flatten]
    ];
\t]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
alphanorm//Clear
(***************************************************************)\t\t\t 
alphanorm[x_]:= x/Apply[Plus,x];
(***************************************************************)
alphanorm//Protect;\t\t\t 
\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(alphanorm\\) is Protected. \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::wrsym\\\"]\\)\"\>"}]], "Message",
  PageWidth->Infinity],

Cell[BoxData[
    RowBox[{\(SetDelayed::"write"\), \(\(:\)\(\ \)\), "\<\"Tag \
\\!\\(alphanorm\\) in \\!\\(alphanorm[x_]\\) is Protected. \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::write\\\"]\\)\"\>"}]], \
"Message",
  PageWidth->Infinity]
}, Open  ]],

Cell[CellGroupData[{

Cell["alphanorm[{1,2.}]", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[BoxData[
    \({0.3333333333333333`, 0.6666666666666666`}\)], "Output",
  PageWidth->Infinity]
}, Open  ]],

Cell["\<\
Sortieren//Clear
(***************************************************************)\t\t\t 
Sortieren[{yii_,Pii_,alphaii_},sort_]:=
(***************************************************************)\t\t\t 
Block[{perm,krit},

krit=
If[sort==1,Map[pNorm,yii//N],       (*else*)
If[sort==2,Map[MatrixTrace,Pii//N], (*else*)
If[sort==3,alphaii//N,              (*else*)
If[sort<0 ,col=Column[yii,-sort]
]]]]; 


perm=PlatzInUngeordneterListe[krit];

{yii[[perm]],Pii[[perm]],alphaii[[perm]]} 

]\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
Resampling//Clear
(***************************************************************)\t\t\t 
Resampling[{yii_,Pii_,alphaii_,N1_},eps_,seed_,{quote_,tanner_}]:= 
(***************************************************************)\t\t\t 
Module[{MM,yiiR,alphai1i},

If [tanner==0,

    yiiR = RandomKDE1[yii,alphaii,Pii,eps,seed,quote]; 
\talphai1i=N1,

(*else*)

\tIf[ (tanner==1||tanner==2), 
\t
\t\t{yiiR,MM}=RandomKDE2[yii,N1,Pii,eps,seed,quote];     (* 1=quote, 2=uni, \
3=sobol, 4=uni/geschichtet *)
\t\talphai1i=alphaii[[MM]];                              (* unnormiert! *)
\t\tIf[ (tanner==2) , alphai1i=alphanorm[alphai1i]];     (* normiert *)
\t  ]
    ];
\t
{yiiR,alphai1i}]\t\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Closed]],

Cell[CellGroupData[{

Cell["Time-Ups", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpFokker//Clear
TimeUpFokker[{Yii_,X_,$dw$_,dt_},Theta_,{f_,g_},step_:EulerStep1]:=
(***************************************************************)\t\t\t 
\t(*mit gegebenen Zufallszahlen dw*) 
\tBlock[{T,n,Y,Yi1i},
\tn = $dw$//Length;
\tT = Length[X]-1;
\tY = MapThread[RungeKutta1[f,g,#1,{X,#2},T,dt,Theta,step]&,{Yii,$dw$}];
\tYi1i = Last/@Y;
\t{Yi1i,Y}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpFokker"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKF//Clear
TimeUpEKF[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_,Dg_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,A,G,Omega,B,BPB,AP,Yi1i,Pi1i,Y,P},

T = Length[X]-1;
p = Length[Yii];
pp = p//Range;
{p,rr} = g[Yii,X[[1]],Theta]//Dimensions;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

Do[ 
\txi = X[[i]];
    A = Df[Yi1i,xi,Theta]; 
    G =  g[Yi1i,xi,Theta];
    Omega = G.Transpose[G];
    
    B = Dg[Yi1i,xi,Theta];\t
\tBPB = Sum[  Bl = B[[pp,l,pp]];
\t\t\t\tBl.Pi1i.Transpose[Bl], {l,rr}];
\t\t\t\t\t\t
\t(*
\tBPB dt //Print;
\tOmega dt//Print;
\t*)
\t
\tYi1i = Yi1i + f[Yi1i,xi,Theta] dt;
\t
\t(*
\tAP = A.Pi1i;   
\tPi1i = Pi1i + (AP + Transpose[AP] + BPB + Omega) dt; 
\t*)
\t
\t(*Variante*)
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + (BPB + Omega) dt; 
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKF[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Y,P,Astern},

T = Length[X]-1;

Yi1i = Yii;
Pi1i = Pii;

(*IP = IdentityMatrix[Yii//Length];*)

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;


Do[ 

\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\t(*If[OVERFLOW,Pi1i=Shift[Pi1i,10^-8];OVERFLOW=False];*)
\t
\t
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];*) 
\t
    A = Df[Yi1i,xi,Theta];  (*A//Print; *)
    
    G =  g[Yi1i,xi,Theta];  (*G//Print;*)
    Omega = G.Transpose[G]; (*Omega//Print;*)  
    
   
    Yi1i = Yi1i + f[Yi1i,xi,Theta] dt;  (*Print[\"Yi1i in Timeup\",Yi1i]; *)
   \t
   \t(*
\tAP   = A.Pi1i;
\tPi1i = Pi1i + (AP + Transpose[AP] + Omega) dt;
\t*)
\t 
\t(*Astern = IP + A dt;*)
\t
\t
\t
\tAstern = IdPlusA[A dt]; (*Astern//Print;*)
\t
\t(*Print[\"Timeup\",(Astern.Pi1i.Transpose[Astern])~ii~(Omega \
dt)//MatrixForm];*)
\t
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;  (*Var(y+fdt+gdW)*)
\t   
\t(*Pi1i//Print;*)
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpEKF"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpSumFilter[{Yii_,Pii_,alphaii_,X_,dt_,corr_},Theta_,{f_,Df_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Y,P,Astern,mue,muen,QneuQ,Qalt,dQ},

T = Length[X]-1;

Yi1i = Yii;
Pi1i = Pii;

n=Yii//Length;

Y = Shape[1,{n,T+1}];
Y[[All,1]]  = Yii;
P = Shape[1,{n,T+1}];
P[[All,1]] = Pii;

If[corr,
mue  = WeightedMean[Yii,alphaii];
muen = Map[(#-mue)&,Yii];
Qalt = Map[Outer[Times,#,#]&,muen]
];


Do[ 
    (*
\ti//Print;
    Yi1i//Print;
\tPi1i//Print;
\t*)
\t
\t
\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; \t
\t
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];*) 
\t
    A = Map[Df[#,xi,Theta]&,Yi1i];  (*A//Print; *)
    
    G =  Map[g[#,xi,Theta]&,Yi1i];  (*G//Print;*)
    
    Omega = Map[#.Transpose[#]&,G]; (*Omega//Print;*)  
    
   
    Yi1i = Yi1i + Map[f[#,xi,Theta]&,Yi1i] dt;  (*Print[\"Yi1i in \
Timeup\",Yi1i]; *)\t
\t
\t
\tAstern = Map[IdPlusA[#]&,A dt]; (*Astern//Print;*)
\t
\tIf[corr,
\tmue  = WeightedMean[Yi1i,alphaii];
\tmuen = Map[(#-mue)&,Yi1i];
\tQneu = Map[Outer[Times,#,#]&,muen];
\tdQ   = Qneu-Qalt
\t];
\t
\t
\t(*
\tPrint[\"Pi1i\",Pi1i];
\tPrint[\"Omega dt\",Omega dt];
\tPrint[\"dQ  \",dQ];
\t*)
\t
\t
\tPi1i = MapThread[#1.#2.Transpose[#1]&,{Astern,Pi1i}] + Omega dt; 
\t       (*Var(y+fdt+gdW)*)
\t
\tIf[corr,
\tPi1i=Pi1i-dQ;
\tQalt=Qneu
\t];
\t
\tPi1i=Map[Shift[#,10^-8]&,Pi1i];
\t 
\t(*Pi1i//Print;*)
\t
\tY[[All,i+1]] = Yi1i;
\tP[[All,i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpSumFilter"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKFJacobi[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_},Nonlin_]:=
(***************************************************************)
(* mit EMM, LL: Nonlin=1*)\t
\t\t 
Block[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Y,P,Astern,Bstern,Ostern,Asterni,b},

T = Length[X]-1;

Yi1i = Yii;
Pi1i = Pii;

(*IP = IdentityMatrix[Yii//Length];*)

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;
Astern=Shape[1,{T}]; 


Do[ 
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];*) 
\t
    A = Df[Yi1i,xi,Theta];  \t\t\t(*A//Print; *)
    
    G =  g[Yi1i,xi,Theta]; \t\t\t    (*G//Print;*)
    Omega = G.Transpose[G]; \t\t    (*Omega//Print;*)  
    
    If[Nonlin==0,
    \tYi1i = Yi1i + f[Yi1i,xi,Theta] dt;  
    \t\t\t\t\t\t\t\t\t(*Print[\"Yi1i in Timeup\",Yi1i]; *)\t
\t\tAsterni = IdPlusA[A dt]; \t\t(*Asterni//Print;*)
\t\t\t\t\t\t\t\t\t\t(*Print[\"Timeup\",(Astern.Pi1i.Transpose[Astern])~ii~(\
Omega dt)//MatrixForm];*)
\t\tPi1i = Asterni.Pi1i.Transpose[Asterni] + Omega dt,
\t\t
\t(*else*)
\t     
\t     (*
\t     b=f[Yi1i,xi,Theta] - A.Yi1i;
\t    {Ostern,Asterni,Bstern} = STERN01R[Omega,A,b,dt,Nonlin];
\t\t Yi1i = Asterni.Yi1i + Bstern;
\t\t *)
\t\t 
\t\t {Ostern,Asterni,Bstern} = STERN01R[Omega,A,1,dt,Nonlin];
\t\t Yi1i = Yi1i + Bstern.f[Yi1i,xi,Theta]; (*Bstern=A1*)
\t\t 
\t\t  
\t\t Pi1i = Asterni.Pi1i.Transpose[Asterni] + Ostern;
\t ]; 
\t 
\t\t(*Pi1i//Print;*)
\t\t
\t\t
\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\t
\tY[[i+1]]    = Yi1i;
\tP[[i+1]]    = Pi1i;
\tAstern[[i]] = Asterni;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P,Astern}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpEKFJacobi"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKFEDM//Clear
TimeUpEKFEDM[{Yii_,Pii_,X_,dt_},Theta_,
             {f_,Df_,g_,
             OsternX_,AsternX_,A1X_,BsternX_,AX_},
             {Nonlin_,const_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,i,xi,A,A1,B,G,Omega,Yi1i,Pi1i,Y,P,Ostern,Astern,Bstern},

T = Length[X]-1;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;


Do[ 
\txi = X[[i]];
\t
\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\tIf[const==False,
\t
    A = Df[Yi1i,xi,Theta]; 
    G =  g[Yi1i,xi,Theta];
    Omega = G.Transpose[G];
     
    (*B = (f[Yi1i,xi,Theta] - A.Yi1i) //Spalte;*)
\t(*{Ostern,Astern,Bstern} = STERN01R[Omega,A,B,dt,Nonlin];*)
\t
\t{Ostern,Astern,A1} = 
\tIf[Det[A]==0,
\tSTERN01R1[Omega,A,1,dt,Nonlin],
\tSTERN01R [Omega,A,1,dt,Nonlin]
\t];

\t\t(*
\t\tPrint[{Omega,A,B}//TableForm];
\t\tPrint[{V,Astern,Bstern}//TableForm];
\t\t*)
\t\t\t
\t(*Yi1i = Astern.Yi1i + Flatten[Bstern];*)
\tYi1i = Yi1i + A1.f[Yi1i,xi,Theta];\t
\t
\t\t
\tPi1i = Astern.Pi1i.Transpose[Astern] + Ostern
\t
\t
\t
\t,(*else konstantes A, f = Ay + b xi*)
\t
\t(*
\tB = (f[Yi1i,xi,Theta] - AX.Yi1i);  (* B = b xi*)
\tBstern=A1X.B;
\tYi1i = AsternX.Yi1i + Bstern;
\t*)
\t
\t
\tYi1i = Yi1i + A1X.f[Yi1i,xi,Theta];
\t
\tPi1i = AsternX.Pi1i.Transpose[AsternX] + OsternX
\t
\t];
\t\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

(*Y//MatrixForm//Print;*)

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpEKFEDM"],

Cell["<<PARTest.m", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[CellGroupData[{

Cell["??STERN01R1", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Global`STERN01R1
STERN01R1[OMEGA_, A_, B_, DT_, NONLIN_] := 
   Module[{}, If[NONLIN == 1, Hermann`PARTest`Private`STERNR1[OMEGA, A, B, \
DT], 
     Hermann`PARTest`Private`LINSTERN1[OMEGA, A, B, DT]]]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
STERN01R[Omega={{1,0},{0,4}},A={{0,1},{16,-4}},B={{0},{1}},dt=2,1]
STERN01 [Omega={{1,0},{0,4}},A={{0,1},{16,-4}},B={{0},{1}},dt=2,1]\
\>", \
"Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{{2285.8409873807013, 5650.487059081753}, \
{5650.487059081753, 

     13968.508568152101}}, {{101.57168296724436, 15.693687722816358}, 

    {251.09900356506148, 38.79693207597901}}, {{6.285730185452778}, 

    {15.693687722816358}}}\
\>", "\<\
 {{{2285.84, 5650.49}, {5650.49, \
13968.5}}, 
  {{101.572, 15.6937}, {251.099, 38.7969}}, {{6.28573}, {15.6937}}}\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
 {{{2285.840987380665, 5650.487059081662}, \
{5650.487059081662, 

     13968.508568151878}}, {{101.57168296724355, 15.69368772281622}, 

    {251.0990035650595, 38.79693207597868}}, {{6.2857301854527226}, 

    {15.693687722816222}}}\
\>", "\<\
 {{{2285.84, 5650.49}, {5650.49, \
13968.5}}, 
  {{101.572, 15.6937}, {251.099, 38.7969}}, {{6.28573}, {15.6937}}}\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKFSmooth//Clear
TimeUpEKFSmooth[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Astern,Phi,F},

T = Length[X]; (* T//Print; *)

Yi1i = Yii;
Pi1i = Pii;
Phi = IdentityMatrix[Yii//Length];


Do[ 
\txi = X[[i]];
\t
    A = Df[Yi1i,xi,Theta]; 
    
    G =  g[Yi1i,xi,Theta]; 
    Omega = G.Transpose[G];
    
   
    Yi1i = Yi1i + f[Yi1i,xi,Theta] dt;
   \t\t
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;   
\t
\tPhi = Astern.Phi;  (* Phi//Print; *)
\t
\t
,{i,1,T}];

F = Pii.Transpose[Phi].Inverse[Pi1i];

{Yi1i,Pi1i,F}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpEKFSmooth"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKFSmoothIter//Clear
TimeUpEKFSmoothIter[{Yii_,xiref_,Pii_,X_,dt_},Theta_,{f_,Df_,g_}]:=
(***************************************************************)
(* xiref = A.B. der Referenztrajektorie xiref(t_i) *)
\t\t\t 
Block[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Astern,Phi,F},

T = Length[X]; (* T//Print; *)

Yi1i = xiref;
Pi1i = Pii;
Phi  = IdentityMatrix[Yii//Length];


Do[ 
\txi = X[[i]];
\t
    A = Df[Yi1i,xi,Theta]; 
    
    G =  g[Yi1i,xi,Theta]; 
    Omega = G.Transpose[G];
    
   
    Yi1i = Yi1i + f[Yi1i,xi,Theta] dt;
   \t\t
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;   
\t
\tPhi = Astern.Phi;  (* Phi//Print; *)
\t
\t
,{i,1,T}];

F    = Pii.Transpose[Phi].Inverse[Pi1i];
Yi1i = Yi1i + Phi.(Yii-xiref);

{Yi1i,Pi1i,F,Phi}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKFSmooth2//Clear
TimeUpEKFSmooth2[{Yii_,_,X_,dt_},Theta_,{f_,Df_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Astern,Phi,Pj1j,F},

T = Length[X];  (* T//Print; *)
p = Yii//Length;


xi = X[[1]];
\t
A = Df[Yii,xi,Theta]; 
    
G =  g[Yii,xi,Theta]; 
Omega = G.Transpose[G];

Phi  = IdentityMatrix[p];    
   
Yi1i = Yii + f[Yii,xi,Theta] dt;
Pi1i = Pj1j = Omega dt;   
\t
Do[ 
\txi = X[[i]];
\t
    A = Df[Yi1i,xi,Theta]; 
    
    G =  g[Yi1i,xi,Theta]; 
    Omega = G.Transpose[G];
    
   
    Yi1i = Yi1i + f[Yi1i,xi,Theta] dt;
   \t\t
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;   
\t
\tPhi = Astern.Phi;  (* Phi//Print; *) (* Phi(t_i+1,tau_j *)
\t\t
,{i,2,T}];

F = Pj1j.Transpose[Phi].Inverse[Pi1i]; (* Gain f\[UDoubleDot]r \
\[CapitalUDoubleDot]bergangsw.*)

(* Print[\"Korr. \[CapitalUDoubleDot]  \",T,Yi1i]; *)

{Yi1i,Pi1i,F}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\

TimeUpEKF2//Clear
(***************************************************************)\t\t\t 
TimeUpEKF2[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,DDf_,g_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,i,xi,DA,A,G,Omega,AP,Yi1i,Pi1i,Y,P,Astern},

T = Length[X]-1;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;


Do[ 

    {Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\txi = X[[i]];
\t

    A  =  Df[Yi1i,xi,Theta];
    DA = DDf[Yi1i,xi,Theta];
    G  =   g[Yi1i,xi,Theta]; 
    Omega = G.Transpose[G];
    
    Yi1i = Yi1i + (f[Yi1i,xi,Theta] + .5 Map[MatrixTrace,DA.Pi1i]) dt;
     
                (*Korrektur 2. Ordnung = Ito-Taylor Entwicklung*)
   \t
   \t
   \t(*
\tAP   = A.Pi1i;
\tPi1i = Pi1i + (AP + Transpose[AP] + Omega) dt + AP.Transpose[A]dt^2;
\tPi1i//Eigenvalues//Print;
\t*)
\t
\t\t 
\t(* Astern = IP + A dt;*)
\t
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;  
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpEKF2"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKF4//Clear
TimeUpEKF4[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,DDf_,Omega_,DDOmega_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,A,DA,O,DDO,AP,Yi1i,Pi1i,Y,P},

T = Length[X]-1;
p = Length[Yii];
pp = p//Range;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

Do[ 
\txi =   X[[i]];
    A  =  Df[Yi1i,xi,Theta]; 
    DA = DDf[Yi1i,xi,Theta]; 
    O  =   Omega[Yi1i,xi,Theta];
    DDO= DDOmega[Yi1i,xi,Theta];
  \t
\tYi1i = Yi1i + (f[Yi1i,xi,Theta] + .5 Map[MatrixTrace,DA.Pi1i]) dt;
\t 
             (* Korrektur 2. Ordnung = Ito-Taylor Entwicklung *)
\t
\t(*
\tAP = A.Pi1i;   
\tPi1i = Pi1i + (AP + Transpose[AP] + 
\t               O + 0.5 Map[MatrixTrace[#.Pi1i]&,DDO,{2}]) dt; 
\t*)
\t
\t(*Variante*)
\t
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + 
\t       (O + 0.5 Map[MatrixTrace[#.Pi1i]&,DDO,{2}]) dt; 
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpEKF4alt//Clear
TimeUpEKF4alt[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,DDf_,g_,Dg_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,A,G,Omega,B,BPB,AP,Yi1i,Pi1i,Y,P},

T = Length[X]-1;
p = Length[Yii];
pp = p//Range;
{p,rr} = g[Yii,X[[1]],Theta]//Dimensions;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

Do[ 
\txi =   X[[i]];
    A  =  Df[Yi1i,xi,Theta]; 
    DA = DDf[Yi1i,xi,Theta]; 
    G  =   g[Yi1i,xi,Theta];
    Omega = G.Transpose[G];
    
    B = Dg[Yi1i,xi,Theta];\t
\tBPB = Sum[  Bl = B[[pp,l,pp]];
\t\t\t\tBl.Pi1i.Transpose[Bl], {l,rr}];
\t\t\t\t\t\t
\t(*
\tBPB dt //Print;
\tOmega dt//Print;
\t*)
\t
\tYi1i = Yi1i + (f[Yi1i,xi,Theta] + .5 Map[MatrixTrace,DA.Pi1i]) dt;
\t 
             (*Korrektur 2. Ordnung = Ito-Taylor Entwicklung*)
\t
\t(*
\tAP = A.Pi1i;   
\tPi1i = Pi1i + (AP + Transpose[AP] + BPB + Omega) dt; 
\t*)
\t
\t(*Variante*)
\tAstern = IdPlusA[A dt];
\tPi1i = Astern.Pi1i.Transpose[Astern] + (BPB + Omega) dt; 
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpHNF24//Clear
TimeUpHNF24[{Yii_,Pii_,X_,dt_},Theta_,
            {f_,Df_,DDf_,DDDf_,DDDDf_,Omega_,DDOmega_,DDDDOmega_},
            {M6anal_,Sanal_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,Astern,f1,f2,f3,f4,O,O2,O4,PP,M4,
        Yi1i,Pi1i,Y,P},

 (*Var(y+f dt) = Var(y) + 2Cov(f,y)dt + Cov(f,f)dt^2
                  = P + ( 2 f'P + 2/6 f'''M4)dt + 
                    
                    (f'^2 P + 1/4 f''^2 (M4-P^2)
                     + 1/36 f'''^2 M6 + 
                       1/3  f'f''' M4)dt^2
 *)
 
T = Length[X]-1;
p = Length[Yii];
pp = p//Range;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

c24=1/24;


Do[ (*i//Print;*)

\txi =  X[[i]];
    f1 =        Df[Yi1i,xi,Theta];
    f2 =       DDf[Yi1i,xi,Theta];
    f3 =      DDDf[Yi1i,xi,Theta];
    f4 =     DDDDf[Yi1i,xi,Theta];
    O  =     Omega[Yi1i,xi,Theta];
    O2 =   DDOmega[Yi1i,xi,Theta];
    O4 = DDDDOmega[Yi1i,xi,Theta];
       
    PP = Outer[Times,Pi1i,Pi1i]; 
    M4 = PP+Transpose[PP,{1,3,2,4}]+Transpose[PP,{1,3,4,2}]; (*Gauss-Fakt.*)
    m4 = Flatten[M4];
  \t
    (*
    diagP = DiagonalMatrix[Pi1i//VecDiag];
    M6=15 Outer[Times,diagP,diagP,diagP];
    *)
    
    M6=MMnum[M6anal,Sanal,Pi1i];
  \t
    PM4=Outer[Times,Pi1i,M4];
    
    f223  = flatten[f2,{2,3}];
    f3234 = flatten[f3,{2,3,4}];
    f42345= flatten[f4,{2,3,4,5}];
    
\tYi1i = Yi1i + (f[Yi1i,xi,Theta] 
\t            +  0.5 f223.Flatten[Pi1i]
\t            + c24 flatten[f4,{2,3,4,5}].m4)*dt;
\t 
             (* Korrektur 2. und 4. Ordnung = Ito-Taylor Entwicklung *)
\t
\t(*Yi1i//Print;*)
\t
\tAstern = IdPlusA[f1 dt]; (*enth\[ADoubleDot]lt f'^2 P dt^2*)
\t
\tf2M4f2= 1/4 f223.flatten[flatten[M4-PP,{1,2}],{2,3}].Transpose[f223]; 
   \t\t (*f2M4f2//Print;*) 
   \t
\tf3M4  = 1/6 f3234.flatten[M4,{1,2,3}]; 
\t\t (*f3M4//Print;*)
  
    f3M6f3= 1/36 f3234.flatten[flatten[M6,{1,2,3}],{2,3,4}].Transpose[f3234];
   \t\t (*f3M6f3//Print;*)
   \t\t 
    f1M4f3= 1/6 f1.flatten[M4,{2,3,4}].Transpose[f3234];
   \t\t (*f1M4f3//Print;*)
   \t\t 
    f2M6f4= 1/48 \
f223.flatten[flatten[M6-PM4,{1,2}],{2,3,4,5}].Transpose[f42345];
\t\t (*f2M6f4//Print;*)
\t
\t(*f4M8f4= (1/24)^2 \
f42345.flatten[flatten[M8-M4M4,{}],{}].Transpose[f42345]*)
\t
\t
\tPi1i = Astern.Pi1i.Transpose[Astern] 
\t
\t       + dt(f3M4 + Transpose[f3M4]
\t            + O 
\t            + 0.5 flatten[O2,{3,4}].Flatten[Pi1i]
\t            + c24 flatten[O4,{3,4,5,6}].Flatten[M4]
\t            )
\t         
\t         
\t       + dt^2(f2M4f2
\t             +f3M6f3
\t             +f1M4f3+Transpose[f1M4f3]
\t             +f2M6f4+Transpose[f2M6f4]
\t             (*+f4M8f4+Transpose[f4M8f4]*)
\t              );     
\t         
\t
\t(*Variante ohne O(dt^2)*)
\t
\t(*
\tf1Pi1i=f1.Pi1i;
\t
\tPi1i = Pi1i + (f1Pi1i + Transpose[f1Pi1i])dt
\t
\t            + (f3M4 + Transpose[f3M4]
\t            + O + 0.5 flatten[O2,{3,4}].Flatten[Pi1i]
\t            + c24 flatten[O4,{3,4,5,6}].Flatten[M4])*dt;
\t*)
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpHNF24"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpHNF22alt//Clear
TimeUpHNF22alt[{Yii_,Pii_,X_,dt_},Theta_,
            {f_,Df_,DDf_,Omega_,DDOmega_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,Astern,f1,f2,f3,f4,O,O2,O4,PP,M4,
        Yi1i,Pi1i,Y,P},

 (*Var(y+f dt) = Var(y) + 2Cov(f,y)dt + Cov(f,f)dt^2
                  = P + 2 f'P dt + (f'^2 P + 1/4 f''^2 (M4-P^2)) dt^2
 *)
 
T = Length[X]-1;
p = Length[Yii];
pp = p//Range;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

c24=1/24;


Do[ (*i//Print;*)

\txi =  X[[i]];
    f1 =        Df[Yi1i,xi,Theta];
    f2 =       DDf[Yi1i,xi,Theta];
    O  =     Omega[Yi1i,xi,Theta];
    O2 =   DDOmega[Yi1i,xi,Theta];
       
    PP = Outer[Times,Pi1i,Pi1i]; 
    M4 = PP+Transpose[PP,{1,3,2,4}]+Transpose[PP,{1,3,4,2}]; (*Gauss-Fakt.*)
    
    f223  = flatten[f2,{2,3}]; (*f223//Print;*)
    (*f223  = Partition[Flatten[f2],p*p];*) (*f223//Print;*)
  \t
  \t
\tYi1i = Yi1i + (f[Yi1i,xi,Theta] + 0.5 f223.Flatten[Pi1i])*dt;
\t 
             (* Korrektur 2. Ordnung = Ito-Taylor Entwicklung *)
\t
\tAstern = IdPlusA[f1 dt]; (*enth\[ADoubleDot]lt f'^2 P dt^2*)
\t
\tf2M4f2= 1/4 f223.flatten[flatten[M4-PP,{1,2}],{2,3}].Transpose[f223];
   \t\t (*f2M4f2//Print;*)
\t
\t(*f2M4f2= 1/4 f223.Partition[Flatten[M4-PP],p*p].Transpose[f223];*)
   \t    (* f2M4f2//Print;*)
\t
\t
\tPi1i = Astern.Pi1i.Transpose[Astern] 
\t
\t       + dt(O + 0.5 flatten[O2,{3,4}].Flatten[Pi1i])
\t                  
\t       + dt^2 * f2M4f2;     
\t            
\t
\t(*Variante ohne O(dt^2)*)
\t(*
\tf1Pi1i=f1.Pi1i;
\t
\tPi1i = Pi1i + (f1Pi1i + Transpose[f1Pi1i] + O)dt;
\t
\t*)
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpHNF22//Clear
TimeUpHNF22[{Yii_,Pii_,X_,dt_},Theta_,
            {f_,Df_,DDf_,Omega_,DDOmega_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,Astern,f1,f2,f3,f4,O,O2,O4,PP,M4,M4mPP,
        Yi1i,Pi1i,Y,P},

 (*Var(y+f dt) = Var(y) + 2Cov(f,y)dt + Cov(f,f)dt^2
                  = P + 2 f'P dt + (f'^2 P + 1/4 f''^2 (M4-P^2)) dt^2
 *)
 
T = Length[X]-1;
p = Length[Yii];
pp = p//Range;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

c24=1/24;


Do[ (*i//Print;*)

\txi =  X[[i]];
    f1 =        Df[Yi1i,xi,Theta];
    f2 =       DDf[Yi1i,xi,Theta];
    O  =     Omega[Yi1i,xi,Theta];
    O2 =   DDOmega[Yi1i,xi,Theta];
       
    PP = Outer[Times,Pi1i,Pi1i]; 
    M4mPP = Transpose[PP,{1,3,2,4}]+Transpose[PP,{1,3,4,2}]; (*Gauss-Fakt.*)
    
    (*f223  = flatten[f2,{2,3}]; *) (*f223//Print;*)
    f223  = Partition[Flatten[f2],p*p]; (*f223//Print;*)
  \t
  \t
\tYi1i = Yi1i + (f[Yi1i,xi,Theta] + 0.5 f223.Flatten[Pi1i])*dt;
\t 
             (* Korrektur 2. Ordnung = Ito-Taylor Entwicklung *)
\t
\tAstern = IdPlusA[f1 dt]; (*enth\[ADoubleDot]lt f'^2 P dt^2*)
\t
\t(*f2M4f2= 1/4 f223.flatten[flatten[M4mPP,{1,2}],{2,3}].Transpose[f223];*)
   \t\t (*f2M4f2//Print;*)
\t
\tf2M4f2= 1/4 f223.Partition[Flatten[M4mPP],p*p].Transpose[f223];
   \t    (* f2M4f2//Print;*)
\t
\t
\tPi1i = Astern.Pi1i.Transpose[Astern] 
\t
\t       + dt(O + 0.5 Partition[Partition[Flatten[O2],p*p].Flatten[Pi1i],p])
\t                  
\t       + dt^2 * f2M4f2;     
\t            
\t
\t(*Variante ohne O(dt^2)*)
\t(*
\tf1Pi1i=f1.Pi1i;
\t
\tPi1i = Pi1i + (f1Pi1i + Transpose[f1Pi1i] + O)dt;
\t
\t*)
\t
\t(*{i,Yi1i,Pi1i}//Print;*)
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpHNF23//Clear
TimeUpHNF23[{Yii_,Pii_,X_,dt_},Theta_,
            {f_,Df_,DDf_,DDDf_,Omega_,DDOmega_},
            {M6anal_,Sanal_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,pp,rr,i,xi,Astern,f1,f2,f3,f4,O,O2,O4,PP,M4,M6,
        Yi1i,Pi1i,Y,P},

 (*Var(y+f dt) = Var(y) + 2Cov(f,y)dt + Cov(f,f)dt^2
                  = P + ( 2 f'P + 2/6 f'''M4)dt + 
                    
                    (f'^2 P + 1/4 f''^2 (M4-P^2)
                     + 1/36 f'''^2 M6 + 
                       1/3  f'f''' M4)dt^2
 *)
 
T = Length[X]-1;
p = Length[Yii];
pp = p//Range;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

c24=1/24;


Do[ (*i//Print;*)

\txi =  X[[i]];
    f1 =        Df[Yi1i,xi,Theta];
    f2 =       DDf[Yi1i,xi,Theta];
    f3 =      DDDf[Yi1i,xi,Theta];
    O  =     Omega[Yi1i,xi,Theta];
    O2 =   DDOmega[Yi1i,xi,Theta];
       
    PP = Outer[Times,Pi1i,Pi1i]; 
    M4 = PP+Transpose[PP,{1,3,2,4}]+Transpose[PP,{1,3,4,2}]; (*Gauss-Fakt.*)
  \t
    (*
    diagP = DiagonalMatrix[Pi1i//VecDiag];
    M6=15 Outer[Times,diagP,diagP,diagP];
    *)
    
    M6=MMnum[M6anal,Sanal,Pi1i];
    
    f223  = flatten[f2,{2,3}];
    f3234 = flatten[f3,{2,3,4}];
    
\tYi1i = Yi1i + (f[Yi1i,xi,Theta] 
\t            +  0.5 f223.Flatten[Pi1i])*dt;
\t 
             (* Korrektur 2. Ordnung = Ito-Taylor Entwicklung *)
\t
\t
\tAstern = IdPlusA[f1 dt]; (*enth\[ADoubleDot]lt f'^2 P dt^2*)
\t
\t
\tf2M4f2= 1/4 f223.flatten[flatten[M4-PP,{1,2}],{2,3}].Transpose[f223]; 
   \t\t (*f2M4f2//Print;*)
   \t
\tf3M4  = 1/6 f3234.flatten[M4,{1,2,3}]; 
\t\t (*f3M4//Print;*)
  
    f3M6f3= 1/36 f3234.flatten[flatten[M6,{1,2,3}],{2,3,4}].Transpose[f3234];
   \t\t (*f3M6f3//Print;*)
   \t\t 
    f1M4f3= 1/6 f1.flatten[M4,{2,3,4}].Transpose[f3234];
   \t\t (*f1M4f3//Print;*)
   \t
   \t
   \t(*
   \tPi1i = Astern.Pi1i.Transpose[Astern]
\t
\t       + dt(f3M4 + Transpose[f3M4]
\t            + O 
\t            + 0.5 flatten[O2,{3,4}].Flatten[Pi1i]
\t            )
\t                
\t       + dt^2(
\t              f2M4f2
\t             +f3M6f3
\t             +f1M4f3+Transpose[f1M4f3]
\t              );     
\t *)      
\t
\t(*Variante ohne O(dt^2)*)
\t
\tf1Pi1i=f1.Pi1i;
\t
\tPi1i = Pi1i + (f1Pi1i + Transpose[f1Pi1i])dt
\t
\t            + (f3M4 + Transpose[f3M4]
\t            + O + 0.5 flatten[O2,{3,4}].Flatten[Pi1i])*dt;
\t
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
\t\t 
(***************************************************************)\t\t\t 
TimeUpEKF[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_},{Y0_,P0_,IP_}]:=
(***************************************************************)\t\t\t 
Module[{T,p,i,xi,A,G,Omega,AP,Yi1i,Pi1i,Y,P,Astern},

T = Length[X]-1;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;


Do[ 
\txi = X[[i]];
\t

    A = Df[Yi1i,xi,Theta]; 
    G =  g[Yi1i,xi,Theta]; 
    Omega = G.Transpose[G];
    
    Yi1i = Yi1i + f[Yi1i,xi,Theta] dt;
   \t\t(*
\t\tAP   = A.Pi1i;
\t\tPi1i = Pi1i + (AP + Transpose[AP] + Omega) dt;
\t\t*) 
\tAstern = IP + A dt;
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;         
\t
\tIf[Max[Abs[Yi1i]] > YMAX,
\t\t    \tPrint[\"possible divergence, i = \",i];
\t\t    \tYi1i = Y0;
\t\t    \tPi1i = P0 ];
\t    \t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpDKS[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_}]:=
(***************************************************************)\t\t\t 
Module[{T,TT,G,Omega,Yi1i,Pi1i,Y,P,ff},

T = Length[X]-1;
TT = Range[0,T]dt;
G =  g[Yii,X[[1]],Theta];
Omega = G.Transpose[G];
P = Map[Times[Omega,#]&,TT];
Pi1i = P//Last; 
Y = Map[Plus[Yii,#]&, Map[Times[f[Yii,X[[1]],Theta],#]&,TT]];
Yi1i = Y//Last;   

{Yi1i,Pi1i,Y,P}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
TimeUpShojiOzaki//Clear
(***************************************************************)\t\t\t 
TimeUpShojiOzaki[{Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,DDf_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,DA,A,G,Omega,AP,Yi1i,Pi1i,Y,P,Astern,b1,b2,fi},

T = Length[X]-1;

Yi1i   = Yii;
Pi1i   = Pii;

Y      = Shape[1,{T+1}];
Y[[1]] = Yii;
P      = Shape[1,{T+1}];
P[[1]] = Pii;

xi     = X[[1]];
fi     = f[Yii,xi,Theta];
A      = Df[Yii,xi,Theta];
DA     = DDf[Yii,xi,Theta];
Astern = IdPlusA[A dt];
G      = g[Yii,xi,Theta]; 
Omega  = G.Transpose[G];
b1     = (fi - A.Yii)dt;
b2     = 0.5 Map[MatrixTrace,DA.Omega] dt*dt; (*i dt = t-ti*)

(* dy = Ay dt + [fi-A.Yii + 1/2 DA*Omega(t-ti)]dt + g dW  *)

Do[ (*i//Print; Yi1i//Print;*)

    {Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\t
    Yi1i = Yi1i + (A.Yi1i) dt + b1 + b2 i;
     
                (*Korrektur 2. Ordnung = Ito-Taylor Entwicklung*)
   \t\t
\tPi1i = Astern.Pi1i.Transpose[Astern] + Omega dt;        
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpShojiOzaki"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpUKF[{Yii_,Pii_,X_,dt_,kappa_},Theta_,{f_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,Yi1i,Pi1i,Y,P,yi1i,yi1ineu,alphai1i,gi1i,omegai1i,Eomegai1i},

T = Length[X]-1;
p=Yii//Length;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;



Do[ 
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
    
\t\t(*Pi1i=Pi1i + 10^-8 IdentityMatrix[p];*) (*Pi1i>0*)
\t
\tPi1i=Shift[Pi1i,10.^-16,\"TimeUpUKF \"]//Symmetrize;
\t{yi1i,alphai1i} = SigmaSample[Yi1i, Pi1i, kappa]; (* sigma-sample mit \
Kleinbuchstaben*)
\t
\t\t(*Print[i,\" vor Euler\",yi1i];*)


    yi1ineu = yi1i + Map[f[#,xi,Theta]dt &,yi1i];  (* update von yi1i*)
    
   \t\t (*Print[i,\"nach Euler\",yi1ineu];*)

   \t
\t{Yi1i,Pi1i} = WeightedMeanAndVariance[yi1ineu,alphai1i]; 
\t
\t\t(* E(y+fdt),Var(y+fdt) *) 
\t
\t\t(*{Yi1i,Pi1i}//Print;*)
\t
\tgi1i =  Map[g[#,xi,Theta]&,yi1i];  
\t
\t\t(*gi1i//Print;*)
\t
\tomegai1i=Map[Flatten[#.Transpose[#]]&,gi1i]; 
\t
\t\t(*omegai1i//Print;*)
    
    Eomegai1i = WeightedMean[omegai1i,alphai1i];  (* E(omega)*)
    
    Eomegai1i = Shape[Eomegai1i,{p,p}];
    
    Pi1i = Pi1i + Eomegai1i*dt; (* Var(yi1i) =Var(y + f dt) + E(Omega) dt *)
\t
\t\t(*Print[Pi1i , Eomegai1i*dt];*)
\t
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];
\t

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpUKF"],

Cell["\<\
(***************************************************************)\t\
\t\t 
TimeUpUKF1[{Yii_,Pii_,X_,dt_,kappa_},Theta_,{f_,g_}]:=
(***************************************************************)\t\t\t 
Block[{T,p,i,xi,Yi1i,Pi1i,Y,P,yi1i,yi1ineu,alphai1i,gg,Eomegai1i},

T = Length[X]-1;
p=Yii//Length;

Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;



Do[ 
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
    
\t\t(*Pi1i=Pi1i + 10^-8 IdentityMatrix[p];*) (*Pi1i>0*)
\t
\tPi1i=Shift[Pi1i,10.^-16,\"TimeUpUKF \"]//Symmetrize;
\t{yi1i,alphai1i} = SigmaSample[Yi1i, Pi1i, kappa]; (* sigma-sample mit \
Kleinbuchstaben*)
\t
\t\t(*Print[i,\" vor Euler\",yi1i];*)


    yi1ineu = yi1i + Map[f[#,xi,Theta]dt &,yi1i];  (* update von yi1i*)
    
   \t\t (*Print[i,\"nach Euler\",yi1ineu];*)

   
\t{Yi1i,Pi1i} = WeightedMeanAndVariance[yi1ineu,alphai1i]; 
\t
\t(*
\tYi1i=alphai1i.yi1ineu;
\tPi1i=alphai1i.Map[Dyad,yi1ineu]-Dyad[Yi1i,Yi1i];
\t*)
\t
\t\t(* E(y+fdt),Var(y+fdt) *) 
\t
\t\t(*{Yi1i,Pi1i}//Print;*)
\t
\tgg=g[Yii,xi,Theta];
    
    Eomegai1i = gg.Transpose[gg];
    
    Pi1i = Pi1i + Eomegai1i*dt; (* Var(yi1i) =Var(y + f dt) + E(Omega) dt *)
\t
\t\t(*Print[Pi1i , Eomegai1i*dt];*)
\t
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];
\t

{Yi1i,Pi1i,Y,P}]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpUKF"],

Cell["\<\
(***************************************************************)
TimeUpSMKF[{Yii_,Pii_,X_,dt_,n_,seed_,anti_},Theta_,{f_,g_}]:=
(***************************************************************)
Block[{T,p,i,xi,Yi1i,Pi1i,Y,P,yi1i,yi1ineu,alphai1i,gi1i,omegai1i,Eomegai1i},

T = Length[X]-1;
p=Yii//Length;\t
\t
Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

alphai1i=1./n;

Do[
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
\t
\t(*Pi1i//Print;*)
\t
\tSeedRandom[seed];
\tyi1i = RandomGauss[Yi1i, Pi1i, n, Gauss, anti]; (*antithetisch*)
\t\t\t\t\t\t\t\t\t\t(* random-sample mit Kleinbuchstaben*)
   \t
   \t(*Print[i,\" vor Euler\",yi1i];*)
\t
    yi1ineu = yi1i + Map[(f[#,xi,Theta]dt)&,yi1i];  (* update von yi1i*)
    
    (*Print[i,\"nach Euler\",yi1ineu];*)

\t{Yi1i,Pi1i} = WeightedMeanAndVariance[yi1ineu,alphai1i]; 
\t
\t      \t\t\t\t(* E(y + f dt),Var(y+fdt)=P+(y,f)dt+(f,y)dt+O(dt^2)*) 
\t
\tgi1i =  Map[g[#,xi,Theta]&,yi1i];  
\t
\t(*gi1i//Print;*)
\t
\tomegai1i=Map[Flatten[#.Transpose[#]]&,gi1i]; 
\t
\t(*omegai1i//Print;*)
    
    Eomegai1i = WeightedMean[omegai1i,alphai1i];  (* E(omega)*)
    
    Eomegai1i = Shape[Eomegai1i,{p,p}];
    
    (*Print[Pi1i//Eigenvalues,Eomegai1i dt//Eigenvalues];*)
    
    Pi1i = Pi1i + Eomegai1i*dt; (* Var(yi1i) =Var(y+fdt) + E(gg') dt *)
    
    Pi1i=Shift[Pi1i,SHIFT$];
\t
\t
\t(*Print[Pi1i , Eomegai1i*dt];*)
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];


{Yi1i,Pi1i,Y,P}//Return;

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpSMKF"],

Cell["\<\
(***************************************************************)
TimeUpGF//Clear
TimeUpGF[{Yii_,Pii_,X_,dt_},Theta_,{f_,Omega_}]:=
(***************************************************************)
(*Gaussian Filter*)
Module[{T,p,xi,Yi1i,Pi1i,Y,P,Ef,fymue,Efymue,Eomega,s,a,b},

T = Length[X]-1;
p=Yii//Length;\t
\t
Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
(*P[[1]] = Pii;*)

Eomega=Shape[0,{p,p}];

Do[
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)

\tPi1i=(Pi1i//Symmetrize) + 10^-8 IdentityMatrix[p]; (*Pi1i>0*)
\t
\tPi1i=Shift[Pi1i,10.^-6];
\t
\tIf[i==1,P[[1]]=Pi1i]; (*falls korrigiert*)
\t
\t(*Pi1i//Print;*)
\t
\ts=Pi1i//VecDiag//Sqrt;
    {a,b}={Yi1i-ksigma s,Yi1i+ksigma s};

\t\t
   \tEf=Table[GaussIntegral[(f[#,xi,Theta][[i]])&,{Yi1i,Pi1i},{a,b},genau],
   \t         {i,p}];
   \t
    Yi1i = Yi1i + Ef*dt; 
    
    (*{i,Yi1i}//Print;*)
\t
    
    (* E(y + f dt),Var(y+fdt)=P+(y,f)dt+(f,y)dt+O(dt^2) *) 
\t
\tfymue=Outer[Times,f[#,xi,Theta],(#-Yi1i)]&;
\t
\tEfymue=Table[GaussIntegral[fymue[#][[i,j]]&,{Yi1i,Pi1i},{a,b},genau],
\t            {i,p},{j,p}];
\t                        
\t(*{i,Efymue}//Print;*)
\t
    Do[Eomega[[i,j]] = 
        GaussIntegral[Omega[#,xi,Theta][[i,j]]&,{Yi1i,Pi1i},{a,b},genau]
       ,{i,p},{j,i,p}];
   
    Table[Eomega[[j,i]]=Eomega[[i,j]],{i,p},{j,i+1,p}]; (*untere Dr.*)
    
    (*Print[Pi1i//Eigenvalues,Eomegai1i dt//Eigenvalues];*)
    
    Pi1i = Pi1i + (Efymue+Transpose[Efymue]+ Eomega)*dt; 
    
    (* Var(yi1i) =Var(y+fdt) + E(gg') dt *)

\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}//Return;

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
TimeUpGHF//Clear
TimeUpGHF[{Yii_,Pii_,X_,dt_,m_},Theta_,{f_,Omega_}]:=
(***************************************************************)
(*Gauss-Hermite-Filter*)
Block[{T,p,xi,Yi1i,Pi1i,Y,P,Ef,fl,yfdt,yfdt1,yfdt2,varyfdt,Eomega,vals},

T = Length[X]-1;\t
\t
Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;


(*   E(y + f dt)=mue+E[f]dt,
   Var(y + f dt)=P+(y,f)dt+(f,y)dt+(f,f)dt^2  *) 
\t
\t

Do[
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
\t
\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\t(*{i,Yi1i,Pi1i//VecDiag//Sqrt}//Print;*)
\t
\tvals = TrafoMueSigma[VALS,{Yi1i,Pi1i},10^-16];
   \t       
   \tfl   = Map[f[#,xi,Theta]&,vals];
    
    yfdt = vals + fl*dt;
    
    Yi1i = WEIGHT.yfdt;  (*E[y+f dt]*)
    
   
    yfdt2 = Map[Outer[Times,#,#]&,yfdt]; 
    varyfdt = WEIGHT.yfdt2 - Outer[Times,Yi1i,Yi1i];
    
    
    (* langsamer*)
    (*
    yfdt1 = Map[(#-Yi1i)&,yfdt];
    varyfdt = WEIGHT.Map[Outer[Times,#,#]&,yfdt1];  (*Var[y+f dt]*)
    *)      
    
    
    Eomega = WEIGHT.Map[Omega[#,xi,Theta]&,vals];
      
    Pi1i = varyfdt + Eomega*dt; 
   
    (*Pi1i=Shift[Pi1i//Symmetrize,10.^-8];*)
    (*Print[nach,Pi1i];*) 
    (* Var(yi1i) =Var(y+fdt) + E(gg') dt *)
\t(*{i,Yi1i,Pi1i//VecDiag//Sqrt}//Print;*)
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"TimeUpGHF"],

Cell["\<\
(***************************************************************)
TimeUpGHF1//Clear
TimeUpGHF1[{Yii_,Pii_,X_,dt_,m_},Theta_,{f_,Omega_}]:=
(***************************************************************)
(*Gauss-Hermite-Filter, konstantes Omega*)
Block[{T,p,xi,Yi1i,Pi1i,Y,P,Ef,fl,yfdt,yfdt1,yfdt2,varyfdt,Eomega,vals},

T = Length[X]-1;\t
\t
Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;


(*   E(y + f dt)=mue+E[f]dt,
   Var(y + f dt)=P+(y,f)dt+(f,y)dt+(f,f)dt^2  *) 
\t
\t

Do[
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
\t
\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\t(*{i,Yi1i,Pi1i//VecDiag//Sqrt}//Print;*)
\t
\tvals = TrafoMueSigma[VALS,{Yi1i,Pi1i},SHIFT$];
\t
\t(*If[OVERFLOW,Return[]];*)
   \t       
   \tfl   = Map[f[#,xi,Theta]&,vals];
    
    yfdt = vals + fl*dt;
    
    
    Yi1i = WEIGHT.yfdt;  (*E[y+f dt]*) 
    yfdt2 = Map[Outer[Times,#,#]&,yfdt]; 
    varyfdt = WEIGHT.yfdt2 - Outer[Times,Yi1i,Yi1i];
    
    
    (*
    Wyfdt=WEIGHT yfdt;
    Yi1i = Apply[Plus,Wyfdt]; 
    varyfdt =  Transpose[Wyfdt].yfdt - Outer[Times,Yi1i,Yi1i];
    *)
    
    (* langsamer*)
    (*
    yfdt1=Map[(#-Yi1i)&,yfdt];
    varyfdt = WEIGHT.Map[Outer[Times,#,#]&,yfdt1];  (*Var[y+f dt]*)
    *)      
    
  
    Eomega = Omega[Yii,xi,Theta]; (*konstant in Yii*)
    
    Pi1i = varyfdt + Eomega*dt; 
   
    (*Pi1i=Shift[Pi1i//Symmetrize,10.^-8];*)
    (*Print[nach,Pi1i];*) 
    (* Var(yi1i) =Var(y+fdt) + E(gg') dt *)
\t(*{i,Yi1i,Pi1i//VecDiag//Sqrt}//Print;*)
\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
TimeUpGHFN//Clear
TimeUpGHFN[{Yii_,Pii_,X_,dt_,mm_},Theta_,{f_,Omega_}]:=
(***************************************************************)
(*Gauss-Hermite-Filter, konstantes Omega, Panel-Daten*)
Block[{n,m,N,T,p,xi,Yi1i,Pi1i,Y,P,Ef,fl,yfdt,yfdt1,yfdt2,varyfdt,Eomega,vals},\


T = Length[X]-1;
N = Yii//Length;\t
\t
Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

varyfdt=Pii;
EYi1i=Yi1i;


(*   E(y + f dt)=mue+E[f]dt,
   Var(y + f dt)=P+(y,f)dt+(f,y)dt+(f,f)dt^2  *) 
\t
\t

Do[
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
\t
\t{Yi1i,OVERFLOW} = Over[Yi1i,YMAX,i]; 
\t{Pi1i,OVERFLOW} = Over[Pi1i,YMAX,i]; 
\t
\t(*{i,Yi1i,Pi1i//VecDiag//Sqrt}//Print;*)
\t
\tDo[
    
\tvals = TrafoMueSigma[VALS1,{{Yi1i[[n]]},{{Pi1i[[n,n]]}}},10^-16];
   \t       
   \tfl   = Map[f[#,xi,Theta]&,vals];
    yfdt = vals + fl*dt;
    
    EYi1i[[n]] = (WEIGHT1.yfdt)[[1]];  (*E[y+f dt]*) 
    varyfdt[[n,n]] = (WEIGHT1.yfdt^2)[[1]] - EYi1i[[n]]^2,
    
    {n,1,N}];
    
  
    
    Do[
    
\tvals = TrafoMueSigma[VALS2,{ Yi1i[[{n,m}]],
\t                           {{Pi1i[[n,n]],Pi1i[[n,m]]},
\t                            {Pi1i[[m,n]],Pi1i[[m,m]]}}},10^-16];
      
   \tfl   = Map[f[#,xi,Theta]&,vals,{2}];
   \t
    yfdt = vals + fl*dt;
  
    yfdt2 = Map[Apply[Times,#]&,yfdt]; 
    
    varyfdt[[n,m]] = WEIGHT2.yfdt2 - EYi1i[[n]]EYi1i[[m]];
    varyfdt[[m,n]] = varyfdt[[n,m]],
    
    {n,1,N},{m,n+1,N}];
    
   
  
    Eomega = Omega[Yii,xi,Theta]; (*konstant in Yii*)
    
    Pi1i = varyfdt + Eomega*dt; 
   
    (*Pi1i=Shift[Pi1i//Symmetrize,10.^-8];*)
    (*Print[nach,Pi1i];*) 
    (* Var(yi1i) =Var(y+fdt) + E(gg') dt *)
\t(*{i,Yi1i,Pi1i//VecDiag//Sqrt}//Print;*)
\t
\t
\tY[[i+1]] = Yi1i = EYi1i; 
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Map[Apply[Times,#]&,Map[ff,{{a,b},{1,2},{3,4}},{2}]]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
{ff[a]*ff[b], ff[1]*ff[2], ff[3]*ff[4]}\
\>", \
"\<\
{ff[a] ff[b], ff[1] ff[2], ff[3] ff[4]}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
(***************************************************************)
TimeUpGHFalt//Clear
TimeUpGHFalt[{Yii_,Pii_,X_,dt_,m_},Theta_,{f_,Omega_}]:=
(***************************************************************)
(*Gauss-Hermite-Filter*)
Block[{T,p,xi,Yi1i,Pi1i,Y,P,Ef,fymue,Efymue,Eomega,s,a,b,vals},

T = Length[X]-1;
p=Yii//Length;\t
\t
Yi1i = Yii;
Pi1i = Pii;

Y = Shape[1,{T+1}];
Y[[1]]  = Yii;
P = Shape[1,{T+1}];
P[[1]] = Pii;

Eomega=Shape[0,{p,p}];
Efymue=Shape[0,{p,p}];

yfdt//Clear;
yfdt[y_,i_]:=y[[i]]+f[y,xi,Theta][[i]]dt;

(*   E(y + f dt)=mue+E[f]dt,
   Var(y + f dt)=P+(y,f)dt+(f,y)dt+(f,f)dt^2  *) 
\t
\t

Do[
\txi = X[[i]];   (*Print[\"xi in Timeup\",xi];  *)
\t
\t
\tvals=TrafoMueSigma[VALS,{Yi1i,Pi1i}];
\t
\t(*
   \tEf=Table[GaussHermite2[(f[#,xi,Theta][[i]])&,{vals,WEIGHT}],
   \t         {i,p}];*)
   \t       
   \tfl=Map[f[#,xi,Theta]&,vals];
   \tEf=WEIGHT.fl;
   \t
    Yi1i = Yi1i + Ef*dt; 
    
    (*{i,Yi1i}//Print;*)
   
\t
\t(* Variante 1*)
\t(*
\tfymue=Outer[Times,f[#,xi,Theta],(#-Yi1i)]&;
\t
\tEfymue=Table[GaussHermite2[fymue[#][[i,j]]&,{vals,WEIGHT}],
\t            {i,p},{j,p}];
\tEfymue= Efymue-Outer[Times,Yi1i,Yi1i];                        
\t*)
\t
\t
\t(*Variante 2*)
\t(*
\tDo[Efymue[[i,j]]=GaussHermite2[yfdt[#,i]*yfdt[#,j]&,{vals,WEIGHT}],{i,p},{j,\
i,p}];
\t
\tDo[Efymue[[j,i]]=Efymue[[i,j]],{i,p},{j,i+1,p}]; (*untere Dr.*)
\t
\tEfymue= Efymue-Outer[Times,Yi1i,Yi1i];                       
    *)
    
    
    yfdt=vals+ fl dt;
    Efymue=Map[Outer[Times,#,#]&,yfdt]; 
    Efymue= WEIGHT.Efymue-Outer[Times,Yi1i,Yi1i];                
\t
\t
\t(*Variante 3*)
\t(*
\tfymue=Outer[Times,#+f[#,xi,Theta] dt,#+f[#,xi,Theta] dt]&;
\t
\tDo[Efymue[[i,j]]=GaussHermite2[(fymue[#][[i,j]])&,{vals,WEIGHT}],
\t            {i,p},{j,i,p}];
\tDo[Efymue[[j,i]]=Efymue[[i,j]],{i,p},{j,i+1,p}]; (*untere Dr.*)
\tEfymue= Efymue-Outer[Times,Yi1i,Yi1i];                                      \
   
\t*)                      
                     
\t(*{i,Efymue}//Print;*)
\t
\t(*
    Do[Eomega[[i,j]] = 
        GaussHermite2[Omega[#,xi,Theta][[i,j]]&,{vals,WEIGHT}]
       ,{i,p},{j,i,p}];
   
    Table[Eomega[[j,i]]=Eomega[[i,j]],{i,p},{j,i+1,p}]; (*untere Dr.*)
    *)
    
    Eomega = GaussHermite2[Omega[#,xi,Theta]&,{vals,WEIGHT}];
   
  
    
    (*Print[Pi1i//Eigenvalues,Eomegai1i dt//Eigenvalues];*)
    
    (*Pi1i = Pi1i + (Efymue+Transpose[Efymue]+ Eomega)*dt; *)(*Variante 1*)
    
    Pi1i = Efymue + Eomega*dt; 
   
    
    Pi1i=Shift[Pi1i//Symmetrize,10.^-8];
   
    (*Print[nach,Pi1i];*)
    
    (* Var(yi1i) =Var(y+fdt) + E(gg') dt *)

\t
\t
\tY[[i+1]] = Yi1i;
\tP[[i+1]] = Pi1i;
\t
,{i,1,T}];

{Yi1i,Pi1i,Y,P}//Return;

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[StyleBox["(*****************************************************\
**********)\nTimeUpGHFn//Clear\n\
TimeUpGHFn[{Yii_,Pii_,X_,dt_,m_},Theta_,{f_,Omega_}]:=\n\
(***************************************************************)\n\
(*Gauss-Hermite-Filter, n-fach*)\n\n\
MapThread[TimeUpGHF[{#1,#2,X,dt,m},Theta,{f,Omega}]&,{Yii,Pii}]//Transpose\n",
  
  FontWeight->"Plain"]], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[TextData[StyleBox["(*****************************************************\
**********)\nTimeUpUKFn//Clear\n\
TimeUpUKFn[{Yii_,Pii_,X_,dt_,kappa_},Theta_,{f_,g_}]:=\n\
(***************************************************************)\n\
(*Gauss-Hermite-Filter, n-fach*)\n\n\
MapThread[TimeUpUKF[{#1,#2,X,dt,kappa},Theta,{f,g}]&,{Yii,Pii}]//Transpose\n",
  
  FontWeight->"Plain"]], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mess-Ups", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\

(***************************************************************)\t\t\t 
MessUpFokker//Clear
MessUpFokker[{Z_,Yi1i_,X_,$z$_},Theta_,{h_,R_}]:=
(***************************************************************)\t\t\t 
\t(*mit gegebenen Zufallszahlen $z$ *) 
\tModule[{n,sm,sm1,pi1i,r,r2,pzy,Zi1i,pzi1i,pii,lik,yy},
\tn = $z$//Length;
\tsm1 = smoothQuickAndDirty[Yi1i]; sm1 //Print;
\tpi1i = (KernDichte[#,Yi1i,GaussKern,sm1])&;
\tr = R[_,X,Theta];
\tr2 = CholeskyDecomposition[r]//Transpose;
\tpzy = GaussDichte[Z,{h[#,X,Theta],r,Inverse[r]}]&;
\tZi1i = Map[h[#,X,Theta]&,Yi1i] + Map[Dot[r2,#]&,$z$];
\tsm = smoothQuickAndDirty[Zi1i]; sm//Print; 
\tsm = r//VecDiag//Max; sm//Print;
\t(*da Zi1i ordinal*) 
\tpzi1i = KernDichte[Z,Zi1i,GaussKern,sm]; (* lik *)
\tpii = (pzy[#] pi1i[#] / pzi1i )&;
\tlik = Log[pzi1i];
\t{pii,pi1i,lik}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpFokker1//Clear
MessUpFokker1[{Z_,Yi1i_,X_,_},Theta_,{h_,R_}]:=
\t(*mit gegebenen Zufallszahlen $z$ *) 
\tModule[{n,sm,pi1i,r,r2,pzy,Zi1i,pzi1i,pii,lik,yy},
\tn = Yi1i//Length;
\tsm = smoothQuickAndDirty[Yi1i]//Evaluate;
\tpi1i = KernDichte[#,Yi1i,GaussKern,sm//Evaluate]&;
\tr = R[_,X,Theta];
\tr2 = CholeskyDecomposition[r]//Transpose;
\tpzy = GaussDichte[Z,{h[#,X,Theta],r,Inverse[r]}]&;
\tpzi1i = Map[pzy,Yi1i]; (* lik *)
\tpzi1i//Print;
\tpzi1i = Apply[Plus,pzi1i]/n;
\tpii = (pzy[#] pi1i[#] / pzi1i)&;
\t
\tlik = Log[pzi1i];
\t{pii,pi1i,lik}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
\t\t\t
MessUpFokker2//Clear
(***************************************************************)\t\t\t 
MessUpFokker2[{Z_,Yi1i_,X_,_},Theta_,{h_,R_},{{y1_,y2_,dy_},nstd_,$n$_}]:=
(***************************************************************)\t\t\t 
\t(*  *) 
\tModule[{sm,m,s,pi1i,r,pzy,piiU,yii,z,lik,pii,y1s,y2s,dys},
\t
\t{sm,m,s} = smoothQuickAndDirty1[Yi1i];
\tIf[sm == 0, Print[\"Singul\[ADoubleDot]re Verteilung pi1i\"]; sm = 10.^-6];
\t
\tpi1i = KernDichte[#,Yi1i,GaussKern,sm]&;\t
\tr = R[y1(*dummy*),X,Theta];  
\tpzy = GaussDichte[Z,{h[#,X,Theta],r,Inverse[r]}]&;
\tpiiU = (pzy[#] pi1i[#])&;
\t{y1s,y2s,dys} = AutomaticGrid[Theta,{m,s,nstd},{Z,Modus},{y1,y2,dy}];
\t{z,yii} = RandomNumbers[{y1s,y2s,dys},piiU,$n$];
\t{z,yii}//Print;
\tlik = Log[z];
\tpii = (piiU[#]/z)&;
\t
\t\t  (*Plot[{pii[{yy}],pi1i[{yy}]}//Evaluate,{yy,-10,10}];*)
\t\t  
\t{yii,pii,pi1i,lik}
]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpEKF//Clear
(***************************************************************)\t\t\t 
MessUpEKF[{Z_,{Yi1i_,Pi1i_},X_,_},Theta_,{h_,Dh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* Standard-Update*) 
\tBlock[{zmiss,lc,H,r,vi,vi1,gain,inn,lik,Yii,k,p,ikh,Pii},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t    
\t    If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)
\t    
\t\tH = Dh[Yi1i,X,Theta]; 
\t\tH = H[[lc]]; 
\t\tr = R[Yi1i,X,Theta][[lc,lc]];\t
\t\tvi = H . Pi1i . Transpose[H] + r; 
\t\t
\t\t(*If[vi[[1,1]]>10^5,Print[\"vi  \",vi]];*)
\t\t
\t\tvi1 = Inverse[vi];
\t\tgain = Pi1i . Transpose[H] . vi1; 
\t\t
\t\t(*
\t\tlc//Print;
\t\th[Yi1i,X,Theta][[lc]]//Print;
\t\t*)
\t\t
\t\tinn = Z[[lc]] - h[Yi1i,X,Theta][[lc]];\t
\t\tlik = -.5(Log[Det[vi]] + inn.vi1.inn);\t
\t\t
\t\tYii = Yi1i + gain.inn;
\t\t
\t\t{k,p} = H//Dimensions; 
\t\tikh = IdentityMatrix[p] - gain.H;
\t\tPii = ikh.Pi1i.Transpose[ikh] + gain.r.Transpose[gain];
\t\t
\t\t(*
\t\tPrint[\"Z\",Z, \"h\",h[Yi1i,X,Theta]//Chop,\"H\",H//Chop,\"lik\",lik];
\t\tPrint[\"Yi1i\",Yi1i,\"Yii\",Yii];
\t\t*)
\t\t(*
\t\tPrint[\"-------------------\"];
\t\tPrint[Pi1i~ii~Pii//MatrixForm];
\t\t*)
\t\t
\t
\t\t{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpEKF"],

Cell["\<\
MessUpHNF22//Clear
(***************************************************************)\t\t\t 
MessUpHNF22[{Z_,{Yi1i_,Pi1i_},X_,_},Theta_,{h_,Dh_,DDh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* Standard-Update*) 
\tBlock[{zmiss,lc,H,r,vi,vi1,gain,inn,lik,Yii,k,p,ikh,Pii,h2,h223,PP,M4mPP},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t    
\t    If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)
\t    
\t\tH = Dh[Yi1i,X,Theta]; 
\t\tH = H[[lc]];

\t\t{k,p}=Dimensions[H]; 

\t\tPP = Outer[Times,Pi1i,Pi1i];  (*ijkl*)
        M4mPP = Transpose[PP,{1,3,2,4}]+Transpose[PP,{1,3,4,2}]; \
(*Gauss-Fakt.*)
                             (*ikjl*)                (*iljk*)
        h2 = DDh[Yi1i,X,Theta]; 
\t\th2 = h2[[lc]];
        h223 =Partition[Flatten[h2],p*p];

        (*h223//Print;*)

\t\tr  = R[Yi1i,X,Theta][[lc,lc]];

\t\t(*var(h+h'(y-m)+1/h''(y-m)^2; var[(y-m)^2]=m_4-m_2^2*)
\t
\t\tvi = H . Pi1i . Transpose[H] + 
             1/4 h223.Partition[Flatten[M4mPP],p*p].Transpose[h223]
             +r; 
\t\t
\t\t(*If[vi[[1,1]]>10^5,Print[\"vi  \",vi]];*)
\t\t
\t\tvi1 = Inverse[vi];
\t\tgain = Pi1i . Transpose[H] . vi1;
\t\tinn = Z[[lc]] - h[Yi1i,X,Theta][[lc]] - 1/2 h223.Flatten[Pi1i];\t
\t\tlik = -.5(Log[Det[vi]] + inn.vi1.inn);\t
\t\t
\t\tYii = Yi1i + gain.inn;
\t\t 
\t\tikh = IdentityMatrix[p] - gain.H;
        Pii = ikh.Pi1i;

\t\t(*PiiJ = ikh.Pi1i.Transpose[ikh] + gain.r.Transpose[gain];*)
\t\t(*Pii-PiiJ//Print;*)
\t\t
\t\t
\t\t(*
\t\tPrint[\"Z\",Z, \"h\",h[Yi1i,X,Theta]//Chop,\"H\",H//Chop,\"lik\",lik];
\t\tPrint[\"Yi1i\",Yi1i,\"Yii\",Yii];
\t\t*)
\t\t(*
\t\tPrint[\"-------------------\"];
\t\tPrint[Pi1i~ii~Pii//MatrixForm];
\t\t*)
\t\t
\t
\t\t{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpEKFIter//Clear
(***************************************************************)\t\t\t 
MessUpEKFIter[{Z_,{Yi1i_,Pi1i_},X_,eta_},Theta_,{h_,Dh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* Mess-Update, entwickelt um eta *) 
\t
\tBlock[{zmiss,lc,H,r,vi,vi1,gain,inn,lik,Yii,k,p,ikh,Pii},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t    
\t    If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)
\t    
\t\tH = Dh[eta,X,Theta]; 
\t\tH = H[[lc]]; 
\t\tr = R[eta,X,Theta][[lc,lc]];\t
\t\tvi = H . Pi1i . Transpose[H] + r; 
\t\t\t
\t\tvi1 = Inverse[vi];
\t\tgain = Pi1i . Transpose[H] . vi1;
\t\tinn = Z[[lc]] - h[eta,X,Theta][[lc]] - H.(Yi1i-eta);\t
\t\tlik = -.5(Log[Det[vi]] + inn.vi1.inn);\t
\t\t
\t\tYii = Yi1i + gain.inn;
\t\t
\t\t{k,p} = H//Dimensions;
\t\tikh = IdentityMatrix[p] - gain.H;
\t\tPii = ikh.Pi1i.Transpose[ikh] + gain.r.Transpose[gain];
\t\t
\t\t(*
\t\tPrint[\"Z\",Z, \"h\",h[Yi1i,X,Theta]//Chop,\"H\",H//Chop,\"lik\",lik];
\t\tPrint[\"Yi1i\",Yi1i,\"Yii\",Yii];
\t\t*)
\t\t(*
\t\tPrint[\"-------------------\"];
\t\tPrint[Pi1i~ii~Pii//MatrixForm];
\t\t*)
\t\t
\t
\t\t{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpEKFInno//Clear
(***************************************************************)\t\t\t 
MessUpEKFInno[{Z_,{Yi1i_,Pi1i_},X_,_},Theta_,{h_,Dh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* ret. innovation, innocov und normierte inno.*) 
\t
\tBlock[{zmiss,lc,H,r,vi,vi1,gain,inn,lik,Yii,k,p,ikh,Pii,innostern},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t    
\t    If[lc == {},Return[{Yi1i,Pi1i,0,{miss},{{miss}},{miss}}]]; (*keine \
Messung*)
\t    
\t\tH = Dh[Yi1i,X,Theta]; 
\t\tH = H[[lc]]; 
\t\tr = R[Yi1i,X,Theta][[lc,lc]];\t
\t\tvi = H . Pi1i . Transpose[H] + r; 
\t\t\t
\t\tvi1 = Inverse[vi];
\t\tgain = Pi1i . Transpose[H] . vi1;
\t\tinn = Z[[lc]] - h[Yi1i,X,Theta][[lc]];\t
\t\tlik = -.5(Log[Det[vi]] + inn.vi1.inn);\t
\t\t
\t\tYii = Yi1i + gain.inn;
\t\t
\t\t{k,p} = H//Dimensions;
\t\tikh = IdentityMatrix[p] - gain.H;
\t\tPii = ikh.Pi1i.Transpose[ikh] + gain.r.Transpose[gain];
\t\tinnostern=Transpose[CholeskyDecomposition[vi1]].inn;
\t\t
\t\t{Yii,Pii,lik,inn,vi,innostern}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpEKFinno"],

Cell["\<\
MessUpEKFcov//Clear
(***************************************************************)\t\t\t 
MessUpEKFcov[{Z_,{Yi1i_,Pi1i_},X_,_},Theta_,{h_,Dh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* EKF-Update, returns Pii and gains etc. *) 
\tModule[{zmiss,lc,H,r,vi,vi1,gain,inn,lik,Yii,k,p,ikh,Pii,
\t        jacobi,prederr},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t
\tlc = Locate[zmiss,False]; 
\t
\t    If[lc == {},Return[{Pi1i,0,0,0,lc}]]; (*keine Messung*)
\t    
\t\tH = Dh[Yi1i,X,Theta];
\t\tH = H[[lc]]; 
\t\tr = R[Yi1i,X,Theta][[lc,lc]];\t
\t\tvi = H . Pi1i . Transpose[H] + r;
\t\tvi1 = Inverse[vi];
\t\tgain = Pi1i . Transpose[H] . vi1;\t\t
\t\tjacobi  = -.5 Log[Det[vi]]; 
\t\t{k,p} = H//Dimensions;
\t\tikh = IdentityMatrix[p] - gain.H;
\t\tPii = ikh.Pi1i.Transpose[ikh] + gain.r.Transpose[gain];
\t
\t\t{Pii,jacobi,vi1,gain,lc}
\t\t
]
MessUpEKFstate//Clear
(***************************************************************)\t\t\t 
MessUpEKFstate[{Z_,{Yi1i_,Pi1i_},X_,_},Theta_,{h_,Dh_,R_},
               {vi1_,gain_,lc_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* EKF-Update, returns states *) 
\tModule[{inn,prederr,Yii},
\t
\t    If[lc == {},Return[{Yi1i,0}]]; (*keine Messung*)
\t    
\t\tinn = Z[[lc]] - h[Yi1i,X,Theta][[lc]];\t
\t\tprederr = -.5 inn.vi1.inn;
\t\tYii = Yi1i + gain.inn;

\t\t{Yii,prederr}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpGARCH//Clear
(***************************************************************)\t\t\t 
MessUpGARCH[{Z_,{Yi1i_,Pi1i_},X_,dt_},Theta_,{g_,h_,Dh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(* *) 
\tBlock[{zmiss,lc,H,r,vi,vi1,gain,inn,lik,Yii,k,p,ikh,Pii},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t    
\t    If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)
\t    
\t\tH = Dh[Yi1i,X,Theta]; 
\t\tH = H[[lc]]; 
\t\tr = R[Yi1i,X,Theta][[lc,lc]];\t
\t\tvi = H . Pi1i . Transpose[H] + r; 
\t\t
\t\t(*If[vi[[1,1]]>10^5,Print[\"vi  \",vi]];*)
\t\t
\t\tvi1 = Inverse[vi];
\t\tgain = Pi1i . Transpose[H] . vi1;
\t\tinn = Z[[lc]] - h[Yi1i,X,Theta][[lc]];\t
\t\tlik = -.5(Log[Det[vi]] + inn.vi1.inn);\t
\t\t
\t\t
\t\tYii = Yi1i + { gain[[1,1]]* inn[[1]], 
\t\t               g[Yi1i,X,Theta][[2,2]]*(inn[[1]]^2/vi[[1,1]]-1)*Sqrt[dt/2] \
};
\t\t
\t\t
\t\t(*Yii = Yi1i + gain.inn;*)
\t\t(*
\t\t{k,p} = H//Dimensions;
\t\tikh = IdentityMatrix[p] - gain.H;
\t\t*)
\t\t
\t\tikh=IdPlusA[-gain.H];
\t\t
\t\tPii = ikh.Pi1i.Transpose[ikh] + gain.r.Transpose[gain];
\t\t
\t\t(*
\t\tPrint[\"Z\",Z, \"h\",h[Yi1i,X,Theta]//Chop,\"H\",H//Chop,\"lik\",lik];
\t\tPrint[\"Yi1i\",Yi1i,\"Yii\",Yii];
\t\t*)
\t\t(*
\t\tPrint[\"-------------------\"];
\t\tPrint[Pi1i~ii~Pii//MatrixForm];
\t\t*)
\t\t
\t
\t\t{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpGARCH"],

Cell["\<\
MessUpEKF1//Clear
(***************************************************************)\t\t\t 
MessUpEKF1[{Z_,Yi1i_,X_,_},Theta_,{h_,Dh_,R_},{$n$_,miss_,Option_}]:=
(***************************************************************)\t\t\t 
\t(* Yi1i = Stichprobe, gemeinsamer update *) 
\t
\tModule[{Pi1i,S,Yi1im,pi1i,Yiim,Pii,lik,pii,z,Yii},
\t
\t{Pi1i,S,Yi1im} = Varianz[Yi1i];
\tpi1i = GaussDichte[#,{Yi1im,Pi1i,Inverse[Pi1i]}]&;
\t
\t{Yiim,Pii,lik} = MessUpEKF[{Z,{Yi1im,Pi1i},X,_},Theta,{h,R,Dh},{miss}];
\t
\tpii = GaussDichte[#,{Yiim,Pii,Inverse[Pii]}]&;
\t\t
\tIf[Option == 1,\t\t
\t\t(* Zufallszahlen N(Yiim,Pii) *)
\t\tz = Table[GaussC[],{jj,$n$},{pp,p}].CholeskyDecomposition[Pii]; 
\t\tYii = (Shape[1,{$n$}]/.(1->Yiim)) + z
\t\t
\t\t,(*else*)
\t\t 
\t\tYii = Indeterminate];
\t\t
\t{Yii,pii,pi1i,lik,Yiim,Pii}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpEKF2//Clear
(***************************************************************)\t\t\t 
MessUpEKF2[{Z_,{Yi1i_,Pi1i_},X_,_},Theta_,{h_,Dh_,R_},{miss_}]:=
(***************************************************************)\t\t\t 
\t(*  *) 
\tModule[{zmiss,lc,H,Hs,r,vi,vi1,gain,inn,
\t\t    lik,Yii},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t
    H = Dh[Yi1i,X,Theta];
\tH = H[[lc]];
\tr = R[Yi1i,X,Theta][[lc,lc]];
\tHs = Transpose[H];\t\t
\tvi = H . Pi1i . Hs  + r;
\tvi1 = Inverse[vi];
\tgain = Pi1i . Hs . vi1;
\t\t(*Print[\"gain \",gain//MatrixForm];*)
\tinn = Z[[lc]] - h[Yi1i,X,Theta][[lc]];\t\t\t
\tlik = -.5(Log[Det[vi]] + inn.vi1.inn);\t
\tYii = Yi1i + gain.inn;
\t\t
{Yii,lik}
\t\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpEKFSum//Clear
(***************************************************************)\t\t\t 
MessUpEKFSum[{Z_,Yi1i_,X_,_},Theta_,{h_,Dh_,R_},{miss_}]:=
(***************************************************************)
(*ohne Gewichte und resampling*)

Module[{sm,m,s,Pi1i,pn,Yii,lik},
\tPi1i = smoothQuickAndDirtyM[Yi1i,1]; (*1 = SML*)
\tpn = MessUpEKF2[{Z,{#,Pi1i},X,_},Theta,{h,Dh,R},{miss}]&;
\t{Yii,lik} = Map[pn,Yi1i]//Transpose;
\tlik = Log[Exp[lik]//mean];
\t{Yii,lik}
]

MessUpEKFSumX//Clear
(***************************************************************)\t\t\t 
MessUpEKFSumX[{Z_,Yi1i_,X_,_},Theta_,{h_,Dh_,R_},{miss_,nn_}]:=
(***************************************************************)
(*mit Gewichten und resampling (ohne Pii)*)

Module[{sm,m,s,Pi1i,pn,Yii,lik,L,LQuer,alpha,n,MM},

\tPi1i = smoothQuickAndDirtyM[Yi1i,1]; (*1 = SML*)
\tpn = MessUpEKF2[{Z,{#,Pi1i},X,_},Theta,{h,Dh,R},{miss}]&;
\t{Yii,lik} = Map[pn,Yi1i]//Transpose;
\tL = Exp[lik];
\tn = Length[Yi1i];
\tLQuer = Apply[Plus,L]/n; 
\talpha = L/(LQuer*n); (*alpha//Print;*)
\tlik = Log[LQuer];
    MM = RandomMultinomial[n//Range,alpha,nn]//Flatten//Sort;
    (*MM//Print;*)
\tYii = Yii[[MM]];
\t{Yii,lik}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpEKFSum1//Clear
(***************************************************************)\t\t\t 
MessUpEKFSum1[{Z_,Yi1i_,X_,_},Theta_,{h_,Dh_,R_},{miss_,nn_}]:=
(***************************************************************)
(* mit Gewichten alpha = Ln/Summe Ln und resampling*)

Module[{Pi1i,pn,Yii,lik,L,LQuer,alpha,n},

\tPi1i = smoothQuickAndDirtyM[Yi1i,1]//Re; (*1 = SML*)
\tPi1i = Pi1i*FACTOR;
\t                    (* Print[\"smooth  in MessUpEKFSum1\",Pi1i//VecDiag]; \
*)
\tn = Length[Yi1i];
\t
\tIf[ LINEARMESS,
\t\t
\t\t{Pii,jacobi,vi1,gain,lc} = 
\t\t\tMessUpEKFcov[{Z,{Yi1i//First,Pi1i},X,_},Theta,{h,Dh,R},{miss}];  
\t\t 
\t\t{Yii,prederr} = 
\t\t\tMap[MessUpEKFstate[{Z,{#,Pi1i},X,_},Theta,{h,Dh,R},
                {vi1,gain,lc},{miss}]&,Yi1i]//Transpose;
    \tlik = jacobi + prederr;
    \t(*Print[jacobi,prederr];*)
    \tPii = Shape[1,{n}]/. 1->Pii;
\t\t
\t,(*else*)
\t
\t    pn = MessUpEKF [{Z,{#,Pi1i},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = Map[pn,Yi1i]//Transpose,
\t\t
\t\tpn = MessUpEKF [{Z,{#,Pi1i},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = Map[pn,Yi1i]//Transpose
\t];
\t
\t(*Pii//First//Print;*)
\t
\tL = Exp[lik];
\tLQuer = Apply[Plus,L]/n; 
\talpha = L/(LQuer*n);    (* alpha//Print; *)
\tlik = Log[LQuer];       (* lik//Print; *)
\t
\t(*
\talpha = Chop[alpha,10.^-1];
\tpos = Position[alpha,0];
\t{alpha,Yii,Pii} = Map[Delete[#,pos]&,{alpha,Yii,Pii}];
\tsum = Apply[Plus,alpha];
\talpha = alpha/sum;
\t*)
\t
\tIf[RESAMPLING,
\t\tYiiR = RandomKDE[Yii,alpha,Pii,GaussC,n], (*resampling*)
\t\tYiiR = Yii];
\t
\t{YiiR,lik}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpEKFSum1"],

Cell["\<\
MessUpEKFSumDKS//Clear
(***************************************************************)\t\t\t 
MessUpEKFSumDKS[{Z_,Yi1i_,Pi1i_,X_},Theta_,{h_,Dh_,R_},{miss_,nn_}]:=
(***************************************************************)
(* mit Gewichten alpha = Ln/Summe Ln und resampling*)

Module[{pn,Yii,YiiR,Pii,lik,L,LQuer,alpha,n},

\t(*Pi1i//First//VecDiag//Print;*)
\t
\tn = Length[Yi1i];
\t
\tIf[ LINEARMESS,
\t\t
\t\t{Pii,jacobi,vi1,gain,lc} = 
\t\t\tMap[MessUpEKFcov[{Z,{Yi1i//First,#},X,_},Theta,{h,Dh,R},{miss}]&,
\t\t\t    Pi1i]//Transpose;  
\t\t 
\t\t{Yii,prederr} = 
\t\t\tMapThread[MessUpEKFstate[{Z,{#1,#2},X,_},Theta,{h,Dh,R},
                      {#3,#4,#5},{miss}]&,
                      {Yi1i,Pi1i,vi1,gain,lc}]//Transpose;
    \tlik = jacobi + prederr;
    \t(*Print[jacobi,prederr];*)
\t\t\t\t
\t,(*else*)
\t
\t    pn = MessUpEKF [{Z,{#1,#2},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = MapThread[pn,{Yi1i,Pi1i}]//Transpose,
\t\t
\t\tpn = MessUpEKF [{Z,{#1,#2},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = MapThread[pn,{Yi1i,Pi1i}]//Transpose
\t];
\t
\t                            (*Pii//First//Print;*)
\tL = (1/n)* Exp[lik];
\tLQuer = Apply[Plus,L]; 
\talpha = L/LQuer;            (* alpha//Print; *)
\tlik = Log[LQuer];

\tIf[RESAMPLING,
\t\tYiiR = RandomKDE[Yii,alpha,Pii,GaussC,n], (*resampling*)
\t\tYiiR = Yii];
\t
\t{YiiR,lik,Yii,Pii,alpha}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpEKFSumDKS"],

Cell["\<\
MessUpEKFSumAlpha//Clear
(***************************************************************)\t\t\t 
MessUpEKFSumAlpha[{Z_,{Yi1i_,Pi1i_,alphai1i_},X_},Theta_,
                  {h_,Dh_,R_},{miss_,n_}]:=
(***************************************************************)
(* mit a priori-Gewichten alphai1i *)
(* Gaussian sum filter             *)

Module[{Pii,jacobi,vi1,gain,lc,Yii,prederr,pn,lik,L,LQuer,alphaii},

\tIf[ LINEARMESS,
\t\t
\t\t{Pii,jacobi,vi1,gain,lc} = 
\t\t\tMap[MessUpEKFcov[{Z,{Yi1i//First,#},X,_},Theta,{h,Dh,R},{miss}]&,
\t\t\t    Pi1i]//Transpose;  
\t\t 
\t\t{Yii,prederr} = 
\t\t\tMapThread[MessUpEKFstate[{Z,{#1,#2},X,_},Theta,{h,Dh,R},
                      {#3,#4,#5},{miss}]&,
                      {Yi1i,Pi1i,vi1,gain,lc}]//Transpose;
    \tlik = jacobi + prederr;
    \t(*Print[jacobi,prederr];*)
\t\t\t\t
\t,(*else*)
\t
\t    pn = MessUpEKF [{Z,{#1,#2},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = MapThread[pn,{Yi1i,Pi1i}]//Transpose,
\t\t
\t\tpn = MessUpEKF [{Z,{#1,#2},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = MapThread[pn,{Yi1i,Pi1i}]//Transpose
\t];
\t
\tL = alphai1i Exp[lik];
\tLQuer = Apply[Plus,L]; 
\talphaii = L/LQuer;
\tlik = Log[LQuer];
\t
\t{Yii,Pii,alphaii,lik}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpEKFSumAlpha"],

Cell[CellGroupData[{

Cell["??MessUpGHF", "Input",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell["\<\
Global`MessUpGHF
MessUpGHF[{Z_, {Yi1i_, Pi1i_}, X_, m_}, Theta_, {h_, R_}, {miss_}] := \
Module[{zmiss, lc, Eh, Varh, CovYZ, VarZ, VarZ1, gain, inn, lik, Yii, Pii, \
vals, hl}, zmiss = (miss === #1 & ) /@ Z; lc = Locate[zmiss, False]; If[lc == \
{}, Return[{Yi1i, Pi1i, 0}]]; vals = TrafoMueSigma[VALS, {Yi1i, Pi1i}]; 
     hl = (h[#1, X, Theta][[lc]] & ) /@ vals; Eh = WEIGHT . hl; Varh = WEIGHT \
. (Outer[Times, #1, #1] & ) /@ hl - Outer[Times, Eh, Eh]; CovYZ = WEIGHT . \
MapThread[Outer[Times, #1, #2] & , {vals, hl}]; CovYZ = CovYZ - Outer[Times, \
Yi1i, Eh]; VarZ = Varh + R[Yi1i, X, Theta][[lc,lc]]; 
     VarZ1 = Inverse[VarZ]; gain = CovYZ . VarZ1; inn = Z[[lc]] - Eh; lik = \
-0.5*(Log[Det[VarZ]] + inn . VarZ1 . inn); Yii = Yi1i + gain . inn; Pii = \
Pi1i - gain . Transpose[CovYZ]; Pii = Shift[Symmetrize[Pii], 10^(-8)]; {Yii, \
Pii, lik}]\
\>", "Print",
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
MessUpOmnibus//Clear
(***************************************************************)\t\t\t 
MessUpOmnibus[{Z_,{Yi1i_,Pi1i_,alphai1i_},X_},Theta_,
                  {h_,Dh_,R_},
                  {miss_,n_,Generator_,seed_,RESAMPLING_:True}]:=
(***************************************************************)
(* mit a priori-Gewichten alphai1i *)
(* alle Methoden                   *)

Block[{Pii,jacobi,vi1,gain,lc,Yii,YiiR,prederr,pn,lik,L,LQuer,alphaii,c},

\tIf[ LINEARMESS,
\t\t
\t\t{Pii,jacobi,vi1,gain,lc} = 
\t\t\tMap[MessUpEKFcov[{Z,{Yi1i//First,#},X,_},Theta,{h,Dh,R},{miss}]&,
\t\t\t    Pi1i]//Transpose;  
\t\t 
\t\t{Yii,prederr} = 
\t\t\tMapThread[MessUpEKFstate[{Z,{#1,#2},X,_},Theta,{h,Dh,R},
                      {#3,#4,#5},{miss}]&,
                      {Yi1i,Pi1i,vi1,gain,lc}]//Transpose;
    \tlik = jacobi + prederr;
    \t(*Print[jacobi,prederr];*)
\t\t\t\t
\t,(*else*)
\t   
\t    pn = MessUpEKF[{Z,{#1,#2},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = MapThread[pn,{Yi1i,Pi1i}]//Transpose,
\t\t
\t\tpn = MessUpEKF[{Z,{#1,#2},X,_},Theta,{h,Dh,R},{miss}]&;
\t\t{Yii,Pii,lik} = MapThread[pn,{Yi1i,Pi1i}]//Transpose
\t];
\t
\t(*Print[pn];*)
\t
\tc = lik//Max;   
\tL = alphai1i Exp[lik-c]; 
\tLQuer = Apply[Plus,L];  
\t
\t(*Print[\"---------------\"]; lik//Print;*)
\t
\talphaii = L/LQuer;
\tlik = Log[LQuer]+c;
\t
\t(*
\talphai1i//Print;
\talphaii//Print;
\tPrint[N[lik,16]]; 
\t*)
\t
\t
\t(*RESAMPLING//Print;*)
\t
\tIf[RESAMPLING,
\t\tYiiR = RandomKDE[Yii,alphaii,Pii,Generator,seed,n], (* resampling *)
\t\tYiiR = Yii];
\t
\t{YiiR,lik,Yii,Pii,alphaii}
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpOmnibus"],

Cell["\<\
\t\t\t
MessUpFokkerOrdinal//Clear
(***************************************************************)\t\t\t 
MessUpFokkerOrdinal[{Z_,Yi1i_,X_,_},Theta_,{h_,R_},{_}]:=
(***************************************************************)\t\t\t 
\t(* Problem: yii k\[UDoubleDot]rzer als yi1i *) 
\t
\tModule[{sm,s,m,pi1i,yii,z,lik,r,ind,pii},
\t
\t{sm,m,s} = smoothQuickAndDirty1[Yi1i];
\tIf[sm == 0, Print[\"Singul\[ADoubleDot]re Verteilung pi1i\"]; sm = 10.^-6];
\tpi1i = KernDichte[#,Yi1i,GaussKern,sm]&;
\tyii = Select[Yi1i,(h[#,X,Theta] == Z)&];
\tz = Length[yii]/Length[Yi1i] //N;
\tlik = Log[z];
\tr = R[{_},X,Theta];  
\tind = chi[{Z,#,X},Theta,{h,r}]&;
\tpii = (ind[#] pi1i[#]/z)&;
\t{yii,pii,pi1i,lik}
]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
SmoothEKF1//Clear
SmoothEKF1[{Z_,Yii_,Pii_,X_,dt_},Theta_,{f_,Df_,g_,h_,Dh_,R_},miss_]:=
(***************************************************************)\t\t\t 
Block[{Yi1i,Pi1i,F,Yi1i1,Pi1i1,yii,pii,liki},

\t{Yi1i,Pi1i,F} = TimeUpEKFSmooth[{Yii,Pii,X,dt},Theta,{f,Df,g}];
\t
\tYi1i = Over[Yi1i,YMAX]; 
\t
\t{Yi1i1,Pi1i1,liki} = \
MessUpEKF[{Z,{Yi1i,Pi1i},X//Last,_},Theta,{h,Dh,R},{miss}];\t
\t
\tyii = Yii + F.(Yi1i1-Yi1i);
\tpii = Pii + F.(Pi1i1-Pi1i).Transpose[F];
\t
\t{yii,pii,liki}
\t
]
\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
EKFFilterSmoother//Clear
EKFFilterSmoother[{Z_,Yii_,Pii_,X_,dt_,L_},Theta_,{f_,Df_,g_,h_,Dh_,R_},miss_]\
:=
(***************************************************************)\t\t\t 
Block[{eta,xiref,Yi1i,Pi1i,F,Phi,Yi1i1,Pi1i1,liki,Yii1,Pii1},

xiref=Yii;

Do[
\t{Yi1i,Pi1i,F,Phi} = \
TimeUpEKFSmoothIter[{Yii,xiref,Pii,X,dt},Theta,{f,Df,g}];
\t
\tYi1i = Over[Yi1i,YMAX]; 
\t
\teta = If[l==1,Yi1i,Yi1i1];
\t{Yi1i1,Pi1i1,liki} = \
MessUpEKFIter[{Z,{Yi1i,Pi1i},X//Last,eta},Theta,{h,Dh,R},{miss}];\t
\t
\tYii1 = Yii + F.(Yi1i1-Yi1i);  (* Yii1 = xirefneu; Yi1i1 = etaneu *)
\tPii1 = Pii + F.(Pi1i1-Pi1i).Transpose[F];
\t
\txiref = Yii1;
\t
 ,{l,1,L}];
 
 {Yii1,Pii1,liki}\t
\t
]
\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
SmoothEKF//Clear
SmoothEKF[{Z_,Yii_,Pii_,alphaii_,X_,dt_},Theta_,{f_,Df_,g_,h_,Dh_,R_},miss_]:=\

(***************************************************************)\t\t\t 
Block[{yiiZ,PiiZ,alphaiiZ,likZ,c},

{yiiZ,PiiZ,likZ}=
MapThread[SmoothEKF1[{Z,#1,#2,X,dt},Theta,{f,Df,g,h,Dh,R},miss]&,
\t                 {Yii,Pii}]//Transpose;

c = likZ//Max; 
alphaiiZ=alphaii*Exp[likZ-c];

\t\t(*Print[\"likZ  \",likZ];
\t\tPrint[\"alphaii  \",alphaii];
\t\tPrint[\"alphaiiZ \",alphaiiZ];
\t\t*)
\t
alphaiiZ=alphaiiZ/Apply[Plus,alphaiiZ];


\t\t(*alphaiiZ=Shape[1./Length[alphaii],{Length[alphaii]}];*)
\t\t(*alphaiiZ=alphaii;*) (*alt*)
\t\t(*Print[\"alphaii  \",alphaii];*)
\t\t(*Print[\"alphaiiZ \",alphaiiZ];*)
\t\t(*Print[\"Pii  \",VecDiag/@Pii ];*)
\t\t(*Print[\"PiiZ \",VecDiag/@PiiZ];*)

                 
{yiiZ,PiiZ,alphaiiZ}\t                  
]\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"SmoothEKF"],

Cell["\<\
(***************************************************************)\t\
\t\t 
SmoothEKFIter//Clear
SmoothEKFIter[{Z_,Yii_,Pii_,alphaii_,X_,dt_,L_},Theta_,{f_,Df_,g_,h_,Dh_,R_},\
miss_]:=
(***************************************************************)\t\t\t 
Block[{yiiZ,PiiZ,alphaiiZ,likZ,c},

{yiiZ,PiiZ,likZ}=
MapThread[EKFFilterSmoother[{Z,#1,#2,X,dt,L},Theta,{f,Df,g,h,Dh,R},miss]&,
\t                        {Yii,Pii}]//Transpose;

c = likZ//Max; 
alphaiiZ=alphaii*Exp[likZ-c];
\t
alphaiiZ=alphaiiZ/Apply[Plus,alphaiiZ];
                 
{yiiZ,PiiZ,alphaiiZ}\t                  
]\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"SmoothEKFIter"],

Cell["\<\
(***************************************************************)\t\
\t\t 
SmoothEKF2//Clear
SmoothEKF2[{Z_,etaj_,_,X_,dt_},Theta_,{f_,Df_,g_,h_,Dh_,R_},miss_]:=
(***************************************************************)\t\t\t 
Block[{Yi1j,Pi1j,Fj,Yi1ji1,Pi1ji1,liki,fI,OmegaI},

\t{Yi1j,Pi1j,Fj} = TimeUpEKFSmooth2[{etaj,_,X,dt},Theta,{f,Df,g}];
\t
\t(* X//Print;
\t{Yi1j,Pi1j,Fj}//Print;*)
\t
\t(*Yi1j//Abs//Max//Print;*)
\t\t
\tYi1j = Over[Yi1j,YMAX]; 
\t
\t{Yi1ji1,Pi1ji1,liki} = 
\t            MessUpEKF[{Z,{Yi1j,Pi1j},X//Last,_},Theta,{h,Dh,R},{miss}];\t
\t
\tfI     = Fj.(Yi1ji1-Yi1j)/dt;
\tOmegaI = Fj.(Pi1ji1-Pi1j).Transpose[Fj]/dt;
\t
\t
\t
\t{fI,OmegaI}
\t
]
\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"SmoothEKF2"],

Cell[TextData[{
  "MessUpUKF//Clear\n\
(*****************************************************************************\
*)\t\t\t \nMessUpUKF[{Z_,{Yi1i_,pi1i_},X_,kappa_},Theta_,{h_,R_},{miss_}]:=\n\
(*****************************************************************************\
*)\t\t\t \n(* Normal-Korrelation mit Unscented Transform*) \n\t\n\
Module[{zmiss,lc,hi1i,Eh,Varh,CovYZ,VarZ,VarZ1,gain,inn,lik,Yii,Pii,Pi1i},\n\t\
\nzmiss = Map[SameQ[miss,#]&,Z];\t\t\nlc = Locate[zmiss,False]; \n\t    \n\
If[lc == {},Return[{Yi1i,pi1i,0}]]; (*keine Messung*)\n\n",
  StyleBox["Pi1i = Shift[",
    FontColor->RGBColor[1, 0, 0]],
  "pi1i",
  StyleBox[",10^-16,\"",
    FontColor->RGBColor[1, 0, 0]],
  "MessUpUKF ",
  StyleBox["\"]//Symmetrize;",
    FontColor->RGBColor[1, 0, 0]],
  "\n{yi1i,alphai1i}=SigmaSample[Yi1i,Pi1i,kappa]; \n\nhi1i = \
Map[h[#,X,Theta][[lc]]&,yi1i]; (* missing weglassen*) \n\n\n\
(*{Eh,Varh,CovYZ}=",
  StyleBox["WeightedMeanAndVarianceSpezial",
    FontColor->RGBColor[1, 0, 0]],
  "[yi1i,Yi1i,hi1i,alphai1i];*)\n\nEh=alphai1i.hi1i; \n\
Varh=alphai1i.Map[Dyad,hi1i]-Dyad[Eh,Eh]; \nCovYZ= \
alphai1i.MapThread[Outer[Times,#1,#2]&,{yi1i,hi1i}]-Dyad[Yi1i,Eh];\n\n\
(*Print[Yi1i,",
  StyleBox["WeightedMean",
    FontColor->RGBColor[1, 0, 0]],
  "[yi1i,alphai1i]];*)\n\nVarZ = Varh + R[Yi1i,X,Theta][[lc,lc]]; (* \
(Z,Z)=(h,h)+R *) \t\n\t\t\nVarZ1 = Inverse[VarZ];  \n\t\t\t\t\ngain = \
CovYZ.VarZ1; (* (Y,Z)=(Y,h) *)\n\t\t\ninn = Z[[lc]] - Eh;\n\t\t\n(*Print[Z, \
Eh];*)\n\t\t\t\nlik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);\t\n\t\t\nYii = \
Yi1i + gain.inn;\n\t\t\nPii = Pi1i - gain.Transpose[CovYZ];\n\n\n(*\n\
Print[\"CovYZ\",CovYZ//MatrixForm];\n\
Print[\"Pi1i\",Pi1i//MatrixForm,\"CovYZ.VarZ1.CovZY\",gain.Transpose[CovYZ]//\
MatrixForm];\nPrint[\"Pii\",Pii//Eigenvalues];\n\
Print[\"Pii\",Pii//MatrixForm];\n*)\n\t\n\t\t(*\n\t\tYii[[2]]=Yi1i[[2]];\n\t\t\
Pii[[2,2]]=Pi1i[[2,2]]; (*ad hoc*)\n\t\t*)\n\t\n{Yii,Pii,lik}\n\t\t\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpUKF"],

Cell[TextData[{
  "MessUpUKFBayes//Clear\n\
(*****************************************************************************\
*)\t\t\t \n\
MessUpUKFBayes[{Z_,{Yi1i_,Pi1i_},X_,kappa_},Theta_,{h_,R_},{miss_}]:=\n\
(*****************************************************************************\
*)\t\t\t \n(* Bayes-Formel mit Normal-Korrelation und UT*) \n\t\n\
Module[{zmiss,lc,Y0,P0,lik0,P01,vals,vals2,phi,phi0,pmess,Lik,Yii,Pii,alpha,p}\
,\n\t\nzmiss = Map[SameQ[miss,#]&,Z];\t\t\nlc = Locate[zmiss,False]; \n\t    \
\nIf[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)\n\n\
{Y0,P0,lik0}=MessUpUKF[{Z,{Yi1i,Pi1i},X,kappa},Theta,{h,R},{miss}];\n\n\
P0=Shift[P0,10^-8,\"MessUpUKFBayes \"]//Symmetrize;\n{vals,alpha}  = \
SigmaSample[Y0,P0,kappa]; \n\nvals2 = Map[Dyad,vals];\n\nPi1i1=Pi1i//Inverse;\
\nphi  =GaussDichte1[#,{Yi1i,Pi1i,Pi1i1}]&;\n\n\
pmess=GaussDichte[Z,{h[#,X,Theta][[lc]],R[#,X,Theta][[lc]]}]&;\n\n\
P01=P0//Inverse;\nphi0 =GaussDichte1[#,{Y0,P0,P01}]&;\n\npl = Map[(pmess[#] \
phi[#]/phi0[#])&,vals]//Chop;\n\nLik= alpha.pl;\n\np=Yi1i//Length;\nIf[ \
Lik==0,Lik=Exp[lik0](2Pi)^(-p/2);Print[\"Warnung: Lik=0, Lik0=\",Lik] ];\n\n\
Yii= (alpha.(pl vals))/Lik;\nPii= (alpha.(pl vals2))/Lik - Dyad[Yii];\n",
  StyleBox["\n(*Pii//Print;*)",
    FontColor->RGBColor[1, 0, 0]],
  "\n\n{Yii,Pii,Lik//Log}\n\t\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "MessUpSMKF//Clear\n\
(*****************************************************************************\
*)\t\t\t \n\
MessUpSMKF[{Z_,{Yi1i_,Pi1i_},X_,n_,seed_,anti_},Theta_,{h_,R_},{miss_}]:=\n\
(*****************************************************************************\
*)\t\t\t \n(* Normal-Korrelation mit Monte Carlo*) \n\t\n\
Module[{zmiss,lc,hi1i,Eh,Varh,CovYZ,VarZ,VarZ1,gain,inn,lik,Yii,Pii,alphai1i},\
\n\t\nzmiss = Map[SameQ[miss,#]&,Z];\t\t\nlc = Locate[zmiss,False]; \n\t    \n\
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)\n\n\nSeedRandom[seed];\n\
yi1i = RandomGauss[Yi1i, Pi1i, n, Gauss, anti]; (*antithetisch=1*)\n\
alphai1i=1/n;\n\t\nhi1i = Map[h[#,X,Theta][[lc]]&,yi1i]; (* missing \
weglassen*) \n\t\n{Eh,Varh,CovYZ}=",
  StyleBox["WeightedMeanAndVarianceSpezial",
    FontColor->RGBColor[1, 0, 0]],
  "[yi1i,Yi1i,hi1i,alphai1i];\n\n(*Print[Yi1i,",
  StyleBox["WeightedMean",
    FontColor->RGBColor[1, 0, 0]],
  "[yi1i,alphai1i]];*)\n\nVarZ = Varh + R[Yi1i,X,Theta][[lc,lc]]; (* \
(Z,Z)=(h,h)+R *) \t\n\t\t\nVarZ1 = Inverse[VarZ];  \n\t\t\t\t\ngain = \
CovYZ.VarZ1; (* (Y,Z)=(Y,h) *)\n\t\t\ninn = Z[[lc]] - Eh;\n\t\t\n(*Print[Z, \
Eh];*)\n\t\t\t\nlik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);\t\n\t\t\nYii = \
Yi1i + gain.inn;\n\t\t\nPii = Pi1i - gain.Transpose[CovYZ];\n\n",
  StyleBox["Pii = Shift[Pii,SHIFT$];\n",
    FontColor->RGBColor[1, 0, 0]],
  "\n\t\n{Yii,Pii,lik}\n\t\t\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpSMKF"],

Cell["\<\
MessUpGF//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGF[{Z_,{Yi1i_,Pi1i_},X_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Normal-Korrelation mit Gauss-Integral*) 
\t
Module[{zmiss,lc,Eh,Varh,CovYZ,VarZ,VarZ1,gain,inn,lik,Yii,Pii,s,a,b},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

k1=lc//Length; 
p=Yi1i//Length;

s=Pi1i//VecDiag//Sqrt;
(*s//Print;*)
{a,b}={Yi1i-ksigma s,Yi1i+ksigma s}; 

hi=(h[#1,X,Theta][[lc]][[#2]])&;

Eh = Table[
     GaussIntegral[hi[#,i]&,{Yi1i,Pi1i},{a,b},genau]
     ,{i,k1}];

Varh = Table[
       GaussIntegral[hi[#,i]hi[#,j]&,{Yi1i,Pi1i},{a,b},genau]
      ,{i,k1},{j,k1}];
      
Varh=Varh-Outer[Times,Eh,Eh];

CovYZ=Table[
       GaussIntegral[#[[i]]*hi[#,j]&,{Yi1i,Pi1i},{a,b},genau]
      ,{i,p},{j,k1}];

CovYZ = CovYZ-Outer[Times,Yi1i,Eh];

VarZ = Varh + R[Yi1i,X,Theta][[lc,lc]]; (* (Z,Z)=(h,h)+R *) \t
\t\t
VarZ1 = Inverse[VarZ];  
\t\t\t\t
gain = CovYZ.VarZ1; (* (Y,Z)=(Y,h) *)
\t\t
inn = Z[[lc]] - Eh;
\t\t
(*Print[Z, Eh];*)
\t\t\t
lik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);\t
\t\t
Yii = Yi1i + gain.inn;
\t\t
Pii = Pi1i - gain.Transpose[CovYZ];


\t
{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpGF"],

Cell["\<\
MessUpGHF//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHF[{Z_,{Yi1i_,Pi1i_},X_,m_},Theta_,{h_,R_},{miss_,zweipi_:True}]:=
(*****************************************************************************\
*)\t\t\t 
(* Normal-Korrelation mit Gauss-Hermite-Integral*) 
\t
Module[{zmiss,lc,Eh,Varh,CovYZ,VarZ,VarZ1,gain,inn,lik,Yii,Pii,vals,hl,p},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

vals  = TrafoMueSigma[VALS,{Yi1i,Pi1i}];
hl    = Map[h[#,X,Theta][[lc]]&,vals];

Eh    = WEIGHT.hl;
Varh  = WEIGHT.Map[Outer[Times,#,#]&,hl]-Outer[Times,Eh,Eh];
CovYZ = WEIGHT.MapThread[Outer[Times,#1,#2]&,{vals,hl}]; 
CovYZ = CovYZ-Outer[Times,Yi1i,Eh];

VarZ  = Varh + R[Yi1i,X,Theta][[lc,lc]]; (* (Z,Z)=(h,h)+R *) \t
\t\t
VarZ1 = Inverse[VarZ];  
\t\t\t\t
gain  = CovYZ.VarZ1; (* (Y,Z)=(Y,h) *)
\t\t
inn   = Z[[lc]] - Eh;
\t\t
(*Print[Z, Eh];*)
\t\t\t
lik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);

If[zweipi,p=Yi1i//Length; lik=lik-p/2 Log[2 Pi]];\t
\t\t
Yii = Yi1i + gain.inn;
\t\t
Pii = Pi1i - gain.Transpose[CovYZ];

(*Pii = Shift[Pii//Symmetrize,10^-8];*)

(*Print[{Yi1i,Yii}//Transpose//MatrixForm];*)

{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpGHF"],

Cell["\<\
MessUpGHFN//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHFN[{Z_,{Yi1i_,Pi1i_},X_,mm_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Normal-Korrelation mit Gauss-Hermite-Integral, Panel-Daten*) 
\t
Module[{N,n,m,k,zmiss,lc,Eh,Varh,CovYZ,VarZ,VarZ1,gain,inn,lik,Yii,Pii,vals,\
hl},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

N = Yi1i//Length;
Eh=Table[0,{n,N}];
Varh=CovYZ=Table[0,{n,N},{n,N}];


Do[ (*univariat*)

vals  = TrafoMueSigma[VALS1,{{Yi1i[[n]]},{{Pi1i[[n,n]]}}}];

hl    = Map[h[#,X,Theta]&,vals];

Eh[[n]]      = (WEIGHT1.hl)[[1]];
Varh[[n,n]]  = (WEIGHT1.hl^2)[[1]];
CovYZ[[n,n]] =  WEIGHT1.MapThread[(Part[#1,1]*Part[#2,1])&,{vals,hl}] 

,{n,1,N}];


Do[ (*bivariat*)

vals = TrafoMueSigma[VALS2,{ Yi1i[[{n,m}]],
\t                       {{Pi1i[[n,n]],Pi1i[[n,m]]},
\t                        {Pi1i[[m,n]],Pi1i[[m,m]]}}},10^-16];

hl    = Map[h[#,X,Theta]&,vals,{2}]; 
  
hl2 = Map[Part[#,1]Part[#,2]&,hl];

Varh[[n,m]]  = (WEIGHT2.hl2);
CovYZ[[n,m]] =  WEIGHT2.MapThread[(Part[#1,1]*Part[#2,2])&,{vals,hl}]; 

Varh[[m,n]]  = Varh[[n,m]];
CovYZ[[m,n]] = CovYZ[[n,m]]

,{n,1,N},{m,n+1,N}];

    
Varh  = (Varh - Outer[Times,Eh,Eh])[[lc,lc]];
CovYZ = (CovYZ-Outer[Times,Yi1i,Eh][[All,lc]]);

VarZ  = Varh + R[Yi1i,X,Theta][[lc,lc]]; (* (Z,Z)=(h,h)+R *) \t
\t\t
VarZ1 = Inverse[VarZ];  
\t\t\t\t
gain  = CovYZ.VarZ1; (* (Y,Z)=(Y,h) *)
\t\t
inn   = Z[[lc]] - Eh[[lc]];
\t\t
(*Print[Z, Eh];*)
\t\t\t
lik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);\t
\t\t
Yii = Yi1i + gain.inn;
\t\t
Pii = Pi1i - gain.Transpose[CovYZ];

(*Pii = Shift[Pii//Symmetrize,10^-8];*)

(*Print[{Yi1i,Yii}//Transpose//MatrixForm];*)

{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(*******************************************************************\
***********)\t\t\t 
pzypyp0//Clear
pzypyp0[z_,lc_,y_,t_,Theta_,h_,R_,mue_,SigmaI_,mue0_,Sigma0I_]:=
(*****************************************************************************\
*)\t\t\t 
Block[{Rl,zhl,Q1,ymue,Q2,ymue0,Q3,zweipi,detRl,jacobi23,Jacobi},

Rl = Map[R[#,t,Theta][[lc,lc]]&,y];
zhl = Map[(z-h[#,t,Theta][[lc]])&,y];
Q1 = MapThread[(#1.Inverse[#2].#1)&,{zhl,Rl}];

ymue = Map[(#-mue)&,y];
Q2 = Map[(#.SigmaI.#)&,ymue];

ymue0 = Map[(#-mue0)&,y];
Q3 = Map[(#.Sigma0I.#)&,ymue0];

zweipi = 2 Pi;
detRl = (Map[Det[zweipi #]&,Rl])^(-.5);

jacobi23 = (Det[SigmaI]/Det[Sigma0I])^(.5); 

Jacobi = detRl jacobi23; 
Jacobi Exp[-.5(Q1+Q2-Q3)]

]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpGHFBayes//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHFBayes[{Z_,{Yi1i_,Pi1i_},X_,m_},Theta_,{h_,R_},{miss_},itermax_:1]:=
(*****************************************************************************\
*)\t\t\t 
(* Bayes-Formel; Normal-Korrelation mit Gauss-Hermite-Integral*) 
\t
Module[{zmiss,lc,Y0,P0,lik0,P01,vals,vals2,Pi1i1,pl,Lik,Yii,Pii,iter},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

{Y0,P0,lik0}=MessUpGHF[{Z,{Yi1i,Pi1i},X,m},Theta,{h,R},{miss}];

(*Y0=Yi1i; P0=Pi1i;*)
(*{Y0,P0,lik0}//Print;*)

Do[  (*Print[\"------------\",iter];*)

If[iter>1,Y0=Yii;P0=Pii];

vals  = TrafoMueSigma[VALS,{Y0,P0}];
vals2 = Map[Dyad,vals];

Pi1i1=Pi1i//Inverse;
P01  =P0//Inverse;

pl = pzypyp0[Z[[lc]],lc,vals,X,Theta,h,R,Yi1i,Pi1i1,Y0,P01];

Lik= WEIGHT.pl;  (*mit 2Pi!!*)

Yii= (WEIGHT.(pl vals))/Lik;
Pii= (WEIGHT.(pl vals2))/Lik - Dyad[Yii];

,{iter,1,itermax}];

{Yii,Pii,Lik//Log}

\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpGHFBayes"],

Cell["\<\
MessUpGHFBayesAlt//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHFBayesAlt[{Z_,{Yi1i_,Pi1i_},X_,m_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Bayes-Formel mit Normal-Korrelation mit Gauss-Hermite-Integral*) 
\t
Module[{zmiss,lc,Y0,P0,lik0,P01,vals,vals2,Pi1i1,phi,phi0,pl,pmess,Lik,Yii,\
Pii},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

{Y0,P0,lik0}=MessUpGHF[{Z,{Yi1i,Pi1i},X,m},Theta,{h,R},{miss}];


(*{Y0,P0,lik0}//Print;*)

vals  = TrafoMueSigma[VALS,{Y0,P0}];
vals2 = Map[Dyad,vals];

Pi1i1=Pi1i//Inverse;
phi  =GaussDichte1[#,{Yi1i,Pi1i,Pi1i1}]&;

pmess=GaussDichte[Z[[lc]],{h[#,X,Theta][[lc]],R[#,X,Theta][[lc,lc]]}]&;

P01  =P0//Inverse;
phi0 =GaussDichte1[#,{Y0,P0,P01}]&;

pl = Map[(pmess[#] phi[#]/phi0[#])&,vals]; 

Lik= WEIGHT.pl;  (*mit 2Pi!!*)

Yii= (WEIGHT.(pl vals))/Lik;
Pii= (WEIGHT.(pl vals2))/Lik - Dyad[Yii];

{Yii,Pii,Lik//Log}

\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpGHFBayesOI//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHFBayesOI[{Z_,{Yi1i_,Pi1i_},X_,m_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Bayes-Formel mit Gauss-Hermite-Integral ohne IS*) 
\t
Module[{zmiss,lc,P01,vals,vals2,Pi1i1,phi,phi0,pl,pmess,Lik,Yii,Pii},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

(*Pi1i//Print;*)

vals  = TrafoMueSigma[VALS,{Yi1i,Pi1i},0];
vals2 = Map[Dyad,vals];

Pi1i1=Pi1i//Inverse;
phi  =GaussDichte1[#,{Yi1i,Pi1i,Pi1i1}]&;

pmess=GaussDichte[Z[[lc]],{h[#,X,Theta][[lc]],R[#,X,Theta][[lc,lc]]}]&;

pl = Map[pmess[#]&,vals]; 

Lik= WEIGHT.pl;  (*mit 2Pi!!*)

Yii= (WEIGHT.(pl vals))/Lik;
Pii= (WEIGHT.(pl vals2))/Lik - Dyad[Yii];

{Yii,Pii,Lik//Log}

\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpGHFBayesOI"],

Cell["\<\
MessUpGHFalt//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHFalt[{Z_,{Yi1i_,Pi1i_},X_,m_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Normal-Korrelation mit Gauss-Hermite-Integral*) 
\t
Module[{zmiss,lc,Eh,Varh,CovYZ,VarZ,VarZ1,gain,inn,lik,Yii,Pii,s,a,b},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)

k1=lc//Length; 
p=Yi1i//Length;

hi=(h[#1,X,Theta][[lc]][[#2]])&;

vals=TrafoMueSigma[VALS,{Yi1i,Pi1i}];

(*
Eh = Table[
     GaussHermite2[hi[#,i]&,{vals,WEIGHT}]
     ,{i,k1}];
     
Varh = Table[
       GaussHermite2[hi[#,i]hi[#,j]&,{vals,WEIGHT}]
      ,{i,k1},{j,k1}];
      
Varh=Varh-Outer[Times,Eh,Eh];

CovYZ=Table[
       GaussHermite2[#[[i]]*hi[#,j]&,{vals,WEIGHT}]
      ,{i,p},{j,k1}];
*)      

hl=Map[h[#,X,Theta][[lc]]&,vals];
Eh =WEIGHT.hl;
Varh = WEIGHT.Map[Outer[Times,#,#]&,hl];
Varh=Varh-Outer[Times,Eh,Eh];
CovYZ=WEIGHT.MapThread[Outer[Times,#1,#2]&,{vals,hl}]; 
 

CovYZ = CovYZ-Outer[Times,Yi1i,Eh];

VarZ = Varh + R[Yi1i,X,Theta][[lc,lc]]; (* (Z,Z)=(h,h)+R *) \t
\t\t
VarZ1 = Inverse[VarZ];  
\t\t\t\t
gain = CovYZ.VarZ1; (* (Y,Z)=(Y,h) *)
\t\t
inn = Z[[lc]] - Eh;
\t\t
(*Print[Z, Eh];*)
\t\t\t
lik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);\t
\t\t
Yii = Yi1i + gain.inn;
\t\t
Pii = Pi1i - gain.Transpose[CovYZ];

Pii=Shift[Pii//Symmetrize,10^-8];

{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpGHFn//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpGHFn[{Z_,{Yi1i_,Pi1i_,alphai1i_},X_,m_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Normal-Korrelation mit Gauss-Hermite-Integral*) 
\t
Module[{zmiss,lc,c,Yii,Pii,alphaii,lik,L},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 

\t    
If[lc == {},Return[{0,Yi1i,Pi1i,alphai1i}]]; (*keine Messung*)


{Yii,Pii,lik}=
\tMapThread[MessUpGHF[{Z,{#1,#2},X,m},Theta,{h,R},{miss}]&,
\t         \t\t    {Yi1i,Pi1i}]//Transpose;

c = lik//Max;   
L = alphai1i Exp[lik-c]; 
LQuer = Apply[Plus,L];  
alphaii = L/LQuer;
lik = Log[LQuer]+c;

(*{lik,Yii,Pii,alphaii}//Print;*)

\t
{lik,Yii,Pii,alphaii}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"MessUpGHFn"],

Cell["\<\
MessUpUKFn//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpUKFn[{Z_,{Yi1i_,Pi1i_,alphai1i_},X_,kappa_},Theta_,{h_,R_},{miss_}]:=
(*****************************************************************************\
*)\t\t\t 
(* Normal-Korrelation mit UT*) 
\t
Module[{zmiss,lc,c,Yii,Pii,alphaii,lik,L},
\t
zmiss = Map[SameQ[miss,#]&,Z];\t\t
lc = Locate[zmiss,False]; 
\t    
If[lc == {},Return[{0,Yi1i,Pi1i,alphai1i}]]; (*keine Messung*)


{Yii,Pii,lik}=
\tMapThread[MessUpUKF[{Z,{#1,#2},X,kappa},Theta,{h,R},{miss}]&,
\t         \t\t    {Yi1i,Pi1i}]//Transpose;

c = lik//Max;   
L = alphai1i Exp[lik-c]; 
LQuer = Apply[Plus,L];  
alphaii = L/LQuer;
lik = Log[LQuer]+c;

(*{lik,Yii,Pii,alphaii}//Print;*)

\t
{lik,Yii,Pii,alphaii}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
MessUpUKFalt//Clear
(*****************************************************************************\
*)\t\t\t 
MessUpUKFalt[{Z_,{Yi1i_,Pi1i_,{yi1i_,alphai1i_}},X_},Theta_,{h_,R_},{miss_}]:=\

(*****************************************************************************\
*)\t\t\t 
\t(* Normal-Korrelation mit Unscented Transform*) 
\t
\tBlock[{zmiss,lc,VarZ,VarZ1,EY,Eh,CovYZ,gain,inn,lik,Yii,Pii},
\t
\tzmiss = Map[SameQ[miss,#]&,Z];\t\t
\tlc = Locate[zmiss,False]; 
\t    
\t If[lc == {},Return[{Yi1i,Pi1i,0}]]; (*keine Messung*)
\t     
\t\thi1i = Map[h[#,X,Theta][[lc]]&,yi1i]; (* missing weglassen*)  
\t\t
\t\t{Eh,Varh} = WeightedMeanAndVariance[hi1i,alphai1i]; (* E(z)=E(h(y)); \
Var(z) = Var(h)+R *)
\t\t
\t\tVarZ = Varh + R[Yi1i,X,Theta][[lc,lc]]; \t
\t\t
\t\tVarZ1 = Inverse[VarZ];  
\t\t
\t\t{EY,Eh,CovYZ} = WeightedMeanAndVariance[yi1i,hi1i,alphai1i];  \
(*Cov(y,z)=Cov(y,h(y))*)

\t\tgain = CovYZ.VarZ1;
\t\t
\t\tinn = Z[[lc]] - Eh[[lc]];
\t\t
\t\t(*Print[Z, Eh];*)
\t\t\t
\t\tlik = -.5(Log[Det[VarZ]] + inn.VarZ1.inn);\t
\t\t
\t\tYii = Yi1i + gain.inn;
\t\t
\t\tPii = Pi1i - CovYZ.VarZ1.Transpose[CovYZ];
\t\t
\t\t(*
\t\tYii[[2]]=Yi1i[[2]];
\t\tPii[[2,2]]=Pi1i[[2,2]]; (*ad hoc*)
\t\t*)
\t
\t\t{Yii,Pii,lik}
\t\t
]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kalman-Filter", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
KalmanFokker//Clear
(***************************************************************)\t\t\t 
KalmanFokker[{Z_,X_},Theta_,{f_,g_,h_,R_,p0_,dt_},
\t\t\t\t{{y1_,y2_,dy_},nstd_,$dw$_,seed_,MISS_}]:=
(***************************************************************)\t\t\t 
Module[{$n$},

ti  = messind[Z,MISS]; (*Indices mit mind. einer Messung*)
dti = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

$n$ = Length[$dw$];

(*ti//Print;*)

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,$n$];
{z,y0}//Print;

{yii,pii,pi1i,lik} = 
\tMessUpFokker2[{Z[[1]],y0,Xi,_},Theta,{h,R},{{y1,y2,dy},nstd,$n$}];
Print[\"yii\",yii];

YF   = {};
Pii  = {pii};
Pi1i = {pi1i};

Do[ Print[i];

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\tPrint[\"nach Timeup\"];
\tyi1i = Over[yi1i,YMAX];
\ty    = Over[y,YMAX];
\tYF = Join[YF,Drop[y//Transpose,-1]];
\tj = ti[[i+1]]; 
\t
\t{yii,pii,pi1i,liki} = 
\t\tMessUpFokker2[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,R},{{y1,y2,dy},nstd,$n$}];
\t
\t(*liki//Print;*)
\tPii  = Append[Pii,pii];
\tPi1i = Append[Pi1i,pi1i];\t
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

YF = Join[YF,{yii}];

{YF,lik,Pii,Pi1i}
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
EKF//Clear
(***************************************************************)\t\t\t 
EKF[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF*)
Block[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,IP,inno,likvec},

OVERFLOW=False;

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta]; \t

(*{Yi1i,Pi1i}//Print;*)

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{Yi1i,Pi1i},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];  
\t\t
If[option==4, inno = {Yii-Yi1i}];
If[option==5, likvec = {lik}];
\t\t
(*wird in TimeUpEKF ben\[ODoubleDot]tigt*)\t\t
Y0 = Yii; P0 = Pii; 
p = Length[Y0]; IP = IdentityMatrix[p];

YF   = {};
PF   = {};


Do[ (*Print[i];*)

\t

\tXi  = Take[ X,dti[[i]] ]; 
\t
\t\t\t(*
\t\t\t{Yi1i,Pi1i,Y,P} = 
\t\t\t\t\tTimeUpEKF[{Yii,Pii,Xi,dt},Theta,{f,Df,g},{Y0,P0,IP}];
\t\t\t*)
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF[{Yii,Pii,Xi,dt},Theta,{f,Df,g}];
\t
\t(*Yi1i//Print;
\tPi1i//MatrixForm//Print;*)
\t
\t(*
\t{Yi1i,Ov} = Over[Yi1i,YMAX,i]; 
\t{Y,Ov}    = Over[Y,YMAX,i];
\t
\tIf[Ov, Pi1i = 100 IP]; 
\t{P,Ov}    = Over[P,YMAX,i];
\t
\t*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\tIf[option==5, likvec = Append[likvec,liki]];

\t\t
\t  (* liki//Print; *)\t
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)\t
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,Return[{lik,inno}//N]];

If[option==5,Return[{lik,likvec}//N]];


];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKF"],

Cell["\<\
EKG//Clear
(***************************************************************)\t\t\t 
EKG[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_,Nonlin_}]:=
(***************************************************************)\t\t\t 
(* EKG Gl\[ADoubleDot]tter*)

Block[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,IP,inno,Y1,P1,ASTERN, Astern,
        YG,YGalt,PG,PGalt},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;


Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta]; 

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{Yi1i,Pi1i},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t
If[option==4, inno = {Yii-Yi1i}];
\t\t

YF   = {};
PF   = {};
Y1   = {};
P1   = {};
ASTERN={};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ]; 
\t
\t{Yi1i,Pi1i,Y,P,Astern} = 
\t\tTimeUpEKFJacobi[{Yii,Pii,Xi,dt},Theta,{f,Df,g},Nonlin]; 
\t
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\tY1 = Join[Y1,Drop[Y, 1]];
\tP1 = Join[P1,Drop[P, 1]];
\tASTERN = Join[ASTERN,Astern]; 
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\t\t
\t  (* liki//Print; *)\t
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)\t
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

YF = Join[YF,{Yii}];
PF = Join[PF,{Pii}];

(*Gl\[ADoubleDot]tter*)

YGalt = YF//Last;
PGalt = PF//Last;
YG = {YGalt};
PG = {PGalt};

(*
ti//Print;
YF//Dimensions//Print; 
PF//Dimensions//Print;
Y1//Dimensions//Print; 
P1//Dimensions//Print; 
*)

\t\t
Do[\t(*Print[j];*)

\tYii   = YF[[j]];
\tYi1i  = Y1[[j]];
\tPii   = PF[[j]];
\tPi1i  = P1[[j]];
\t
\t\t(*Pi1i//Print;*)
\t\t\t
\t{YGalt,PGalt} = MNonLinGlattUp[ {YGalt,PGalt},
\t\t\t\t\t\t\t\t    {Yii,Pii,Yi1i,Pi1i},ASTERN[[j]] ];
\t\t\t\t\t\t\t\t    
\t(*{YGalt,PGalt}//Print;*) 
\t
\tYG = Join[{YGalt},YG];
\tPG = Join[{PGalt},PG];
\t\t\t
\t\t
,{j,(ti//Last)-1,1,-1}];

\t\t\t\t
{YG,PG,YF,PF,lik}

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKG"],

Cell["\<\
MNonLinGlattUp//Clear
MNonLinGlattUp[{YG_,PG_},{Yii_,Pii_,Yi1i_,Pi1i_},Asterni_]:=
\tBlock[{YGneu,PGneu,Pistern},
\t\t
\t\t\tPistern = LinearSolve[Pi1i,Asterni.Pii]//Transpose;
\t\t\t
\t\t\tYGneu = Yii + Pistern.(YG - Yi1i);
\t\t\tPGneu = Pii + Pistern.(PG - Pi1i).Transpose[Pistern];
\t
\t\t   {YGneu,PGneu}
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
EKFEDM//Clear
(***************************************************************)\t\t\t 
EKFEDM[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t   {miss_,option_,Nonlin_:1,const_:False}]:=
(***************************************************************)\t\t\t 
(* EKF mit EDM *)
Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,likvec,
        A,B,G,Omega,Ostern,Astern,Bstern,A1},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;


Xi = X[[1]];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];

If[option==5, likvec = {lik}];

If[const, (*konstantes A*)
\t
    A = Df[Yii,Xi,Theta]; 
    G =  g[Yii,Xi,Theta];
    Omega = G.Transpose[G];
    
    (* 
    B = (f[Yii,Xi,Theta] - A.Yii)//Spalte;  
\t{Ostern,Astern,Bstern} = STERN01R[Omega,A,B,dt,Nonlin];
\tp=Yii//Length;
\tA1=Inverse[A].(Astern-IdentityMatrix[p]);
\tA1//Print;
\t*)
    
    If[Det[A]==0, Print[\"|A|=0\"];
    {Ostern,Astern,A1} = STERN01R1[Omega,A,1,dt,Nonlin],
    {Ostern,Astern,A1} = STERN01R[Omega,A,1,dt,Nonlin]
    ];
\t
];

YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t\t
    {Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKFEDM[{Yii,Pii,Xi,dt},Theta,
\t\t             {f,Df,g,
\t\t              Ostern,Astern,A1,Bstern,A},{Nonlin,const}];
\t
\t(*
\tYi1i//MatrixForm//Print;
\tPi1i//Print;
\tReturn[];
    *)
\t
\t
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];

\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t   
\t(*{Yi1i,Pi1i}//Print;*)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t
\tIf[option==5, likvec = Append[likvec,liki]];
\t
\t  (* liki//Print; *)\t
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)\t
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==1, Return[lik//N]];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==5,Return[{lik,likvec}//N]];
\t
\t
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKFEDM"],

Cell["\<\
(***************************************************************)\t\
\t\t 
EKF[{Z_,X_},Theta_,{f_,Df_,g_,Dg_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF*)
Module[{ti,dti,dti1,Xi,Yii,Pii,lik,liki,YF,PF,Yi1i,Pi1i,Y,P,j},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Short//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1; 

Xi = X[[1]];
{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},Theta,{h,Dh,R},{\
miss}];

YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF[{Yii,Pii,Xi,dt},Theta,{f,Df,g,Dg}];
\t
\tYi1i = Over[Yi1i,YMAX];
\t(*Y    = Over[Y,YMAX];*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*j//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
EKF2//Clear
(***************************************************************)\t\t\t 
EKF2[{Z_,X_},Theta_,{f_,Df_,DDf_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF mit Korr. 2. Ordnung*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,IP},

OVERFLOW=False;

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;



Xi = X[[1]];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t\t
(*wird in TimeUpEKF ben\[ODoubleDot]tigt*)\t\t
Y0 = Yii; P0 = Pii; 
p = Length[Y0]; IP = IdentityMatrix[p];

YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF2[{Yii,Pii,Xi,dt},Theta,{f,Df,DDf,g}];
\t
\t(*
\tYi1i = Over[Yi1i,YMAX]; 
\tY    = Over[Y,YMAX];
\tPi1i = Over[Pi1i,YMAX]; 
\tP    = Over[P,YMAX];
\t*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t(*{Yii,Pii,liki}//Print;*)
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKF2"],

Cell["\<\
EKF4//Clear
(***************************************************************)\t\t\t 
EKF4[{Z_,X_},Theta_,{f_,Df_,DDf_,Omega_,DDOmega_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF mit Korr. 2. Ordnung in f und Omega*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,IP},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;



Xi = X[[1]];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t\t
YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF4[{Yii,Pii,Xi,dt},Theta,{f,Df,DDf,Omega,DDOmega}];
\t
\t
\tYi1i = Over[Yi1i,YMAX]; 
\t(*Y    = Over[Y,YMAX];*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t(*{Yii,Pii,liki}//Print;*)
\t(*liki//Print;*)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKF4"],

Cell["\<\
HNF22//Clear
(***************************************************************)\t\t\t 
HNF22[{Z_,X_},Theta_,{f_,Df_,DDf_,Omega_,DDOmega_,
                      h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* HNF(2,2) mit Korr. 2. Ordnung in f und Omega; Gauss-Fakt.*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,IP},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];

(*{Yii,Pii,lik}//Print;*)
\t\t\t
YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpHNF22[{Yii,Pii,Xi,dt},Theta,
\t\t            {f,Df,DDf,Omega,DDOmega}];
\t
\t
\t(*Yi1i = Over[Yi1i,YMAX];*)
\t(*Y    = Over[Y,YMAX];*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t\t
\t(*{Yii,Pii,liki}//Print;*)
\t(*liki//Print;*)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"HNF22"],

Cell["\<\
HNF23//Clear
(***************************************************************)\t\t\t 
HNF23[{Z_,X_},Theta_,{f_,Df_,DDf_,DDDf_,
                      Omega_,DDOmega_,
                      h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* HNF(2,3) mit Korr. 3. Ordnung in f und Omega*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,IP},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];

s//Clear;
p=mue[Xi,Theta]//Length;
{M6anal,Sanal}=MOMENTanalytisch[6,p,s];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t\t
YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpHNF23[{Yii,Pii,Xi,dt},Theta,
\t\t            {f,Df,DDf,DDDf,Omega,DDOmega},
\t\t            {M6anal,Sanal}];

\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t(*{Yii,Pii,liki}//Print;*)
\t(*liki//Print;*)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->{"HNF22", "HNF23"}],

Cell["\<\
HNF24//Clear
(***************************************************************)\t\t\t 
HNF24[{Z_,X_},Theta_,{f_,Df_,DDf_,DDDf_,DDDDf_,
                      Omega_,DDOmega_,DDDDOmega_,
                      h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* HNF(2,4) mit Korr. 4. Ordnung in f und Omega*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,s},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];

s//Clear;
p=mue[Xi,Theta]//Length;
{M6anal,Sanal}=MOMENTanalytisch[6,p,s];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t\t
YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpHNF24[{Yii,Pii,Xi,dt},Theta,
\t\t            {f,Df,DDf,DDDf,DDDDf,Omega,DDOmega,DDDDOmega},
\t\t            {M6anal,Sanal}];
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t(*{Yii,Pii,liki}//Print;*)
\t(*liki//Print;*)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->{"HNF22", "HNF23", "HNF24"}],

Cell["\<\
EKF4alt//Clear
(***************************************************************)\t\t\t 
EKF4alt[{Z_,X_},Theta_,{f_,Df_,DDf_,g_,Dg_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF mit Korr. 2. Ordnung in f und g*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,IP},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;



Xi = X[[1]];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t\t
(*wird in TimeUpEKF ben\[ODoubleDot]tigt*)\t\t
Y0 = Yii; P0 = Pii; 
p = Length[Y0]; IP = IdentityMatrix[p];

YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF4[{Yii,Pii,Xi,dt},Theta,{f,Df,DDf,g,Dg}];
\t
\tYi1i = Over[Yi1i,YMAX]; 
\t(*Y    = Over[Y,YMAX];*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t(*{Yii,Pii,liki}//Print;*)
\t(*liki//Print;*)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
EKFGARCH//Clear
(***************************************************************)\t\t\t 
EKFGARCH[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t {miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF mit GARCH update*)

Block[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,IP,inno},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]*dt;


Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta];

{Yii,Pii,lik} = 
\tMessUpGARCH[{Z[[1]],{Yi1i,Pi1i},Xi,0},
\t\tTheta,{g,h,Dh,R},{miss}];

(* {Yii,Pii,lik}//Print; *)
\t\t
If[option==4, inno = {Yii-Yi1i}];

YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF[{Yii,Pii,Xi,dt},Theta,{f,Df,g}];
\t\t
\t
\tYi1i = Over[Yi1i,YMAX]; 
\tY    = Over[Y,YMAX];
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpGARCH[{Z[[j]],{Yi1i,Pi1i},X[[j]],dti1[[i]]},Theta,{g,h,Dh,R},{miss}]\
;\t
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\t\t
\t  (* liki//Print; *)\t
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)\t
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,Return[{lik,inno//N}]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKFGARCH"],

Cell["\<\
EKFInno//Clear
(***************************************************************)\t\t\t 
EKFInno[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* EKF mit verz\[ODoubleDot]gerten Messungen*)

Block[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,IP,
        inno,vi,innostern,Inno,deltat},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta];  

{Yii,Pii,lik,inno,vi,innostern} = 
\tMessUpEKFInno[{Z[[1]],{Yi1i,Pi1i},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];
\t\t
YF   = {};
PF   = {};
Inno = {innostern};

(* { inno,vi,innostern} //Print; *)


Do[ (*Print[i];*)

\t

\tXi  = Take[ X,dti[[i]] ];
\tdeltat = Table[(dti1[[i]]-1)*dt,{j,dti1[[i]]}];
\t
\t(* deltat//Print; *)\t
\t(* innostern//Print; *)
\t
\tinnostern1 = Table[innostern,{j,dti1[[i]]}];
\t
\t(*innostern1//Print; *)
\t
\t
\t(* {Xi,innostern,deltat}//Transpose//Print; *)
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\tTimeUpEKF[{Yii,Pii,{Xi,innostern1,deltat}//Transpose,dt},Theta,{f,Df,g}];
\t\t
\t
\tYi1i = Over[Yi1i,YMAX]; 
\tY    = Over[Y,YMAX];
\t
\t
\tIf[option==2,
\t\tYF = Join[YF,Drop[Y,-1]];
\t\tPF = Join[PF,Drop[P,-1]]
\t];
\t
\tIf[option==4,
\t\tYF = Join[YF,Drop[Y,-1]];
\t\tPF = Join[PF,Drop[P,-1]];
\t\tInno = Append[Inno,innostern] 
\t];
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t
\t{Yii,Pii,liki,inno,vi,innostern} = 
\t\tMessUpEKFInno[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t\t
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tInno = Append[Inno,innostern];
\tReturn[{YF,PF,lik,Inno//N}]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"EKFInno"],

Cell["\<\
ShojiOzaki//Clear
(***************************************************************)\t\t\t 
ShojiOzaki[{Z_,X_},Theta_,{f_,Df_,DDf_,g_,h_,Dh_,R_,mue_,sigma_,dt_},
\t\t{miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* ShojiOzaki-Methode mit Korr. 2. Ordnung*)

Block[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,IP},

OVERFLOW=False;

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];

{Yii,Pii,lik} = 
\tMessUpEKF[{Z[[1]],{mue[Xi,Theta],sigma[Xi,Theta]},Xi,_},
\t\tTheta,{h,Dh,R},{miss}];\t\t\t


YF   = {};
PF   = {};

Do[ (*Print[i];*)

\tXi  = Take[ X,dti[[i]] ];
\t
\t
\t{Yi1i,Pi1i,Y,P} = TimeUpShojiOzaki[{Yii,Pii,Xi,dt},Theta,{f,Df,DDf,g}];
\t
\t
\t(*Yi1i = Over[Yi1i,YMAX];*)
\t(*Y    = Over[Y,YMAX];*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\tj = ti[[i+1]];
\t(*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = 
\t\tMessUpEKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],_},Theta,{h,Dh,R},{miss}];\t
\t(*{Yii,Pii,liki}//Print;*)
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N],
\t
\tReturn[lik//N]];

];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"ShojiOzaki"],

Cell["\<\
KalmanFokkerEKF//Clear
(***************************************************************)\t\t\t 
KalmanFokkerEKF[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t{{y1_,y2_,dy_},nstd_,$dw$_,seed_,miss_}]:=
(***************************************************************)\t\t\t 
(* exakter time update, summarischer EKF1-Me\[SZ]update*)
Module[{$n$},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
dti = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

$n$ = Length[$dw$];

ti//Print;

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,$n$];

{yii,pii,pi1i,lik,ym,pm} = 
\tMessUpEKF1[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{$n$,miss,1}];


YF   = {};
Pii  = {pii};
Pi1i = {pi1i};

Do[ 

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\t
\tyi1i = Over[yi1i,YMAX];
\ty    = Over[y,YMAX];
\tYF = Join[YF,Drop[y//Transpose,-1]];
\tj = ti[[i+1]]; 
\t
\t{yii,pii,pi1i,liki,ym,pm} = 
\t\tMessUpEKF1[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,Dh,R},{$n$,miss,1}];
\t
\t(*liki//Print;*)
\tPii  = Append[Pii ,pii];
\tPi1i = Append[Pi1i,pi1i];\t
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

YF = Join[YF,{yii}];

{YF,lik,Pii,Pi1i}
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
KalmanFokkerEKFSum//Clear
(***************************************************************)\t\t\t 
KalmanFokkerEKFSum[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t   {{y1_,y2_,dy_},_,$dw$_,seed_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* exakter time update, EKFSum-Me\[SZ]update*)
Module[{ti,dti,$n$,Xi,z,y0,yii,lik,YF,dwi,yi1i,y,j,liki},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
dti = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

$n$ = Length[$dw$];

(*ti//Print;*)

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,$n$];

{yii,lik} = 
\tMessUpEKFSum[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{miss}];

YF   = {};

Do[ 

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\t
\tyi1i = Over[yi1i,YMAX];
\t(*y    = Over[y,YMAX];*)
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]]  ];
\tj = ti[[i+1]]; 
\t
\t{yii,liki} = 
\t\tMessUpEKFSum[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,Dh,R},{miss}];
\t
\t(*liki//Print;*)
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{yii}];Return[{YF,lik}],
\t\tReturn[lik]];
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Length[p0]", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
KalmanFokkerEKFSum1//Clear
(***************************************************************)\t\t\t 
KalmanFokkerEKFSum1[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t   {$dw$_,seed_,Generator_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* exakter time update, EKFSum1-Me\[SZ]update === KDF *)

Module[{ti,T1,dti,dti1,n,n1,Xi,z,y0,P0,yii,yiiR,lik,YF,dwi,yi1i,y,j,liki},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
                       (*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
                       (*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;
n = Length[$dw$];
n1 = 1./n;

Print[\"Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];

SeedRandom[seed];

Xi = X[[1]];

If[Length[p0]==0,
\t{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,n],
\t    y0 = RandomGauss[Xi,Theta,p0,n]
  ];

SeedRandom[seed];

(*{yiiR,lik} = MessUpEKFSum1[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{miss,n}];*)

P0 = FACTOR*smoothQuickAndDirtyM[y0,1]//Re; (*1 = SML*)
P0 = Shape[1,{n}]/.(1->P0);

{yiiR,lik,yii,Pii,alphaii} = 
\tMessUpOmnibus[{Z[[1]],{y0,P0,n1},X[[1]]},Theta,{h,Dh,R},
\t              {miss,n,Generator,seed,True}];
\t\t                  \t
YF   = {};

Do[  

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];
\t\t
\t{yi1i,y} = TimeUpFokker[{yiiR,Xi,dwi,dt},Theta,{f,g}];
\t
\tyi1i = Over[yi1i,YMAX];\t
\t(*y  = Over[y,YMAX];*)
\t
\t
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]]  ];
\tj = ti[[i+1]];
\t 
\t(*Print[{i+1,j}];*)
\t
\tSeedRandom[seed];
\t
\t(*
\t{yiiR,liki} = 
\t\tMessUpEKFSum1[{Z[[j]],yi1i,X[[j]],_},Theta,{h,Dh,R},{miss,n}];
\t*)
\t
\tPi1i = FACTOR*smoothQuickAndDirtyM[yi1i,1]//Re; (*1 = SML*)
\tPi1i = Shape[1,{n}]/.(1->Pi1i);
\t
    {yiiR,liki,yii,Pii,alphaii} = 
\t         MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,n1},X[[1]]},Theta,{h,Dh,R},
\t                       {miss,n,Generator,seed,True}];

\t\t\t
\t(*Print[\"yiiR  \",yiiR];*)
\t(*liki//Print;*)
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{yiiR}];Return[{YF,lik}],
\tReturn[lik]];
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"KalmanFokkerEKFSum1"],

Cell["\<\
KernDichteFilter//Clear
(***************************************************************)\t\t\t 
KernDichteFilter[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t   {dW_,seed_,Generator_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* KDF *)

Module[{ti,T1,dti,dti1,n,n1,Xi,z,y0,P0,yii,yiiR,lik,YF,dwi,yi1i,y,j,liki},

{ti,T1,T,dti,dti1} = Zeiten[Z,miss];

n = Length[dW];
n1 = 1./n; 

Print[\"Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];

{y0,P0,alpha0} = p0[X[[1]],Theta,n];

{yiiR,lik,yii,Pii,alphaii} = 
\t\t    MessUpOmnibus[{Z[[1]],{y0,P0,alpha0},X[[1]]},Theta,{h,Dh,R},
\t\t                  {miss,n,Generator,seed,True}];
\t\t                  \t
YF   = {};

Do[  

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,dW];
\t\t
\t{yi1i,y} = TimeUpFokker[{yiiR,Xi,dwi,dt},Theta,{f,g}];
\t
\tyi1i = Over[yi1i,YMAX];\t
\t(*y  = Over[y,YMAX];*)
\t\t
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]]  ];
\t
\tj = ti[[i+1]];
\t 
\t(*Print[{i+1,j}];*)
\t
\tPi1i = FACTOR*smoothQuickAndDirtyM[yi1i,1]//Re; (*1 = SML*)
\tPi1i = Shape[1,{n}]/.(1->Pi1i);
\t

    {yiiR,liki,yii,Pii,alphaii} = 
\t         MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,n1},X[[1]]},Theta,{h,Dh,R},
\t                       {miss,n,Generator,seed,True}];
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{yiiR}];Return[{YF,lik}],
\tReturn[lik]];
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"KernDichteFilter"],

Cell[TextData[{
  StyleBox["KDFImportance",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["KDFImportance",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t             \
{{l0_,l1_,l2_:0},{FACTOR_,FIX_},\n\t\t\t\t             \
step_,dW_,seed_,Generator_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
importance sampling, Pi1i fix oder Kerndichte-Gl\[ADoubleDot]ttparameter   \n\
\n   p_{i+1|i} = 1/N sum phi(y_{i+1}; y_J, P(i+1|i) * alpha{i+1|i}; \n   dy = \
fdt + gdW \n \n   option = 1: lik, \n   option = 2: YF: \
TxNxp,(Stichproben-Trajektorien) \n   option = 3: YF: Tx2xp (m und s)\n\n*)\n\
\nModule[{ti,T1,T,dti,dti1,n,n1,Xi,z,y0,P0,yiiR,lik,yii,Pii,alphaii,alphai1i,\
\n        YF,Misch,likvec,xi,dwi,yJ1,y,G,Pi1i,yi1i,liki,fI,f2,f1,g1,g2,XZ,p,\n\
        likratio,loglik},\n\n{ti,T1,T,dti,dti1} = Zeiten[Z,miss];\n\nn = \
Length[dW]; n1 = 1./n; \n\nPrint[\"",
  StyleBox["KDFImportance: ",
    FontColor->RGBColor[1, 0, 0]],
  "Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nfI//Clear; \n\
fI[{z_,y_},{x_,_,_},Th_]:= (z - h[y,x,Th]).Inverse[ R[y,x,Th] ].Dh[y,x,Th];\n \
                        \nf2//Clear;\nf2[y_,{x_,z_,lambdat_},Th_]:= f[y,x,Th] \
+ lambdat*fI[{z,y},{x,_,_},Th];\n\nf1//Clear;\nf1[y_,{x_,z_,lambdat_},Th_]:= \
f[y,x,Th]; \n\ng1//Clear;\ng1[y_,{x_,z_,lambdat_},Th_]:= g[y,x,Th];\n\n\
g2//Clear;\ng2[y_,{x_,z_,lambdat_},Th_]:= g[y,x,Th];\n\n\n\nSeedRandom[seed];\
\n\n{y0,P0,alpha0} = p0[X[[1]],Theta,n];  {n,p}=Dimensions[y0];\n\n\n\
{yiiR,lik,yii,Pii,alphaii} = \n\t\t    \
MessUpOmnibus[{Z[[1]],{y0,P0,alpha0},X[[1]]},Theta,{h,Dh,R},\n\t\t            \
      {miss,n,Generator,seed,True}];\n\t\t                  \n\t\t            \
      \t\t\t\t                 \t\nYF   = {}; Misch = {}; likvec = {lik};\n\n\
lambdat = Lambda",
  StyleBox["2",
    FontColor->RGBColor[0, 0, 1]],
  "[ti,T1,{l0,l1},miss];\n  \nXZ = {X, ",
  StyleBox["Interpol",
    FontColor->RGBColor[1, 0, 0]],
  "[Z,miss,1],lambdat}//Transpose;\n\nDo[  \n\n\t\tXi  = Take[ XZ,dti[[i]] ];\
\n \txi  = Xi//Last;\n\t\tdwi = Map[Take[#,dti1[[i]] ]&,dW];\n \n\t\t{yi1i,y} \
= TimeUpFokker[{yiiR,Xi,dwi,dt},Theta,{f2,g2},step];\n\t\t\n\t\t(* \
yi1i//Print; *)\n\t\t\n \tPi1i = If[FIX, FACTOR*IdentityMatrix[p],\n \t\n \t\t\
\t\t\t\t\t\t\t\t\t     FACTOR*smoothQuickAndDirtyM[yi1i,1]//Re (*1 = SML*)\n \
\t\t\t\t\t\t\t\t\t\t\t];\n \t\t \t\n\t Pi1i = Shape[1,{n}]/.(1->Pi1i);\n\n\t\t\
yi1i = Over[yi1i,YMAX];\n\t\t(*y  = Over[y,YMAX];*)\n\n\t\tIf[option==2,\n\t\t\
\t\t \tYF = Join[YF,Drop[y//Transpose,-1]];   \n\t   ];\n\t  \n\t \
If[option==3,\n\t\t\t\t YF = Join[YF,Drop[y//TensorMS//Transpose,-1]];\n\t\t\t\
\t (*YF//Print; *) \n\t   ];\n\t   \n\tj = ti[[i+1]]; \n\t(*Print[{i+1,j}];*)\
\n\t\n\tIf[dti1[[i]] =!= 1,\n\t\t\t\t\n\t\t\t\tloglik = ",
  StyleBox["LogLikelihoodRatio",
    FontColor->RGBColor[1, 0, 0]],
  "[#,{f1,f2},g1,Xi,dt,Theta]&; \n\t\t\t\talphai1i = n1*(Map[loglik,y]//Exp),\
\t  \n\t\n\t\t\t\talphai1i = n1\n\t];\n\n\n (* alphai1i//Print; *)\n\n\n\t\
{yiiR,liki,yii,Pii,alphaii} = \n\t\t    \
MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,alphai1i},X[[j]]},\n\t\t\t\t                 \
Theta,{h,Dh,R},{miss,n,Generator,seed,True}];\n\t\n\t(*liki//Print;*)\t\n\t\
(*likvec = Append[likvec,liki];*)\n\t\n\tlik +=liki;\n\t\n\
,{i,1,Length[ti]-1}];\n\n\n\nIf[option==1,Return[lik] ];\n\nIf[option==2,\n\t\
YF = Join[YF,{yiiR}];\n\t(*Misch = Append[Misch,{alphaii,yii,Pii}];*)\n\t\
Return[{YF,lik,Misch//Transpose}] ];\n\t\nIf[option==3,\n\tYF = \
Join[YF,{yiiR//TensorMS}];\n\tReturn[{YF,lik,Misch}] ];\t\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"KDFImportance"],

Cell["\<\

(***************************************************************)\t\t\t 
KalmanFokkerEKFSum1Mean[data_,parameter_,system_, 
\t  \t\t            {{y1_, y2_, dy_}, _, dw_, {seed_,M_},MISS_}] :=
(***************************************************************)\t\t\t 
\t Module[{m,s,lik},
\t  lik = 
\t  Table[
\t  KalmanFokkerEKFSum1[data,parameter,system, 
\t  \t\t\t\t\t  {{y1, y2, dy}, _, dw, seed+mm 1000,MISS}]
\t  ,{mm,M}];
\t  {m,s} = lik//Spalte//MS1;
\t  Print[\"gemittelte Lik, std  \",{m,s}];
\t  FDIGITS = -Log[10,s//First]; 
\t  Print[\"FDIGITS  \", FDIGITS];
\t  m[[1]]
\t  ]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
KalmanFokkerEKFSum2//Clear
(***************************************************************)\t\t\t 
KalmanFokkerEKFSum2[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t   {{y1_,y2_,dy_},_,$dw$_,seed_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* langes W(t), nur einmal seedrandom *)

Module[{ti,dti,n,Xi,z,y0,yii,lik,YF,dwi,yi1i,y,j,liki},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;
n = Length[$dw$];
(*Print[\"Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];*)

SeedRandom[seed];

Xi = X[[1]];

If[Length[p0]==0,
\t{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,n],
\t    y0 = RandomGauss[Xi,Theta,p0,n]
  ];


{yii,lik} = 
\tMessUpEKFSum1[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{miss,n}];
\t
YF   = {};

Do[  

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti[[i]] ]&,$dw$];
\t
\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\t
\tyi1i = Over[yi1i,YMAX];
\t(*y  = Over[y,YMAX];*)

\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]]  ];
\tj = ti[[i+1]]; 
\t(*Print[{i+1,j}];*)
\t
\t{yii,liki} = 
\t\tMessUpEKFSum1[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,Dh,R},{miss,n}];
\t
\t(*liki//Print;*)
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{yii}];Return[{YF,lik}],
\t\tReturn[lik]];
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "GaussianSumFilter//Clear\n\
(***************************************************************)\t\t\t \n\
GaussianSumFilter[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t     \
         {n_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
gaussian sum filter *)\n\n\
Module[{ti,dti,Xi,z,yi1i,Pi1i,alphai1i,yii,yiiR,Pii,lik,YF,PF,alphaii,\n      \
  y,P,j,liki,n1,alpha,m,sigma,s},\n\n{ti,T1,T,dti,dti1} = Zeiten[Z,miss];\n\n\
n1 = 1./n; \n\nPrint[\"GaussianSumFilter/EKF, n = \",n];\n\n\
{yi1i,Pi1i,alphai1i} = p0[X[[1]],Theta,n];\n\n(*alphai1i//Print;*)\n\n\
{yiiR,lik,yii,Pii,alphaii} = \n\t\t    \
MessUpOmnibus[{Z[[1]],{yi1i,Pi1i,alphai1i},X[[1]]},Theta,{h,Dh,R},\n\t\t      \
            {miss,n,Generator,seed,",
  StyleBox["False",
    FontColor->RGBColor[1, 0, 0]],
  "}];\n                 \nYF  = {}; PF  = {}; alpha = {};\n\nDo[  \n\n\tXi  \
= Take[ X,dti[[i]] ];\n\n\t{yi1i,Pi1i,y,P} = \n\t    \t\
MapThread[TimeUpEKF[{#1,#2,Xi,dt},Theta,{f,Df,g}]&,{yii,Pii}]//Transpose;\t\t\
\n\t\n\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]];\n\t             PF \
= Join[PF,Drop[P//Transpose,-1]];\n\t             alpha = \
Join[alpha,Shape[1,{dti1[[i]]-1}]/. 1->alphaii]\n\t             ];\n\t\n\t\
(*y=nxTxp; P=nxTxpxp*)\n\t\n\tIf[option==3,{m,sigma,s}=\n\t\t\t\t\t\t\t\t\t\t\
\t\tMapThread[Mischverteilung[alphaii,#1,#2]&,\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\t{Drop[y//Transpose,-1],\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t Drop[P//Transpose,-1]}]//Transpose;\n\t\t\t\t\t\t\t\t\t\t\t\t\
YF=Join[YF,m];\n\t\t\t\t\t\t\t\t\t\t\t\tPF=Join[PF,sigma];\n\t];\n\t\n\t      \
                   \n\tj = ti[[i+1]]; \n\t(*Print[{i+1,j}];*)\n\t\n\t\
alphai1i=alphaii;\n\t\n\t{yiiR,liki,yii,Pii,alphaii} = \n\t\t      \
MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,alphai1i},X[[j]]},\n\t\t\t\t                 \
  Theta,{h,Dh,R},{miss,n,Generator,seed,",
  StyleBox["False",
    FontColor->RGBColor[1, 0, 0]],
  "}];\t\t\n\t\t\t\t                   \t\n\t(* Print[alphaii]; *)            \
   \n\t(* liki//Print;\t*)  \n\t\n\tlik +=liki;\n\t\n,{i,1,Length[ti]-1}];\n\n\
If[option==2,\n     \tYF = Join[YF,{yii}];\n     \tPF = Join[PF,{Pii}];\n     \
\talpha = Join[alpha,{alphaii}];\n\t     Return[{YF,PF,alpha,lik}]];\n\t\n\t\
If[option==3,\n\t\t\t\t{m,sigma,s}=Mischverteilung[alphaii,yii,Pii];\n\t\t\t\t\
\tYF=Join[YF,{m}];\n\t\t\t\t\tPF=Join[PF,{sigma}];\n\t\t\t\t\t\
Return[{YF,PF,lik}]];  \n\t\n\tIf[option==1,Return[lik]];\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"GaussianSumFilter"],

Cell[TextData[{
  "GaussianSumFilter1//Clear\n\
(***************************************************************)\t\t\t \n\
GaussianSumFilter1[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,p0_,dt_,corr_},\n\t\t\t\
\t               {n_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
gaussian sum filter (mit Zusatzterm *)\n\n\
Module[{ti,dti,Xi,z,yi1i,Pi1i,alphai1i,yii,yiiR,Pii,lik,YF,PF,alphaii,\n      \
  y,P,j,liki,n1,alpha,m,sigma,s},\n\n{ti,T1,T,dti,dti1} = Zeiten[Z,miss];\n\n\
n1 = 1./n; \n\nPrint[\"GaussianSumFilter, n = \",n,\"  corr = \",corr];\n\n\
{yi1i,Pi1i,alphai1i} = p0[X[[1]],Theta,n];\n\n(*alphai1i//Print;*)\n\n\
{yiiR,lik,yii,Pii,alphaii} = \n\t\t    \
MessUpOmnibus[{Z[[1]],{yi1i,Pi1i,alphai1i},X[[1]]},Theta,{h,Dh,R},\n\t\t      \
            {miss,n,Generator,seed,",
  StyleBox["False",
    FontColor->RGBColor[1, 0, 0]],
  "}];\n\n                 \nYF  = {}; PF  = {}; alpha = {};\n\nDo[  \n\n\tXi \
 = Take[ X,dti[[i]] ];\n\n\t{yi1i,Pi1i,y,P} = \
TimeUpSumFilter[{yii,Pii,alphaii,Xi,dt,corr},Theta,{f,Df,g}];\n\t\n\t\n\t\
If[option==2,YF = Join[YF,Drop[y//Transpose,-1]];\n\t             PF = \
Join[PF,Drop[P//Transpose,-1]];\n\t             alpha = \
Join[alpha,Shape[1,{dti1[[i]]-1}]/. 1->alphaii]\n\t             ];\n\t\n\t\
(*y=nxTxp; P=nxTxpxp*)\n\t\n\tIf[option==3,{m,sigma,s}=\n\t\t\t\t\t\t\t\t\t\t\
\t\tMapThread[Mischverteilung[alphaii,#1,#2]&,\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\t{Drop[y//Transpose,-1],\n\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t Drop[P//Transpose,-1]}]//Transpose;\n\t\t\t\t\t\t\t\t\t\t\t\t\
YF=Join[YF,m];\n\t\t\t\t\t\t\t\t\t\t\t\tPF=Join[PF,sigma];\n\t];\n\t\n\t      \
                   \n\tj = ti[[i+1]]; \n\t(*Print[{i+1,j}];*)\n\t\n\t\n\t\
{yiiR,liki,yii,Pii,alphaii} = \n\t\t      \
MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,alphaii},X[[j]]},\n\t\t\t\t                  \
 Theta,{h,Dh,R},{miss,n,Generator,seed,",
  StyleBox["False",
    FontColor->RGBColor[1, 0, 0]],
  "}];\t\t\n\t\t\t\t                   \t\n\t(* Print[alphaii]; *)            \
   \n\t(* liki//Print;\t*)  \n\t\n\tlik +=liki;\n\t\n,{i,1,Length[ti]-1}];\n\n\
If[option==2,\n     \tYF = Join[YF,{yii}];\n     \tPF = Join[PF,{Pii}];\n     \
\talpha = Join[alpha,{alphaii}];\n\t     Return[{YF,PF,alpha,lik}]];\n\t\n\t\
If[option==3,\n\t\t\t\t{m,sigma,s}=Mischverteilung[alphaii,yii,Pii];\n\t\t\t\t\
\tYF=Join[YF,{m}];\n\t\t\t\t\tPF=Join[PF,{sigma}];\n\t\t\t\t\t\
Return[{YF,PF,lik}]];  \n\t\n\tIf[option==1,Return[lik]];\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"GaussianSumFilter1"],

Cell["\<\
GaussianSumFilterGHF//Clear
(***************************************************************)\t\t\t 
GaussianSumFilterGHF[{Z_,X_},Theta_,
                     {f_,Omega_,h_,R_,p0_,dt_,m_,eps_:10^-16,ksigma_:Infinity}\
,
\t\t\t\t              {n_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* gaussian sum filter mit GHF update*)

Module[{ti,dti,Xi,z,yi1i,Pi1i,alphai1i,yii,Pii,lik,YF,PF,alphaii,
        y,P,j,liki,n1,alpha,mean,sigma,s},

{ti,T1,T,dti,dti1} = Zeiten[Z,miss];

(*{ti,T1,T,dti,dti1}//Print;*)

n1 = 1./n; 

Print[\"GaussianSumFilter/GHF, n = \",n];  

{yi1i,Pi1i,alphai1i} = p0[X[[1]],Theta,n];

(* Gewicht N(0,1) *)
{VALS,WEIGHT}=GaussHermitePointsMulti2[m,p=yi1i//First//Length,eps,ksigma];

{lik,yii,Pii,alphaii} = 
\t\t    MessUpGHFn[{Z[[1]],{yi1i,Pi1i,alphai1i},X[[1]],m},Theta,{h,R},{miss}];\


                
YF  = {}; PF  = {}; alpha = {};

Do[  

\tXi  = Take[ X,dti[[i]] ];

\t{yi1i,Pi1i,y,P} = TimeUpGHFn[{yii,Pii,Xi,dt,m},Theta,{f,Omega}];

\t
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]];
\t             PF = Join[PF,Drop[P//Transpose,-1]];
\t             alpha = Join[alpha,Shape[1,{dti1[[i]]-1}]/. 1->alphaii]
\t             ];
\t
\t(*y=nxTxp; P=nxTxpxp*)
\t
\tIf[option==3,{mean,sigma,s}=
\t\t         MapThread[Mischverteilung[alphaii,#1,#2]&,
\t\t\t\t               {Drop[y//Transpose,-1],
\t\t\t  \t                Drop[P//Transpose,-1]}]//Transpose;
\t\t\t\tYF=Join[YF,mean];
\t\t\t\tPF=Join[PF,sigma];
\t];
\t

\t                        
\tj = ti[[i+1]]; 
\t(*Print[{i+1,j}];*)
\t
\talphai1i=alphaii;
\t
\t{liki,yii,Pii,alphaii} = 
\t\t      MessUpGHFn[{Z[[j]],{yi1i,Pi1i,alphai1i},X[[j]],m},Theta,{h,R},{miss}\
];\t\t
\t
\t                 \t
\t(* Print[alphaii]; *)               
\t(* liki//Print;\t*)  
\t
\tlik +=liki;
\t
,{i,1,Length[ti]-1}];


    If[option==2,
     \tYF = Join[YF,{yii}];
     \tPF = Join[PF,{Pii}];
     \talpha = Join[alpha,{alphaii}];
\t     Return[{YF,PF,alpha,lik}]];
\t
\tIf[option==3,
\t\t{mean,sigma,s}=Mischverteilung[alphaii,yii,Pii];
\t\tYF=Join[YF,{mean}];
\t\tPF=Join[PF,{sigma}];
\t\tReturn[{YF,PF,lik}]];  
\t
\tIf[option==1,Return[lik]];
\t
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"GaussianSumFilterGHF"],

Cell["\<\
SumFilterUKF//Clear
(***************************************************************)\t\t\t 
SumFilterUKF[{Z_,X_},Theta_,{f_,g_,h_,R_,p0_,dt_,kappa_},
\t\t\t\t                        {n_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* sum filter mit UKF update*)

Module[{ti,dti,Xi,z,yi1i,Pi1i,alphai1i,yii,Pii,lik,YF,PF,alphaii,
        y,P,j,liki,n1,alpha,mean,sigma,s},

{ti,T1,T,dti,dti1} = Zeiten[Z,miss];

n1 = 1./n; 

Print[\"SumFilter/UKF, n = \",n];

{yi1i,Pi1i,alphai1i} = p0[X[[1]],Theta,n];

{lik,yii,Pii,alphaii} = 
\t\t    MessUpUKFn[{Z[[1]],{yi1i,Pi1i,alphai1i},X[[1]],kappa},Theta,{h,R},{\
miss}];

                
YF  = {}; PF  = {}; alpha = {};

Do[  

\tXi  = Take[ X,dti[[i]] ];

\t{yi1i,Pi1i,y,P} = TimeUpUKFn[{yii,Pii,Xi,dt,kappa},Theta,{f,g}];

\t
\t
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]];
\t             PF = Join[PF,Drop[P//Transpose,-1]];
\t             alpha = Join[alpha,Shape[1,{dti1[[i]]-1}]/. 1->alphaii]
\t             ];
\t
\t(*y=nxTxp; P=nxTxpxp*)
\t
\tIf[option==3,{mean,sigma,s}=
\t\t           \t\tMapThread[Mischverteilung[alphaii,#1,#2]&,
\t\t\t\t                   {Drop[y//Transpose,-1],
\t\t\t  \t                    Drop[P//Transpose,-1]}]//Transpose;
\t\t\t\tYF=Join[YF,mean];
\t\t\t\tPF=Join[PF,sigma];
\t];
\t

\t                        
\tj = ti[[i+1]]; 
\t(*Print[{i+1,j}];*)
\t
\talphai1i=alphaii;
\t
\t{liki,yii,Pii,alphaii} = 
\t\t      MessUpUKFn[{Z[[j]],{yi1i,Pi1i,alphai1i},X[[j]],kappa},Theta,{h,R},{\
miss}];\t\t
\t
\t\t\t                   \t
\t(* Print[alphaii]; *)               
\t(* liki//Print;\t*)  
\t
\tlik +=liki;
\t
,{i,1,Length[ti]-1}];

If[option==2,
     \tYF = Join[YF,{yii}];
     \tPF = Join[PF,{Pii}];
     \talpha = Join[alpha,{alphaii}];
\t     Return[{YF,PF,alpha,lik}]];
\t
\tIf[option==3,
\t\t{mean,sigma,s}=Mischverteilung[alphaii,yii,Pii];
\t\t YF=Join[YF,{mean}];
\t\t PF=Join[PF,{sigma}];
\t\t Return[{YF,PF,lik}]];  
\t
\tIf[option==1,Return[lik]];
\t
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"SumFilterUKF"],

Cell["\<\
GaussianSumFilteralt//Clear
(***************************************************************)\t\t\t 
GaussianSumFilteralt[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t  {{y1_,y2_,dy_},_,n_,seed_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* gaussian sum filter *)

Module[{ti,dti,Xi,z,y0,yii,Pii,lik,YF,PF,alpha,alphai,
        yi1i,Pi1i,y,P,j,liki},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;
Print[\"Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];

SeedRandom[seed];

Xi = X[[1]];

If[Length[p0]==0,
\t{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,n],
\t   y0  = RandomGauss[Xi,Theta,p0,n]
  ];

If[ n == 1, y0 = {p0[[1]][_,Theta]}  ]; (* a priori mean *)
y0//Print;
P0 = If[n > 1, smoothQuickAndDirtyM[y0,1], p0[[2]][_,Theta]];
P0//Print;
P0 = (Shape[1,{n}]/.(1->P0));
alphai = Shape[1/n,{n}]//N;

{yii,Pii,alphai,lik} = 
\tMessUpEKFSumAlpha[{Z[[1]],{y0,P0,alphai},Xi},Theta,{h,Dh,R},{miss,n}];

YF   = {}; PF   = {}; alpha = {};

Do[  

\tXi  = Take[ X,dti[[i]] ];

\t{yi1i,Pi1i,y,P} = 
\t\tMapThread[TimeUpEKF[{#1,#2,Xi,dt},Theta,{f,Df,g}]&,{yii,Pii}]//Transpose;\
\t
\t\t
\tyi1i = Over[yi1i,YMAX];
\t(*y  = Over[y,YMAX];*)
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]];
\t             PF = Join[PF,Drop[P//Transpose,-1]];
\t             alpha = Join[alpha,{alphai}] ];
\tj = ti[[i+1]]; 
\t(*Print[{i+1,j}];*)
\t
\t{yii,Pii,alphai,liki} = 
\t\tMessUpEKFSumAlpha[{Z[[j]],{yi1i,Pi1i,alphai},X[[j]]},
\t\t\t\tTheta,{h,Dh,R},{miss,n}];
\tliki//Print;\t
\tlik +=liki;
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{yii}];
\tPF = Join[PF,{Pii}];
\talpha = Join[alpha,{alphai}];
\tReturn[{YF,PF,alpha,lik}],
\t
\tReturn[lik]];
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "KalmanFokkerEKFSumDKS//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["KalmanFokkerEKFSumDKS",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t                  \
{n_,seed_,Generator_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
Diskretisiertes kontinuierliches sampling\n   p_i+1|i = sum phi(y_i+1|i, \
P_i+1|i)            *)\n\n\
Module[{ti,dti,Xi,z,y0,yii,yiiR,Pii,lik,alpha,alphaii,\n        \
yi1i,Pi1i,y,P,j,liki,YF,PF,YFiiR,n1},\n\n{ti,T1,T,dti,dti1} = Zeiten[Z,miss];\
\n\nn1 = 1./n; \n\nPrint[\"Monte-Carlo-Stichprobe n = \",n,\"  seed = \", \
seed];\n\n{y0,P0,alpha0} = p0[X[[1]],Theta,n];\n\n{yiiR,lik,yii,Pii,alphaii} \
= \n\t\t    MessUpOmnibus[{Z[[1]],{y0,P0,alpha0},X[[1]]},Theta,{h,Dh,R},\n\t\t\
                  {miss,n,Generator,seed,True}];\n                 \nYF   = \
{}; PF   = {}; alpha = {}; YFiiR = {}; null = Pii*0.;\n\nDo[  \n\n\tXi  = \
Take[ X,dti[[i]] ];\n\t       \n\ttimeup = \
TimeUpEKF[{#1,#2,Xi,dt},Theta,{f,Df,g}]&;\n\t\t       \n\t{yi1i,Pi1i,y,P} = \
MapThread[timeup,{yiiR,null}]//Transpose;\t\n\t\n\tyi1i = Over[yi1i,YMAX];\n\t\
(*y  = Over[y,YMAX];*)\n\t\n\tIf[option==2,y = y//Transpose;\n\t\t\t\t y = \
Drop[y,-1];\n\t\t\t\t y = ReplacePart[y,yii,1];\n\t\t\t\t YF = Join[YF,y];\n\t\
\t\t\t \t\t\t\t\t\t\t\t\t(*YF//Print;*)\n\t    PF = \
Join[PF,ReplacePart[Drop[P//Transpose,-1],Pii,1] ];\n\t    \t\t\t\t\t\t\t\t\t\
(*PF//Print;*)\n\t    YFiiR = Join[YFiiR,{yiiR}];\n\t    alpha = \
Join[alpha,Join[{alphaii},Shape[n1,{dti1[[i]]-2}] ] ];\n\t             \
(*alphaii//Print;*)\n\t  ];\n\t  \n\n\tj = ti[[i+1]]; \n\t(*Print[{i+1,j}];*)\
\n\t \n\t      \n\t{yiiR,liki,yii,Pii,alphaii} = \n\t     \
MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,n1},X[[j]]},Theta,{h,Dh,R},\n\t              \
     {miss,n,Generator,seed,True}];\n\t           \n\tlik +=liki;\n\t\n\
,{i,1,Length[ti]-1}];\n\nIf[option==2,\n\t      YF = Join[YF,{yii}];\n\t      \
PF = Join[PF,{Pii}];\n\t      YFiiR = Join[YFiiR,{yiiR}];\n\t      alpha = \
Join[alpha,{alphaii}];\n\t\n\tReturn[{YF,PF,alpha,lik,YFiiR}],\n\t\n\t\
Return[lik]];\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"KalmanFokkerEKFSumDKS"],

Cell[TextData[{
  "FunctionalFilter//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["FunctionalFilter",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t \
{{quote_,anti_,tanner_,sort_},dW_,seed_,Generator_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
Funktional-Integral \n   int p(y_J|y_J-1)...p(y_1|y_0)p_i|i(y_0)\n   p_i+1|i \
= 1/N sum p(y_J|y_J-1); dy = fdt + gdW \n \n   option = 1: lik, \n   option = \
2: YF: TxNxp,(Stichproben-Trajektorien) \n   option = 3: YF: Tx2xp (m und s)\n\
   \n   quote = 1,2,3\n\n*)\n\n\
Block[{ti,T,T1,dti,dti1,n,n1,Xi,z,y0,P0,alpha0,yiiR,lik,yii,Pii,alphaii,\n    \
    YF,Misch,likvec,xi,dwi,yJ1,y,G,Pi1i,yi1i,liki,eps,N1,p},\n\n\n\
{ti,T1,T,dti,dti1} = Zeiten1[Z,miss];\n\nn = Length[dW];\nn1 = 1./n; \n\n\
Print[\"Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\n\
{y0,P0,alpha0} = p0[X[[1]],Theta,n];\n\n{yiiR,lik,yii,Pii,alphaii} = \n\t\t   \
 MessUpOmnibus[{Z[[1]],{y0,P0,alpha0},X[[1]]},Theta,{h,Dh,R},\n\t\t           \
       {miss,n,Generator,seed,False}];\n\nN1 = Table[n1,{n}];  (* a \
priori-Gewichte 1/n *)\n\n{n,p}=yii//Dimensions;\neps= \
zufall[Generator,n,p,seed,anti];    (* eps=Zufallmatrix (0,1) *)\n\n\
If[sort!=0,{yii,Pii,alphaii} = Sortieren[{yii,Pii,alphaii},sort]];\n\n\
{yiiR,alphai1i} = Resampling[{yii,Pii,alphaii,N1},eps,seed,{quote,tanner}];\n\
\n(*            \n\
Print[Spalte[alphaii]~ii~yii~ii~yiiR~ii~y0//Chop//MatrixForm];\nPii//Print;\n\
*)\n\n\n\nYF   = {}; Misch = {}; likvec = {lik};\n\nDo[  \n\n\t  Xi  = Take[ \
X,dti[[i]] ];\n   xi  = Xi//Last;\n\t  dwi = Map[Take[#,dti1[[i]] ]&,dW];\n  \
\n   {yJ1,y} = TimeUpFokker[{yiiR,Xi,dwi,dt},Theta,{f,g}];\n \n   G    = \
Map[g[#,xi,Theta]&,yJ1]; \n   Pi1i = MapThread[Dot,{G,Map[Transpose,G]}] dt;\n\
   yi1i = yJ1 + Map[f[#,xi,Theta]&,yJ1] dt; \n\n \n   \t\t\t\t\t\
(*Print[Pi1i//First//VecDiag]; *)\n   \t\t\t\t\t(*yi1i//Abs//Max//Print; \t\t\
*)\n   \t\t\t\t\t\n\t  yi1i = Over[yi1i,YMAX]; \n\t  \n\t  \t\t\t\t\t(*y  = \
Over[y,YMAX];*)\n\n\t  If[option==2,\n\t\t\t\t   YF = Join[YF,y//Transpose];\n\
\t\t\t\t   (*YF//Print;*)\n\t      (*Misch = \
Append[Misch,{alphaii,yii,Pii}];*)       \n\t  ];\n\t  \n\t  If[option==3,\n\t\
      (*\n\t      y//Dimensions//Print;\n\t      \
y//TensorMS//Dimensions//Print;\n\t      *)\n\t      \n\t\t\t\t   YF = \
Join[YF,y//TensorMS//Transpose];\n\t\t\t\t   \n\t\t\t\t   (*YF//Print; *) \n\t\
  ];\n\t   \n\t  j = ti[[i+1]];     (* Print[{i+1,j}]; *)\n\t\t\n\t\t \
{yiiR,liki,yii,Pii,alphaii} = \n\t\t         \
MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,alphai1i},X[[j]]},Theta,{h,Dh,R},\n\t\t      \
                 {miss,n,Generator,seed,False}];\n\n\t\t\t(* \
alphaii//Chop//Print; *)\n\t\t\t\n\t\t\tIf[sort!=0,{yii,Pii,alphaii} = \
Sortieren[{yii,Pii,alphaii},sort]];\n\t\t\t\n\t\t\t{yiiR,alphai1i} = \
Resampling[{yii,Pii,alphaii,N1},eps,seed,{quote,tanner}];\n\n\t  lik +=liki; \
\n\n\t\n,{i,1,Length[ti]-1}];\n\n\n\nIf[option==1,Return[lik] ];\n\n\
If[option==2,\n\t     YF = Join[YF,{yiiR}];\n\t     (*Misch = \
Append[Misch,{alphaii,yii,Pii}];*)\n\t\t\t\t\t\t\
Return[{YF,lik,Misch//Transpose}] ];\n\t\nIf[option==3,\n\t\t\t\t\t\tYF = \
Join[YF,{yiiR//TensorMS}];\n\t     Return[{YF,lik,Misch}] ];\t\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"FunctionalFilter"],

Cell["\<\
KalmanFokkerEKFSumX//Clear
(***************************************************************)\t\t\t 
KalmanFokkerEKFSumX[{Z_,X_},Theta_,
\t                {f_,g_,h_,Dh_,R_,p0_,dt_,MessUpEKFSumX_},
\t\t\t\t    {{y1_,y2_,dy_},_,$dw$_,seed_,miss_,option_:1}]:=
(***************************************************************)\t\t\t 
(* exakter time update, EKFSumX-Me\[SZ]update*)
Module[{ti,dti,y0,n,Xi,z,yii,lik,YF,dwi,yi1i,y,j,liki},

ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
dti = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

n = Length[$dw$];

(*ti//Print;*)

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,n];

SeedRandom[seed];
{yii,lik} = 
\tMessUpEKFSumX[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{miss,n}];

YF   = {};

Do[ 

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\t
\tyi1i = Over[yi1i,YMAX];
\t(*y    = Over[y,YMAX];*)
\tIf[option==2,YF = Join[YF,Drop[y//Transpose,-1]]  ];
\tj = ti[[i+1]]; 
\t
\tSeedRandom[seed];
\t{yii,liki} = 
\t\tMessUpEKFSumX[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,Dh,R},{miss,n}];
\t
\t(*liki//Print;*)
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{yii}];Return[{YF,lik}],
\t\tReturn[lik]];
];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
UKF//Clear
(***************************************************************)\t\t\t 
UKF[{Z_,X_},Theta_,{f_,g_,h_,R_,mue_,sigma_,dt_,kappa_,
                    messupdate_:MessUpUKF,timeupdate_:TimeUpUKF1},
\t\t           {miss_,option_:1}]:=
(***************************************************************)\t\t\t 
Block[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,Y,P,j,Y0,P0,p,IP,inno,likvec},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
(*ti//Print;*)
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta]; 

{Yii,Pii,lik} = messupdate[{Z[[1]],{Yi1i,Pi1i},Xi,kappa},Theta,{h,R},{miss}];

(*{Yii,Pii,lik}//Print;*)

If[option==4, inno = {Yii-Yi1i}];
If[option==5, likvec = {lik}];


YF   = {};
PF   = {};

Do[ (*Print[i];*)

\t

\tXi  = Take[ X,dti[[i]] ];  
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\t\ttimeupdate[{Yii,Pii,Xi,dt,kappa},Theta,{f,g}];
\t
\t
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t
\t{Yii,Pii,liki} = \
messupdate[{Z[[j]],{Yi1i,Pi1i},X[[j]],kappa},Theta,{h,R},{miss}];\t

    (*{i,Yii,Pii,liki}//Print;*)

\t(*Print[Z[[j]],Yi1i,Yii];*)
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\tIf[option==5, likvec = Append[likvec,liki]];

\t\t
\t  (* liki//Print; *)\t
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)\t
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

If[option==2,
\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,Return[{lik,inno}//N]];

If[option==5,Return[{lik,likvec}//N]];


];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"UKF"],

Cell["\<\

GF//Clear
(***************************************************************)
GF[{Z_,X_},Theta_,{f_,Omega_,h_,R_,mue_,sigma_,dt_},{miss_,option_:1}]:=
(***************************************************************)
(* Gauss-Filter*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,yi1i,alphai1i,Y,P,j,Y0,P0,p,
        inno,likvec},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
ti//Print;
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta];

ksigma=4;
genau=10.^-8;

Print[\"GF: \",\"ksigma = \",ksigma,\", genau = \",genau];

{Yii,Pii,lik} = MessUpGF[{Z[[1]],{Yi1i,Pi1i},Xi},Theta,{h,R},{miss}];

Pii=Shift[Pii,10^-6];

{Yii,Pii}//Print;


If[option==4, inno = {Yii-Yi1i}];
If[option==5, likvec = {lik}];


YF   = {};
PF   = {};


Do[ (*Print[i];*)



\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\t\tTimeUpGF[{Yii,Pii,Xi,dt},Theta,{f,Omega}];
\t
\t(*
\tYi1i = Over[Yi1i,YMAX];
\tY    = Over[Y,YMAX];
\t*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t
\t{yi1i,alphai1i}=SigmaSample[Yi1i,Pi1i,0];

\t{Yii,Pii,liki} = MessUpGF[{Z[[j]],{Yi1i,Pi1i},X[[j]]},Theta,{h,R},{miss}];

\t
\t(*Print[Z[[j]],Yi1i,Yii];*)
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\tIf[option==5, likvec = Append[likvec,liki]];

\t  (* liki//Print; *)
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

\t
If[option==2,
 (*
\tPii=(Pii//Symmetrize) + 10^-8 IdentityMatrix[Pii//Length]; (*Pii>0*)
\tPii=Shift[Pii,10.^-6];
\t*)

\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,Return[{lik,inno}//N]];

If[option==5,Return[{lik,likvec}//N]];


];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"GF"],

Cell["\<\

GHF//Clear
(***************************************************************)
GHF[{Z_,X_},Theta_,{f_,Omega_,h_,R_,mue_,sigma_,dt_,
     m_,eps_:10^-16,ksigma_:Infinity,
     update_:MessUpGHF,timeup_:TimeUpGHF1},
     {miss_,option_:1,Panel_:False}]:=
(***************************************************************)
(* Gauss-Hermite-Filter, TimeUpGHF1: konstantes Omega(_,t_,Theta_) *)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,yi1i,alphai1i,Y,P,j,Y0,P0,p,
        inno,likvec},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)

(*ti//Print; *)
(*{update,timeup}//Print;*)

T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta];

(*Print[\"GHF: \",\"m = \",m];*)

If[Panel,
  
\t{VALS1,WEIGHT1}=GaussHermitePointsMulti2[m,1,eps,ksigma];
\t{VALS2,WEIGHT2}=GaussHermitePointsMulti2[m,2,eps,ksigma],

\t(*else*)
\t(* Gewicht N(0,1) *)
\t
\t{VALS,WEIGHT}=GaussHermitePointsMulti2[m,p=Yi1i//Length,eps,ksigma,1]
];


{Yii,Pii,lik} = update[{Z[[1]],{Yi1i,Pi1i},Xi,m},Theta,{h,R},{miss}];


If[option==4, inno = {Yii-Yi1i}];
If[option==5, likvec = {lik}];


YF   = {};
PF   = {};


Do[ (*Print[i];*)



\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = 
\t\t\ttimeup[{Yii,Pii,Xi,dt,m},Theta,{f,Omega}];
\t
\t
\t(*
\tYi1i = Over[Yi1i,YMAX];
\tY    = Over[Y,YMAX];
\t*)
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)

\t{Yii,Pii,liki} = update[{Z[[j]],{Yi1i,Pi1i},X[[j]],m},Theta,{h,R},{miss}];
\t
\t(*Print[Z[[j]],Yi1i,Yii];*)
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\tIf[option==5, likvec = Append[likvec,liki]];

\t  (* liki//Print; *)
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

\t
If[option==2,

\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,Return[{lik,inno}//N]];

If[option==5,Return[{lik,likvec}//N]];


];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"GHF"],

Cell["\<\

SMKF//Clear
(***************************************************************)
SMKF[{Z_,X_},Theta_,{f_,g_,h_,R_,mue_,sigma_,dt_,n_,seed_,anti_},{miss_,\
option_:1}]:=
(***************************************************************)
(* simulated moments KF*)

Module[{T1,ti,dti,dti1,Xi,Yii,Pii,lik,liki,
        YF,PF,Yi1i,Pi1i,yi1i,alphai1i,Y,P,j,Y0,P0,p,inno,likvec},


ti  = messind[Z,miss]; (*Indices mit mind. einer Messung*)
ti//Print;
T1 = Length[Z];
ti = Union[ti,{1,T1}];
(*ti//Print;*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

Xi = X[[1]];
Yi1i=mue[Xi,Theta];
Pi1i=sigma[Xi,Theta];

{Yii,Pii,lik} = \
MessUpSMKF[{Z[[1]],{Yi1i,Pi1i},Xi,n,seed,anti},Theta,{h,R},{miss}];

{Yii,Pii}//Print; 


If[option==4, inno = {Yii-Yi1i}];
If[option==5, likvec = {lik}];


YF   = {};
PF   = {};


Do[ (*Print[i];*)



\tXi  = Take[ X,dti[[i]] ];
\t
\t{Yi1i,Pi1i,Y,P} = TimeUpSMKF[{Yii,Pii,Xi,dt,n,seed,anti},Theta,{f,g}];
\t
\tIf[option==2,
\tYF = Join[YF,Drop[Y,-1]];
\tPF = Join[PF,Drop[P,-1]];
\t];
\t
\t
\tj = ti[[i+1]];
\t
\t   (*{i,j}//Print; *)
\t

\t{Yii,Pii,liki} = \
MessUpSMKF[{Z[[j]],{Yi1i,Pi1i},X[[j]],n,seed,anti},Theta,{h,R},{miss}];

\t
\t(*Print[Z[[j]],Yi1i,Yii];*)
\t
\tIf[option==4, inno = Join[inno,{Yii-Yi1i}]];
\tIf[option==5, likvec = Append[likvec,liki]];

\t  (* liki//Print; *)
\t  (* Print[i,\"\\n\",Yi1i,\" \",Yii]; *)
\t  (* {i,Yii,Pii,liki}//Print; *)
\t
\tlik +=liki;
\t
\t
,{i,1,Length[ti]-1}];

\t
If[option==2,

\tPii=(Pii//Symmetrize) + 10^-8 IdentityMatrix[Pii//Length]; (*Pii>0*)
\tPii=Shift[Pii,10.^-6];

\tYF = Join[YF,{Yii}];
\tPF = Join[PF,{Pii}];
\tReturn[{YF,PF,lik}//N]];
\t
If[option==1,Return[lik//N]];

If[option==4,Return[{lik,inno}//N]];

If[option==5,Return[{lik,likvec}//N]];


];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"SMKF"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SML", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["AntiThetisch",
    FontColor->RGBColor[1, 0, 0]],
  "[x_]:= Join[x,-x];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["AntiThetisch1//Clear\nAntiThetisch1",
    FontColor->RGBColor[1, 0, 0]],
  "[x_]:= \nModule[{n,x1,xi},\nn = Length[x];\nx1 = Range[2n];\nDo[xi = \
x[[i]];x1[[2i-1]] = xi; x1[[2i]] = -xi,{i,n}];\nx1\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["AntiThetisch1[{1,2,{3},A,{B}}]",
  FontColor->RGBColor[1, 0, 0]]], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{1, -1, 2, -2, {3}, {-3}, A, -A, {B}, {-B}}\
\>", \
"\<\
{1, -1, 2, -2, {3}, {-3}, A, -A, {B}, {-B}}\
\>"], "Output",
  InitializationCell->True,
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  StyleBox["dW//Clear;\ndW",
    FontColor->RGBColor[1, 0, 0]],
  "[Generator_,seed_,{n_,T_,r_,dt_}]:=\nModule[{nn,tt,rr,dt2},\n\
SeedRandom[seed];\ndt2 = Sqrt[dt];\n\
Table[Generator[]*dt2,{nn,n},{tt,T+1},{rr,r}] ]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["dWAntiThetisch",
    FontColor->RGBColor[1, 0, 0]],
  "[Generator_,seed_,{n_,T_,r_,dt_}]:=\nModule[{dwn,nn,tt,rr,dt2},\n\
SeedRandom[seed];\ndt2 = Sqrt[dt];\nTable[If[OddQ[nn], dwn = \
Table[Generator[]*dt2,{tt,T+1},{rr,r}], \n                  -dwn],\n     \
{nn,n} ] ]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "pzy//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["pzy",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,Y_,X_},Theta_,{h_,R_},{miss_}]:=\n\
(***************************************************************)\t\t\t \n\t\
(* Dichte p(z|y) *) \n\t\n\tModule[{zmiss,lc,r,r1,inn},\n\t\n\t zmiss = \
Map[SameQ[miss,#]&,Z];\t\t\n\t lc = Locate[zmiss,False];\n\t    \n\t If[lc == \
{},Return[1] ]; (*keine Messung*)\n\t    \n\t\t\n\t\tr = \
R[Y,X,Theta][[lc,lc]];\t\n\t\tr1 = r//Inverse;\n\t\tinn = Z[[lc]] - \
h[Y,X,Theta][[lc]];\t\n\t\t\n\t\t\t\t\t\t(* Print[{Z[[lc]],Y,inn,r,r1} ]; *)\n\
\t\t\n\t\tDet[r]^(-0.5) Exp[(-0.5) (inn.r1.inn)]\t\n\t\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "Logpzy//Clear\n\
(***************************************************************)\t\t\t \n\
Log",
  StyleBox["pzy",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,Y_,X_},Theta_,{h_,R_},{miss_}]:=\n\
(***************************************************************)\t\t\t \n\t\
(* Dichte Log p(z|y) *) \n\t\n\tModule[{zmiss,lc,r,r1,inn},\n\t\n\t zmiss = \
Map[SameQ[miss,#]&,Z];\t\t\n\t lc = Locate[zmiss,False];\n\t    \n\t If[lc == \
{},Return[0] ]; (*keine Messung*)\n\t    \n\t\t\n\t\tr = \
R[Y,X,Theta][[lc,lc]]; \n\t\tr1 = r//Inverse;\n\t\tinn = Z[[lc]] - \
h[Y,X,Theta][[lc]];\t\n\t\t(*Print[{Z[[lc]],Y,inn,r,r1} ];*)\n\t\t\t\t\n\t\t\
-0.5( Log[Det[r]]+(inn.r1.inn) )\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "\nInterpol//Clear\n\
(***************************************************************)\n",
  StyleBox["Interpol",
    FontColor->RGBColor[1, 0, 0]],
  "[XM_,MISS_,ORDER_] := \n\
(***************************************************************)\n\t\
Module[{XMr,Xint,tau3,T1,q,data,i},\n\t  {T1,q} = XM//Dimensions; \n\t\t XMr \
= XM//Reverse;\n\t\t\n\t\t Xint = \n\t\t Table[tau3 = \
Locate[XMr[[T1//Range,qq]] ~sameq~ MISS, False];\n\t\t       \n\t\t       \
If[tau3=={},\n\t\t       Print[\"keine Daten in Spalte \",qq];\n\t\t       \
i=Table[MISS,{j,T1}],\n\t\t       \n\t\t       (*else*)\n\t\t\t      data = \
{tau3,XMr[[tau3,qq]]}//Transpose;\n\t\t\t      (*data//Print;*)\n         \
i=Interpolation[data,InterpolationOrder->ORDER][(T1)//Range];\n         \
(*i//Print;*)\n         If[XMr[[1,q]]=!=MISS && ORDER==0,i[[1]]=XMr[[1,q]] ];\
\n         ];\n         \n         i\n         \n   ,{qq,q}];\n       \t\t  \n\
\t\tXint=Transpose[Xint]//Reverse\n\t\n\t ]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
Phi//Clear
Phi[y_,mue_,sigma_] := 
\tModule[{dy = y-mue},
\tDet[sigma]^(-0.5) Exp[-0.5 dy.Inverse[sigma].dy ]
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
Phi1//Clear
Phi1[y_,mue_,sigma1_] := 
\tModule[{dy = y-mue},
\tDet[sigma1]^(0.5) Exp[-0.5 dy.sigma1.dy ]
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
LogPhi//Clear
LogPhi[y_,mue_,sigma_] := 
\tModule[{dy = y-mue},
\t-0.5( Log[Det[sigma]] + dy.Inverse[sigma].dy) 
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
LogPhi1//Clear
LogPhi1[y_,mue_,sigma1_] := 
\tModule[{dy = y-mue},
\t-0.5( -Log[Det[sigma1]] + dy.sigma1.dy) 
\t]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
Phi[{1},0,{{2}}]
Phi1[{1},0,{{2}}//Inverse]
LogPhi[{1},0,{{2}}]//Exp//N
LogPhi1[{1},0,{{2}}//Inverse]//Exp//N\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
0.5506953149031838\
\>", "\<\
0.550695\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
0.5506953149031838\
\>", "\<\
0.550695\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
0.5506953149031837\
\>", "\<\
0.550695\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14],

Cell[OutputFormData["\<\
0.5506953149031837\
\>", "\<\
0.550695\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  StyleBox["likratio0",
    FontColor->RGBColor[1, 0, 0]],
  "[y_,{yii1_,Pii1_,alphaii1_},{yii2_,Pii2_,alphaii2_}]:=\nModule[{p1,p2},\n\
p1=Apply[Plus,alphaii1*MapThread[Phi[y,#1,#2]&,{yii1,Pii1}]];\n\
p2=Apply[Plus,alphaii2*MapThread[Phi[y,#1,#2]&,{yii2,Pii2}]];\n\np1/p2 \n\n]\t\
"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
likratio0[{y},{ {{y11},{y12}} , {{{1}},{{2}}}, {.2,.8}}, 
              { {{y21},{y22}} , {{{1}},{{2}}}, {.4,.6}}]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
(0.2/E^(0.5*(y - y11)^2) + \
0.5656854249492382/E^(0.25*(y - y12)^2))/(0.4/E^(0.5*(y - y21)^2) + \
0.4242640687119285/E^(0.25*(y - y22)^2))\
\>", "\<\
      0.2             \
0.565685
--------------- + ----------------
              2                  2
 0.5 (y - y11)     0.25 (y - y12)
E                 E
----------------------------------
      0.4             0.424264
--------------- + ----------------
              2                  2
 0.5 (y - y21)     0.25 (y - y22)
E                 E\
\>"], "Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  "SML//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["SML",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t   \
{{y1_,y2_,dy_},_,$dw$_,seed_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
langes W(t), nur einmal seedrandom *)\n\n\
Module[{ti,T1,dti,dti1,n,Xi,z,y0,dwi,yii,yi1i,y,j,Liki,Lik},\n\nti  = \
messind[Z,miss]; (*Indices mit mind. einer Messung*)\n(*ti//Print;*)\nT1 = \
Length[Z];\nti = Union[ti,{T1}];\n(*ti//Print;*)\ndti  = \
Delta[ti,ti,List,-1];\ndti1 = Delta[ti]+1;\nn = Length[$dw$];\nPrint[\"SML: \
Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nSeedRandom[seed];\n\n\
Xi = X[[1]];\n\nIf[Length[p0]==0,\n\t{z,y0} = \
RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,n],\n\t    y0 = \
RandomGauss[Xi,Theta,p0,n]\n  ];\n\nLik = Map[",
  StyleBox["pzy",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z[[1]],#,X[[1]]},Theta,{h,R},{miss}]&,y0];\n\t\nyii = y0;\n\n(*YF = {}; \
*)\t\n\nDo[  \n\n\t\tXi  = Take[ X,dti[[i]] ];\n\t\tdwi = Map[Take[#,dti[[i]] \
]&,$dw$];\n\t\t\n\t\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];\n\t\
\t\n\t\tyi1i = Over[yi1i,YMAX];\n\t\t(*y  = Over[y,YMAX];*)\n\t\t\n\t (*YF = \
Join[YF,Drop[y//Transpose,-1]];*)\n\t\t\n\t\tj = ti[[i+1]]; \n\t\t\
(*Print[{i+1,j}];*)\n\t\t\n\t\tLiki = Map[",
  StyleBox["pzy",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z[[j]],#,X[[j]]},Theta,{h,R},{miss}]&,yi1i];\n\t yii = yi1i;\n\t\t\t\n\t\
\t(*Liki//Print;*)\n\t\t\t\n\t\tLik *= Liki; \n\n,{i,1,Length[ti]-1}];\n\n\t\t\
Return[Log[mean[Lik]] ]\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "SML1//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["SML1",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t   \
{{y1_,y2_,dy_},_,$dw$_,seed_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
langes W(t), nur einmal seedrandom *)\n\n\
Module[{ti,T1,dti,n,Xi,z,y0,dwi,yii,yi1i,y,j,Liki,Lik,lik},\n\nti  = \
messind[Z,miss]; (*Indices mit mind. einer Messung*)\n(*ti//Print;*)\nT1 = \
Length[Z];\nti = Union[ti,{T1}];\n(*ti//Print;*)\ndti  = \
Delta[ti,ti,List,-1];\ndti1 = Delta[ti]+1;\nn = Length[$dw$];\nPrint[\"SML1: \
Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nSeedRandom[seed];\n\n\
Xi = X[[1]];\n\nIf[Length[p0]==0,\n\t{z,y0} = \
RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,n],\n\t    y0 = \
RandomGauss[Xi,Theta,p0,n]\n  ];\n\n  (*YF = {}; *)\t\n\t\t\n\t\t{yi1i,y} = \
TimeUpFokker[{y0,X,$dw$,dt},Theta,{f,g}];\n\t\t\n\t\ty = Map[Part[#,ti]&,y];\n\
\t\t\n\t\t\n\t\tLik = Table[\n\t\t\t\t\t\t\t\t\t\t\t\t\t\tApply[Times,\n\t\t  \
          MapThread[",
  StyleBox["pzy",
    FontColor->RGBColor[1, 0, 0]],
  "[{#1,#2,#3},Theta,{h,R},{miss}]&,\n\t\t\t                     \
{Z[[ti]],y[[nn]],X[[ti]]}]],\n\t\t\t           {nn,n}];\n\t\t(*\t           \n\
\t Lik//Print; \n  Lik//Max//Log//Print;\n  Lik//Min//Log//Print;\n  *)\n     \
\n  lik = Lik//mean//Log;\n      \n\t\tIf[option == 1, lik,\n\t\tIf[option == \
2,     lik,                        \n\t\tIf[option == 3,{lik,lik},\n\t\t\
If[option == 4, Log[CuMean[Lik]]                        \n\t\t  ]]]]\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "Lambda//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["Lambda",
    FontColor->RGBColor[1, 0, 0]],
  "[ti_,T1_,{l0_,l1_,l2_:0},Miss_] := \n\
(***************************************************************)\t\t\t \n\
Module[{tt,lambda},\ntt = Drop[ti,-1] + Delta[ti]/2.//Ceiling;\ntt = \
Intersection[tt,Complement[Range[T1],ti]];\n\n(*Mitte zwischen den Messungen \
(au\[SZ]er Delta[ti] = 1*)\n\nlambda = Shape[Miss,{T1}];\n(*ti//Print;*)\n\
(*tt//Print;*)\nMap[(lambda[[#]]=l1)&,ti];\nMap[(lambda[[#]]=l0)&,tt];\n\
lambda = Interpol[lambda//Spalte,Miss,1]//Flatten//N;\nMap[Max[#,l2]&,lambda]\
\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "Lambda1//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["Lambda1",
    FontColor->RGBColor[1, 0, 0]],
  "[ti_,T1_,{l0_,l1_,l2_:0},Miss_] := \n\
(***************************************************************)\t\t\t \n\
Module[{tt,lambda},\n\nlambda = Shape[Miss,{T1}];\n\n\
Map[(lambda[[#]]=l1)&,ti];\ntt = \
Intersection[Drop[ti,-1]+1,Complement[Range[T1],ti]];\n\
Map[(lambda[[#]]=l0)&,tt];\nlambda = \
Interpol[lambda//Spalte,Miss,1]//Flatten//N;\nMap[Max[#,l2]&,lambda]\n]\n\n\
Lambda2//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["Lambda2",
    FontColor->RGBColor[1, 0, 0]],
  "[ti_,T1_,{l0_,l1_,l2_:0},Miss_] := \n\
(***************************************************************)\t\t\t \n\
Module[{tt,lambda},\n\nlambda = Shape[Miss,{T1}];\n\n\
Map[(lambda[[#]]=l0)&,ti];\ntt = \
Intersection[Drop[ti,1]-1,Complement[Range[T1],ti]];\n\
Map[(lambda[[#]]=l1)&,tt];\nlambda = \
Interpol[lambda//Spalte,Miss,1]//Flatten//N;\nMap[Max[#,l2]&,lambda]\n]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["toExpression",
    FontColor->RGBColor[1, 0, 0]],
  "[y_]:= If[StringQ[y],ToExpression[y],y,y];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "Zeiten//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["Zeiten",
    FontColor->RGBColor[1, 0, 0]],
  "[Z_,miss_]:= \n\
(***************************************************************)\t\t\t \n\
Module[{ti,T1,T,dti,dti1},\nti  = messind[Z,miss]; (*Indices mit mind. einer \
Messung*)\n\t\t\t(*ti//Print;*)\nT1 = Length[Z];\nT = T1-1;\nti = \
Union[ti,{1,T1}];\n\t\t\t(*ti//Print;*)\ndti  = Delta[ti,ti,List,-1];\ndti1 = \
Delta[ti]+1;\n\n{ti,T1,T,dti,dti1}]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  "Zeiten1//Clear\n\
(***************************************************************)\t\t\t \n",
  StyleBox["Zeiten1",
    FontColor->RGBColor[1, 0, 0]],
  "[Z_,miss_]:= \n\
(***************************************************************)\t\t\t \n\
Module[{ti,T1,T,dti,dti1},\nti  = messind[Z,miss]; (*Indices mit mind. einer \
Messung*)\n\t\t\t(*ti//Print;*)\nT1 = Length[Z];\nT = T1-1;\nti = \
Union[ti,{1,T1}];\n\t\t\t(*ti//Print;*)\ndti  = Delta[ti,ti-1,List,-1];\ndti1 \
= Delta[ti];\n\n{ti,T1,T,dti,dti1}]"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
CompressData[Z_,miss_]:= Module[{ti},
(***************************************************************)\t\t\t 
\tti  = messind[Z,miss];
\tti  = Union[ti,{1,Length[Z]}];
\t{Z[[ti]],ti}]

(***************************************************************)\t\t\t 
ExpandData[{Z_,ti_},miss_]:= Module[{Tc,k,T1,ZE},
(***************************************************************)\t\t\t 
\t{Tc,k} = Z//Dimensions;
\t T1    = ti//Last;
\t
\tZE = Shape[miss,{T1,k}];
\tMap[ (ZE[[ti[[#]] ]]=Z[[#]])&,Tc//Range];
\t
\tZE
\t
\t]\t
\t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["GAMMA = 1.;\nSMLImportance",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["SMLImportance",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t          \
{{l0_,l1_,l2_:0},step_:EulerStep1,dw_,\n\t\t\t\t          \
seed_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
langes W(t), nur einmal seedrandom *)\n\n\
Module[{fI,f1,f2,g1,i,n,ti,T1,T,dti,dti1,X0,mue,sigma,\n        \
Y00,P00,lik0,sigma1,P001,z,y0,ZI,XZ,zi,xi,\n        \
Lik,lik,norm,lognorm,likratiomean,\n        \
y0n,yn,yni,dwn,likratioT,likratio0,pZY},\n\n{ti,T1,T,dti,dti1} = ",
  StyleBox["Zeiten",
    FontColor->RGBColor[1, 0, 0]],
  "[Z,miss];\n\nn = Length[toExpression[dw]];\n\nPrint[\"",
  StyleBox["SMLImportance",
    FontColor->RGBColor[1, 0, 0]],
  ": Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nfI//Clear; \n\
fI[{z_,y_},{x_,_,_},Th_]:= (z - h[y,x,Th]).Inverse[ R[y,x,Th] ].Dh[y,x,Th];\n\
\n(*\nfI//Clear; \nfI[{z_,y_},{x_,_,_},Th_]:= \nModule[{K,H,SH,r,r1},\nH = \
Dh[y,x,Th];\nr = R[y,x,Th];\nr1 = r//Inverse;\nSH = SIGMA.Transpose[H];\nK = \
SH.Inverse[H.SH + r];\n(z-h[y,x,Th]).r1.H + Inverse[SIGMA - \
K.H.SIGMA].(MUE-y)\n];\n*)\n                         \nf2//Clear;\n\
f2[y_,{x_,z_,lambdat_},Th_]:= f[y,x,Th] + lambdat*fI[{z,y},{x,_,_},Th];\n\n\
f1//Clear;\nf1[y_,{x_,z_,lambdat_},Th_]:= f[y,x,Th]; \n \ng1//Clear;\n\
g1[y_,{x_,z_,lambdat_},Th_]:= g[y,x,Th];\n\ng2//Clear;\n\
(*g2[y_,{x_,z_,lambdat_},Th_]:= GAMMA * g[y,x,Th];*)\n\
g2[y_,{x_,z_,lambdat_},Th_]:=         g[y,x,Th];\n\nX0    =  X[[1]];\nmue   = \
p0[[1]][X0,Theta];\nsigma = p0[[2]][X0,Theta];\n\n{Y00,P00,lik0} = \
MessUpEKF[{Z[[1]],{mue,sigma},X0,_},Theta,{h,Dh,R},{miss}];\t\n        \n \
sigma1 = sigma//Inverse;\n P001   = P00  //Inverse;        \n\n\
SeedRandom[seed];\n       \t\nIf[Length[p0]==0,\n\t {z,y0} = \
RandomNumbers[{y1,y2,dy},p0[#,X0,Theta]&,n],\n\t    y0  = \
RandomGauss[Y00,P00,n]\n  ];  \n  (*AB aus EKF-posteriori-Verteilung*)\n    \n\
  ZI = ",
  StyleBox["Interpol",
    FontColor->RGBColor[1, 0, 0]],
  "[Z,miss,1];\n  lambdat = Lambda[ti,T1,{l0,l1},miss];\n  \n\t\tXZ = \
{X,ZI,lambdat}//Transpose;\n\t\t\n\t\tzi = Z[[ti]];\n\t\txi = X[[ti]];\n\t\t\
YY = {};\n\t\t\t\t\n\t\tLik = \n\t\tTable[ \n\t\t      y0n = y0[[nn]];\n\t\t  \
    \n\t\t      dwn = toExpression[dw][[nn]];\n\t\t      \n\t\t      yn = \
RungeKutta1[f2,g2,y0n,{XZ,dwn}, T, dt, Theta, step];\t\t     \n\t\t      yni \
= yn[[ti]];\n\t\t      \n\t\t      (*AppendTo[YY,yn];*)\n\t\t      \n       \t\
(*likratioT  =   ",
  StyleBox["LogLikelihoodRatio2",
    FontColor->RGBColor[1, 0, 0]],
  "[yn,{f1,f2},{g1,g2},XZ,dt,Theta];*)\n       \t\n       \tlikratioT  =   ",
  StyleBox["LogLikelihoodRatio",
    FontColor->RGBColor[1, 0, 0]],
  "[yn,{f1,f2},g1,XZ,dt,Theta];\n       \n       \n      \t\tlikratio0 =  \
(LogPhi1[y0n,mue,sigma1]-\n\t\t                    LogPhi1[y0n,Y00,P001  ]);\n\
\t\t                   \n\t\t      pZY =  Apply[Plus,\n\t\t                   \
MapThread[Log",
  StyleBox["pzy",
    FontColor->RGBColor[1, 0, 0]],
  "[{#1,#2,#3},Theta,{h,R},{miss}]&,\n\t\t                   {zi,yni,xi}]];\n\
\t\t\t                                             \n       likrat = \
Exp[likratioT+likratio0];\n       \n         (*{likrat, \
Exp[pZY]*likrat}//Print; *)\n               \n      \t{likrat, \
Exp[pZY]*likrat}\n       \n      \t\t\t      \n\t\t,{nn,n}];\n\t\t\n\t\tLik = \
Lik//Transpose;\n\t\t\n\t\tnorm = Plus@@Lik[[1]] ;\n\t\tlognorm = norm//Log;\n\
\t\tlik = Log[mean[Lik[[2]] ]]; \n\t\t\n\t\t           \
(*Lik[[2]]//Print;Lik[[2]]//Max//Log//Print;*)\n\t\t\n\t\tlikratiomean = \
norm/n;\n\t (*likratiomean//Print;*)\n  \n\t\tIf[option == 1, \
{lik,likratiomean},\n\t\tIf[option == 2,      lik - lognorm,                  \
      \n\t\tIf[option == 3, {lik,lik - lognorm},\n\t\tIf[option == 4, \
Log[CuMean[Lik[[2]] ]]                        \n\t\t  ]]]]\n\t\t              \
  \n\t\t \n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["LikFIF",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["LikFIF",
    FontColor->RGBColor[1, 0, 0]],
  "[{Y_,X_},Theta_,{f_,g_,p0_,dt_},{dW_,seed_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
Funktional-Integral, kein Me\[SZ]-Modell, ohne IS\n \n   int \
p(y_J|y_J-1)...p(y_1|y_0)p_i|i(y_0)\n   p_i+1|i = 1/N sum p(y_J|y_J-1); dy = \
fdt + gdW \n \n   option = 1: lik\n\n*)\n\n\
Module[{ti,T1,T,dti,dti1,n,X0,lik,mue,sigma,Xi,xi,dwi,Yi,yJ1,y,\n        \
G,Pi1i,yi1i,j,liki},\n\n{ti,T1,T,dti,dti1} = Zeiten1[Y,miss];\n\nn = \
Length[dW]; \nPrint[\"",
  StyleBox["LikFIF: ",
    FontColor->RGBColor[1, 0, 0]],
  "Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nSeedRandom[seed];\
\n\nX0 = X[[1]];\n\nIf[Length[p0]==0,\n\t \tlik = Log[ p0[Y[[1]],X0,Theta] ],\
\n\t \t\t\t(*else*)\n\t \tmue   = p0[[1]][X0,Theta];\n  \tsigma = \
p0[[2]][X0,Theta];  \n  \tlik = LogPhi[Y[[1]],mue,sigma]; (*AB*)\t \n  ];  \n \
 \n(*lik//Print;*)\n\nDo[ \n\n\tXi  = Take[ X,dti[[i]] ]; \n xi  = Xi//Last;\n\
\tdwi = Map[Take[#,dti1[[i]] ]&,dW];\n Yi = Y[[ti[[i]] ]];\n Yi = \
Table[Yi,{n}];\n \n If[dti1[[i]] =!= 1,\n      {yJ1,y} = \
TimeUpFokker[{Yi,Xi,dwi,dt},Theta,{f,g}],\n            (*else*)  \t\n         \
   yJ1 = Yi;   (*DKS*)\n ];\n\n G =  Map[g[#,xi,Theta]&,yJ1]; \n Pi1i = \
MapThread[Dot,{G,Map[Transpose,G]}] dt;\n yi1i = yJ1 + \
Map[f[#,xi,Theta]&,yJ1] dt;  \n    \t\t\n\tyi1i = Over[yi1i,YMAX];\n\t(*y  = \
Over[y,YMAX];*)\n\t   \n\tj = ti[[i+1]];      (*Print[{i+1,j}];*)\n\t\n\tliki \
= MapThread[Phi[Y[[j]],#1,#2]&,{yi1i,Pi1i}];\n\t\n\tliki = If[option == 1, \
Log[mean[liki] ], Log[CuMean[liki] ]   ];\n\t\n     (*liki//Print;*)\n\t\t\n\t\
lik += liki;\n\t\n,{i,1,Length[ti]-1}];\n\nlik\n\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["LikFIFImportance",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["LikFIFImportance",
    FontColor->RGBColor[1, 0, 0]],
  "[{Y_,X_},Theta_,{f_,g_,p0_,dt_},\n                 \
{{l0_,l1_,l2_:0},dW_,seed_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
Funktional-Integral, kein Me\[SZ]-Modell, mit IS\n \n   int \
p(y_J|y_J-1)...p(y_1|y_0)p_i|i(y_0)\n   p_i+1|i = 1/N sum p(y_J|y_J-1); dy = \
fdt + gdW \n \n   option = 1: lik\n\n*)\n\n\
Module[{ti,T1,T,dti,dti1,n,X0,lik,mue,sigma,Xi,xi,dwi,Yi,yJ1,y,\n        \
G,Pi1i,yi1i,j,liki,fI,f1,f2,g1,p,likratio},\n\n{ti,T1,T,dti,dti1} = \
Zeiten1[Y,miss];\n\nn = Length[dW]; \nPrint[\"",
  StyleBox["LikFIFImportance: ",
    FontColor->RGBColor[1, 0, 0]],
  "Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nfI//Clear; \n\
fI[{z_,y_},{x_,_,_},Th_]:= (z - y); ",
  StyleBox["(*ohne R*)",
    FontColor->RGBColor[1, 0, 0]],
  "\n                         \nf2//Clear;\nf2[y_,{x_,z_,lambdat_},Th_]:=  \
f[y,x,Th] + lambdat*fI[{z,y},{x,_,_},Th];\n\nf1//Clear;\n\
f1[y_,{x_,z_,lambdat_},Th_]:= f[y,x,Th]; \n \ng1//Clear;\n\
g1[y_,{x_,z_,lambdat_},Th_]:= g[y,x,Th];\nSeedRandom[seed];\n\nX0 = X[[1]];\n\
\nIf[Length[p0]==0,\n\n\t \tlik = Log[ p0[Y[[1]],X0,Theta] ],\n\t \t\n\t\
(*else*)\n\t \tmue   = p0[[1]][X0,Theta];\n  \tsigma = p0[[2]][X0,Theta];  \n \
 \tlik = LogPhi[Y[[1]],mue,sigma]; (*AB*)\t\n  \t \n  ];  \n  \n\
(*lik//Print;*)\n\nYI = ",
  StyleBox["Interpol",
    FontColor->RGBColor[1, 0, 0]],
  "[Y,miss,1];\nlambdat = Lambda",
  StyleBox["2",
    FontColor->RGBColor[1, 0, 0]],
  "[ti,T1,{l0,l1,l2},miss];\n  \nXY = {X,YI,lambdat}//Transpose;\n\nYY = {};\n\
\nDo[ \n\n\tXi  = Take[ XY,dti[[i]] ]; \n xi  = Xi//Last;\n\tdwi = Map[ \
Take[#,dti1[[i]] ]&, dW];\n Yi  = Y[[ti[[i]] ]];\n Yi  = Table[Yi,{n}];\n \t\n\
 If[dti1[[i]] =!= 1,\n      {yJ1,y} = TimeUpFokker[{Yi,Xi,dwi,dt},Theta,{",
  StyleBox["f2",
    FontColor->RGBColor[1, 0, 0]],
  ",g1}],\n   (*else*)  \t\n      yJ1 = Yi; y = Map[List,Yi]   (*DKS*)\n ];\n \
\n       (* YY = Join[YY,y//Transpose];*)\n  \n G =  \
Map[g1[#,xi,Theta]&,yJ1]; \n Pi1i = MapThread[Dot,{G,Map[Transpose,G]}] dt;\n \
yi1i = yJ1 + Map[f1[#,xi,Theta]&,yJ1] dt; \n    \t\t\n\tyi1i = \
Over[yi1i,YMAX];\n\t(*y  = Over[y,YMAX];*)\n\t   \n\tj = ti[[i+1]];      \
(*Print[{i+1,j}];*)\n\t\t   \n\tp = ",
  StyleBox["LogLikelihoodRatio",
    FontColor->RGBColor[1, 0, 0]],
  "[#,{f1,f2},g1,Xi,dt,Theta]&;\n      \t\t\n\tlikratio = Map[p,y]; \n\t\n\t\t\
\t\t\t(*{y//Dimensions,likratio}//Print; *)\n\t\n\tliki = \
Exp[MapThread[LogPhi[Y[[j]],#1,#2]&,{yi1i,Pi1i}] + likratio];\n\t\n\t(*liki = \
MapThread[Phi[Y[[j]],#1,#2]&,{yi1i,Pi1i}] * likratio;*)\n\t\n\tliki = \
If[option == 1, Log[mean[liki] ], Log[CuMean[liki] ]   ];\n\t\n\t(*liki = \
Log[mean[liki] ];*)\n (*liki//Print;*)\n\t\t\n\tlik += liki;\n\t\n\
,{i,1,Length[ti]-1}];\n\n(*YY = Join[YY,{yi1i}];*)\n\nlik\n\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"LikFIFImportance"],

Cell[TextData[{
  StyleBox["FIFImportance",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["FIFImportance",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t             \
{{l0_,l1_,l2_:0},step_,dW_,seed_,Generator_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
Funktional-Integral mit importance sampling \n   int \
p(y_J|y_J-1)...p(y_1|y_0)p_i|i(y_0)\n   p_{i+1|i} = 1/N sum p(y_{i+1} = \
y_J|y_J-1) * alpha{i+1|i}; \n   dy = fdt + gdW \n \n   option = 1: lik, \n   \
option = 2: YF: TxNxp,(Stichproben-Trajektorien) \n   option = 3: YF: Tx2xp \
(m und s)\n\n*)\n\n\
Module[{ti,T1,T,dti,dti1,n,n1,Xi,z,y0,P0,yiiR,lik,yii,Pii,alphaii,alphai1i,\n \
       YF,Misch,likvec,xi,dwi,yJ1,y,G,Pi1i,yi1i,liki,fI,f2,f1,g1,g2,XZ,p,\n   \
     likratio},\n\n{ti,T1,T,dti,dti1} = Zeiten1[Z,miss];\n\nn = Length[dW]; \
n1 = 1./n; \n\nPrint[\"",
  StyleBox["FIFImportance: ",
    FontColor->RGBColor[1, 0, 0]],
  "Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nfI//Clear; \n\
fI[{z_,y_},{x_,_,_},Th_]:= (z - h[y,x,Th]).Inverse[ R[y,x,Th] ].Dh[y,x,Th];\n \
                        \nf2//Clear;\nf2[y_,{x_,z_,lambdat_},Th_]:= f[y,x,Th] \
+ lambdat*fI[{z,y},{x,_,_},Th];\n\nf1//Clear;\nf1[y_,{x_,z_,lambdat_},Th_]:= \
f[y,x,Th]; \n\ng1//Clear;\ng1[y_,{x_,z_,lambdat_},Th_]:= g[y,x,Th];\n\n\
g2//Clear;\ng2[y_,{x_,z_,lambdat_},Th_]:= g[y,x,Th];\n\n\n\nSeedRandom[seed];\
\n\n{y0,P0,alpha0} = p0[X[[1]],Theta,n];\n\n{yiiR,lik,yii,Pii,alphaii} = \n\t\
\t    MessUpOmnibus[{Z[[1]],{y0,P0,alpha0},X[[1]]},Theta,{h,Dh,R},\n\t\t      \
            {miss,n,Generator,seed,True}];\n\t\t                  \n\t\t      \
            \t\t\t\t                 \t\nYF   = {}; Misch = {}; likvec = \
{lik};\n\nlambdat = Lambda",
  StyleBox["2",
    FontColor->RGBColor[0, 0, 1]],
  "[ti,T1,{l0,l1},miss];\n  \nXZ = {X, ",
  StyleBox["Interpol",
    FontColor->RGBColor[1, 0, 0]],
  "[Z,miss,1],lambdat}//Transpose;\n\nDo[  \n\n\tXi  = Take[ XZ,dti[[i]] ];\n \
xi  = Xi//Last;\n\tdwi = Map[Take[#,dti1[[i]] ]&,dW];\n \n If[dti1[[i]] =!= \
1,\n  \n\t\t{yJ1,y} = TimeUpFokker[{yiiR,Xi,dwi,dt},Theta,{f2,g2},step],\n\t\t\
\n   yJ1 = yiiR; y = {yiiR}//Transpose  (*DKS*)\n ];\n \n G =  \
Map[g1[#,xi,Theta]&,yJ1]; \n Pi1i = MapThread[Dot,{G,Map[Transpose,G]}] dt;\n \
yi1i = yJ1 + Map[f1[#,xi,Theta]&,yJ1] dt; \n\n (*Print[yi1i//First];*)\n \
(*Print[Pi1i//First//VecDiag]; *)\n    \t\t\n\tyi1i = Over[yi1i,YMAX];\n\t(*y \
 = Over[y,YMAX];*)\n\n\tIf[option==2,\n\t\t\t\t YF = Join[YF,y//Transpose];\n\
\t\t\t\t (*YF//Print;*)\n\t    (*Misch = Append[Misch,{alphaii,yii,Pii}];*)   \
    \n\t  ];\n\t  \n\tIf[option==3,\n\t    (*y//Dimensions//Print;\n\t    \
y//TensorMS//Dimensions//Print;*)\n\t\t\t\t YF = \
Join[YF,y//TensorMS//Transpose];\n\t\t\t\t (*YF//Print; *) \n\t  ];\n\t   \n\t\
j = ti[[i+1]]; \n\t(*Print[{i+1,j}];*)\n\t\n\tIf[dti1[[i]] =!= 1,\n\t\n\t\t\t\
\tp = ",
  StyleBox["LogLikelihoodRatio",
    FontColor->RGBColor[1, 0, 0]],
  "[#,{f1,f2},g1,Xi,dt,Theta]&; \n\t\t\t\talphai1i = n1*(Map[p,y]//Exp),\t  \n\
\t\n\t\t\t\talphai1i = n1\n\t];\n\n\nalphai1i//Print;\n\n\n         (* \
yi1i//Print;*)\n\t\t\t\t\t\t\t \t(* oder:alphai1i = \
alphai1i/(Plus@@alphai1i); *)    \t\t(*Normierung*)\t\n       \t \
(*Plus@@alphai1i//Print;*)\n\t\t\n\t{yiiR,liki,yii,Pii,alphaii} = \n\t\t    \
MessUpOmnibus[{Z[[j]],{yi1i,Pi1i,alphai1i},X[[j]]},\n\t\t\t\t                 \
Theta,{h,Dh,R},{miss,n,Generator,seed,True}];\n\t\n\t(*liki//Print;*)\t\n\t\
(*likvec = Append[likvec,liki];*)\n\t\n\tlik +=liki;\n\t\n\
,{i,1,Length[ti]-1}];\n\n\n\nIf[option==1,Return[lik] ];\n\nIf[option==2,\n\t\
YF = Join[YF,{yiiR}];\n\t(*Misch = Append[Misch,{alphaii,yii,Pii}];*)\n\t\
Return[{YF,lik,Misch//Transpose}] ];\n\t\nIf[option==3,\n\tYF = \
Join[YF,{yiiR//TensorMS}];\n\tReturn[{YF,lik,Misch}] ];\t\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"FIFImportance"],

Cell["\<\
(***************************************************************)\t\
\t\t 
alphamax[alphaiiZ_]:=Module[{alphaiimax,imax,n=alphaiiZ//Length},
(***************************************************************)\t\t\t 
imax=Position[alphaiiZ,alphaiiZ//Max]//Flatten;
alphaiimax=Shape[0,{n}];
Map[(alphaiimax[[#]]=1./Length[imax])&,imax];
alphaiimax
]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["alphamax[{.4,.4,.6,.4}]", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{0, 0, 1., 0}\
\>", "\<\
{0, 0, 1., 0}\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
(***************************************************************)\t\
\t\t 
alphafilter[alpha_,c_]:=
(***************************************************************)\t
Module[{pos,alpha1},\t\t 
pos=Position[Map[(#<c)&,alpha],True];
alpha1=ReplacePart[alpha,0,pos];
alpha1=alpha1/Apply[Plus,alpha1]
]
\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
alpha={.1,.1,.2,.6};
alphafilter[alpha,.21]\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{0, 0, 0, 1.}\
\>", "\<\
{0, 0, 0, 1.}\
\>"], \
"Output",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[TextData[{
  StyleBox["FIFImportanceSmooth",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["FIFImportanceSmooth",
    FontColor->RGBColor[1, 0, 0]],
  "[{Z_,X_},Theta_,{f_,Df_,g_,h_,Dh_,R_,p0_,dt_},\n\t\t\t\t                \
{{l0_:1,l1_:1,l2_:0,iter_:1,\n\t\t\t\t                  \
quote_,anti_,tanner_,sort_,Alphanorm_},\n\t\t\t\t                \
step_,dW_,seed_,Generator_,\n\t\t\t\t                 miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
Funktional-Integral mit exaktem importance sampling\n   f\[UDoubleDot]r \
lineare Systeme \n   \n   int p(y_J|y_J-1)...p(y_1|y_0)p_i|i(y_0)\n   \
p_{i+1|i} = 1/N sum p(y_{i+1} = y_J|y_J-1) * alpha{i+1|i}; \n   dy = fdt + \
gdW \n \n   option = 1: lik, \n   option = 2: YF: \
TxNxp,(Stichproben-Trajektorien) \n   option = 3: YF: Tx2xp (m und s)\n\n*)\n\
\nBlock[{ti,T1,T,dti,dti1,n,n1,Xi,z,y0,P0,yiiR,lik,yii,Pii,alphaii,alphai1i,\n\
        yiiZ,PiiZ,alphaiiZ,\n        \
YF,Misch,(*likvec,*)xi,dwi,yJ1,y,G,Pi1i,yi1i,liki,f2g2,fI,f2,f1,g1,g2,XZ,p,\n \
       likratio,lik2,lik1,Zi1},\n\n{ti,T1,T,dti,dti1} = Zeiten1[Z,miss];\n\n\
(*\nti//Print;\ndti//Print;  \ndti1//Print; \n*)\n\nn = Length[dW]; n1 = \
1./n; \n\nPrint[\"",
  StyleBox["FIFImportanceSmooth: ",
    FontColor->RGBColor[1, 0, 0]],
  "Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\n\nf2g2//Clear;\n\
f2g2[y_,{XX_,z_},Th_]:= Block[{fI,OmegaI,F1,F2,G,Omega,G2},\n\t\n\t   \
{fI,OmegaI} = SmoothEKF2[{z,y,_,XX,dt},Th,{f,Df,g,h,Dh,R},miss];\t\n\t\n\t   \
F1 = f[y,XX//First,Th];\n\t   F2 = F1 + l0*fI;\n\t \n\t   G = \
g[y,XX//First,Th];\n\t   Omega = G.Transpose[G];\t  \n\t   \n\t   G2 =  \
CholeskyDecomposition[Symmetrize[Omega + l1*OmegaI]]//Transpose;\n\t   \n\t   \
(*Print[XX//First,F1,F2,G,G2]; *)\n\t \n\t {F2,G2}\t ];\n\t \n\t \n\
{yi1i,Pi1i,alphai1i} = p0[X[[1]],Theta,n];\n\n{yiiR,lik,yii,Pii,alphaii} = \n\
\t\t    MessUpOmnibus[{Z[[1]],{yi1i,Pi1i,alphai1i},X[[1]]},Theta,{h,Dh,R},\n\t\
\t                  {miss,n,Generator,seed,False}];\n\t\t                  \n\
likneu=lik;\n\n\t\t\t\t\t(*\n\t\t\t\t\t\t{yiiZ,PiiZ,alphaiiZ} = \
SmoothEKF[{Z[[ti[[2]] ]],yii,Pii,alphaii,\n                                \t\
\t\t\t\t\t  Take[X,dti[[1]] ],dt},Theta,\n                                \t\t\
\t\t\t\t {f,Df,g,h,Dh,R},miss];\n\n\t\t\t\t\t\t{yiiZ,PiiZ,alphaiiZ}//Print;\n\
\n\t\t\t\t\t\t*)\n                                ",
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]],
  "\n{yiiZ,PiiZ,alphaiiZ} = SmoothEKFIter[{Z[[ti[[2]] ]],yii,Pii,alphaii,\n   \
                                  Take[X,dti[[1]] ],dt,iter},Theta,\n         \
                            {f,Df,g,h,Dh,R},miss];\n                          \
                                    \n                                 \nIf[\
l2==1,alphaiiZ= Shape[n1,{n}]  ];\nIf[l2==2,alphaiiZ= ALPHIIZ[[1]] ];\n\
If[l2==3,ALPHIIZ = Append[{},alphaiiZ] ];\nIf[l2==4,alphaiiZ= \
alphamax[alphaiiZ]  ];\nIf[l2==6,alphaiiZ= alphafilter[alphaiiZ,n1]  ];\n\t\n\
\t\t\t\t\nN1 = Table[n1,{n}];  (* a priori-Gewichte 1/n *)\n\n\
{n,p}=yii//Dimensions;\neps= zufall[Generator,n,p,seed,anti];    (* \
eps=Zufallmatrix (0,1) *)",
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]],
  "\nIf[sort!=0,{yiiZ,PiiZ,alphaiiZ} = Sortieren[{yiiZ,PiiZ,alphaiiZ},sort]];\
\n\n{yiiR,alphai1i} = \
Resampling[{yiiZ,PiiZ,alphaiiZ,N1},eps,seed,{quote,tanner}];\n\n        \
(*PiiZ//TableForm//Print;\n          PiiZ[[1]]//Eigenvalues//Print;*)",
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]],
  "\n\t\t\t\t\t\t\t\t(*yiiR = \
RandomKDE[yiiZ,alphaiiZ,PiiZ,Generator,seed,n];*) (* resampling *)\n\n\np0Z = \
Map[likratio0[#,{yii,Pii,alphaii},{yiiZ,PiiZ,alphaiiZ}]&,yiiR];\t             \
   \n\n(*\nPrint[i,\"  \",p0Z];\nPrint[i,\"  \",yiiR]; \n*)   \n\t\t          \
        \t\t\t\t                 \t\nYF   = {}; Misch = {}; likvec = {lik};\n \
 \nDo[  \n\n\tj   = ti[[i+1]];      (*Print[{i+1,j}];*)\n\tZi1 = Z[[j]];\n\t\n\
\tXi  = Take[ X,dti[[i]] ];\n\tXZ  = \
Table[{Drop[Xi,j-1],Zi1},{j,1,Xi//Length}];\n\t\n\t(* XZ//Print; *)\n\t\n\t\n \
xi  = Xi//Last;\n\tdwi = Map[Take[#,dti1[[i]] ]&,dW];  \n\n\t{y,lik2} = \
MapThread[RungeKutta1Lik[f2g2,#1,{XZ,#2},\n\t                     \
Length[XZ]-1,dt,Theta,EulerStep1Lik]&,{yiiR,dwi}]//Transpose;\n",
  StyleBox["\n ",
    FontColor->RGBColor[0, 0, 1]],
  "\n yJ1 = Map[Last,y];\n \n (* yJ1//Print; lik2//Print; *)\n\t\n\t\n G =  \
Map[g[#,xi,Theta]&,yJ1]; \n Pi1i = MapThread[Dot,{G,Map[Transpose,G]}] dt;\n \
yi1i = yJ1 + Map[f[#,xi,Theta]&,yJ1] dt; \n\n \n \
(*Print[Pi1i//First//VecDiag]; *)\n \n (* yi1i//Abs//Max//Print;*)\n   \t\t\n\
\tyi1i = Over[yi1i,YMAX];\n\t(*y  = Over[y,YMAX];*)\n\n\tIf[option==2,\n\t\t\t\
\t YF = Join[YF,y//Transpose];\n\t\t\t\t (*YF//Print;*)     \n\t  ];\n\t  \n\t\
If[option==3,\n\t    (*y//Dimensions//Print;\n\t    \
y//TensorMS//Dimensions//Print;*)\n\t\t\t\t YF = \
Join[YF,y//TensorMS//Transpose];\n\t\t\t\t (*YF//Print; *) \n\t  ];\n\t   \n\t\
\n\tIf[dti1[[i]] =!= 1,\n\t\t\t\t\n\t\t\t\t\
lik1=Map[LogLikelihood[#,f,g,Xi,dt,Theta]&,y];\n\t\t\t\talphai1i = \
n1*Exp[lik1-lik2]*p0Z,\t  \n\t\n\t\t\t\talphai1i = n1*p0Z\n\t];\n\t\n  \
If[Alphanorm==1,alphai1i =\talphanorm[alphai1i]];\n\t\n\t\
{yiiR,liki,yii,Pii,alphaii} = \n\t\t    \
MessUpOmnibus[{Zi1,{yi1i,Pi1i,alphai1i},X[[j]]},\n\t\t\t\t                 \
Theta,{h,Dh,R},{miss,n,Generator,seed,False}];\n\t\t\t\t                 \n",
  StyleBox["\t(*Print[liki1,\"   \",liki];*)",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIf[i < Length[ti]-1,\n\t\t\t\t\t\n\t\t\t\t",
  StyleBox["(*\n\t\t\t\t{yiiZ,PiiZ,alphaiiZ} = \
SmoothEKF[{Z[[ti[[i+2]]]],yii,Pii,alphaii,\n\t\t\t\t                          \
        Take[X,dti[[i+1]] ],dt},\n\t\t\t\t                                  \
Theta,{f,Df,g,h,Dh,R},miss];\n\t\t\t\t                                  \n\t\t\
\t\tPrint[\"alphaiiZ \",alphaiiZ//Chop]; \n\t\t\t\t*)   ",
    FontColor->GrayLevel[0.666651]],
  "\n\t\t\t\t                              \n\t\t\t\t{yiiZ,PiiZ,alphaiiZ} = \
SmoothEKFIter[{Z[[ti[[i+2]] ]],yii,Pii,alphaii,\n                             \
            Take[X,dti[[i+1]] ],dt,iter},Theta,\n                             \
            {f,Df,g,h,Dh,R},miss];\n                                     \n\t\
\t\t\tIf[l2==1,alphaiiZ= Shape[n1,{n}]  ];\n\t\t\t\tIf[l2==2,alphaiiZ= \
ALPHIIZ[[i+1]] ];\n\t\t\t\tIf[l2==3,ALPHIIZ = Append[ALPHIIZ,alphaiiZ] ];\n\t\
\t\t\tIf[l2==4,alphaiiZ= alphamax[alphaiiZ]  ];\n\t\t\t\tIf[l2==6,alphaiiZ= \
alphafilter[alphaiiZ,n1]  ];\n\t\t\t\t\n\t\t\t\tPrint[\"alphaiiZ \
\",alphaiiZ//Chop];\n\t\t\t\t(* Print[\"PiiZ \",PiiZ]; *)\n\t\t\t\t\n\t\t\t\t\
\n\t\t\t\tIf[sort!=0,{yiiZ,PiiZ,alphaiiZ} = \
Sortieren[{yiiZ,PiiZ,alphaiiZ},sort]];\n\n    {yiiR,alphai1i} = \
Resampling[{yiiZ,PiiZ,alphaiiZ,N1},eps,seed,{quote,tanner}];\n\t\n   \t\t\t\t\
\t\t",
  StyleBox["(*\n\t\t\t\t\t\t\t\t\tSeedRandom[seed];                    \n \t\t\
 \t\t\t\t\tyiiR = RandomKDE[yiiZ,alphaiiZ,PiiZ,Generator,seed,n]; (* \
resampling *)\n    \t\t\t\t\t*)",
    FontColor->GrayLevel[0.666651]],
  "\n    \t\t\t\t\t \t\t \n \t\t p0Z = \
Map[likratio0[#,{yii,Pii,alphaii},{yiiZ,PiiZ,alphaiiZ}]&,yiiR];\n \t\t \n \t\t\
 (*\n \t\t Print[i,\"yi1i\",yi1i];\n \t\t Print[i,\"Pi1i\",Pi1i];  \n \t\t \
Print[i,\"alphai1i\",alphai1i//Log];\n \t\t Print[i,\"yii\",yii];\n \t\t \
Print[i,\"Pii\",Pii];  \n \t\t Print[i,\"alphaii\",alphaii];\n \t\t \
Print[i,\"yiiZ\",yiiZ];\n \t\t Print[i,\"PiiZ\",PiiZ];  \n \t\t \
Print[i,\"alphaiiZ\",alphaiiZ];\n \t\t \n \t\t Print[i,\"yiiR\",yiiR]; \n \t\t\
 Print[i,\"p0Z \",p0Z];  \n \t\t *) \n \t\t \n \t\t (*Return[];*)             \
       \n\t\t\t\t\n\t  ];\n  \t\t\n\t\n\tlikvec = Append[likvec,liki];\t\n\t\
lik +=liki;\n\t\n\t(*",
  StyleBox["likneu+=liki1;*)",
    FontColor->RGBColor[0, 0, 1]],
  "\n\t\n,{i,1,Length[ti]-1}];\n\n\n\nIf[option==1,Return[lik] ];\n\n\
If[option==2,\n\tYF = Join[YF,{yiiR}];\n\tReturn[{YF,lik,likvec}] ];\n\t\n\
If[option==3,\n\tYF = Join[YF,{yiiR//TensorMS}];\n\tReturn[{YF,lik,Misch}] ];\
\t\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"FIFImportanceSmooth"],

Cell[TextData[{
  StyleBox["LikKernDichte",
    FontColor->RGBColor[1, 0, 0]],
  "//Clear\n(***************************************************************)\
\t\t\t \n",
  StyleBox["LikKernDichte",
    FontColor->RGBColor[1, 0, 0]],
  "[{Y_,X_},Theta_,{f_,g_,p0_,dt_},{dW_,seed_,miss_,option_:1}]:=\n\
(***************************************************************)\t\t\t \n(* \
KernDichte, kein Me\[SZ]-Modell, ohne IS\n   \n   p_i+1|i = 1/N sum \
K(y_J|eta_J); dy = fdt + gdW \n \n   option = 1: lik\n\n*)\n\n\
Module[{ti,T1,T,dti,dti1,n,X0,lik,mue,sigma,smooth,smooth1,Xi,dwi,Yi,y,\n     \
   yi1i,j,i,liki,jacobi},\n\n{ti,T1,T,dti,dti1} = Zeiten[Y,miss];        \
(*dti//Print; dti1//Print;*)\n\nn = Length[dW]; \nPrint[\"",
  StyleBox["LikKernDichte: ",
    FontColor->RGBColor[1, 0, 0]],
  "Monte-Carlo-Stichprobe n = \",n,\"  seed = \", seed];\n\nSeedRandom[seed];\
\n\nX0 = X[[1]];\n\nIf[Length[p0]==0,\n\t \tlik = Log[ p0[Y[[1]],X0,Theta] ],\
\n\t \t\t\t(*else*)\n\t \tmue   = p0[[1]][X0,Theta];\n  \tsigma = \
p0[[2]][X0,Theta];  \n  \tlik = LogPhi[Y[[1]],mue,sigma]; (*AB*)\t \n  ];  \n \
 \n(*lik//Print;*)\nYY = {};\n\nDo[ \n\n\tXi  = Take[ X,dti[[i]] ]; \n\tdwi = \
Map[Take[#,dti1[[i]] ]&,dW];\n Yi = Y[[ti[[i]] ]];\n Yi = Table[Yi,{n}];\n \n \
{yi1i,y} = TimeUpFokker[{Yi,Xi,dwi,dt},Theta,{f,g}];\n         \t\t\n\tyi1i = \
Over[yi1i,YMAX];\n\t(*y  = Over[y,YMAX];*)  \n\t\n\t(*YY = \
Join[YY,Drop[y//Transpose,-1]];*)\n\n\tj = ti[[i+1]];   (*Print[{i+1,j}];*)\n\
\t\n\tsmooth  = smoothQuickAndDirtyM[yi1i,1];  \n\tsmooth1 = smooth//Inverse;\
\t\n\tjacobi  = Det[smooth]^(-.5); \n\tliki    = Map[ GaussKernO[Y[[j]] - \
#,{smooth,smooth1}]&, yi1i];\t\n\t(*liki//Print;*)\n\tliki    = Log[ \
jacobi*mean[liki] ];\n\t\n     (*liki//Print;*)\n\t\t\n\tlik += liki;\n\t\n\
,{i,1,Length[ti]-1}];\n\nlik\n\n\t\n];"
}], "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Likelihoods", "Section",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
LikKalmanFokkerN//Clear
(***************************************************************)\t\t\t 
LikKalmanFokkerN[{Z_,X_},Theta_,{f_,g_,h_,R_,p0_,dt_},
\t\t\t\t{{y1_,y2_,dy_},nstd_,$dw$_,seed_,miss_}]:=
(***************************************************************)\t\t\t 
\t\t\t\t
Module[{ti,dti,dti1,$n$,z,y0,yii,pii,pi1i,lik,Xi,dwi,yi1i,j},

Print[\"LikKalmanFokkerN: \"];

ti   = messind[Z,miss]; (*Indices mit mind. einer Messung*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

$n$ = Length[$dw$]; 

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,$n$];

{yii,pii,pi1i,lik} = 
\tMessUpFokker2[{Z[[1]],y0,Xi,_},Theta,{h,R},{{y1,y2,dy},nstd,$n$}];

Do[ (*Print[\"LikKalmanFokkerN: \",i];*)

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\tyi1i = Over[yi1i,YMAX];
\tj = ti[[i+1]]; 
\t
\t{yii,pii,pi1i,liki} = 
\t\tMessUpFokker2[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,R},{{y1,y2,dy},nstd,$n$}];\t
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

lik ];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
LikKalmanFokkerEKFN//Clear
(***************************************************************)\t\t\t 
LikKalmanFokkerEKFN[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t{{y1_,y2_,dy_},_,$dw$_,seed_,miss_}]:=
(***************************************************************)\t\t\t \t\t\t\
\t
Module[{ti,dti,dti1,$n$,z,y0,yii,pii,pi1i,lik,Xi,dwi,yi1i,j},

Print[\"LikKalmanFokkerEKFN: \"];

ti   = messind[Z,miss]; (*Indices mit mind. einer Messung*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

$n$ = Length[$dw$]; 

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,$n$];

{yii,pii,pi1i,lik,ym,pm} = 
\tMessUpEKF1[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{$n$,miss,1}];

Do[ (*Print[\"LikKalmanFokkerN: \",i];*)

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\tyi1i = Over[yi1i,YMAX];
\tj = ti[[i+1]]; 
\t
\t{yii,pii,pi1i,liki,ym,pm} = 
\t\tMessUpEKF1[{Z[[j]],yi1i,X[[j]],_},
\t\t\t\tTheta,{h,Dh,R},{$n$,miss,1}];
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

lik ];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
LikKalmanFokkerEKFSumN//Clear
(***************************************************************)\t\t\t 
LikKalmanFokkerEKFSumN[{Z_,X_},Theta_,{f_,g_,h_,Dh_,R_,p0_,dt_},
\t\t\t\t{{y1_,y2_,dy_},_,$dw$_,seed_,miss_}]:=
(***************************************************************)\t\t\t \t\t\t\
\t
Module[{ti,dti,dti1,$n$,z,y0,yii,pii,pi1i,lik,Xi,dwi,yi1i,j},

Print[\"LikKalmanFokkerEKFSumN: \"];

ti   = messind[Z,miss]; (*Indices mit mind. einer Messung*)
dti  = Delta[ti,ti,List,-1];
dti1 = Delta[ti]+1;

$n$ = Length[$dw$]; 

SeedRandom[seed];

Xi = X[[1]];
{z,y0} = RandomNumbers[{y1,y2,dy},p0[#,Xi,Theta]&,$n$];

{yii,lik} = 
\tMessUpEKFSum[{Z[[1]],y0,Xi,_},Theta,{h,Dh,R},{miss}];

Do[ (*Print[\"LikKalmanFokkerN: \",i];*)

\tXi  = Take[ X,dti[[i]] ];
\tdwi = Map[Take[#,dti1[[i]] ]&,$dw$];

\t{yi1i,y} = TimeUpFokker[{yii,Xi,dwi,dt},Theta,{f,g}];
\tyi1i = Over[yi1i,YMAX];
\tj = ti[[i+1]]; 
\t
\t{yii,liki} = 
\t\tMessUpEKFSum[{Z[[j]],yi1i,X[[j]],_},Theta,{h,Dh,R},{miss}];
\t\t
\tlik +=liki;

,{i,1,Length[ti]-1}];

lik ];\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lik,Score,BFGS", "Section",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\


Lik//Unprotect
Lik//Clear
(***************************************************************)\t\t\t 
Lik[data_,Theta_,{system_,LikN_},misc_]:=
(***************************************************************)\t\t\t 
Apply[Plus,
Map[LikN[#,Theta*SCALING,system,misc]&,data]
]

Lik//Protect;\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{\"Lik\"}\
\>", "\<\
{Lik}\
\>"], "Output",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Unprotect[Lik1]
Lik1//Clear
(***************************************************************)\t\t\t 
Lik1[data_,Theta_,{system_,LikN_},misc_]:=
(***************************************************************)\t\t\t 
Sum[LikN[data[[i]],Theta*SCALING,system,misc],{i,data//Length}]

Lik1//Protect;\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell[OutputFormData["\<\
{\"Lik1\"}\
\>", "\<\
{Lik1}\
\>"], "Output",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14]
}, Open  ]],

Cell["\<\
Score//Clear
(***************************************************************)\t\t\t 
Score[data_,Theta_,{system_,{Lik_,LikN_}},misc_]:=
(***************************************************************)\t\t\t 
Module[{INC,i,LIK,LIKI,INC1,SNUM},

LIK = Lik[data,Theta,{system,LikN},misc]; (*setzt FDIGITS*)

ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/2) max[Abs[Theta],Abs[TYP]];
Print[\"Score: INC: \",INC]; 
INC1= 1./INC; 

SNUM = {};
u=Length[Theta];

Do[ (*Print[\"Score: \",i];*)
   \t
   \tThetai=GRIDI[Theta,i, INC];
    LIKI = Lik[data,Thetai,{system,LikN},misc];
    
    (*Thetai//PaddedForm[#,{20,15}]&//Print;*)
    (*LIKI//PaddedForm[#,{20,20}]&//Print;*)
    (*Print[LIKI//PaddedForm[#,{20,20}]&,\"   \",
          LIK//PaddedForm[#,{20,20}]&,\"    \",
          LIKI-LIK//PaddedForm[#,{20,20}]&,\"   \", INC1[[i]] ];
     *)
    
    SNUM = Append[SNUM,(LIKI-LIK)*INC1[[i]]//N ]
    
  ,{i,u} ];
  
{SNUM,LIK}
]\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
cScore//Clear
(***************************************************************)\t\t\t 
cScore[data_,Theta_,{system_,{Lik_,LikN_}},misc_]:=
(***************************************************************)\t
(*berechnet u Likelihoods simultan in C*)\t\t 
Module[{INC,i,LIK,LIKI,INC1,SNUM,u,Thetai},

(*LIK = Lik[data,Theta,{system,LikN},misc];*) (*setzt FDIGITS*)

ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/2) max[Abs[Theta],Abs[TYP]];
Print[\"Score: INC: \",INC]; 
INC1= 1./INC; 

SNUM = {};
u=Length[Theta];

Thetai= Table[ SCALING*GRIDI[Theta,i, INC],{i,u} ]; (* uxu!!*) 
Thetai= Join [{SCALING*Theta},Thetai];

LIKI = Sum[LikN[data[[i]],Thetai,system,misc],{i,data//Length}]; (* \
u+1-Vektor!!*)

LIK =LIKI//First;
LIKI=LIKI//Rest;

Do[(*Print[\"Score: \",i];*)
   (*
    Print[LIKI[[i]]//PaddedForm[#,{20,20}]&,\"   \",
          LIK//PaddedForm[#,{20,20}]&,\"    \",
          LIKI[[i]]-LIK//PaddedForm[#,{20,20}]&,\"   \", INC1[[i]] ];
    *)
    
    SNUM = Append[SNUM,(LIKI[[i]]-LIK)*INC1[[i]]//N ]
    
  ,{i,u} ];  
  
{SNUM,LIK}
]\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\

Score2//Clear
(***************************************************************)\t\t\t 
Score2[data_,Theta_,{system_,{Lik_,LikN_}},misc_]:=
(***************************************************************)\t\t\t 
Module[{INC,i,LIK,LIKup,LIKdo,INC1,SNUM},

LIK = Lik[data,Theta,{system,LikN},misc]; (*setzt FDIGITS*)

ETA = Max[$MachineEpsilon,10.^-FDIGITS]; 
INC = ETA^(1/3) max[Abs[Theta],Abs[TYP]];
Print[\"Score2: INC: \",INC]; 
INC1= 1/(2 INC);
 

SNUM = {};
Do[ (*Print[\"Score2: \",i];*)
   
    LIKup = Lik[data,GRIDI[Theta,i, INC],{system,LikN},misc];
    LIKdo = Lik[data,GRIDI[Theta,i,-INC],{system,LikN},misc];
    SNUM = Append[SNUM,(LIKup-LIKdo)*INC1[[i]] ]
    
  ,{i,Length[Theta]} ];
  
{SNUM,LIK}
]
\t\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
\t
(***************************************************************)\t\t\t 
Hesse2[data_,Theta_,{system_,{Lik_,LikN_,Score_}},misc_]:=
(***************************************************************)\t\t\t 
(* NUMERISCHER SCORE (MIT MISSING DATA) 2-seitig*)

Module[{INC,i,LIK,INC1,
\t\tSup,Sdo,DS,S,HNUM,SNUM},

{S,LIK} = Score[data,Theta,{system,{Lik,LikN}},misc];

ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/3);
INC = INC max[Abs[Theta],Abs[TYP]];
INC1=1/(2 INC);
HNUM = {};
SNUM = {};
Do[ 
    {Sup,likup} = Score[data,GRIDI[Theta,i, INC],{system,{Lik,LikN}},misc];
\t{Sdo,likdo} = Score[data,GRIDI[Theta,i,-INC],{system,{Lik,LikN}},misc];
\t
    HNUM = Append[HNUM,(Sup  -  Sdo)*INC1[[i]]];
    SNUM = Append[SNUM,(likup-likdo)*INC1[[i]]]
    
  ,{i,Length[Theta]} ];

HNUM = .5(HNUM + Transpose[HNUM]);  
DS = S-SNUM;
Print[ \"KONTROLLE: NUMERISCHER SCORE - ZENTRALE DIFFERENZEN\"];
Print[MatrixForm[{SNUM, S, DS, Theta, INC }//Transpose,
\tTableHeadings->{Automatic,{\"SNUM\",\"S\",\"DS\",\"THETA\",\"INC\"}}]];  
{HNUM,LIK}
]\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
Hesse[data_,Theta_,{system_,{Lik_,LikN_,Score_}},misc_]:=
(***************************************************************)
(* NUMERISCHE HESSE-MATRIX MIT NUMERISCHEM SCORE:              *)
(* ZENTRALE DIFFERENZEN                                        *)
(* s_i=1/(2h_i) (l^i-l^{-i}) ; l^i=l(theta+h_i e_i)            *)
(* H_{ij} = 1/(4H_i H_j) (l^{ij}-l^{i,-j} -l^{-i,j}+l^{-i,-j}) *)


Module[{LIK,L2,INK,INK2,H4,H,
\t\tLIJ,LIMJ,LIJM,LIMJM,L2I,LM2I,I,J},
\t\t
LIK  = Lik[data,Theta,{system,LikN},misc]; (*setzt FDIGITS*)
\t\t
ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/3);
INK = INC max[Abs[Theta],Abs[TYP]];
Print[\"INK: \",INK];
U    = Length[Theta];
INK2 = 2 INK;
H4   = .25/Outer[Times,INK,INK];
L2   = 2 LIK;

H = Shape[0,{U,U}];

Do[ 

{LIJ,LIMJ,LIJM,LIMJM} = 
\tMap[Lik[data,#,{system,LikN},misc]&,
\t\t\t{GRIDIJ[Theta ,I,J,  INK,  INK],
\t\t\t GRIDIJ[Theta ,I,J,  INK, -INK],
\t\t\t GRIDIJ[Theta ,I,J, -INK,  INK],
\t\t\t GRIDIJ[Theta ,I,J, -INK, -INK]
\t\t\t }];
\t
    H[[I,J]] = LIJ - LIMJ - LIJM + LIMJM;
    
,{I,1,U},{J,I+1,U}];

H = H + Transpose[H]; 

Do[ 

{L2I,LM2I} = 
\tMap[Lik[data,#,{system,LikN},misc]&,
\t\t\t{GRIDI[Theta ,I, INK2],
\t\t\t GRIDI[Theta ,I,-INK2]
\t\t\t }];
    H[[I,I]] = L2I - L2 + LM2I;
    
,{I,1,U}];

H = H H4;
{H,LIK}
]
\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
cHesse[data_,Theta_,{system_,{Lik_,LikN_,Score_}},misc_]:=
(***************************************************************)
(* NUMERISCHE HESSE-MATRIX MIT NUMERISCHEM SCORE:              *)
(* ZENTRALE DIFFERENZEN                                        *)
(* s_i=1/(2h_i) (l^i-l^{-i}) ; l^i=l(theta+h_i e_i)            *)
(* H_{ij} = 1/(4H_i H_j) (l^{ij}-l^{i,-j} -l^{-i,j}+l^{-i,-j}) *)


Module[{LIK,L2,INK,INK2,H4,H,
\t\tLIJ,LIMJ,LIJM,LIMJM,L2I,LM2I,I,J,LIKI,lin,ThetaM,LIKI},
\t\t
\t\t
ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/3);
INK = INC max[Abs[Theta],Abs[TYP]];
Print[\"INK: \",INK];
U    = Length[Theta];
INK2 = 2 INK;
H4   = .25/Outer[Times,INK,INK];
L2   = 2 LIK;

H = Shape[0,{U,U}];

ThetaM={};

Do[ 

{LIJ,LIMJ,LIJM,LIMJM} = 
\t\t\t{SCALING*GRIDIJ[Theta ,I,J,  INK,  INK],
\t\t\t SCALING*GRIDIJ[Theta ,I,J,  INK, -INK],
\t\t\t SCALING*GRIDIJ[Theta ,I,J, -INK,  INK],
\t\t\t SCALING*GRIDIJ[Theta ,I,J, -INK, -INK]};

ThetaM=Join[ThetaM,{LIJ,LIMJ,LIJM,LIMJM}];\t
   
,{I,1,U},{J,I,U}];

ThetaM//Dimensions//Print;

LIKI = Sum[LikN[data[[i]],ThetaM,system,misc],{i,data//Length}]; (* \
u-Vektor!!*)

LIK=LIKI[[2]];

lin=0;

Do[ 

LIJ  =LIKI[[lin+=1]];
LIMJ =LIKI[[lin+=1]];
LIJM =LIKI[[lin+=1]];
LIMJM=LIKI[[lin+=1]];


H[[I,J]] = LIJ - LIMJ - LIJM + LIMJM;

H[[J,I]] = H[[I,J]];

,{I,1,U},{J,I,U}];  


H = H H4;
{H,LIK}
]
\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
lin//Unprotect;
lin//Clear;

lin[{i_,j_},{I_,J_}]:=(i-1)J+j;

lin//Protect;

partition//Unprotect;
partition//Clear

partition[x_,JJ_]:=
Module[{LL=x//Length},
Table[Take[x,{lin[{i,1},{_,JJ}],Min[lin[{i,JJ},{_,JJ}],LL]}],{i,1,LL/JJ//\
Ceiling}]
]

partition//Protect;\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)
cHesse1[data_,Theta_,{system_,{Lik_,LikN_,_}},misc_]:=
(***************************************************************)
(* NUMERISCHE HESSE-MATRIX MIT NUMERISCHEM SCORE:              *)
(* ZENTRALE DIFFERENZEN                                        *)
(* s_i=1/(2h_i) (l^i-l^{-i}) ; l^i=l(theta+h_i e_i)            *)
(* H_{ij} = 1/(4H_i H_j) (l^{ij}-l^{i,-j} -l^{-i,j}+l^{-i,-j}) *)
(* mit CHUNKS = 127                                            *)

Module[{LIK,L2,ETA,INC,INK,INK2,U,H4,H,
\t\tLIJ,LIMJ,LIJM,LIMJM,L2I,LM2I,I,J,lin,ThetaM,LIKI},
\t\t
(*LIK  = Lik[data,Theta,{system,LikN},misc];*) (*setzt FDIGITS*)
\t\t
ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/3);
INK = INC max[Abs[Theta],Abs[TYP]];
Print[\"INK: \",INK];
U    = Length[Theta]; (*U=UU;*)
INK2 = 2 INK;
H4   = .25/Outer[Times,INK,INK];

H = Shape[0,{U,U}];

ThetaM={};

Do[ 

{LIJ,LIMJ,LIJM,LIMJM} = 
\t\t\t{SCALING*GRIDIJ[Theta ,I,J,  INK,  INK],
\t\t\t SCALING*GRIDIJ[Theta ,I,J,  INK, -INK],
\t\t\t SCALING*GRIDIJ[Theta ,I,J, -INK,  INK],
\t\t\t SCALING*GRIDIJ[Theta ,I,J, -INK, -INK]};

ThetaM=Join[ThetaM,{LIJ,LIMJ,LIJM,LIMJM}];\t
   
,{I,1,U},{J,I+1,U}];

(*Diagonale*)

Do[ 

{LIJ,LIMJM} = 
\t\t\t{SCALING*GRIDI[Theta ,I,  INK2],
\t\t\t SCALING*GRIDI[Theta ,I, -INK2]};

ThetaM=Join[ThetaM,{LIJ,LIMJM}];\t
   
,{I,1,U}];

ThetaM//Dimensions//Print;

ThetaM=Join[{SCALING*Theta},ThetaM];

ThetaM=partition[ThetaM,CHUNKS = 127]; (*chunks maximal 127 x u*)

LIKI = 
Map[

Sum[LikN[data[[i]],#,system,misc],{i,data//Length}]&,

ThetaM]//Flatten;


LIK =LIKI//First;
LIKI=LIKI//Rest;

L2   = 2 LIK;

lin=0;
Do[ 

LIJ  =LIKI[[lin+=1]];
LIMJ =LIKI[[lin+=1]];
LIJM =LIKI[[lin+=1]];
LIMJM=LIKI[[lin+=1]];


H[[I,J]] = LIJ - LIMJ - LIJM + LIMJM;

,{I,1,U},{J,I+1,U}];  

H = H + Transpose[H]; 


(*Diagonale*)

Do[ 


LIJ  =LIKI[[lin+=1]];
LIMJM=LIKI[[lin+=1]];


H[[I,I]] = LIJ - L2 + LIMJM;

,{I,1,U}];  

H = H H4[[Range[1,U],Range[1,U]]];

{H,LIK}
]
\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"cHesse1"],

Cell["\<\
FisherInformationN//Clear
(***************************************************************)\t\t\t 
FisherInformationN[data_,Theta_,{system_,LikN_},misc_]:=
(***************************************************************)
(*F = Sum[E[s_t s_t']]*)
(*nur f\[UDoubleDot]r Likelihood mit option=5*)
\t\t\t 
Module[{INC,i,LIK,Thetai,LIKI,INC1,SNUM,SNUMt,F,likvec,likveci},

{LIK,likvec} = LikN[data,Theta*SCALING,system,misc]; (*likvec*) 

ETA = Max[$MachineEpsilon,10.^-FDIGITS];
INC = ETA^(1/2) max[Abs[Theta],Abs[TYP]];
(*Print[\"Score: INC: \",INC];*)
INC1= 1./INC; 

SNUM = SNUMt = {};
u=Length[Theta]; 

Do[ (*Print[\"Score: \",i];*)
   \t
   \tThetai=GRIDI[Theta,i, INC];
    {LIKI,likveci} = LikN[data,Thetai*SCALING,system,misc];
    
     (*{LIKI,likveci}//Print;*)
     (*
      Print[LIKI//PaddedForm[#,{20,20}]&,\"   \",
            LIK//PaddedForm[#,{20,20}]&,\"    \",
            LIKI-LIK//PaddedForm[#,{20,20}]&,\"   \", INC1[[i]] ];
      *)

  
    SNUM = Append[SNUM,(LIKI-LIK)*INC1[[i]]//N];
   
    SNUMt = Append[SNUMt,(likveci-likvec)*INC1[[i]]//N];
    
  ,{i,u} ];

F=Apply[Plus,Map[Outer[Times,#,#]&,SNUMt//Transpose]]; 

{F,LIK,likvec,SNUM,SNUMt}
]\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
FisherInformation//Unprotect;
FisherInformation//Clear
(***************************************************************)\t\t\t 
FisherInformation[data_,Theta_,{system_,LikN_,FisherInformationN_},misc_]:=
(***************************************************************)
(*F = Sum[E[s_t s_t']]*)
(*nur f\[UDoubleDot]r Likelihood mit option=5*)\t\t 
Module[{F},

F=Apply[Plus,
        Map[(FisherInformationN[#,Theta,{system,LikN},misc]//First)&,
        data]];

F];\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
FisherInformation//Protect;
\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
FisherInformation1//Unprotect;
FisherInformation1//Clear
(***************************************************************)\t\t\t 
FisherInformation1[data_,Theta_,{system_,LikN_,FisherInformationN_},misc_]:=
(***************************************************************)
(*F = Sum[E[s_t s_t']]*)
(*nur f\[UDoubleDot]r Likelihood mit option=5*)\t\t 
Module[{F},

F=Sum[FisherInformationN[data[[i]],
                          Theta,
                          {system,LikN},misc]//First
                         ,{i,data//Length}];

F];\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
BFGSUP//Clear
(***************************************************************)\t\t\t 
BFGSUP[F_,SNEU_,S_,STEP_] := 
\tModule[{MACHEPS2,Y,FSTEP,A,B,Fup},
(***************************************************************)\t\t\t 
(*NOISE LEVEL*)
ETA = Max[$MachineEpsilon,10.^-FDIGITS];
TOL = If[ANALGRAD,ETA,ETA^0.5,ETA^0.5];
NOISE = (Max[Abs[SNEU]]+Max[Abs[S]])*TOL;
Print[\"NOISE  \",NOISE];
MACHEPS2 = $MachineEpsilon^0.5;
Y = -SNEU+S;
FSTEP = F.STEP;
A = Y.STEP;
If[ A < MACHEPS2 Max[Abs[STEP]] Max[Abs[Y]], Return[F]  ];
If[ Max[Abs[Y-FSTEP]] < NOISE, Return[F]  ];
A=1/A;
B = 1/(STEP.FSTEP);
Print[\"*BFGSUP \", A,\"  \", B];  
Fup = F + Outer[Times, A Y ,Y] - Outer[Times,B FSTEP,FSTEP];
(*Fup=.5 (F+Transpose[Fup] *)
Fup
]

(***************************************************************)\t\t\t 
LikTest[LIKNEU_]:=
(***************************************************************)
\tIf[(LIKNEU//NumberQ//Not)||(Im[LIKNEU]=!=0)||(LIKNEU>10.^10),
\t \tPrint[\"LIKNEU = \",LIKNEU,\" reset to -10.^10\"]; -10.^10,
\t \t\tLIKNEU]\t\t\t\t\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
(***************************************************************)\t\
\t\t 
BFGS//Clear
BFGS[data_,
\t {THETA0_,F0_},
\t {system_,{Lik_,LikN_,Score_,Hesse_}},
\t {misc_,KMAX_,{EPS1_,EPS2_},OPTION_,PRINT_}]:= 
(***************************************************************)\t\t\t 
Module[{MINSTEP,BOUND,ALPHA,u,THETA,THETA1,F,
        S,LIKALT,LIKI,psii,scoreii,STEPL,STEP,
        LIKNEU,SNEU,likpsi,COV,LIKELI,n,T,T1,Tc,P,Q,k,K,KK,Z,Y,X,
        ReturnCode},


MINSTEP=10.^-10;
FMAX = 10^3; (*Maximaler EW*)
BOUND=10.^-6;
ALPHA=10.^-4;


n = data//Length;

Q = Dimensions[data[[1,2]]][[2]];

If[Depth[data]===5, {T1,K}=Map[Dimensions[Part[#,1]]&,data]//Transpose,

(* else *) 

If[Depth[data]===6, {T1,K}=Map[Dimensions[Part[#,1,1]]&,data]//Transpose

]];

Depth[data]//Print[\"Tiefe von data = \",#]&;  

Print[\"L\[ADoubleDot]nge der Paneldaten\"];
T1//Print;
T = T1-1; 

If[PRINT[[1]] == 1,
Print[\"***********************LSDE1**********************************\"];
Print[\"***********************MODUL:    BFGS (skeleton)**************\"];
Print[\"**************************************************************\"];
Print[\"Technical Output\"];
Print[LikN];
Print[\"**************************************************************\"];
VecPrint[{ KMAX,  EPS1,  EPS2,  K//First,  Q,  n,  T//First,  \
OPTION}//Spalte,
         {\"KMAX\",\"EPS1\",\"EPS2\",\"K\",\"Q\",\"n\",\"T\",\"OPTION\"}];
Print[ \"\"];
VecPrint[{ MAXSTEP,  MINSTEP,  BOUND,  STEPREDUCE,  FMAX}//Spalte,
         {\"MAXSTEP\",\"MINSTEP\",\"BOUND\",\"STEPREDUCE\",\"FMAX\"}];
Print[ \"\"];

VecPrint[{RESAMPLING,  FDIGITS,  TYP,  YMAX,  ANALGRAD,   FACTOR,  CSEED \
}//Spalte,
        {\"RESAMPLING\",\"FDIGITS\",\"TYP\",\"YMAX\",\"ANALGRAD\", \
\"FACTOR\",\"CSEED\"}];
Print[ \"\"];

Print[\"    SCALING\"];
Print[MatrixForm[SCALING//Spalte//Transpose,
      TableHeadings->{Automatic,{\"SCALING\"}},
      TableDepth->0] 
      ];




Print[ \"\"];
Print[\"**************************************************************\"];
Print[ \"\"];
Print[ \"STARTWERT THETA0 = \", THETA0]
];

u = Length[THETA0]; 

THETA=THETA0;
F=F0;
If[OPTION == 1, F = SHIFT[F,BOUND] ]; 


{S,LIKALT} = Score[data,THETA0,{system,{Lik,LikN}},misc]; 


Print[{S,LIKALT}];  

LIKI = {}; psii = {}; scoreii = {};
ReturnCode = 0;
k=0;



DoUntil[{KK,KMAX},
    (ReturnCode == 3),
     
    (*
\t(ReturnCode == 1 || ReturnCode == 2 || 
\t ReturnCode == 3 || ReturnCode == 4), 
\t *)
 \t
\tIf[PRINT[[2]] == 1,
\tPrint[\"-----------------------------------------------------------------\"]\
;
    Print[\"BFGS: Iteration = \",KK];
    ];
    
    LIKI=Append[LIKI,LIKALT];
    psii=Append[psii,THETA];
    scoreii = Append[scoreii,S];
    
 \tSTEP=LinearSolve[F,S];  
 \t

    (*BEGRENZUNG DER SCHRITTL\[CapitalADoubleDot]NGE*)
    STEPL=Max[Abs[STEP]]+$MachineEpsilon; (*falls STEP=0*)
    STEP=STEP*Min[1,MAXSTEP/STEPL];
    

    (*STEP-Reduction*)
   
    THETA1 = THETA + STEP;   (*VOLLER NEWTON-STEP*)
    
    (*Print[\"VOLLER NEWTON-STEP  \",THETA1,\"   \",THETA];*)
    
  \tLIKNEU = Lik[data,THETA1,{system,LikN},misc];\t
  \t
  \t(*LIKNEU//Print;*)
  \t\t\t
   \tLIKNEU = LikTest[LIKNEU];
  \t
   \t\t 
    DoWhile[{half,100}, (LIKNEU<LIKALT+ALPHA*(S.STEP) &&
          \t\t\t\t Max[Abs[STEP]]>MINSTEP),
          \t\t\t\t 
         STEP=STEP/STEPREDUCE;
         
         THETA1 = THETA + STEP; 
         
         LIKNEU = Lik[data,THETA1,{system,LikN},misc];\t
\t\t\t  \t\t
\t\t LIKNEU = LikTest[LIKNEU];
\t  \t\t
\t\t If[PRINT[[3]] == 1,
         Print[\"STEP-REDUCTION:  \",half,
         \t\t\t\"  LIKNEU  \", PaddedForm[LIKNEU,{20,15}],
         \t\t\t\"  LIKALT  \", PaddedForm[LIKALT,{20,15}]];
         ];
     ]; (*End DoWhile*)
     
     
\tIf[LIKNEU - LIKALT < 0,
\t\tPrint[\"ReturnCode = 4\"];ReturnCode = 4;Break[]];
\t\t
\t(* If[LIKNEU - LIKALT < 0,
\t\t  Print[\"LIKNEU - LIKALT < 0\"];FDIGITS+=1]; *)
\t\t

\t(* If[Max[Abs[STEP]] < 10^6 MINSTEP,
\t\t  Print[\"schlechte Suchrichtung\"]; FDIGITS+=1]; *)
\t\t\t
\tIf[PRINT[[4]] == 1,
    Print[\"LIKNEU  \", PaddedForm[LIKNEU,{20,15}],
          \"  LIKALT  \", PaddedForm[LIKALT,{20,15}],
          \"  LIKNEU - LIKALT  \",PaddedForm[LIKNEU-LIKALT,{20,15}]];
    Print[\"\"];
    ];
    
  
    If[PRINT[[5]] == 1, 
    Print[PaddedForm[
          MatrixForm[{THETA1,THETA,STEP,S}//Transpose//Chop[#,10^-5]&,
    \t  TableHeadings->{Automatic,{\"THETA1\",\"THETA\",\"STEP\",\"SCORE\"}}],\

    \t  {5,4}]
    \t  ]];
    
    If[PRINT[[6]] == 1,
    Print[\"\"];
    MatPrint[F];
    ];
       
    {SNEU,LIKALT} = 
    \tScore[data,THETA1,{system,{Lik,LikN}},misc]; 
\t\t
    
    (* BFGS-UPDATE *)
    
    F = BFGSUP[F,SNEU,S,STEP];
    
    (*F = F0;(*steepest descent*)*)
    (*Feigen = F//Eigenvalues;*)
    (*Print[\"Fup: Eigenwerte:  \",Feigen];*)
    (*If[Max[Abs[Feigen]]>FMAX,F = F0];*) 
    
    
    S = SNEU;
    
    THETA = THETA1GLOBAL=THETA1;
    k = KK;
    
    relgrad = Max[Abs[S max[Abs[THETA],TYP]]]/Abs[LIKNEU];
    Print[\"relgrad = \",relgrad,\" = Elastizitaet(d l/l)/(d theta/theta)\"];
    
    
    If[Max[Abs[S   ]]<EPS1,Print[\"ReturnCode = 1\"];ReturnCode = 1];
    If[Max[Abs[STEP]]<EPS2,Print[\"ReturnCode = 2\"];ReturnCode = 2];
    If[Max[Abs[S   ]]<EPS1 && 
       Max[Abs[STEP]]<EPS2,Print[\"ReturnCode = 3\"];ReturnCode = 3];
   
\t

];

If[PRINT[[7]] == 1,
Print[ \"BFGS:  ENDE DER ITERATION  \",k,\"  \",KMAX] ];

If[PRINT[[5]] == 1, 
    Print[MatrixForm[{SNEU}//Transpose,
    \t  TableHeadings->{Automatic,{\"SCORE\"}}]
    \t  ]];
    
If[PRINT[[6]] == 1,
    Print[\"\"];
    MatPrint[F];
    ];
    
LIKI = Append[LIKI,LIKALT]; 
psii = Append[psii,THETA];
scoreii = Append[scoreii,S];

likpsi = Spalte[LIKI]~ii~psii;

If[PRINT[[8]] == 1,
Print[MatrixForm[likpsi,
\t\tTableHeadings->{Automatic,{\"Likelihood\",\"THETA\"}} ]];
];
\t\t\t\t\t

If[FISHER&&(k<KMAX),

\t{F,LIKELI} = Hesse[data,THETA,{system,{Lik,LikN,Score}},misc];
\t\t
\tF=-F;
\t
\tCOV = OUTPUT[THETA,F,.05,S,LIKELI];
\tLKOMP[LIKELI,u,Apply[Plus,T1]];
\t
,(* else *)

\tCOV = Inverse[F]; (* BFGS-UPDATE!!*)
];

{THETA,COV,LIKI,psii,scoreii,k,ReturnCode}

]\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain",
  CellTags->"BFGS"],

Cell[" ", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\
\t
(***************************************************************)\t\t\t 
GRIDSEARCH//Clear
GRIDSEARCH[data_,
\t {THETA0_,F0_},
\t  {system_,{Lik_,LikN_,Score_}},
\t  {misc_,KMAX_,EPS2_,{STEPREDUCE_,nhalf_},PRINT_}]:= 
(***************************************************************)
(*F0 = Matrix der Suchrichtungen*)\t
\t\t 
Module[{MINSTEP,BOUND,ALPHA,u,THETA,THETA1,THETA1j,THETAj,F,
        S,LIKALT,LIKI,psii,scoreii,STEPL,STEP,
        LIKNEU,SNEU,likpsi,COV,LIKELI,n,T,T1,P,Q,k,KK,Y,Z,X,
        ReturnCode},

MAXSTEP=1;
MINSTEP=10.^-10;

(*STEPREDUCE = 2;
nhalf = 9;*)

BOUND=10.^-6;


{Z,X} = data;

{n,T1,Q} = Dimensions[X];

If[Depth[Z]===4,{n,T1,K} = Dimensions[Z],

(* else *) If[Depth[Z]===5,{Tc,K}=Dimensions[Z[[1,1]] ]

]];

Depth[Z]//Print;

T = T1-1;

If[PRINT[[1]] == 1,
Print[\"***********************LSDE1**********************************\"];
Print[\"***********************MODUL: GRIDSEARCH (skeleton)***********\"];
Print[\"**************************************************************\"];
Print[\"Technical Output\"];
Print[LikN];
VecPrint[{KMAX,EPS2,K,Q,n,T,OPTION,MAXSTEP}//Spalte,
         {\"KMAX\",\"EPS2\",\"K\",\"Q\",\"n\",\"T\",\"OPTION\",\"MAXSTEP\"}];
VecPrint[{ MINSTEP,  BOUND,  STEPREDUCE,  nhalf}//Spalte,
         {\"MINSTEP\",\"BOUND\",\"STEPREDUCE\",\"nhalf\"}];

Print[ \"\"];
Print[ \"STARTWERT THETA0 = \", THETA0]
];

u = Length[THETA0];

THETA=THETA0;
LIKALT = Lik[data,THETA,{system,LikN},misc];

LIKI = {}; psii = {}; 
ReturnCode = 0;

DoUntil[{KK,KMAX}, 
\t(ReturnCode == 1 || ReturnCode == 2 || 
\t ReturnCode == 3 || ReturnCode == 4),
 \t
\tIf[PRINT[[2]] == 1,
\tPrint[\"-----------------------------------------------------------------\"]\
;
    Print[\"GRIDSEARCH: Iteration = \",KK];
    ];
     
    LIKI=Append[LIKI,LIKALT];
    psii=Append[psii,THETA];
    
   \tLIKALTj = LIKALT;
    THETAj = THETA;
    
    Do[ (*Zyklisch, 1...u*)
    
    \tPrint[\"j = \",j,\"   LIKALTj = \", LIKALTj]//If[PRINT[[3]] == 1,#]&;
   
 \t\tSTEP=F0[[j]]; 
 \t\tPrint[\"Suchrichtung  \",STEP]//If[PRINT[[3]] == 1,#]&;
 \t\t\t
    \t{LIKNEUj,THETA1j} = LINESEARCH[STEP,THETAj,LIKALTj,nhalf,STEPREDUCE,
                                   \t   {data,{system,LikN},misc}];
      
\t   \tIf[LIKNEUj - LIKALTj <= 0, 
\t\t
\t\tSTEP= -STEP; (*andere Richtung*)
\t   \tPrint[\"Suchrichtung  \",STEP]//If[PRINT[[3]] == 1,#]&;
\t   
\t   \t{LIKNEUj,THETA1j} = LINESEARCH[STEP,THETAj,LIKALTj,nhalf,STEPREDUCE,
\t                                   {data,{system,LikN},misc}]
\t   \t];
\t  \t
\t  \tIf[LIKNEUj - LIKALTj > 0, 
\t   \t\t\t\tTHETAj  = THETA1j;
    \t\t\t\tLIKALTj = LIKNEUj];
\t
\t   ,{j,1,u}]; 

\t   \tTHETA1  = THETAj;
   \t\tLIKNEU  = LIKALTj;
    
    (* Acceleration Step *)
    
 \t\tIf[Mod[KK,2] == 0,
 \t\t   \t
    \t\tSTEP=THETA1-THETA;
    \t\tPrint[\"Acceleration Step  \",STEP]//If[PRINT[[3]] == 1,#]&;
    \t\tnorm = pNorm[STEP];
    \t\tIf[norm > 0, 
 \t\t\tPrint[\"Acceleration Step, Suchrichtung  \",STEP = \
STEP]//If[PRINT[[3]] == 1,#]&;
    \t\t{LIKNEUacc,THETA1acc} = 
    \t\t\tLINESEARCH[STEP,THETA1,LIKNEU,nhalf,STEPREDUCE,
\t                       {data,{system,LikN},misc}];
       ];
       
       If[LIKNEUacc-LIKNEU > 0, THETA1 = THETA1acc; LIKNEU = LIKNEUacc];
     ];                           
                                                           
                                \t
\tIf[PRINT[[4]] == 1,
    Print[\"LIKNEU  \", PaddedForm[LIKNEU,{20,15}],\"      \",
          \"LIKALT  \", PaddedForm[LIKALT,{20,15}] ];
    Print[\"LIKNEU - LIKALT  \",PaddedForm[LIKNEU-LIKALT,{20,15}] ];
    Print[\"\"];
    ];
    
  
    If[PRINT[[5]] == 1, 
    Print[MatrixForm[{THETA1,THETA}//Transpose,
    \t  TableHeadings->{Automatic,{\"THETA1\",\"THETA\"}}]
    \t  ]];
    
    k = KK;
    THETA  = THETA1;
    LIKALT = LIKNEU;
    
    If[Max[Abs[STEP]]<EPS2,Print[\"ReturnCode = 2\"];ReturnCode = 2];
   
\t

];

If[PRINT[[7]] == 1,
Print[ \"GRIDSEARCH:  ENDE DER ITERATION  \",k,\"  \",KMAX] ];

LIKI=Append[LIKI,LIKALT];
psii=Append[psii,THETA];

likpsi = Spalte[LIKI]~ii~psii;

If[PRINT[[8]] == 1,
Print[MatrixForm[likpsi,
\t\tTableHeadings->{Automatic,{\"Likelihood\",\"THETA\"}} ]];
];
\t\t\t\t\t

If[Fisher,
\t
\t{S,LIKELI} = 
    \tScore[data,THETA,{system,{Lik,LikN}},misc];
    \t 
\t{F,LIKELI} = 
\t\tHesse[data,THETA,{system,{Lik,LikN,Score}},misc];
\t\t
\tF=-F;
\t
\tCOV = OUTPUT[THETA,F,.05,S,LIKELI];
\tLKOMP[LIKELI,u,(T+1)];
\t
,(* else *)
\tCOV = F0; (* BFGS-UPDATE!!*)
];

{THETA,COV,LIKI,psii,k,ReturnCode}

]\
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"],

Cell["\<\

(***************************************************************)
LINESEARCH//Clear
LINESEARCH[step_,THETA_,LIKALT_,nhalf_,STEPREDUCE_,
           {data_,{system_,LikN_},misc_}]:= 
(***************************************************************)           
Module[{THETA1,LIKNEU,half,STEP},

\tSTEP = step;

    THETA1 = THETA + STEP;   (*VOLLER STEP*)
    
  \tLIKNEU = Lik[data,THETA1,{system,LikN},misc];\t \t
   \tLIKNEU = LikTest[LIKNEU];
   \t
   (*STEP-Reduction*)
   
    DoWhile[{half,nhalf}, (LIKNEU<=LIKALT && Max[Abs[STEP]]>MINSTEP),
    
         STEP=STEP/STEPREDUCE;
         
         (*
         lambda = (1-half/(nhalf+1))//N;
         STEP = step*lambda; 
         Print[\"lambda  \",lambda];
         *)
         
         THETA1 = THETA + STEP; 
        
         LIKNEU = Lik[data,THETA1,{system,LikN},misc];\t
\t\t\t  \t\t
\t\t LIKNEU = LikTest[LIKNEU];
\t  \t\t
\t\t If[PRINT[[3]] == 1,
         \t\tPrint[\"STEP-REDUCTION:  \",half,
         \t\t\t  \"  LIKNEU  \", PaddedForm[LIKNEU,{20,15}],
         \t\t\t  \"  LIKALT  \", PaddedForm[LIKALT,{20,15}],
         \t\t\t  \"  LIKNEU - LIKALT  \", PaddedForm[LIKNEU-LIKALT,{20,15}]];
         ];
     ]; (*End DoWhile*)
     
    {LIKNEU,THETA1}
    ]; \
\>", "Input",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontSize->14,
  FontWeight->"Plain"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{42, 1440}, {0, 878}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{810, 852},
WindowMargins->{{Automatic, 3}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3416806370-7050022"->{
    Cell[42983, 1552, 805, 21, 200, "Print",
      Evaluatable->True,
      InitializationCell->True,
      CellTags->"Info3416806370-7050022"]},
  "TimeUpFokker"->{
    Cell[65472, 2398, 592, 19, 204, "Input",
      InitializationCell->True,
      CellTags->"TimeUpFokker"]},
  "TimeUpEKF"->{
    Cell[67235, 2478, 1415, 68, 972, "Input",
      InitializationCell->True,
      CellTags->"TimeUpEKF"]},
  "TimeUpSumFilter"->{
    Cell[68653, 2548, 1758, 91, 1340, "Input",
      InitializationCell->True,
      CellTags->"TimeUpSumFilter"]},
  "TimeUpEKFJacobi"->{
    Cell[70414, 2641, 1812, 74, 1084, "Input",
      InitializationCell->True,
      CellTags->"TimeUpEKFJacobi"]},
  "TimeUpEKFEDM"->{
    Cell[72229, 2717, 1705, 85, 1260, "Input",
      InitializationCell->True,
      CellTags->"TimeUpEKFEDM"]},
  "TimeUpEKFSmooth"->{
    Cell[75621, 2874, 895, 43, 588, "Input",
      InitializationCell->True,
      CellTags->"TimeUpEKFSmooth"]},
  "TimeUpEKF2"->{
    Cell[78651, 3021, 1254, 62, 908, "Input",
      InitializationCell->True,
      CellTags->"TimeUpEKF2"]},
  "TimeUpHNF24"->{
    Cell[82433, 3202, 3339, 133, 1996, "Input",
      InitializationCell->True,
      CellTags->"TimeUpHNF24"]},
  "TimeUpShojiOzaki"->{
    Cell[94034, 3698, 1281, 53, 70, "Input",
      InitializationCell->True,
      CellTags->"TimeUpShojiOzaki"]},
  "TimeUpUKF"->{
    Cell[95318, 3753, 1587, 74, 1084, "Input",
      InitializationCell->True,
      CellTags->"TimeUpUKF"],
    Cell[96908, 3829, 1470, 71, 1036, "Input",
      InitializationCell->True,
      CellTags->"TimeUpUKF"]},
  "TimeUpSMKF"->{
    Cell[98381, 3902, 1659, 74, 1100, "Input",
      InitializationCell->True,
      CellTags->"TimeUpSMKF"]},
  "TimeUpGHF"->{
    Cell[101801, 4059, 1612, 75, 1116, "Input",
      InitializationCell->True,
      CellTags->"TimeUpGHF"]},
  "MessUpEKF"->{
    Cell[114097, 4577, 1420, 55, 796, "Input",
      InitializationCell->True,
      CellTags->"MessUpEKF"]},
  "MessUpEKFinno"->{
    Cell[118724, 4754, 1227, 40, 540, "Input",
      InitializationCell->True,
      CellTags->"MessUpEKFinno"]},
  "MessUpGARCH"->{
    Cell[121497, 4847, 1531, 59, 844, "Input",
      InitializationCell->True,
      CellTags->"MessUpGARCH"]},
  "MessUpEKFSum1"->{
    Cell[126154, 5017, 1725, 62, 892, "Input",
      InitializationCell->True,
      CellTags->"MessUpEKFSum1"]},
  "MessUpEKFSumDKS"->{
    Cell[127882, 5081, 1539, 52, 748, "Input",
      InitializationCell->True,
      CellTags->"MessUpEKFSumDKS"]},
  "MessUpEKFSumAlpha"->{
    Cell[129424, 5135, 1379, 45, 636, "Input",
      InitializationCell->True,
      CellTags->"MessUpEKFSumAlpha"]},
  "MessUpOmnibus"->{
    Cell[131851, 5207, 1741, 65, 956, "Input",
      InitializationCell->True,
      CellTags->"MessUpOmnibus"]},
  "SmoothEKF"->{
    Cell[136013, 5368, 1074, 39, 508, "Input",
      InitializationCell->True,
      CellTags->"SmoothEKF"]},
  "SmoothEKFIter"->{
    Cell[137090, 5409, 742, 25, 284, "Input",
      InitializationCell->True,
      CellTags->"SmoothEKFIter"]},
  "SmoothEKF2"->{
    Cell[137835, 5436, 831, 34, 444, "Input",
      InitializationCell->True,
      CellTags->"SmoothEKF2"]},
  "MessUpUKF"->{
    Cell[138669, 5472, 2089, 43, 988, "Input",
      InitializationCell->True,
      CellTags->"MessUpUKF"]},
  "MessUpSMKF"->{
    Cell[142199, 5545, 1568, 31, 780, "Input",
      InitializationCell->True,
      CellTags->"MessUpSMKF"]},
  "MessUpGF"->{
    Cell[143770, 5578, 1478, 67, 988, "Input",
      InitializationCell->True,
      CellTags->"MessUpGF"]},
  "MessUpGHF"->{
    Cell[145251, 5647, 1408, 54, 780, "Input",
      InitializationCell->True,
      CellTags->"MessUpGHF"]},
  "MessUpGHFBayes"->{
    Cell[149484, 5823, 1196, 49, 700, "Input",
      InitializationCell->True,
      CellTags->"MessUpGHFBayes"]},
  "MessUpGHFBayesOI"->{
    Cell[151888, 5924, 1063, 42, 588, "Input",
      InitializationCell->True,
      CellTags->"MessUpGHFBayesOI"]},
  "MessUpGHFn"->{
    Cell[154590, 6043, 952, 39, 540, "Input",
      InitializationCell->True,
      CellTags->"MessUpGHFn"]},
  "EKF"->{
    Cell[159350, 6251, 2169, 112, 1708, "Input",
      InitializationCell->True,
      CellTags->"EKF"]},
  "EKG"->{
    Cell[161522, 6365, 2276, 120, 1836, "Input",
      InitializationCell->True,
      CellTags->"EKG"]},
  "EKFEDM"->{
    Cell[164242, 6505, 2305, 113, 1724, "Input",
      InitializationCell->True,
      CellTags->"EKFEDM"]},
  "EKF2"->{
    Cell[167855, 6684, 1598, 80, 1196, "Input",
      InitializationCell->True,
      CellTags->"EKF2"]},
  "EKF4"->{
    Cell[169456, 6766, 1481, 73, 1084, "Input",
      InitializationCell->True,
      CellTags->"EKF4"]},
  "HNF22"->{
    Cell[170940, 6841, 1573, 75, 1116, "Input",
      InitializationCell->True,
      CellTags->"HNF22"],
    Cell[172516, 6918, 1619, 75, 1116, "Input",
      InitializationCell->True,
      CellTags->{"HNF22", "HNF23"}],
    Cell[174138, 6995, 1662, 74, 1100, "Input",
      InitializationCell->True,
      CellTags->{"HNF22", "HNF23", "HNF24"}]},
  "HNF23"->{
    Cell[172516, 6918, 1619, 75, 1116, "Input",
      InitializationCell->True,
      CellTags->{"HNF22", "HNF23"}],
    Cell[174138, 6995, 1662, 74, 1100, "Input",
      InitializationCell->True,
      CellTags->{"HNF22", "HNF23", "HNF24"}]},
  "HNF24"->{
    Cell[174138, 6995, 1662, 74, 1100, "Input",
      InitializationCell->True,
      CellTags->{"HNF22", "HNF23", "HNF24"}]},
  "EKFGARCH"->{
    Cell[177357, 7148, 1715, 87, 1292, "Input",
      InitializationCell->True,
      CellTags->"EKFGARCH"]},
  "EKFInno"->{
    Cell[179075, 7237, 2116, 104, 1580, "Input",
      InitializationCell->True,
      CellTags->"EKFInno"]},
  "ShojiOzaki"->{
    Cell[181194, 7343, 1471, 71, 1052, "Input",
      InitializationCell->True,
      CellTags->"ShojiOzaki"]},
  "KalmanFokkerEKFSum1"->{
    Cell[185659, 7557, 2256, 91, 70, "Input",
      InitializationCell->True,
      CellTags->"KalmanFokkerEKFSum1"]},
  "KernDichteFilter"->{
    Cell[187918, 7650, 1562, 62, 70, "Input",
      InitializationCell->True,
      CellTags->"KernDichteFilter"]},
  "KDFImportance"->{
    Cell[189483, 7714, 3853, 66, 70, "Input",
      InitializationCell->True,
      CellTags->"KDFImportance"]},
  "GaussianSumFilter"->{
    Cell[195594, 7875, 2664, 45, 70, "Input",
      InitializationCell->True,
      CellTags->"GaussianSumFilter"]},
  "GaussianSumFilter1"->{
    Cell[198261, 7922, 2663, 45, 70, "Input",
      InitializationCell->True,
      CellTags->"GaussianSumFilter1"]},
  "GaussianSumFilterGHF"->{
    Cell[200927, 7969, 2341, 95, 1404, "Input",
      InitializationCell->True,
      CellTags->"GaussianSumFilterGHF"]},
  "SumFilterUKF"->{
    Cell[203271, 8066, 2154, 88, 1324, "Input",
      InitializationCell->True,
      CellTags->"SumFilterUKF"]},
  "KalmanFokkerEKFSumDKS"->{
    Cell[207400, 8235, 2361, 39, 1148, "Input",
      InitializationCell->True,
      CellTags->"KalmanFokkerEKFSumDKS"]},
  "FunctionalFilter"->{
    Cell[209764, 8276, 3478, 55, 1932, "Input",
      InitializationCell->True,
      CellTags->"FunctionalFilter"]},
  "UKF"->{
    Cell[214655, 8395, 1871, 93, 1404, "Input",
      InitializationCell->True,
      CellTags->"UKF"]},
  "GF"->{
    Cell[216529, 8490, 2049, 112, 1708, "Input",
      InitializationCell->True,
      CellTags->"GF"]},
  "GHF"->{
    Cell[218581, 8604, 2244, 117, 1788, "Input",
      InitializationCell->True,
      CellTags->"GHF"]},
  "SMKF"->{
    Cell[220828, 8723, 1881, 99, 1468, "Input",
      InitializationCell->True,
      CellTags->"SMKF"]},
  "LikFIFImportance"->{
    Cell[244580, 9417, 3186, 61, 1724, "Input",
      InitializationCell->True,
      CellTags->"LikFIFImportance"]},
  "FIFImportance"->{
    Cell[247769, 9480, 4103, 70, 2252, "Input",
      InitializationCell->True,
      CellTags->"FIFImportance"]},
  "FIFImportanceSmooth"->{
    Cell[253489, 9627, 8255, 136, 4076, "Input",
      InitializationCell->True,
      CellTags->"FIFImportanceSmooth"]},
  "cHesse1"->{
    Cell[277933, 10368, 2268, 111, 1660, "Input",
      InitializationCell->True,
      CellTags->"cHesse1"]},
  "BFGS"->{
    Cell[284692, 10629, 6353, 263, 3996, "Input",
      InitializationCell->True,
      CellTags->"BFGS"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3416806370-7050022", 298411, 11169},
  {"TimeUpFokker", 298577, 11174},
  {"TimeUpEKF", 298705, 11178},
  {"TimeUpSumFilter", 298837, 11182},
  {"TimeUpEKFJacobi", 298976, 11186},
  {"TimeUpEKFEDM", 299112, 11190},
  {"TimeUpEKFSmooth", 299248, 11194},
  {"TimeUpEKF2", 299380, 11198},
  {"TimeUpHNF24", 299509, 11202},
  {"TimeUpShojiOzaki", 299646, 11206},
  {"TimeUpUKF", 299778, 11210},
  {"TimeUpSMKF", 300015, 11217},
  {"TimeUpGHF", 300143, 11221},
  {"MessUpEKF", 300271, 11225},
  {"MessUpEKFinno", 300402, 11229},
  {"MessUpGARCH", 300535, 11233},
  {"MessUpEKFSum1", 300668, 11237},
  {"MessUpEKFSumDKS", 300805, 11241},
  {"MessUpEKFSumAlpha", 300946, 11245},
  {"MessUpOmnibus", 301085, 11249},
  {"SmoothEKF", 301216, 11253},
  {"SmoothEKFIter", 301347, 11257},
  {"SmoothEKF2", 301478, 11261},
  {"MessUpUKF", 301605, 11265},
  {"MessUpSMKF", 301733, 11269},
  {"MessUpGF", 301860, 11273},
  {"MessUpGHF", 301986, 11277},
  {"MessUpGHFBayes", 302118, 11281},
  {"MessUpGHFBayesOI", 302257, 11285},
  {"MessUpGHFn", 302392, 11289},
  {"EKF", 302513, 11293},
  {"EKG", 302630, 11297},
  {"EKFEDM", 302750, 11301},
  {"EKF2", 302871, 11305},
  {"EKF4", 302989, 11309},
  {"HNF22", 303108, 11313},
  {"HNF23", 303471, 11323},
  {"HNF24", 303728, 11330},
  {"EKFGARCH", 303871, 11334},
  {"EKFInno", 303996, 11338},
  {"ShojiOzaki", 304124, 11342},
  {"KalmanFokkerEKFSum1", 304263, 11346},
  {"KernDichteFilter", 304406, 11350},
  {"KDFImportance", 304543, 11354},
  {"GaussianSumFilter", 304681, 11358},
  {"GaussianSumFilter1", 304824, 11362},
  {"GaussianSumFilterGHF", 304970, 11366},
  {"SumFilterUKF", 305112, 11370},
  {"KalmanFokkerEKFSumDKS", 305255, 11374},
  {"FunctionalFilter", 305402, 11378},
  {"UKF", 305531, 11382},
  {"GF", 305646, 11386},
  {"GHF", 305762, 11390},
  {"SMKF", 305880, 11394},
  {"LikFIFImportance", 306010, 11398},
  {"FIFImportance", 306149, 11402},
  {"FIFImportanceSmooth", 306291, 11406},
  {"cHesse1", 306428, 11410},
  {"BFGS", 306551, 11414}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 365, 21, 268, "Input",
  InitializationCell->True],
Cell[2144, 76, 58, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2239, 82, 183, 8, 60, "Input",
  InitializationCell->True],
Cell[2425, 92, 133, 3, 24, "Message",
  InitializationCell->True],
Cell[2561, 97, 182, 6, 24, "Message",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2780, 108, 129, 4, 63, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2934, 116, 132, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[3069, 122, 298, 10, 70, "Input",
  InitializationCell->True],
Cell[3370, 134, 289, 12, 70, "Input",
  InitializationCell->True],
Cell[3662, 148, 243, 11, 70, "Input",
  InitializationCell->True],
Cell[3908, 161, 806, 20, 70, "Input",
  InitializationCell->True],
Cell[4717, 183, 471, 16, 70, "Input",
  InitializationCell->True],
Cell[5191, 201, 776, 32, 70, "Input",
  InitializationCell->True],
Cell[5970, 235, 367, 12, 70, "Input",
  InitializationCell->True],
Cell[6340, 249, 478, 17, 70, "Input",
  InitializationCell->True],
Cell[6821, 268, 506, 17, 70, "Input",
  InitializationCell->True],
Cell[7330, 287, 398, 13, 70, "Input",
  InitializationCell->True],
Cell[7731, 302, 738, 26, 70, "Input",
  InitializationCell->True],
Cell[8472, 330, 553, 18, 70, "Input",
  InitializationCell->True],
Cell[9028, 350, 387, 14, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[9440, 368, 127, 3, 70, "Input"],
Cell[9570, 373, 134, 7, 70, "Output"]
}, Open  ]],
Cell[9719, 383, 370, 16, 70, "Input",
  InitializationCell->True],
Cell[10092, 401, 167, 7, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[10284, 412, 143, 4, 70, "Input",
  InitializationCell->True],
Cell[10430, 418, 178, 8, 70, "Output",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10657, 432, 139, 4, 22, "Subsubsection",
  InitializationCell->True],
Cell[10799, 438, 649, 21, 268, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[11473, 463, 81, 2, 28, "Input"],
Cell[11557, 467, 142, 7, 26, "Output"]
}, Open  ]],
Cell[11714, 477, 688, 17, 332, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[12427, 498, 64, 1, 26, "Input"],
Cell[12494, 501, 230, 4, 41, "Output"]
}, Open  ]],
Cell[12739, 508, 755, 17, 396, "Input",
  InitializationCell->True],
Cell[13497, 527, 258, 9, 60, "Input",
  InitializationCell->True],
Cell[13758, 538, 366, 10, 156, "Input",
  InitializationCell->True],
Cell[14127, 550, 541, 13, 268, "Input",
  InitializationCell->True],
Cell[14671, 565, 519, 13, 268, "Input",
  InitializationCell->True],
Cell[15193, 580, 466, 11, 172, "Input",
  InitializationCell->True],
Cell[15662, 593, 601, 13, 220, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16300, 611, 139, 4, 22, "Subsubsection",
  InitializationCell->True],
Cell[16442, 617, 680, 23, 300, "Input",
  InitializationCell->True],
Cell[17125, 642, 693, 24, 316, "Input",
  InitializationCell->True],
Cell[17821, 668, 557, 21, 268, "Input",
  InitializationCell->True],
Cell[18381, 691, 635, 21, 268, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[19041, 716, 134, 3, 44, "Input"],
Cell[19178, 721, 82, 2, 24, "Print"],
Cell[19263, 725, 406, 11, 26, "Output"]
}, Open  ]],
Cell[19684, 739, 674, 26, 348, "Input",
  InitializationCell->True],
Cell[20361, 767, 983, 38, 540, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[21369, 809, 128, 5, 44, "Input"],
Cell[21500, 816, 153, 5, 40, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21690, 826, 125, 2, 28, "Input"],
Cell[21818, 830, 95, 2, 24, "Print"],
Cell[21916, 834, 20915, 706, 182, 6430, 522, "GraphicsData", "PostScript", \
"Graphics"],
Cell[42834, 1542, 134, 7, 26, "Output"]
}, Open  ]],
Cell[42983, 1552, 805, 21, 200, "Print",
  Evaluatable->True,
  InitializationCell->True,
  CellTags->"Info3416806370-7050022"],
Cell[43791, 1575, 580, 19, 236, "Input",
  InitializationCell->True],
Cell[44374, 1596, 334, 10, 76, "Input",
  InitializationCell->True],
Cell[44711, 1608, 882, 32, 444, "Input",
  InitializationCell->True],
Cell[45596, 1642, 930, 35, 492, "Input",
  InitializationCell->True],
Cell[46529, 1679, 644, 25, 332, "Input",
  InitializationCell->True],
Cell[47176, 1706, 766, 36, 492, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47991, 1748, 157, 5, 63, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[48173, 1757, 690, 27, 348, "Input",
  InitializationCell->True],
Cell[48866, 1786, 305, 5, 21, "Message"],
Cell[49174, 1793, 367, 6, 21, "Message"],
Cell[49544, 1801, 64, 2, 26, "Output"]
}, Open  ]],
Cell[49623, 1806, 409, 14, 140, "Input",
  InitializationCell->True],
Cell[50035, 1822, 770, 28, 364, "Input",
  InitializationCell->True],
Cell[50808, 1852, 865, 31, 396, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[51698, 1887, 819, 29, 380, "Input",
  InitializationCell->True],
Cell[52520, 1918, 301, 5, 21, "Message"],
Cell[52824, 1925, 386, 6, 21, "Message"],
Cell[53213, 1933, 64, 2, 26, "Output"]
}, Open  ]],
Cell[53292, 1938, 696, 27, 348, "Input",
  InitializationCell->True],
Cell[53991, 1967, 1013, 34, 460, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[55029, 2005, 189, 4, 26, "Input"],
Cell[55221, 2011, 150, 2, 26, "Output"]
}, Open  ]],
Cell[55386, 2016, 1559, 60, 860, "Input",
  InitializationCell->True],
Cell[56948, 2078, 1334, 48, 668, "Input",
  InitializationCell->True],
Cell[58285, 2128, 1304, 47, 652, "Input",
  InitializationCell->True],
Cell[59592, 2177, 1053, 36, 476, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[60670, 2217, 161, 5, 28, "Input",
  InitializationCell->True],
Cell[60834, 2224, 72, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60943, 2231, 175, 3, 41, "Input"],
Cell[61121, 2236, 292, 5, 26, "Output"],
Cell[61416, 2243, 291, 5, 26, "Output"]
}, Open  ]],
Cell[61722, 2251, 779, 32, 412, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[62526, 2287, 365, 12, 108, "Input",
  InitializationCell->True],
Cell[62894, 2301, 297, 5, 21, "Message"],
Cell[63194, 2308, 327, 6, 21, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63558, 2319, 158, 5, 28, "Input",
  InitializationCell->True],
Cell[63719, 2326, 99, 2, 26, "Output"]
}, Open  ]],
Cell[63833, 2331, 638, 25, 316, "Input",
  InitializationCell->True],
Cell[64474, 2358, 830, 29, 364, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65341, 2392, 128, 4, 33, "Section",
  InitializationCell->True],
Cell[65472, 2398, 592, 19, 204, "Input",
  InitializationCell->True,
  CellTags->"TimeUpFokker"],
Cell[66067, 2419, 1165, 57, 828, "Input",
  InitializationCell->True],
Cell[67235, 2478, 1415, 68, 972, "Input",
  InitializationCell->True,
  CellTags->"TimeUpEKF"],
Cell[68653, 2548, 1758, 91, 1340, "Input",
  InitializationCell->True,
  CellTags->"TimeUpSumFilter"],
Cell[70414, 2641, 1812, 74, 1084, "Input",
  InitializationCell->True,
  CellTags->"TimeUpEKFJacobi"],
Cell[72229, 2717, 1705, 85, 1260, "Input",
  InitializationCell->True,
  CellTags->"TimeUpEKFEDM"],
Cell[73937, 2804, 78, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[74040, 2810, 78, 2, 28, "Input"],
Cell[74121, 2814, 276, 8, 72, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74434, 2827, 210, 6, 44, "Input"],
Cell[74647, 2835, 479, 17, 40, "Output"],
Cell[75129, 2854, 477, 17, 40, "Output"]
}, Open  ]],
Cell[75621, 2874, 895, 43, 588, "Input",
  InitializationCell->True,
  CellTags->"TimeUpEKFSmooth"],
Cell[76519, 2919, 975, 45, 636, "Input",
  InitializationCell->True],
Cell[77497, 2966, 1151, 53, 748, "Input",
  InitializationCell->True],
Cell[78651, 3021, 1254, 62, 908, "Input",
  InitializationCell->True,
  CellTags->"TimeUpEKF2"],
Cell[79908, 3085, 1206, 53, 764, "Input",
  InitializationCell->True],
Cell[81117, 3140, 1313, 60, 876, "Input",
  InitializationCell->True],
Cell[82433, 3202, 3339, 133, 1996, "Input",
  InitializationCell->True,
  CellTags->"TimeUpHNF24"],
Cell[85775, 3337, 1935, 83, 1244, "Input",
  InitializationCell->True],
Cell[87713, 3422, 1986, 84, 70, "Input",
  InitializationCell->True],
Cell[89702, 3508, 2691, 114, 70, "Input",
  InitializationCell->True],
Cell[92396, 3624, 1036, 49, 70, "Input",
  InitializationCell->True],
Cell[93435, 3675, 596, 21, 70, "Input",
  InitializationCell->True],
Cell[94034, 3698, 1281, 53, 70, "Input",
  InitializationCell->True,
  CellTags->"TimeUpShojiOzaki"],
Cell[95318, 3753, 1587, 74, 1084, "Input",
  InitializationCell->True,
  CellTags->"TimeUpUKF"],
Cell[96908, 3829, 1470, 71, 1036, "Input",
  InitializationCell->True,
  CellTags->"TimeUpUKF"],
Cell[98381, 3902, 1659, 74, 1100, "Input",
  InitializationCell->True,
  CellTags->"TimeUpSMKF"],
Cell[100043, 3978, 1755, 79, 1196, "Input",
  InitializationCell->True],
Cell[101801, 4059, 1612, 75, 1116, "Input",
  InitializationCell->True,
  CellTags->"TimeUpGHF"],
Cell[103416, 4136, 1770, 81, 1228, "Input",
  InitializationCell->True],
Cell[105189, 4219, 1998, 92, 1388, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[107212, 4315, 119, 2, 26, "Input"],
Cell[107334, 4319, 184, 7, 24, "Output"]
}, Open  ]],
Cell[107533, 4329, 2797, 126, 1678, "Input",
  InitializationCell->True],
Cell[110333, 4457, 472, 10, 124, "Input",
  InitializationCell->True],
Cell[110808, 4469, 472, 10, 124, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[111317, 4484, 128, 4, 33, "Section",
  InitializationCell->True],
Cell[111448, 4490, 957, 27, 364, "Input",
  InitializationCell->True],
Cell[112408, 4519, 680, 23, 300, "Input",
  InitializationCell->True],
Cell[113091, 4544, 1003, 31, 428, "Input",
  InitializationCell->True],
Cell[114097, 4577, 1420, 55, 796, "Input",
  InitializationCell->True,
  CellTags->"MessUpEKF"],
Cell[115520, 4634, 1886, 69, 1020, "Input",
  InitializationCell->True],
Cell[117409, 4705, 1312, 47, 684, "Input",
  InitializationCell->True],
Cell[118724, 4754, 1227, 40, 540, "Input",
  InitializationCell->True,
  CellTags->"MessUpEKFinno"],
Cell[119954, 4796, 1540, 49, 716, "Input",
  InitializationCell->True],
Cell[121497, 4847, 1531, 59, 844, "Input",
  InitializationCell->True,
  CellTags->"MessUpGARCH"],
Cell[123031, 4908, 948, 32, 444, "Input",
  InitializationCell->True],
Cell[123982, 4942, 851, 31, 428, "Input",
  InitializationCell->True],
Cell[124836, 4975, 1315, 40, 502, "Input",
  InitializationCell->True],
Cell[126154, 5017, 1725, 62, 892, "Input",
  InitializationCell->True,
  CellTags->"MessUpEKFSum1"],
Cell[127882, 5081, 1539, 52, 748, "Input",
  InitializationCell->True,
  CellTags->"MessUpEKFSumDKS"],
Cell[129424, 5135, 1379, 45, 636, "Input",
  InitializationCell->True,
  CellTags->"MessUpEKFSumAlpha"],

Cell[CellGroupData[{
Cell[130828, 5184, 78, 2, 28, "Input"],
Cell[130909, 5188, 927, 16, 200, "Print"]
}, Open  ]],
Cell[131851, 5207, 1741, 65, 956, "Input",
  InitializationCell->True,
  CellTags->"MessUpOmnibus"],
Cell[133595, 5274, 832, 26, 348, "Input",
  InitializationCell->True],
Cell[134430, 5302, 699, 26, 332, "Input",
  InitializationCell->True],
Cell[135132, 5330, 878, 36, 460, "Input",
  InitializationCell->True],
Cell[136013, 5368, 1074, 39, 508, "Input",
  InitializationCell->True,
  CellTags->"SmoothEKF"],
Cell[137090, 5409, 742, 25, 284, "Input",
  InitializationCell->True,
  CellTags->"SmoothEKFIter"],
Cell[137835, 5436, 831, 34, 444, "Input",
  InitializationCell->True,
  CellTags->"SmoothEKF2"],
Cell[138669, 5472, 2089, 43, 988, "Input",
  InitializationCell->True,
  CellTags->"MessUpUKF"],
Cell[140761, 5517, 1435, 26, 732, "Input",
  InitializationCell->True],
Cell[142199, 5545, 1568, 31, 780, "Input",
  InitializationCell->True,
  CellTags->"MessUpSMKF"],
Cell[143770, 5578, 1478, 67, 988, "Input",
  InitializationCell->True,
  CellTags->"MessUpGF"],
Cell[145251, 5647, 1408, 54, 780, "Input",
  InitializationCell->True,
  CellTags->"MessUpGHF"],
Cell[146662, 5703, 1972, 84, 1260, "Input",
  InitializationCell->True],
Cell[148637, 5789, 844, 32, 444, "Input",
  InitializationCell->True],
Cell[149484, 5823, 1196, 49, 700, "Input",
  InitializationCell->True,
  CellTags->"MessUpGHFBayes"],
Cell[150683, 5874, 1202, 48, 684, "Input",
  InitializationCell->True],
Cell[151888, 5924, 1063, 42, 588, "Input",
  InitializationCell->True,
  CellTags->"MessUpGHFBayesOI"],
Cell[152954, 5968, 1633, 73, 1100, "Input",
  InitializationCell->True],
Cell[154590, 6043, 952, 39, 540, "Input",
  InitializationCell->True,
  CellTags->"MessUpGHFn"],
Cell[155545, 6084, 913, 37, 462, "Input",
  InitializationCell->True],
Cell[156461, 6123, 1354, 53, 764, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[157852, 6181, 133, 4, 63, "Section",
  InitializationCell->True],
Cell[157988, 6187, 1359, 62, 924, "Input",
  InitializationCell->True],
Cell[159350, 6251, 2169, 112, 1708, "Input",
  InitializationCell->True,
  CellTags->"EKF"],
Cell[161522, 6365, 2276, 120, 1836, "Input",
  InitializationCell->True,
  CellTags->"EKG"],
Cell[163801, 6487, 438, 16, 188, "Input",
  InitializationCell->True],
Cell[164242, 6505, 2305, 113, 1724, "Input",
  InitializationCell->True,
  CellTags->"EKFEDM"],
Cell[166550, 6620, 1302, 62, 892, "Input",
  InitializationCell->True],
Cell[167855, 6684, 1598, 80, 1196, "Input",
  InitializationCell->True,
  CellTags->"EKF2"],
Cell[169456, 6766, 1481, 73, 1084, "Input",
  InitializationCell->True,
  CellTags->"EKF4"],
Cell[170940, 6841, 1573, 75, 1116, "Input",
  InitializationCell->True,
  CellTags->"HNF22"],
Cell[172516, 6918, 1619, 75, 1116, "Input",
  InitializationCell->True,
  CellTags->{"HNF22", "HNF23"}],
Cell[174138, 6995, 1662, 74, 1100, "Input",
  InitializationCell->True,
  CellTags->{"HNF22", "HNF23", "HNF24"}],
Cell[175803, 7071, 1551, 75, 1132, "Input",
  InitializationCell->True],
Cell[177357, 7148, 1715, 87, 1292, "Input",
  InitializationCell->True,
  CellTags->"EKFGARCH"],
Cell[179075, 7237, 2116, 104, 1580, "Input",
  InitializationCell->True,
  CellTags->"EKFInno"],
Cell[181194, 7343, 1471, 71, 1052, "Input",
  InitializationCell->True,
  CellTags->"ShojiOzaki"],
Cell[182668, 7416, 1352, 62, 924, "Input",
  InitializationCell->True],
Cell[184023, 7480, 1331, 57, 844, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[185379, 7541, 128, 4, 70, "Input",
  InitializationCell->True],
Cell[185510, 7547, 134, 7, 70, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[185659, 7557, 2256, 91, 70, "Input",
  InitializationCell->True,
  CellTags->"KalmanFokkerEKFSum1"],
Cell[187918, 7650, 1562, 62, 70, "Input",
  InitializationCell->True,
  CellTags->"KernDichteFilter"],
Cell[189483, 7714, 3853, 66, 70, "Input",
  InitializationCell->True,
  CellTags->"KDFImportance"],
Cell[193339, 7782, 714, 22, 70, "Input",
  InitializationCell->True],
Cell[194056, 7806, 1535, 67, 70, "Input",
  InitializationCell->True],
Cell[195594, 7875, 2664, 45, 70, "Input",
  InitializationCell->True,
  CellTags->"GaussianSumFilter"],
Cell[198261, 7922, 2663, 45, 70, "Input",
  InitializationCell->True,
  CellTags->"GaussianSumFilter1"],
Cell[200927, 7969, 2341, 95, 1404, "Input",
  InitializationCell->True,
  CellTags->"GaussianSumFilterGHF"],
Cell[203271, 8066, 2154, 88, 1324, "Input",
  InitializationCell->True,
  CellTags->"SumFilterUKF"],
Cell[205428, 8156, 1969, 77, 1148, "Input",
  InitializationCell->True],
Cell[207400, 8235, 2361, 39, 1148, "Input",
  InitializationCell->True,
  CellTags->"KalmanFokkerEKFSumDKS"],
Cell[209764, 8276, 3478, 55, 1932, "Input",
  InitializationCell->True,
  CellTags->"FunctionalFilter"],
Cell[213245, 8333, 1407, 60, 892, "Input",
  InitializationCell->True],
Cell[214655, 8395, 1871, 93, 1404, "Input",
  InitializationCell->True,
  CellTags->"UKF"],
Cell[216529, 8490, 2049, 112, 1708, "Input",
  InitializationCell->True,
  CellTags->"GF"],
Cell[218581, 8604, 2244, 117, 1788, "Input",
  InitializationCell->True,
  CellTags->"GHF"],
Cell[220828, 8723, 1881, 99, 1468, "Input",
  InitializationCell->True,
  CellTags->"SMKF"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222746, 8827, 123, 4, 33, "Section",
  InitializationCell->True],
Cell[222872, 8833, 214, 8, 28, "Input",
  InitializationCell->True],
Cell[223089, 8843, 343, 9, 140, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[223457, 8856, 200, 5, 28, "Input",
  InitializationCell->True],
Cell[223660, 8863, 243, 9, 26, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[223918, 8875, 346, 10, 108, "Input",
  InitializationCell->True],
Cell[224267, 8887, 413, 11, 124, "Input",
  InitializationCell->True],
Cell[224683, 8900, 820, 17, 380, "Input",
  InitializationCell->True],
Cell[225506, 8919, 807, 18, 348, "Input",
  InitializationCell->True],
Cell[226316, 8939, 1101, 21, 446, "Input",
  InitializationCell->True],
Cell[227420, 8962, 239, 10, 82, "Input",
  InitializationCell->True],
Cell[227662, 8974, 234, 10, 70, "Input",
  InitializationCell->True],
Cell[227899, 8986, 242, 10, 70, "Input",
  InitializationCell->True],
Cell[228144, 8998, 239, 10, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[228408, 9012, 235, 9, 70, "Input",
  InitializationCell->True],
Cell[228646, 9023, 160, 8, 70, "Output",
  InitializationCell->True],
Cell[228809, 9033, 160, 8, 70, "Output",
  InitializationCell->True],
Cell[228972, 9043, 160, 8, 70, "Output",
  InitializationCell->True],
Cell[229135, 9053, 160, 8, 70, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[229310, 9064, 413, 11, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[229748, 9079, 240, 7, 70, "Input",
  InitializationCell->True],
Cell[229991, 9088, 617, 20, 70, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[230623, 9111, 1757, 34, 70, "Input",
  InitializationCell->True],
Cell[232383, 9147, 1754, 32, 876, "Input",
  InitializationCell->True],
Cell[234140, 9181, 784, 17, 300, "Input",
  InitializationCell->True],
Cell[234927, 9200, 1193, 27, 476, "Input",
  InitializationCell->True],
Cell[236123, 9229, 238, 8, 28, "Input",
  InitializationCell->True],
Cell[236364, 9239, 642, 15, 252, "Input",
  InitializationCell->True],
Cell[237009, 9256, 644, 15, 252, "Input",
  InitializationCell->True],
Cell[237656, 9273, 723, 26, 70, "Input",
  InitializationCell->True],
Cell[238382, 9301, 4198, 76, 70, "Input",
  InitializationCell->True],
Cell[242583, 9379, 1994, 36, 1020, "Input",
  InitializationCell->True],
Cell[244580, 9417, 3186, 61, 1724, "Input",
  InitializationCell->True,
  CellTags->"LikFIFImportance"],
Cell[247769, 9480, 4103, 70, 2252, "Input",
  InitializationCell->True,
  CellTags->"FIFImportance"],
Cell[251875, 9552, 472, 15, 156, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[252372, 9571, 141, 4, 28, "Input",
  InitializationCell->True],
Cell[252516, 9577, 160, 8, 26, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[252691, 9588, 426, 15, 156, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[253142, 9607, 169, 7, 44, "Input",
  InitializationCell->True],
Cell[253314, 9616, 160, 8, 26, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[253489, 9627, 8255, 136, 4076, "Input",
  InitializationCell->True,
  CellTags->"FIFImportanceSmooth"],
Cell[261747, 9765, 1938, 34, 1100, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[263722, 9804, 131, 4, 63, "Section",
  InitializationCell->True],
Cell[263856, 9810, 1194, 47, 684, "Input",
  InitializationCell->True],
Cell[265053, 9859, 1196, 47, 684, "Input",
  InitializationCell->True],
Cell[266252, 9908, 1158, 46, 668, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[267447, 9959, 255, 6, 63, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[267727, 9969, 536, 19, 204, "Input",
  InitializationCell->True],
Cell[268266, 9990, 267, 9, 26, "Output",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[268570, 10004, 543, 15, 140, "Input",
  InitializationCell->True],
Cell[269116, 10021, 269, 9, 26, "Output",
  InitializationCell->True]
}, Open  ]],
Cell[269400, 10033, 1183, 41, 556, "Input",
  InitializationCell->True],
Cell[270586, 10076, 1301, 46, 620, "Input",
  InitializationCell->True],
Cell[271890, 10124, 965, 34, 444, "Input",
  InitializationCell->True],
Cell[272858, 10160, 1292, 40, 540, "Input",
  InitializationCell->True],
Cell[274153, 10202, 1594, 63, 908, "Input",
  InitializationCell->True],
Cell[275750, 10267, 1663, 73, 1052, "Input",
  InitializationCell->True],
Cell[277416, 10342, 514, 24, 268, "Input",
  InitializationCell->True],
Cell[277933, 10368, 2268, 111, 1660, "Input",
  InitializationCell->True,
  CellTags->"cHesse1"],
Cell[280204, 10481, 1418, 49, 684, "Input",
  InitializationCell->True],
Cell[281625, 10532, 712, 21, 236, "Input",
  InitializationCell->True],
Cell[282340, 10555, 275, 9, 44, "Input",
  InitializationCell->True],
Cell[282618, 10566, 782, 22, 252, "Input",
  InitializationCell->True],
Cell[283403, 10590, 1286, 37, 492, "Input",
  InitializationCell->True],
Cell[284692, 10629, 6353, 263, 3996, "Input",
  InitializationCell->True,
  CellTags->"BFGS"],
Cell[291048, 10894, 240, 6, 28, "Input",
  InitializationCell->True],
Cell[291291, 10902, 4759, 188, 2876, "Input",
  InitializationCell->True],
Cell[296053, 11092, 1476, 50, 700, "Input",
  InitializationCell->True]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

