(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    175232,       3142]*)
(*NotebookOutlinePosition[    176365,       3180]*)
(*  CellTagsIndexPosition[    176275,       3174]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Impl", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
Unprotect[\"code`KernDichte`*\"];
Clear[\"code`KernDichte`*\"];
Remove[\"code`KernDichte`Private`*\"];\t\t\t\t\t\t



BeginPackage[\"code`KernDichte`\",

\t\t\t{\"code`Kronecker`\",
\t\t\t \"LinearAlgebra`MatrixManipulation`\",
\t         (*\"LinearAlgebra`Cholesky`\",*)
\t\t\t \"Utilities`FilterOptions`\",
\t\t\t \"Graphics`Graphics`\",
\t\t\t \"Statistics`Common`DistributionsCommon`\",
\t\t     \"Statistics`NormalDistribution`\",
\t\t \t \"Statistics`DescriptiveStatistics`\",
\t         \"Statistics`DataManipulation`\",                                  \
       
\t\t     \"Global`\"}]



KernDichte::usage = \"KernDichte[x_,data_,Kern_,theta_] oder
\t\t\t\t\t KernDichte[x_,data_,Kern_,theta_,Op_]\"
\t\t
GaussKern::usage = \"GaussKern = (2 Pi sigma)^(-.5 p) Exp[-.5 (x.x)/sigma]\"

smoothQuickAndDirty::usage = \"smoothQuickAndDirty[ST_]\"

smoothQuickAndDirty1::usage = \"smoothQuickAndDirty1[ST_]\"

smoothQuickAndDirtyM::usage = \"smoothQuickAndDirtyM[y_,option_]\"

Mischverteilung::usage = \"Mischverteilung[alpha_,mue_,Sigma_], 
\tErwartungswert, Varianz und Standardabweichung der Mischverteilung
\tSum alpha[[i]] phi(mue[[i]],Sigma[[i]]); 
\tEi[y]=mue[[i]]; Vari[y]=Sigma[[i]]; 
\tSigma -->0, alpha = 1/n: Stichprobenvarianz\"
\t
GaussFaktor::usage = \"    \"

GaussKernO::usage = \"    \"

KernDichteM::usage = \"KernDichteM[x_,data_,Kern_,sm_,op_:Plus],
\tMultivariate Kerndichte, Kern = radial-symmetrisch, z.B.
\tGaussKern[#,1]& oder EpanechnikovM[#]&\"

N01::usage = \"N01 = (2Pi)^(-.5)Exp[-.5 (#^2)]&\"

Epanechnikov::usage = \"Epanechnikov = If[Abs[#]<1,.75(1-#^2),0]&\"

DreiEck::usage = \"DreiEck = If[Abs[#]<1,1-Abs[#],0]& \"

UnitSphere::usage = \"UnitSphere[p_] := 2 Pi^(p/2)/(p Gamma[p/2])\"

EpanechnikovM::usage = \"EpanechnikovM[x_], multivariater E. Kern\" 
    
smoothEpanechnikov::usage = \"smoothEpanechnikov[y_]\"

\t

Begin[\"`Private`\"]


(***************************************************************)\t\t\t 
smoothQuickAndDirty[ST_]:= 
(***************************************************************)\t\t\t 
\t(Varianz[ST]//First//VecDiag//Max) Length[ST]^(-2/5) //N

(***************************************************************)\t\t\t 
smoothQuickAndDirty1[ST_]:= 
(***************************************************************)\t\t\t 
\tModule[{m,s,sm},
\t{m,s} =  ST//MS1;
\tsm = (s//Max)^2 Length[ST]^(-2/5) //N;
\t{sm,m,s}]
\t
\t
(***************************************************************)\t\t\t 
smoothQuickAndDirtyM//Clear
smoothQuickAndDirtyM[y_,option_]:= 
(***************************************************************)\t\t\t 
\tModule[{m,S,SML,n,p,expo,A,h,sm},
\t(*Fukunaga, Silverman,S.78ff*)
\t
\t{SML,S,m} =  Varianz[y];
\t{n,p} = y//Dimensions;
\texpo = 1/(p+4);
\t(*A = (4/(2p+1))^expo//N;*)
\tA = (4/(p+2))^expo//N;
\th = A n^(-expo);
\tsm = If[option ==1,h^2 SML,
\t\t If[option ==2,h^2 mean[VecDiag[SML]],
\t\t If[option ==3,h^2 Max[ VecDiag[SML]],
\t\t If[option ==4,h^2 Min[ VecDiag[SML]],
\t\t If[option ==5,h^2 DiagonalMatrix[VecDiag[SML]]
\t\t ]]]]];
\t\t 
\tsm//N]

\t
(***************************************************************)\t\t\t 
smoothQuickAndDirtyM[y_,option_,alpha_]:= 
(***************************************************************)\t\t\t 
\tModule[{m,S,SML,n,p,expo,A,h,sm},
\t
\t(*mit gewichteten Daten*)
\t(*Fukunaga, Silverman,S.78ff*)
\t
\t{SML,m} =  Varianz[y,alpha];
\t{n,p} = y//Dimensions;
\texpo = 1/(p+4);
\t(*A = (4/(2p+1))^expo//N;*)
\tA = (4/(p+2))^expo//N;
\th = A n^(-expo);
\tsm = If[option ==1,h^2 SML,
\t\t If[option ==2,h^2 mean[VecDiag[SML]],
\t\t If[option ==3,h^2 Max[ VecDiag[SML]],
\t\t If[option ==4,h^2 Min[ VecDiag[SML]],
\t\t If[option ==5,h^2 DiagonalMatrix[VecDiag[SML]]
\t\t ]]]]];
\t\t 
\tsm//N]\t
\t\t
KernDichte//Clear
KernDichte[x_,data_,Kern_,theta_,Op_:Plus]:=
\tModule[{g},
\tg = Kern[#-x,theta]&//Evaluate; 
\tApply[Op,Map[g,data]]/Length[data]//N
\t]
\t
KernDichte[x_,data_,{Kern_,Faktor_},theta_,Op_:Plus]:=
\tModule[{g},
\tg = Kern[#-x,theta]&; 
\tFaktor*Apply[Op,Map[g,data]]/Length[data]//N
\t]
\t\t
GaussKern//Clear
GaussKern[x_?VectorQ,{sigma_?MatrixQ,sigma1_?MatrixQ}]:= 
\tDet[2 Pi sigma]^(-.5) Exp[-.5 x.sigma1.x]//N

GaussKern[x_?VectorQ,sigma_?MatrixQ]:= 
\tModule[{p = Length[x],sigma1=sigma//Inverse}, 
\tDet[2 Pi sigma]^(-.5) Exp[-.5 x.sigma1.x]//N
\t];
\t
GaussKern[x_?VectorQ,sigma_?ScalarQ]:= 
\tModule[{p = Length[x]}, 
\t(2 Pi sigma)^(-.5 p) Exp[-.5 (x.x)/sigma]//N
\t];

GaussKern[x_?VectorQ,{sigma_?ScalarQ}]:= 
\tModule[{p = Length[x]}, 
\t(2 Pi sigma)^(-.5 p) Exp[-.5 (x.x)/sigma]//N
\t];

GaussKern[x_?ScalarQ,sigma_?ScalarQ]:= 
\tModule[{}, 
\t(2 Pi sigma)^(-.5) Exp[-.5 (x x)/sigma]//N
\t];\t\t
\t\t
GaussKernO//Clear
GaussKernO[x_,{sigma_,sigma1_}]:= Exp[-.5 (x.sigma1.x)]//N 
\t(*ohne Determinante*)

GaussKernO[x_,sigma_?ScalarQ]:= Exp[-.5 (x.x)/sigma]//N
\t
\t
GaussFaktor//Clear
GaussFaktor[sigma_]:= Det[2 Pi sigma]^(-.5)

GaussFaktor[sigma_,p_]:= (2 Pi sigma)^(-.5 p)

Mischverteilung[alpha_,mue_,Sigma_]:=
 Module[{am,m,mm,var,std},
 \tam = alpha*mue;
 \tm = Plus@@am;
 \tmm = MapThread[Outer[Times,##]&,{mue,mue}];
 \t
 \tIf[TensorRank[Sigma]===3,
 \tvar = Apply[Plus,alpha*(Sigma + mm)] - Outer[Times,m,m],
 \t
 \t(*gleiche Kovarianzen*)
 \tvar = Sigma + Apply[Plus,alpha* mm ] - Outer[Times,m,m]
 \t];
 \t
 \tstd = Transpose[var,{1,1}]//Sqrt;
 \t{m,var,std} 
 \t];
 \t
KernDichteM//Clear
KernDichteM[x_,data_,Kern_,sm_,op_:Plus]:=
\tModule[{sm1,jacobi,z},
\tIf[TensorRank[data]==1,Print[\"Warning:scalar data\"]];
\tjacobi = Det[sm]^(-.5);
\tsm1 = sm//CholeskyDecomposition//Transpose//Inverse;
\tz = Map[(sm1.(x-#))&,data];
\tz = Map[Kern,z];
\tjacobi Apply[op,z]/Length[data]//N
\t]
\t
N01 = (2Pi)^(-.5)Exp[-.5 (#^2)]&
Epanechnikov = If[Abs[#]<1,.75(1-#^2),0]&
DreiEck = If[Abs[#]<1,1-Abs[#],0]& 

UnitSphere[p_] := 2 Pi^(p/2)/(p Gamma[p/2])

EpanechnikovM[x_] := 
\tModule[{d = x//Length,xx = x.x},
    If[xx < 1, .5/UnitSphere[d] (d+2) (1-xx),0]//N
    ]
    
(***************************************************************)\t\t\t 
smoothEpanechnikov[y_]:= 
(***************************************************************)\t\t\t 
\tModule[{m,S,SML,n,p,expo,A,h,sm},
\t(*Fukunaga, Silverman,S.78ff*)
\t
\t{SML,S,m} =  Varianz[y];
\t{n,p} = y//Dimensions;
\texpo = 1/(p+4);
\tA = ( 8/UnitSphere[p]  (p+4)2 Pi^(p/2) )^expo//N;
\th = A n^(-expo);
\tsm = h^2 SML//N
]\t
\t
End[]

Protect[\"Mischverteilung\"]\t

EndPackage[ ]\t
\t \t\
\>", "Input",
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[" ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["??GaussKern", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("GaussKern = (2 Pi sigma)^(-.5 p) Exp[-.5 (x.x)/sigma]"\)], "Print",
  CellTags->"Info3373627869-2632070"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(GaussKern[
                      Hermann`KernDichte`Private`x_?
                        VectorQ, {Hermann`KernDichte`Private`sigma_?MatrixQ, 
                        Hermann`KernDichte`Private`sigma1_?MatrixQ}] := 
                    N[\[ExponentialE]\^\(\(-0.5`\)\ \
Hermann`KernDichte`Private`x . Hermann`KernDichte`Private`sigma1 . \
Hermann`KernDichte`Private`x\)\/Det[2\ \[Pi]\ \
Hermann`KernDichte`Private`sigma]\^0.5`]\)},
                {" "},
                {\(GaussKern[Hermann`KernDichte`Private`x_?VectorQ, 
                      Hermann`KernDichte`Private`sigma_?MatrixQ] := 
                    Module[{Hermann`KernDichte`Private`p = 
                          Length[Hermann`KernDichte`Private`x], 
                        Hermann`KernDichte`Private`sigma1 = 
                          Inverse[Hermann`KernDichte`Private`sigma]}, 
                      N[\[ExponentialE]\^\(\(-0.5`\)\ \
Hermann`KernDichte`Private`x . Hermann`KernDichte`Private`sigma1 . \
Hermann`KernDichte`Private`x\)\/Det[2\ \[Pi]\ \
Hermann`KernDichte`Private`sigma]\^0.5`]]\)},
                {" "},
                {\(GaussKern[Hermann`KernDichte`Private`x_?VectorQ, 
                      Hermann`KernDichte`Private`sigma_?
                        Hermann`Kronecker`ScalarQ] := 
                    Module[{Hermann`KernDichte`Private`p = 
                          Length[Hermann`KernDichte`Private`x]}, 
                      N[\((2\ \[Pi]\ \
Hermann`KernDichte`Private`sigma)\)\^\(\(-0.5`\)\ \
Hermann`KernDichte`Private`p\)\ \[ExponentialE]\^\(-\(\(0.5`\ \
Hermann`KernDichte`Private`x . \
Hermann`KernDichte`Private`x\)\/Hermann`KernDichte`Private`sigma\)\)]]\)},
                {" "},
                {\(GaussKern[
                      Hermann`KernDichte`Private`x_?
                        VectorQ, {Hermann`KernDichte`Private`sigma_?
                          Hermann`Kronecker`ScalarQ}] := 
                    Module[{Hermann`KernDichte`Private`p = 
                          Length[Hermann`KernDichte`Private`x]}, 
                      N[\((2\ \[Pi]\ \
Hermann`KernDichte`Private`sigma)\)\^\(\(-0.5`\)\ \
Hermann`KernDichte`Private`p\)\ \[ExponentialE]\^\(-\(\(0.5`\ \
Hermann`KernDichte`Private`x . \
Hermann`KernDichte`Private`x\)\/Hermann`KernDichte`Private`sigma\)\)]]\)},
                {" "},
                {\(GaussKern[
                      Hermann`KernDichte`Private`x_?
                        Hermann`Kronecker`ScalarQ, 
                      Hermann`KernDichte`Private`sigma_?
                        Hermann`Kronecker`ScalarQ] := 
                    Module[{}, 
                      N[\[ExponentialE]\^\(-\(\(0.5`\ \
\((Hermann`KernDichte`Private`x\ \
Hermann`KernDichte`Private`x)\)\)\/Hermann`KernDichte`Private`sigma\)\)\/\((2\
\ \[Pi]\ Hermann`KernDichte`Private`sigma)\)\^0.5`]]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "GaussKern"],
      Editable->False]], "Print",
  CellTags->"Info3373627869-2632070"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GaussKernO[xx,sss1]
GaussFaktor[{xx},sss1]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
2.718281828459045^((-0.5*xx . xx)/sss1)\
\>", "\<\
  \
     (-0.5 xx . xx)/sss1
2.71828\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1/(2^(0.5*sss1)*(Pi*xx)^(0.5*sss1))}\
\>", "\<\
    \
         1
{-------------------------}
  0.5 sss1        0.5 sss1
 2         (Pi xx)\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dimensions[{xx}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1}\
\>", "\<\
{1}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["<<Hermann`Kronecker`", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["GaussKern[{xx},1.]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0.3989422804014326779/2.718281828459045235^(0.5*xx^2)\
\
\>", "\<\
   0.398942
--------------
             2
       0.5 xx
2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GaussDichte[#1,{0,#2}]&[",
    FontWeight->"Plain"],
  "{xx},sigma",
  StyleBox["]",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0.3989422804014326779/(2.718281828459045235^((0.5*xx^\
2)/sigma)*sigma^0.5)\
\>", "\<\
           0.398942
-------------------------------
              2
       (0.5 xx )/sigma      0.5
2.71828                sigma\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussKern[{xx,yy},{{1/2,0},{0,1}}]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.08333333333333337034*Second, \
0.2250790790392765174/2.718281828459045235^(0.5*(2.*xx^2 + yy^2))}\
\>", \
"\<\
                           0.225079
{0.0833333 Second, -------------------------}
                                    2     2
                          0.5 (2. xx  + yy )
                   2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussKern[{xx,yy},{{{1/2,0},{0,1}},{{2,0},{0,1}}}]//Timing", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.0499999999999999889*Second, \
0.2250790790392765174/2.718281828459045235^(0.5*(2.*xx^2 + yy^2))}\
\>", \
"\<\
                      0.225079
{0.05 Second, -------------------------}
                               2     2
                     0.5 (2. xx  + yy )
              2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
expo = 1/(d+4);
A = (4/(d+2))^expo//N
h = A nn^(-expo)\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
4.^(4. + d)^(-1)*((2. + d)^(-1))^(4. + d)^(-1)\
\>", \
"\<\
  1/(4. + d)    1    1/(4. + d)
4.           (------)
              2. + d\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
(4.^(4. + d)^(-1)*((2. + d)^(-1))^(4. + \
d)^(-1))/nn^(4 + d)^(-1)\
\>", "\<\
  1/(4. + d)    1    1/(4. + d)
4.           (------)
              2. + d
-------------------------------
            1/(4 + d)
          nn\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[Table[h,{d,1,5}]//Evaluate,{nn,10,500}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PICT", "\<\
91X0100Y07P0iP0A0_l<0?ooool0:@0000@0003V0000N0000000000N00402P04
02T0N03V09X0003oP_@0000007@0_@0000@0000004P000180000400P00<02000
0002njSH000000000000M02m00@0:@1h0>H0900Djon10>40i?n10>40i?n10>40
n_l1BN_o0@00o?l00?co003lo`00o?l00?co003ko`00o?l00?co003lo`00o?l0
0?_o003lo`00o?l00?co003lo`00o?l00?_o003lo`00o?l00?co003lo`00nol0
0?co003lo`00o?l00?ko003To`400?co003lo`00o?l00?co003lo`00nol00?co
003lo`00o?l00?co003ko`00o?l00?co003lo`00o?l00?co003ko`00o?l00?co
003lo`00o?l00?_o003lo`00o?l00?co003no`00i?l1003lo`00o?l00?co003l
o`00o?l00?_o003lo`00o?l00?co003lo`00nol00?co003lo`00o?l00?co003l
o`00nol00?co003lo`00o?l00?co003ko`00o?l00?co003lo`00o_l00?[o023[
o`00POoSo`00i?l0087ohol00>Co0021on?o003jo`0Xjol00?ko0021onOo003T
o`00POoSo`00i?l00?ko06J1onOo003jo`0[jol00?ko0021onSo0@00i?l0087o
i?l1003To`00o_l0IX7oj?l1003jo`0Xjol00?ko0021onOo003To`00POoSo`00
i?l00?ko06J1onOo003jo`13oOl1003ioo`0o_l00?ko0021onOo003fo`400?Wo
o03no`00POoSo`00m_l1003ioo`0o_l00?ko06J1onOo003jo`1Eo_l30?oo0?[o
003no`00o_l00?ko0021onOo003go`<0ool0n_l00?ko003no`00POoSo`00mol3
0?oo0?[o003no`00o_l00?ko06J1onOo003jo`19o_l30?oo0?Ko003no`00o_l0
087oiol00?Oo0`3oo`3fo`00o_l0087ohol00?Oo0`3oo`3fo`00o_l00?ko06J1
onOo003jo`1?o_l30?oo0?Oo003mo`D00?oo<`21onWo0@00mol30?oo0?Oo003m
o`40087oiOl1003go`<0ool0mol00?go1@00ool0IX7ojOl1003jo`1;o_l30?oo
0?Oo003mo`00o_l1<`21onSo003go`<0ool0mol00?go0021on?o003go`<0ool0
mol00?go003no`40IX7oj?l00?[o04gno`<0ool0n?l00?co003no`8co`21onWo
003go`<0ool0n?l00?co0021on?o003go`<0ool0n?l00?co003no`80ofJ1onWo
003jo`1CoOl1003mo`00o?l00?co003no`;<<`21onWo003fo`400?go003lo`00
o?l0087ohol00?Ko0@00oOl00?co003lo`00o_l2001VPOoYo`00n_l0;n_o003n
o`;<<`21on[o0@00i?l0087oi?l1003To`00o_l2001VPOoZo`400?[o02k[o`00
o_l3c3?o087oj_l00>Co0021on?o003To`00o_l3003oIX7oj_l00?[o02k[o`00
o_l3c?lc087oj_l00>Co0021on?o003To`00o_l30?l0IX7oj_l00?[o033[o`00
oOl2c3<0POoZo`00i?l00?ko09V1onOo003To`00o_on001VPOoZo`00n_l0<^_o
003mo`?<<ol0POo[o`00i?l00?ko09V1onOo003To`00o_on007oIX7ojol00?[o
03K[o`00oOl3c?lc087ok?l1003To`00o_l0VH7oj?l1003To`00o_l4003o06J1
onco0@00n_l0=N_o003mo`C<oc?o087ok?l00>Co003no`2IPOoWo`00i?l00?ko
1@00o`3oIX7ok?l00?[o03K[o`00o?l4c3?oo`21ongo003To`00o_l0VH7oiol0
0>Co003no`H0o`00oomVPOo]o`00n_l0=^_o003lo`C<oc?o087okOl00>Co003n
o`40VH7oj?l00>Co003nooh00ol0ofJ1ongo003jo`0kjol00?co1Lco<ooo087o
kol1003To`00o_l109V1onWo0@00i?l00?kooP04o`3oofJ1onoo0@00n_l0>>_o
003ko`C<<ooo087ok_l00>Co003no`40VH7oj?l00>Co003no`L00?l00?ooIX7o
k_l00?[o03[[o`00nol5c?lcool0POo_o`00i?l00?ko0@2IPOoXo`00i?l00?ko
2000o`3o0?ooIX7okol00?[o03[[o`00nol6c?oo<ooo087ol?l00>Co003mo`40
VH7ojOl00>Co003mooh01Ooo0?ooIX7ol?l00?[o03g[o`00n_l5c?lcool0POoa
o`400>Co003mo`40VH7oj_l1003To`00oOl8003o0?l0oomVPOoao`400?[o03c[
o`00n_l6c?oo<ooo087olOl00>Co003mo`40VH7ojOl00>Co003mo`T00?l0ool0
oomVPOoao`00n_l0GOgo0@00mol1003mo`00n_l3c?oo<oko0021oo;o003fo`40
0?Oo0@00oOl00?go0P3oVH7oj_l00?Ko0@00mol1003mo`00oOl60?l00?oo0?ko
06J1oo;o003jo`1Oo_l30?oo0?Wo003ko`00nOl3c?oo<oko0021oo?o003go`<0
ool0nOl00?_o003lo`40VH7oj_l00?Oo0`3oo`3io`00nol00?co1P00o`3oo`3n
o`1VPOoco`00n_l0HOko0`3oo`3jo`00n_l00?Wo0<cno`0co_l0087om?l00?Oo
0`3oo`3jo`00n_l00?co0@2IPOoZo`00mol30?oo0?[o003jo`00o?l3003o0?ko
003no`1VPOodo`00n_l0I_ko0`3oo`3jood0oOl1003io`?<oolcoOl0087om_l1
003go`<0ool0n_om0?go0@00oOl109V1on_o0@00mol30?oo0?[oo@3mo`400?go
1`00ool0ool0oOl0IX7om_l1003jo`1ao_l30?oo0?[o003no`00o_l00?So0<cn
o`0coOl10021ooOo003go`<0ool0n_l00?ko003no`00o?l20?nIPOo[o`00mol3
0?oo0?[o003no`00o_l00?co103o0?l0o_l00?go0FIVPOogo`00n_l0K_ko0`3o
o`3jo`00o_l00?ko003go`3<o_l0<oco0021ooSo003go`<0ool0n_l00?ko003n
o`00nol109V1on_o003go`<0ool0n_l00?ko003no`00nol4003oo`3no`00o?l0
IX7on?l00?[o06[mo`400?go003mooh0oOl00?Oo0<cmo`0co?l10021oo[o003f
o`400?go003mooh0oOl00?_o0@2IPOo[o`00m_l1003mo`00oOon0?go003ko`@0
0?oo0?go003lo`5VIX7on_l00?[o04K[o`00m_l0c?ko03?jo`00POolo`400>Co
003ko`80oiV1ongo0@00i?l00?_o1@3o0?oo0?ko003jo`1VPOolo`400?[o04K[
o`00mOl0c?ko03?jo`40087ooOl00>Co003ko`80oiV1onco003To`00nol20?l0
o_l00?ko003jo`5VIX7ooOl00?[o04G[o`00mOl0c?go03?io`00POono`00i?l0
0?_o0`3ooiV1ongo003To`00nol60?oo0?oo0?go003io`1VPOono`00n_l0A^_o
003do`3<oOl1<c?jo`40087o0Ol0i?l00?[o0P3oVH7okOl00>Co003jo`80o`3n
o`00oOl1003jo`5VIX7o0Ol0n_l0A>_o003co`3<o?l0<oWo0@00P_l00>Co003j
o`<0oonIPOo^o`00i?l00?[o0`3oo`3no`00o?l00?Wo0FIVP_l00?[o04W[o`00
l_l0c?co0C<cnOl10025o`400>Co003jo`<0oonIPOo_o`400>Co003jo`<0ool0
oOl00?co0@00nOl1IVJ5o`400?[o04C[o`00l_l0c?[o03?hooh0Qol00>Co003j
o`00o_l0VH7okol00>Co003jo`00o_l00?ko003jo`00n?onIXOo003jo`14jol0
0?7o0<cjo`4c<oOooP2:o`00i?l00?Wo0`3ooiV1onoo003To`00nOl30?oo0?go
003jo`400?OooVJ:o`00n_l0A>_o003`o`3<nOl0<oGoo@2>o`00i?l00?Wo003n
o`2IPOo`o`00i?l00?Wo003no`00oOl00?Wo003eooeVS_l00?[o04O[o`00kol0
c?Wo0C<cloon09;o0@00i?l00?So0`3ooiV1oo7o0@00i?l00?So0`3oo`3lo`00
nOl1003cooiVT_l1003jo`16jol00>ko0<cho`4c<o;oo@2Eo`00i?l00?So003n
o`2IPOoao`00i?l00?So003no`00o?l00?So0@00l_omIYGo003jo`14jol00>go
0<cgo`4c<o3oo02Jo`00i?l00?Oo0`3ooiV1oo7o003To`00mol30?oo0?_o003g
o`400?3oo6JJo`00n_l0A^_o003/o`7<c?OooS?^ooh0WOl00>Co003go`00o_l0
VH7ol_l00>Co003go`00o_l00?_o0@00moon0>kooVJMo`00n_l0A>_o003Zo`3<
mOon<nkoo02Ro`00i?l00?Oo003mo`2IPOoco`00i?l00?Oo003mo`00n_l00?Go
oP3^ooaVX_l00?[o04W[o`00jOl1c<cdoodckOok0:Wo0@00i?l00?Ko003no`2I
POodo`400>Co003fo`00o_l00?Wo0@00m?om0>gonfJYo`400?[o05omo`400?Wo
o03no`00iol0c?7ooS?Zoo/0[_l00?Ko0@00nOol0?ko003fo`00oOl0VH7om?l0
0?Ko0@00nOol0?ko003fo`00oOl00?So003aooh0j_okIZko003jo`1Wo_l30?oo
0?[o003jo`00i_l1c<c`oohciooj0;Go003go`<0ool0n_l00?[o003eo`00oOl0
VH7omOl00?Oo0`3oo`3jo`00n_l00?Go003mo`00n?l1003`ooh0ioojI[Go003j
o`1Wo_l30?oo0?[oo@3mo`00i?l1c<c_oohchook0;_o003go`<0ool0n_om0?go
003eo`00o?l0VH7om_l00?Oo0`3oo`3jood0oOl00?Go003lo`00mol1003_ooh0
hookI[_o003jo`1]o_l30?oo0?Ko003no`400>?o0Lc<k_on<n3on`32o`400?Oo
0`3oo`3fo`00o_l1003eo`00o?l0VH7on?l1003go`<0ool0m_l00?ko0@00mOl0
0?co003fo`400>kooP3Poo]V`_l1003jo`1Wo_l30?oo0?Ko003no`00h?l1c<c]
oohcgOoj0<So003go`<0ool0m_l00?ko003do`00nol0VH7on?l00?Oo0`3oo`3f
o`00o_l00?Co003ko`00mOl1003]ooh0gOojI/So003jo`1eo_l30?oo0?[o003n
o`00o_l00=ko0Lc<k?ol<m_om@3Do`00mol30?oo0?[o003no`00o_l00??o003k
o`6IVH7on_l00?Oo0`3oo`3jo`00o_l00?ko003co`00nol1003eo`400>coo03K
ooEVe?l00?[o06_mo`400?go003mooh0oOl00=coo/cZoo/ceOoj0=_o003fo`40
0?go003mooh0oOl00?;o003jo`2IPOoko`00m_l1003mo`00oOon0?go003bo`00
n_l00?CooP3Zoo/0eOojI]_o003jo`19jol00=Woo/cWoo/ce?oe0>So0@00i?l0
0?;o003io`6IVH7oo_l1003To`00l_l00?Wo0@00loon0>Oon`3DooEVj?l1003j
o`14jol00=Koo/cTooXccood0?Co003To`00lOl00?So09V1ooko003To`00lOl0
0?So003aooh0i?oj0<oom6Kdo`00n_l0AN_o003Cook<h?ok<lSom`3no`00i?l0
0?3o003ho`6IVH7o0Ol0i?l00?3o003ho`400?3ooP3Poo/0b?ogI_ko003jo`0j
jol00=3oo/cMoo/c`Ol00>Co003_o`00mol0VH7o003To`00kol00?Oo003^ooh0
gOok0<7o003jo`0ljol00<goo/cJooXcb?l00>Co003^o`00mol1VIV3o`00i?l0
0>ko003go`400>gooP3JooX0b?l00?[o03g[o`00b_onc=Konc??o`400>Co003]
o`00m_l0VHGo0@00i?l00>go003fo`00joon0=Kon`3?o`400?[o03c[o`00aool
c=Gom3?Ko`00i?l00>co003fo`6IVHKo003To`00k?l00?Ko0@00j_ol0=Gom03K
o`00n_l0?>_o0032oo_<c_ok<n7o003To`00jol00?Go0IVIR?l00>Co003[o`00
mOl1003Woo/0c_ok0>7o003jo`0jjol00;coo<c=oo@ck_l00>Co003Zo`00m?on
VH_o003To`00j_l00?CooP3Too`0cOod0>ko003jo`0ojol00;Ooo/c3ooDcnol1
003To`00jOl1003coojISol1003To`00jOl1003cooh0h_on0<?om@3ko`400?[o
03[[o`00]?olc;cooC?no`00i?l00>Oo003aoojITOl00>Co003Wo`00lOon0>;o
o02lood0o_l00?[o03;[o`00[ookc;_o003To`00i_l00>oooYVDo`00i?l00>Ko
003_ooh0h?ok0;_o003jo`0bjol00:Wonlc1o`00i?l00>Go003]oojIUol00>Co
003Uo`00kOon0=gon`31o`00n_l0<^_o002SooC<c_l00>Co003To`00joonVI[o
003To`00i?l00>_ooP3Joo@0c_l00?[o03O[o`00U_okc=Go0@00i?l00>?o0@00
j_onVIko0@00i?l00>?o0@00j_on0=3on`3Eo`400?[o04gmo`400?Ko003mo`00
T?ojc=_o003fo`400?Ko003mo`00hOl00>Soo9VRo`00m_l1003fo`00oOl00>7o
003Xoo`0cooj0=_o003jo`1Ho_l30?oo0?So0@00oOl008WomLcWo`00mol30?oo
0?So0@00oOl00>3o0@00iOolVJOo003go`<0ool0n?l1003mo`00h?l1003Uoo`0
cOoe0>Oo003jo`1Mo_l30?oo0?Wo0P3o0?go0021oogom<cdo`00mol30?oo0?Wo
0P3o0?go003No`400>;ooYVZo`00mol30?oo0?Wo0P3o0?go003No`400>;ooP34
oo@0m?l00?[o06Cno`<0ool0n_l30?oo0?go0@00POoaoo_<nol1003go`<0ool0
n_l30?oo0?go0@00gOon0>;ooIV_o`400?Oo0`3oo`3jo`<0ool0oOl1003Mooh0
h_om0;_on`3ko`400?[o05Gno`<0ool0n_ol0?ko0021on[ooLcno`00mol30?oo
0?[oo03no`00fOon0>7onYVeo`00mol30?oo0?[oo03no`00fOon0>7onP2lood0
o_l00?[o04gno`<0ool0mol00?go0021on?o003go`<0ool0mol00?go003Fooh0
gOokVK_o003go`<0ool0mol00?go003Fooh0gOok0;_o003jo`1CoOl1003mo`00
o?on0?ko0021on?o003fo`400?go003looh0o_l00=?ooP3Joo^I`Ol00?Ko0@00
oOl00?cooP3no`00doon0=[on`31o`00n_l0;>_o0021on?o003To`00d?on0=Oo
nYW8o`00i?l00=3ooP3GooX0b?l00?[o02o[o`00POoTo`400>Co003=ooh0dook
VLoo0@00i?l00<gooP3Coo/0col1003jo`0/jol0087ohol00>Co003:ooh0d?od
VM_o003To`00b_on0=3om03Ko`00n_l0;>_o0021on?o003To`00aoon0<KoniWQ
o`00i?l00<OooP36oo/0hOl00?[o02c[o`00POoSo`00i?l00<CooP33ooBIk_l0
0>Co0034ooh0`ood0>ko003jo`0_jol0087oi?l1003To`00`Ool0;_oniWeo`40
0>Co0031oo`0^ook0?Go0@00n_l0;>_o0021on?o003To`00_?ok0;_omiWno`00
i?l00;con`2kooL0o_l00?[o02C[o`00POoSo`00i?l00;Koo02co`00i?l00;Ko
o02co`00n_l09>_o0021on?o003To`00/Oon0;Ko003To`00/Oon0;Ko003jo`0T
jol0087ohol00>Co002^oo`0^ol00>Co002^oo`0^ol00?[o02O[o`00POoTo`40
0>Co002Yoo/0`_l1003To`00ZOok0<;o0@00n_l09>_o0021on?o003To`00Xooj
0<So003To`00Xooj0<So003jo`0Tjol0087ohol00>Co002LooD0e?l00>Co002L
ooD0e?l00?[o02C[o`00POoSo`00i?l0093onP3Ko`00i?l0093onP3Ko`00n_l0
9n_o0021onCo0@00i?l008Won`3Ro`400>Co0029oo/0h_l1003jo`0ooOl1003h
ooh0oOl0087ohol00?Ko0@00n?on0?go0023oo@0k_l00?Ko0@00n?on0?go0023
oo@0k_l00?[o05Gno`<0ool0n_l00?ko003no`00POoSo`00mol30?oo0?[o003n
o`00o_l0087om_ok0?Co003go`<0ool0n_l00?ko003no`00POofoo/0m?l00?[o
04Wno`<0ool0m_l00?ko0021on?o003go`<0ool0m_l00?ko0021oo3om`3no`00
mol30?oo0?Ko003no`00POo`ooL0o_l00?[o04[no`<0ool0n?l1003mo`40087o
iOl1003go`<0ool0n?l1003mo`40087oiOl1003go`<0ool0n?l1003mo`40087o
iOl1003jo`0eo_l30?oo0?Ko003noh40h@3go`<0ool0m_l00?koP@3Q0?Oo0`3o
o`3fo`00o_n10>40n_l0=Oko0`3oo`3jo`00o_l0087oe?l30?oo0?[o003no`00
POoDo`<0ool0n_l00?ko0021omOo02omo`400?go003mooh0POoBo`400?go003m
ooh0POoBo`400?go003mooh0POoFo`0:POn1oh7oPOo:o`0:POn1oh7oPOo:o`0:
POn1oh7oPOo:o`0:POn1oh7oPOo:o`0:POn1oh7oPOo:o`3Sjol1003[o`00o?l1
003mo`400?7ooP3mo`400?go0@00lOon0?go0@00oOl1003_o`00oOl1003mo`40
0?;oo03no`400?go0@00i_l1003[o`00o?l1003mo`400?7ooP3mo`400?go0@00
lOon0?go0@00oOl1003_o`00oOl1003mo`400?;oo03no`400?go0@00i_l1003[
o`00o?l1003mo`400?7ooP3mo`400?go0@00lOon0?go0@00oOl1003_o`00oOl1
003mo`400?;oo03no`400?go0@00o?l1;^co0`3oo`3]o`400?go2@3oo`3oo`3o
o`3co`00o_l<0?oo0?oo0?oo0?oo0??o003no``0ool0ool0ool0ool0lOl1003n
o`T0ool0ool0ool0lol00?_o2@3oo`3oo`3oo`3Xo`<0ool0kOl1003mo`T0ool0
ool0ool0lol00?ko303oo`3oo`3oo`3oo`3co`00o_l<0?oo0?oo0?oo0?oo0?7o
0@00o_l90?oo0?oo0?oo0??o003ko`T0ool0ool0ool0j?l30?oo0>go0@00oOl9
0?oo0?oo0?oo0??o003no``0ool0ool0ool0ool0lol00?ko303oo`3oo`3oo`3o
o`3ao`400?ko2@3oo`3oo`3oo`3co`00nol90?oo0?oo0?oo0?go0B;/o`<0ool0
k?l00?go2@3oo`3oo`3oo`3co`00o_l<0?oo0?oo0?oo0?oo0>oo303oo`3oo`3o
o`3oo`3bo`80o`3no`T0ool0ool0ool0loom0?ko2@3oo`3oo`3oo`3Xo`<0ool0
k?l00?go2@3oo`3oo`3oo`3co`00o_l<0?oo0?oo0?oo0?oo0>oo303oo`3oo`3o
o`3oo`3bo`80o`3no`T0ool0ool0ool0loom0?ko2@3oo`3oo`3oo`3Xo`<0ool0
k?l00?go2@3oo`3oo`3oo`3co`00o_l<0?oo0?oo0?oo0?oo0>oo303oo`3oo`3o
o`3oo`3bo`80o`3no`T0ool0ool0ool0loom0?ko2@3oo`3oo`3oo`3mo`4Ok?l3
0?oo0>co003mo`T0ool0ool0ool0l?l00?ko2@3oo`3oo`3oo`3ao`400?ko2@3o
o`3oo`3oo`3co`<0ool0o_l90?oo0?oo0?oo0>oo303oo`3oo`3oo`3oo`3Xo`<0
ool0k?l00?go2@3oo`3oo`3oo`3`o`00o_l90?oo0?oo0?oo0?7o0@00o_l90?oo
0?oo0?oo0??o0`3oo`3no`T0ool0ool0ool0kol<0?oo0?oo0?oo0?oo0>So0`3o
o`3/o`00oOl90?oo0?oo0?oo0?3o003no`T0ool0ool0ool0lOl1003no`T0ool0
ool0ool0lol30?oo0?ko2@3oo`3oo`3oo`3_o``0ool0ool0ool0ool0oOl14>co
0`3oo`3/o`00oOl90?oo0?oo0?oo0?7o003mo`T0ool0ool0ool0kol<0?oo0?oo
0?oo0?oo0??oo00;ool0ool0ool0ool0kol<0?oo0?oo0?oo0?oo0>So0`3oo`3/
o`00oOl90?oo0?oo0?oo0?7o003mo`T0ool0ool0ool0kol<0?oo0?oo0?oo0?oo
0??oo00;ool0ool0ool0ool0kol<0?oo0?oo0?oo0?oo0>So0`3oo`3/o`00oOl9
0?oo0?oo0?oo0?7o003mo`T0ool0ool0ool0kol<0?oo0?oo0?oo0?oo0??oo00;
ool0ool0ool0ool0kol<0?oo0?oo0?oo0?oo0?go0Bk/o`<0ool0k?l00?go2@3o
o`3oo`3oo`3bo`l0ool0ool0ool0ool0ool0lol00?ko303oo`3oo`3oo`3oo`3`
o`00o_l90?oo0?oo0?oo0??o003no``0ool0ool0ool0ool0j?l30?oo0>co003m
o`T0ool0ool0ool0l_l?0?oo0?oo0?oo0?oo0?oo0??o003no``0ool0ool0ool0
ool0l?l00?ko2@3oo`3oo`3oo`3co`00o_l<0?oo0?oo0?oo0?oo0>So0`3oo`3/
o`00oOl90?oo0?oo0?oo0?;o3`3oo`3oo`3oo`3oo`3oo`3co`00o_l<0?oo0?oo
0?oo0?oo0?3o003no`T0ool0ool0ool0lol00?ko303oo`3oo`3oo`3oo`3mo`3S
jol1003/ooh0oOl1003mo`400?;oo03no`400?go0@00lOon0?go0@00oOl1003`
ooh0o_l1003mo`400?7ooP3mo`400?go0@00i_l1003/ooh0oOl1003mo`400?;o
o03no`400?go0@00lOon0?go0@00oOl1003`ooh0o_l1003mo`400?7ooP3mo`40
0?go0@00i_l1003/ooh0oOl1003mo`400?;oo03no`400?go0@00lOon0?go0@00
oOl1003`ooh0o_l1003mo`400?7ooP3mo`400?go0@00o?l02X7oPOn1oh7ob_l0
2X7oPOn1oh7ob_l02X7oPOn1oh7ob_l00?l\>"], "Graphics",
  ImageSize->{189, 116},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Graphics[\"<<>>\"]\
\>", "\<\
-Graphics-\
\>"], \
"Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["data = Table[Gauss[],{10},{2}].{{1,.5},{.5,1}}", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
 {{-1.26840941972792, -0.796325344840207}, \
{0.3065086559150196, -0.04225881803621024}, {-0.5660103234731558, \
0.2055750638726228}, 
  {0.7865589527786266, -0.1914947831348375}, {-0.7831454173749744, \
-1.460415252215929}, {0.2052127609868877, 0.1867262166859378}, 
  {-0.0905492635472274, -1.231254342525899}, {0.3286322436768114, \
-0.7550863115179794}, {0.2046603825125963, 0.859344779934941}, 
  {0.1923218398972874, 1.307750669754295}}\
\>", "\<\
 {{-1.26841, \
-0.796325}, {0.306509, -0.0422588}, {-0.56601, 0.205575}, {0.786559, \
-0.191495}, {-0.783145, -1.46042}, {0.205213, 0.186726}, 
  {-0.0905493, -1.23125}, {0.328632, -0.755086}, {0.20466, 0.859345}, \
{0.192322, 1.30775}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussKern[{x,y},1]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0.1591549430918953/2.718281828459045^(0.5*(x^2 + \
y^2))\
\>", "\<\
      0.159155
--------------------
             2    2
       0.5 (x  + y )
2.71828\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["<<KernDichte.m", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
sm = smoothQuickAndDirtyM[data,1]
kd = KernDichteM[{x,y},data,GaussKern[#,1]&,sm];
ContourPlot[kd//Evaluate,{x,-2,2},{y,-2,2}]//Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{0.1599277045214914, 0.0961598833392584}, \
{0.0961598833392584, 0.3272181610613296}}\
\>", "\<\
{{0.159928, 0.0961599}, \
{0.0961599, 0.327218}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PICT", "\<\
POH0100Y0;/0h00A0_l<0?ooool0:@0000@0003P0000^`000000000N00402P04
02T0^`3P09X0003oP]`000000;L0]`0000@0000004P000180000400P00<02000
0002njFT000000000000]`2g00@0:@2k0>00900:POn1oh7oPOoLo`0:POn1oh7o
POoLo`0ElOn10=`0kon10=`0kon10=`00Ooo0B;hooh0oOl00?ko003ko`00n_l0
0?[o003jo`00n_l00?[o003ko`00n_l00?[o003jo`00n_l00?[o003ko`00n_l0
0?[o003jo`00n_l00?[o003jo`00nol00?ko003fooh0oOl00?ko003ko`00n_l0
0?[o003jo`00n_l00?[o003ko`00n_l00?[o003jo`00n_l00?[o003ko`00n_l0
0?[o003jo`00n_l00?[o003jo`00nol00?ko003fooh0oOl00?ko003ko`00n_l0
0?[o003jo`00n_l00?[o003ko`00n_l00?[o003jo`00n_l00?[o003ko`00n_l0
0?[o003jo`00n_l00?[o003jo`00nol00?ko0P3oo`0hnOl00?ko003no`00POoN
o`00mol00?ko003no`00POoNo`00mol00?ko003no`00POoNo`80ool0>?Wo003n
o`00o_l0087og_l00?Oo003no`00o_l0087og_l00?Oo003no`00o_l0087og_l2
0?oo05gfo`00oOl3003ookD0nAT00>dc003h6MP00OoooP3do`00oOl3003ookD0
nAT00>dc003h6MP00OoooP3do`00oOl3003ookD0nAT00>dc003h6MP00OoooP01
ool0E_Oo003lo`00o_nf0?TI003[<`00nAWH0?go003eo`00o?l00?ko]P3i6@00
jc<00?TIf03mo`00mOl00?co003nokH0nAT00>/c003i6MP0oOl20?oo05oho`<0
ool0o_l00?ko]`3i6@00jS<00?PIf@3mo`00m_l30?oo0?ko003nokL0nAT00>Xc
003h6MT0oOl00?Ko0`3oo`3no`00o_ng0?TI003Z<`00n1WI0?go0P3oo`1FnOol
0?ko003nokP0nAT00>Pc003i6MT0oOl00?Ooo03no`00o_nh0?TI003X<`00nAWI
0?go003goo`0o_l00?ko^03i6@00j3<00?TIf@3mo`80ool0E_7o003nokT0nAT0
0?Tcn`3e<`00nAWI0?go003_o`00o_ni0?TI003i<o/0mC<00?TIf@3mo`00kol0
0?ko^@3i6@00nC?k0?Dc003i6MT0oOl20?oo06Gao`00o_nj0?XI0@00nC<00?]<
n`3j<`00nQWI0?go003_o`00o_nj0?XI0@00nC<00?]<n`3j<`00nQWI0?go003_
o`00o_nj0?XI0@00nC<00?]<n`3j<`00nQWI0?go0P3oo`1UlOl00?ko^`3j6@00
nC<1003dC000nS<00?XIfP3mo`00kol00?ko^`3j6@00nC<1003dC000nS<00?XI
fP3mo`00kol00?ko^`3j6@00nC<1003dC000nS<00?XIfP3mo`80ool0J?7o0`00
oonl0?XI003i<`00lD`00?/c003j6MX0o_l1003_o`<00?oo_03j6@00nC<00?5<
003k<`00nQWJ0?ko0@00kol3003ook`0nQT00?Tc003aC000nc<00?XIfP3no`<0
0?oo06;ao`00o_nn0?TI003i<`00kd`00?/c003k6MX0oOl00>oo003nokh0nAT0
0?Tc003_C000nc<00?/IfP3mo`00kol00?ko_P3i6@00nC<00>m<003k<`00naWJ
0?go0P3oo`1dlOl00?ko_`3i6@00nS<1003lC0400?A<003l<`00nQWK0?go003_
o`00o_no0?TI003j<`400?a<0@00m4`00?`c003j6M/0oOl00>oo003nokl0nAT0
0?Xc0@00o4`1003dC000o3<00?XIf`3mo`80ool0N_7o003nol00nAT00?Xc003k
C080IVKm0?M<003l<`00naWK0?go003_o`00o_o00?TI003j<`00nd`206IVo@3g
C000o3<00?/If`3mo`00kol00?ko`03i6@00nS<00?]<0P1VI_d0md`00?`c003k
6M/0oOl20?oo08?ao`00o_o00?TI003l<`400?a<0@00nVKn0?U<0@00oS<00?/I
f`3mo`00kol00?ko`03i6@00o3<1003lC0400?YVoP3iC0400?hc003k6M/0oOl0
0>oo003nol00nAT00?`c0@00o4`1003jI_h0nD`1003n<`00naWK0?go0P3oo`1j
lOl00?ko`@3i6@00o3<00?]<003eIP00nD`00?dc003l6M/0oOl00>oo003nol40
nAT00?`c003kC000mFH00?U<003m<`00o1WK0?go003_o`00o_o10?TI003l<`00
nd`00?EV003iC000oC<00?`If`3mo`80ool0OO7o003nol80nAT00?`c003kC000
lfH1003kC000oC<00?/Ig03mo`00kol00?ko`P3i6@00o3<00?]<003cIP400?]<
003m<`00naWL0?go003_o`00o_o20?TI003l<`00nd`00?=V0@00nd`00?dc003k
6M`0oOl20?oo07gao`00o_o20?XI003l<`00o4`1003`IP00nd`00?hc003k6M`0
oOl00>oo003nol80nQT00?`c003lC0400?1V003kC000oS<00?/Ig03mo`00kol0
0?ko`P3j6@00o3<00?a<0@00l6H00?]<003n<`00naWL0?go0P3oo`2<lOl3003o
ol<0nAT00?dc003lC000nVH00?IV003kC000oC<00?`Ig03no`400>oo0`00ooo3
0?TI003m<`00o4`00?YV003fIP00nd`00?dc003l6M`0o_l1003_o`<00?oo``3i
6@00oC<00?a<003jIP00mVH00?]<003m<`00o1WL0?ko0`00ool0S?7o003nol<0
nQT00?dc003lC000nVH207l0mVH00?a<003m<`00o1WL0?go003_o`00o_o30?XI
003m<`00o4`00?YV0P1o0?IV003lC000oC<00?`Ig03mo`00kol00?ko``3j6@00
oC<00?a<003jIP80O`3fIP00o4`00?dc003l6M`0oOl20?oo09_ao`00o_o40?XI
003l<`00oT`1003kIP400?io0@00n6H00?a<003m<`00naWM0?go003_o`00o_o4
0?XI003l<`00oT`1003kIP400?io0@00n6H00?a<003m<`00naWM0?go003_o`00
o_o40?XI003l<`00oT`1003kIP400?io0@00n6H00?a<003m<`00naWM0?go0P3o
o`2BlOl00?koa@3j6@00o3<00?i<003jIP00nWl00?QV003mC000oC<00?/Ig@3m
o`00kol00?koa@3j6@00o3<00?i<003jIP00nWl00?QV003mC000oC<00?/Ig@3m
o`00kol00?koa@3j6@00o3<00?i<003jIP00nWl00?QV003mC000oC<00?/Ig@3m
o`80ool0V?7o003nolD0nQT00?dc003nC000nfH1003hO`400?UV003mC000oS<0
0?/Ig@3mo`00kol00?koa@3j6@00oC<00?i<003kIP400?Qo0@00nFH00?e<003n
<`00naWM0?go003_o`00o_o50?XI003m<`00oT`00?]V0@00n7l1003iIP00oD`0
0?hc003k6Md0oOl20?oo0:Cao`00o_o60?XI003m<`00oT`00?aV0@00ngl00?]o
0@00nfH00?e<003m<`00naWN0?go003_o`00o_o60?XI003m<`00oT`00?aV0@00
ngl00?]o0@00nfH00?e<003m<`00naWN0?go003_o`00o_o60?XI003m<`00oT`0
0?aV0@00ngl00?]o0@00nfH00?e<003m<`00naWN0?go0P3oo`2ZlOl00?koa`3j
6@00oC<00?i<003lIP00ngl2002IoP3lO`00nfH00?i<003m<`00naWN0?go003_
o`00o_o70?XI003m<`00oT`00?aV003kO`8009Wn0?ao003kIP00oT`00?dc003k
6Mh0oOl00>oo003nolL0nQT00?dc003nC000o6H00?]o0P00VOh0o7l00?]V003n
C000oC<00?/IgP3mo`80ool0]_7o003nolL0nQT00?dc003nC000oVH1003lO`40
0?^I0@00oGl1003mIP00oT`00?dc003k6Mh0oOl00>oo003nolL0nQT00?dc003n
C000oVH1003lO`400?^I0@00oGl1003mIP00oT`00?dc003k6Mh0oOl00>oo003n
olL0nQT00?dc003nC000oVH1003lO`400?^I0@00oGl1003mIP00oT`00?dc003k
6Mh0oOl20?oo0;3ao`<00?ooa`3k6@00oC<00?i<003nIP00ngl00?NI003mO`00
oFH00?i<003m<`00naWN0?ko0@00kol3003oolL0naT00?dc003nC000oVH00?]o
003gV@00oGl00?eV003nC000oC<00?/IgP3no`400>oo0`00ooo70?/I003m<`00
oT`00?iV003kO`00miT00?eo003mIP00oT`00?dc003k6Mh0o_l3003oo`2WlOl0
0?kob03k6@00o3<304a<0?iV003kO`00mYT00?eo003mIP00oT`00?dc003j6Ml0
oOl00>oo003nolP0naT00?`c0`1<C03nIP00ngl00?JI003mO`00oFH00?i<003m
<`00nQWO0?go003_o`00o_o80?/I003l<`<0C4`0oVH00?]o003fV@00oGl00?eV
003nC000oC<00?XIg`3mo`80ool0Yo7o003nolP0naT00?dc003nC0<0IVH0ngl0
0?BI003mO`00oVH00?i<003l<`00naWO0?go003_o`00o_o80?/I003m<`00oT`3
06IV0?]o003dV@00oGl00?iV003nC000o3<00?/Ig`3mo`00kol00?kob03k6@00
oC<00?i<0`1VIP3kO`00m9T00?eo003nIP00oT`00?`c003k6Ml0oOl20?oo0;?a
o`00o_o90?/I003m<`00oT`306IV0?]o003jV@00niT00?eo003nIP00oT`00?`c
003k6Ml0oOl00>oo003nolT0naT00?dc003nC0<0IVH0ngl00?ZI003kV@00oGl0
0?iV003nC000o3<00?/Ig`3mo`00kol00?kob@3k6@00oC<00?i<0`1VIP3kO`00
nYT00?^I003mO`00oVH00?i<003l<`00naWO0?go0P3oo`2ilOl00?kobP3j6@00
oC<00?i<0`1VIP3lO`00nYT20;<0o9T00?eo003nIP00oT`00?`c003j6N00oOl0
0>oo003nolX0nQT00?dc003nC0<0IVH0o7l00?ZI0P2c0?bI003mO`00oVH00?i<
003l<`00nQWP0?go003_o`00o_o:0?XI003m<`00oT`306IV0?ao003jV@80/`3l
V@00oGl00?iV003nC000o3<00?XIh03mo`80ool0aO7o003nol/0nQT00?dc003n
C0<0IVH0oGl1003kV@400?jc003lV@00oGl00?iV003nC000oC<00?XIh03mo`00
kol00?kob`3j6@00oC<00?i<0`1VIP3mO`400?^I0@00o[<00?bI003mO`00oVH0
0?i<003m<`00nQWP0?go003_o`00o_o;0?XI003m<`00oT`306IV0?eo0@00niT1
003n/`00o9T00?eo003nIP00oT`00?dc003j6N00oOl20?oo0;cao`00o_o<0?XI
003l<`H0C4`0IVH0oGl00?ZI003k/`00oIT00?eo003nIP00oT`00?dc003j6N00
oOl00>oo003nol`0nQT00?`c1P1<C01VIP3mO`00nYT00?^c003mV@00oGl00?iV
003nC000oC<00?XIh03mo`00kol00?koc03j6@00o3<604a<06IV0?eo003jV@00
nk<00?fI003mO`00oVH00?i<003m<`00nQWP0?go0P3oo`2olOl00?koc@3i6@00
oC<00?i<0P1V0?eo003kV@400?Vc003mV@00oWl00?iV003nC000o3<00?/Ih03m
o`00kol00?koc@3i6@00oC<00?i<0P1V0?eo003kV@400?Vc003mV@00oWl00?iV
003nC000o3<00?/Ih03mo`00kol00?koc@3i6@00oC<00?i<0P1V0?eo003kV@40
0?Vc003mV@00oWl00?iV003nC000o3<00?/Ih03mo`80ool0_o7o0`00ooo>0?TI
003l<`D0C4`0IP3mO`00o9T1003f/`00oYT00?eo0`1VIP3nC000o3<00?XIh@3n
o`400>oo0`00ooo>0?TI003l<`D0C4`0IP3mO`00o9T1003f/`00oYT00?eo0`1V
IP3nC000o3<00?XIh@3no`400>oo0`00ooo>0?TI003l<`D0C4`0IP3mO`00o9T1
003f/`00oYT00?eo0`1VIP3nC000o3<00?XIh@3no`<00?oo0;Kao`00o_o?0?TI
003l<`D0C4`0IP3mO`00o9T00?>c003nV@00oWl306IV0?i<003l<`00nQWQ0?go
003_o`00o_o?0?TI003l<`D0C4`0IP3mO`00o9T00?>c003nV@00oWl306IV0?i<
003l<`00nQWQ0?go003_o`00o_o?0?TI003l<`D0C4`0IP3mO`00o9T00?>c003n
V@00oWl306IV0?i<003l<`00nQWQ0?go0P3oo`35lOl00?koc`3i6@00o3<904a<
06H0Ogl00?fI0@00n;<00?bc003nV@00oWl306IV0?i<003l<`00nQWQ0?go003_
o`00o_o?0?TI003l<`T0C4`0IP1oO`00oIT1003h/`00o;<00?jI003nO`<0IVH0
oT`00?`c003j6N40oOl00>oo003noll0nAT00?`c2@1<C01V07mo003mV@400?Rc
003l/`00oYT00?io0`1VIP3nC000o3<00?XIh@3mo`80ool0aO7o003nom00nAT0
0?`c201<C01VIP1o0?bI003g/`80c03m/`00oYT00?io0`1VIP3mC000oC<00?TI
hP3mo`00kol00?kod03i6@00o3<804a<06IV07l0o9T00?Nc0P3<0?fc003nV@00
oWl306IV0?e<003m<`00nAWR0?go003_o`00o_o@0?TI003l<`P0C4`0IVH0O`3l
V@00mk<20<`0oK<00?jI003nO`<0IVH0oD`00?dc003i6N80oOl20?oo0<kao`00
o_oA0?PI003m<`00oT`506H0Ogl0o9T00?Vc1000c<`0o;<00?jI0`1oO`3nIP00
oT`00?`c003i6N<0oOl00>oo003nom40n1T00?dc003nC0D0IP1oO`3lV@00nK<4
003<c03l/`00oYT307mo0?iV003nC000o3<00?TIh`3mo`00kol00?kod@3h6@00
oC<00?i<1@1V07mo0?bI003i/`@00<c<0?bc003nV@<0Ogl0oVH00?i<003l<`00
nAWS0?go0P3oo`3Mmol00?co003nom40nAT00?dc003nC0H0IVH0Ogl0oIT00?Vc
003lc000oK<00?jI003nO`<0IVH0oT`00?`c003i6N<0oOl00?Go003lo`00o_oA
0?TI003m<`00oT`606IV07mo0?fI003i/`00o<`00?fc003nV@00oWl306IV0?i<
003l<`00nAWS0?go003eo`00o?l00?kod@3i6@00oC<00?i<1P1VIP1oO`3mV@00
nK<00?c<003m/`00oYT00?io0`1VIP3nC000o3<00?TIh`3mo`80ool0h?So0@00
o?l00?kodP3h6@00oC<00?i<1@1VIP1o0?bI003k/`400?_<003m/`00oYT00?io
0`1VIP3mC000oC<00?PIi03mo`00m_l1003lo`00o_oB0?PI003m<`00oT`506IV
07l0o9T00?^c0@00nl`00?fc003nV@00oWl306IV0?e<003m<`00n1WT0?go003f
o`400?co003nom80n1T00?dc003nC0D0IVH0O`3lV@00nk<1003kc000oK<00?jI
003nO`<0IVH0oD`00?dc003h6N@0oOl20?oo0>3go`00o?l00?kodP3i6@00oC<0
0?i<1P1VIP1oO`3mV@00o;<1003ic000oK<00?jI003nO`<0IVH0oD`00?dc003h
6N@0oOl00?Go003lo`00o_oB0?TI003m<`00oT`606IV07mo0?fI003l/`400?W<
003m/`00oYT00?io0`1VIP3mC000oC<00?PIi03mo`00mOl00?co003nom80nAT0
0?dc003nC0H0IVH0Ogl0oIT00?bc0@00nL`00?fc003nV@00oWl306IV0?e<003m
<`00n1WT0?go0P3oo`3Wmol00?co0`00oooC0?TI003m<`00oT`00?iV0`1oO`3n
V@00o;<00?K<003m/`00oYT307mo0?iV003nC000o3<00?PIi@01ooon0?Go003l
o`<00?ood`3i6@00oC<00?i<003nIP<0Ogl0oYT00?bc003fc000oK<00?jI0`1o
O`3nIP00oT`00?`c003h6ND00OoooP3eo`00o?l3003oom<0nAT00?dc003nC000
oVH307mo0?jI003l/`00m/`00?fc003nV@<0Ogl0oVH00?i<003l<`00n1WU007o
ooh00Ooo0>3go`00o?l00?koe03h6@00oC<00?i<003nIP80O`3mV@00o[<1003e
c000oK<00?jI0`1oO`3nIP00oT`00?`c003g6NH0oOl00?Go003lo`00o_oD0?PI
003m<`00oT`00?iV0P1o0?fI003n/`400?G<003m/`00oYT307mo0?iV003nC000
o3<00?LIiP3mo`00mOl00?co003nom@0n1T00?dc003nC000oVH207l0oIT00?jc
0@00mL`00?fc003nV@<0Ogl0oVH00?i<003l<`00maWV0?go0P3oo`3Pmol00?co
003nom@0nAT00?dc003nC000oVH307mo0?jI003n/`00l/`00?jc003nV@00oWl3
06IV0?e<003m<`00maWV0?go003eo`00o?l00?koe03i6@00oC<00?i<003nIP<0
Ogl0oYT00?jc003bc000o[<00?jI003nO`<0IVH0oD`00?dc003g6NH0oOl00?Go
003lo`00o_oD0?TI003m<`00oT`00?iV0`1oO`3nV@00o[<00?;<003n/`00oYT0
0?io0`1VIP3mC000oC<00?LIiP3mo`80ool0h?SooP3mo`00o_oE0?TI003m<`00
oD`00?iV0`1oO`3nV@00o[<00?;<003m/`00oYT307mo0?iV003nC000o3<00?LI
i`3mo`00m_on0?go003nomD0nAT00?dc003mC000oVH307mo0?jI003n/`00l/`0
0?fc003nV@<0Ogl0oVH00?i<003l<`00maWW0?go003fooh0oOl00?koe@3i6@00
oC<00?e<003nIP<0Ogl0oYT00?jc003bc000oK<00?jI0`1oO`3nIP00oT`00?`c
003g6NL0oOl20?oo0=Cao`00o_oF0?TI003m<`00oD`00?iV0`1oO`3nV@00o[<0
0?3<003n/`00oYT307mo0?iV003nC000o3<00?HIj03mo`00kol00?koeP3i6@00
oC<00?e<003nIP<0Ogl0oYT00?jc003`c000o[<00?jI0`1oO`3nIP00oT`00?`c
003f6NP0oOl00>oo003nomH0nAT00?dc003mC000oVH307mo0?jI003n/`00l<`0
0?jc003nV@<0Ogl0oVH00?i<003l<`00mQWX0?go0P3oo`3DlOl00?koeP3i6@00
oC<00?e<003nIP<0Ogl0oYT00?jc003`c000o[<00?jI0`1oO`3nIP00oT`00?`c
003f6NP0oOl00>oo003nomH0nAT00?dc003mC000oVH307mo0?jI003n/`00l<`0
0?jc003nV@<0Ogl0oVH00?i<003l<`00mQWX0?go003_o`00o_oF0?TI003m<`00
oD`00?iV0`1oO`3nV@00o[<00?3<003n/`00oYT307mo0?iV003nC000o3<00?HI
j03mo`80ool0f_7o003nomL0nAT00?`c003nC000oVH00?io003nV@00o[<00?3<
003n/`00oYT00?io003nIP00oT`00?`c003f6NT0oOl00>oo003nomL0nAT00?`c
003nC000oVH00?io003nV@00o[<00?3<003n/`00oYT00?io003nIP00oT`00?`c
003f6NT0oOl00>oo003nomL0nAT00?`c003nC000oVH00?io003nV@00o[<00?3<
003n/`00oYT00?io003nIP00oT`00?`c003f6NT0oOl20?oo0>3ao`00o_oH0?TI
003l<`00oT`00?eV0`1oO`3nV@00o[<00?C<003lc000o[<00?jI0`1oO`3nIP00
oT`00?/c003g6NT0oOl00>oo003nomP0nAT00?`c003nC000oFH307mo0?jI003n
/`00m<`00?c<003n/`00oYT307mo0?iV003nC000nc<00?LIj@3mo`00kol00?ko
f03i6@00o3<00?i<003mIP<0Ogl0oYT00?jc003dc000o<`00?jc003nV@<0Ogl0
oVH00?i<003k<`00maWY0?go0P3oo`3_lOl3003oomP0nQT00?`c003mC000oVH0
0?io003nV@00o[<00?G<0P3V0?g<003n/`00oYT307mo0?iV003mC000o3<00?HI
jP3no`400>oo0`00oooH0?XI003l<`00oD`00?iV003nO`00oYT00?jc003ec080
iP3mc000o[<00?jI0`1oO`3nIP00oD`00?`c003f6NX0o_l1003_o`<00?oof03j
6@00o3<00?e<003nIP00oWl00?jI003n/`00mL`20>H0oL`00?jc003nV@<0Ogl0
oVH00?e<003l<`00mQWZ0?ko0`00ool0ko7o003nomT0nAT00?`c003nC000oVH0
0?io003mV@00o[<00?K<0`3ViP3mc000o[<00?jI003nO`00oVH00?i<003k<`00
maWZ0?go003_o`00o_oI0?TI003l<`00oT`00?iV003nO`00oIT00?jc003fc0<0
i^H0oL`00?jc003nV@00oWl00?iV003nC000nc<00?LIjP3mo`00kol00?kof@3i
6@00o3<00?i<003nIP00oWl00?fI003n/`00m/`30>KV0?g<003n/`00oYT00?io
003nIP00oT`00?/c003g6NX0oOl20?oo0?;ao`00o_oJ0?TI003l<`00oD`00?iV
003nO`00oYT00?jc003gc0400?kV003lc000o[<00?jI0`1oO`3nIP00oD`00?/c
003g6N/0oOl00>oo003nomX0nAT00?`c003mC000oVH00?io003nV@00o[<00?O<
0@00o^H00?c<003n/`00oYT307mo0?iV003mC000nc<00?LIj`3mo`00kol00?ko
fP3i6@00o3<00?e<003nIP00oWl00?jI003n/`00ml`1003niP00o<`00?jc003n
V@<0Ogl0oVH00?e<003k<`00maW[0?go0P3oo`3blOl00?kofP3j6@00nc<00?i<
003nIP00oWl00?fI003n/`00n<`00?_V003mc000o[<00?jI003nO`00oVH00?i<
003k<`00maW[0?go003_o`00o_oJ0?XI003k<`00oT`00?iV003nO`00oIT00?jc
003hc000nnH00?g<003n/`00oYT00?io003nIP00oT`00?/c003g6N/0oOl00>oo
003nomX0nQT00?/c003nC000oVH00?io003mV@00o[<00?S<003kiP00oL`00?jc
003nV@00oWl00?iV003nC000nc<00?LIj`3mo`80ool0mO7o003nom/0nQT00?/c
003nC000oFH00?io003mV@00o[<00?[<0@00n^H00?g<003n/`00oYT00?io003n
IP00oD`00?/c003h6N/0oOl00>oo003nom/0nQT00?/c003nC000oFH00?io003m
V@00o[<00?[<0@00n^H00?g<003n/`00oYT00?io003nIP00oD`00?/c003h6N/0
oOl00>oo003nom/0nQT00?/c003nC000oFH00?io003mV@00o[<00?[<0@00n^H0
0?g<003n/`00oYT00?io003nIP00oD`00?/c003h6N/0oOl20?oo0?;ao`00o_oL
0?XI003k<`00oD`00?iV003mO`00oYT00?jc003jc000mnH00?g<003n/`00oYT0
0?io003nIP00oT`00?/c003g6N`0oOl00>oo003nom`0nQT00?/c003mC000oVH0
0?eo003nV@00o[<00?[<003giP00oL`00?jc003nV@00oWl00?iV003nC000nc<0
0?LIk03mo`00kol00?kog03j6@00nc<00?e<003nIP00oGl00?jI003n/`00n/`0
0?OV003mc000o[<00?jI003nO`00oVH00?i<003k<`00maW/0?go0P3oo`3blOl0
0?kog03j6@00nc<00?i<003nIP00oGl00?fI003n/`00nl`00?KV003mc000o[<0
0?jI003nO`00oVH00?e<003k<`00n1W/0?go003_o`00o_oL0?XI003k<`00oT`0
0?iV003mO`00oIT00?jc003kc000m^H00?g<003n/`00oYT00?io003nIP00oD`0
0?/c003h6N`0oOl00>oo003nom`0nQT00?/c003nC000oVH00?eo003mV@00o[<0
0?_<003fiP00oL`00?jc003nV@00oWl00?iV003mC000nc<00?PIk03mo`80ool0
no7o0`00oooM0?TI003l<`00oD`00?iV003mO`00oIT00?jc003mc0400?GV003m
c000o[<00?jI003nO`00oVH00?e<003k<`00n1W/0?ko0@00kol3003oomd0nAT0
0?`c003mC000oVH00?eo003mV@00o[<00?g<0@00mNH00?g<003n/`00oYT00?io
003nIP00oD`00?/c003h6N`0o_l1003_o`<00?oog@3i6@00o3<00?e<003nIP00
oGl00?fI003n/`00oL`1003eiP00oL`00?jc003nV@00oWl00?iV003mC000nc<0
0?PIk03no`<00?oo0?;ao`00o_oN0?TI003l<`00oD`00?iV003mO`00oIT00?jc
003lc000lnH00?g<003n/`00oYT00?io003nIP00oD`00?/c003h6Nd0oOl00>oo
003nomh0nAT00?`c003mC000oVH00?eo003mV@00o[<00?c<003ciP00oL`00?jc
003nV@00oWl00?iV003mC000nc<00?PIk@3mo`00kol00?kogP3i6@00o3<00?e<
003nIP00oGl00?fI003n/`00o<`00??V003mc000o[<00?jI003nO`00oVH00?e<
003k<`00n1W]0?go0P3oo`3blOl00?kogP3i6@00o3<00?e<003nIP00oGl00?fI
003n/`00o<`00??V003mc000o[<00?jI003nO`00oVH00?e<003k<`00n1W]0?go
003_o`00o_oN0?TI003l<`00oD`00?iV003mO`00oIT00?jc003lc000lnH00?g<
003n/`00oYT00?io003nIP00oD`00?/c003h6Nd0oOl00>oo003nomh0nAT00?`c
003mC000oVH00?eo003mV@00o[<00?c<003ciP00oL`00?jc003nV@00oWl00?iV
003mC000nc<00?PIk@3mo`80ool0l_7o003noml0nAT00?`c003mC000oVH00?eo
003lV@00o[<00?c<003biP00oL`00?jc003nV@00oWl00?iV003mC000o3<00?PI
k@3mo`00kol00?kog`3i6@00o3<00?e<003nIP00oGl00?bI003n/`00o<`00?;V
003mc000o[<00?jI003nO`00oVH00?e<003l<`00n1W]0?go003_o`00o_oO0?TI
003l<`00oD`00?iV003mO`00o9T00?jc003lc000l^H00?g<003n/`00oYT00?io
003nIP00oD`00?`c003h6Nd0oOl20?oo0?;ao`00o_oP0?TI003l<`00oD`00?eV
003mO`00oIT00?fc003lc000l^H00?g<003n/`00oYT00?io003nIP00o4`00?`c
003i6Nd0oOl00>oo003non00nAT00?`c003mC000oFH00?eo003mV@00oK<00?c<
003biP00oL`00?jc003nV@00oWl00?iV003lC000o3<00?TIk@3mo`00kol00?ko
h03i6@00o3<00?e<003mIP00oGl00?fI003m/`00o<`00?;V003mc000o[<00?jI
003nO`00oVH00?a<003l<`00nAW]0?go0P3oo`3blOl00?koh@3i6@00o3<00?a<
003mIP00oGl00?fI003n/`00o<`00?3V003nc000oK<00?jI003nO`00oVH00?a<
003m<`00n1W^0?go003_o`00o_oQ0?TI003l<`00o4`00?eV003mO`00oIT00?jc
003lc000l>H00?k<003m/`00oYT00?io003nIP00o4`00?dc003h6Nh0oOl00>oo
003non40nAT00?`c003lC000oFH00?eo003mV@00o[<00?c<003`iP00o/`00?fc
003nV@00oWl00?iV003lC000oC<00?PIkP3mo`80ool0l_7o003non40nAT00?dc
003lC000oFH00?eo003lV@00o[<00?c<003`iP00oL`00?jc003nV@00oWl00?iV
003kC000oS<00?PIkP3mo`00kol00?koh@3i6@00oC<00?a<003mIP00oGl00?bI
003n/`00o<`00?3V003mc000o[<00?jI003nO`00oVH00?]<003n<`00n1W^0?go
003_o`00o_oQ0?TI003m<`00o4`00?eV003mO`00o9T00?jc003lc000l>H00?g<
003n/`00oYT00?io003nIP00nd`00?hc003h6Nh0oOl20?oo0>oao`00o_oR0?TI
003m<`00nd`00?eV003mO`00o9T00?jc003lc000l>H00?g<003n/`00oYT00?eo
0`1VIP3kC000oS<00?PIkP3mo`00kol00?kohP3i6@00oC<00?]<003mIP00oGl0
0?bI003n/`00o<`00?3V003mc000o[<00?jI003mO`<0IVH0nd`00?hc003h6Nh0
oOl00>oo003non80nAT00?dc003kC000oFH00?eo003lV@00o[<00?c<003`iP00
oL`00?jc003nV@00oGl306IV0?]<003n<`00n1W^0?go0P3oo`3hlOl3003oon<0
nAT00?`c003lC000oFH00?ao003lV@00o[<00?c<003_iP00oL`00?jc003nV@00
oWl00?iV003lC000oC<00?TIkP3no`400>oo0`00oooS0?TI003l<`00o4`00?eV
003lO`00o9T00?jc003lc000knH00?g<003n/`00oYT00?io003nIP00o4`00?dc
003i6Nh0o_l1003_o`<00?ooh`3i6@00o3<00?a<003mIP00o7l00?bI003n/`00
o<`00>oV003mc000o[<00?jI003nO`00oVH00?a<003m<`00nAW^0?ko0`00ool0
l_7o003non@0n1T00?dc003lC000o6H00?eo003lV@00oK<00?c<003_iP00oL`0
0?jc003nV@00oWl00?iV003lC000oC<00?TIkP3mo`00kol00?koi03h6@00oC<0
0?a<003lIP00oGl00?bI003m/`00o<`00>oV003mc000o[<00?jI003nO`00oVH0
0?a<003m<`00nAW^0?go003_o`00o_oT0?PI003m<`00o4`00?aV003mO`00o9T0
0?fc003lc000knH00?g<003n/`00oYT00?io003nIP00o4`00?dc003i6Nh0oOl2
0?oo0?kao`00o_oT0?TI003l<`00o4`00?eV003lO`00o9T00?jc003lc000mNH0
0?[V003mc000o[<00?jI003nO`00oVH00?a<003n<`00n1W_0?go003_o`00o_oT
0?TI003l<`00o4`00?eV003lO`00o9T00?jc003lc000mNH00?[V003mc000o[<0
0?jI003nO`00oVH00?a<003n<`00n1W_0?go003_o`00o_oT0?TI003l<`00o4`0
0?eV003lO`00o9T00?jc003lc000mNH00?[V003mc000o[<00?jI003nO`00oVH0
0?a<003n<`00n1W_0?go0P3oo`44lOl00?koi@3i6@00nc<00?e<003lIP00o7l0
0?bI003n/`00o<`00?KV0P3o0?_V003mc000o[<00?jI003nO`00oVH00?a<003m
<`00nAW_0?go003_o`00o_oU0?TI003k<`00oD`00?aV003lO`00o9T00?jc003l
c000m^H20?l0nnH00?g<003n/`00oYT00?io003nIP00o4`00?dc003i6Nl0oOl0
0>oo003nonD0nAT00?/c003mC000o6H00?ao003lV@00o[<00?c<003fiP80o`3k
iP00oL`00?jc003nV@00oWl00?iV003lC000oC<00?TIk`3mo`80ool12_7o003n
onH0nAT00?/c003mC000o6H00?ao003kV@00o[<00?c<003giP00o_l00?_V003m
c000o[<00?jI003nO`00oVH00?e<003m<`00nAW_0?go003_o`00o_oV0?TI003k
<`00oD`00?aV003lO`00niT00?jc003lc000mnH00?ko003kiP00oL`00?jc003n
V@00oWl00?iV003mC000oC<00?TIk`3mo`00kol00?koiP3i6@00nc<00?e<003l
IP00o7l00?^I003n/`00o<`00?OV003no`00nnH00?g<003n/`00oYT00?io003n
IP00oD`00?dc003i6Nl0oOl20?oo0@gao`00o_oV0?TI003k<`00oD`00?aV003l
O`00niT00?jc003lc000nNH1003mo`00nnH00?g<003n/`00oYT00?io003nIP00
oD`00?dc003i6Nl0oOl00>oo003nonH0nAT00?/c003mC000o6H00?ao003kV@00
o[<00?c<003iiP400?go003kiP00oL`00?jc003nV@00oWl00?iV003mC000oC<0
0?TIk`3mo`00kol00?koiP3i6@00nc<00?e<003lIP00o7l00?^I003n/`00o<`0
0?WV0@00oOl00?_V003mc000o[<00?jI003nO`00oVH00?e<003m<`00nAW_0?go
0P3oo`47lOl00?koi`3i6@00nc<00?e<003lIP00ngl00?^I003n/`00o<`00?WV
003ko`00nnH00?g<003n/`00oYT307mo0?iV003mC000oC<00?TIk`3mo`00kol0
0?koi`3i6@00nc<00?e<003lIP00ngl00?^I003n/`00o<`00?WV003ko`00nnH0
0?g<003n/`00oYT307mo0?iV003mC000oC<00?TIk`3mo`00kol00?koi`3i6@00
nc<00?e<003lIP00ngl00?^I003n/`00o<`00?WV003ko`00nnH00?g<003n/`00
oYT307mo0?iV003mC000oC<00?TIk`3mo`80ool12_7o003nonL0nQT00?/c003n
C0400?]V003kO`00niT00?fc003mc000nNH00?_o003kiP00oL`00?jc003nV@<0
Ogl0oVH00?e<003m<`00nAW_0?go003_o`00o_oW0?XI003k<`00oT`1003kIP00
ngl00?^I003m/`00oL`00?WV003ko`00nnH00?g<003n/`00oYT307mo0?iV003m
C000oC<00?TIk`3mo`00kol00?koi`3j6@00nc<00?i<0@00nfH00?]o003kV@00
oK<00?g<003iiP00nol00?_V003mc000o[<00?jI0`1oO`3nIP00oD`00?dc003i
6Nl0oOl20?oo0@gao`<00?ooj03i6@00o3<00?i<003iIP00ngl00?ZI003n/`00
o<`00?_V003io`00nnH00?g<0`2c/`3nV@00oWl00?iV003nC000oC<00?TIk`3n
o`400>oo0`00oooX0?TI003l<`00oT`00?UV003kO`00nYT00?jc003lc000nnH0
0?Wo003kiP00oL`30;>c0?jI003nO`00oVH00?i<003m<`00nAW_0?ko0@00kol3
003oonP0nAT00?`c003nC000nFH00?]o003jV@00o[<00?c<003kiP00nOl00?_V
003mc0<0/k<0oYT00?io003nIP00oT`00?dc003i6Nl0o_l3003oo`47lOl00?ko
j@3i6@00nc<00?i<003jIP00nWl00?ZI003n/`00o<`00?_V003io`00nnH00?g<
003n/`00oYT307mo0?iV003nC000oC<00?TIk`3mo`00kol00?koj@3i6@00nc<0
0?i<003jIP00nWl00?ZI003n/`00o<`00?_V003io`00nnH00?g<003n/`00oYT3
07mo0?iV003nC000oC<00?TIk`3mo`00kol00?koj@3i6@00nc<00?i<003jIP00
nWl00?ZI003n/`00o<`00?_V003io`00nnH00?g<003n/`00oYT307mo0?iV003n
C000oC<00?TIk`3mo`80ool11o7o003nonT0nQT00?/c003nC000nFH00?Yo003j
V@00o[<00?c<003kiP00n?l00?_V003nc000o[<00?jI0`1oO`3nIP00oT`00?dc
003i6Nl0oOl00>oo003nonT0nQT00?/c003nC000nFH00?Yo003jV@00o[<00?c<
003kiP00n?l00?_V003nc000o[<00?jI0`1oO`3nIP00oT`00?dc003i6Nl0oOl0
0>oo003nonT0nQT00?/c003nC000nFH00?Yo003jV@00o[<00?c<003kiP00n?l0
0?_V003nc000o[<00?jI0`1oO`3nIP00oT`00?dc003i6Nl0oOl20?oo0@Cao`00
o_oZ0?TI003l<`00oD`00?UV003iO`00niT00?fc003mc000nnH00?Oo003liP00
oL`30;>c0?jI0`1oO`3nIP00oT`00?hc003i6Nh0oOl00>oo003nonX0nAT00?`c
003mC000nFH00?Uo003kV@00oK<00?g<003kiP00mol00?cV003mc0<0/k<0oYT3
07mo0?iV003nC000oS<00?TIkP3mo`00kol00?kojP3i6@00o3<00?e<003iIP00
nGl00?^I003m/`00oL`00?_V003go`00o>H00?g<0`2c/`3nV@<0Ogl0oVH00?i<
003n<`00nAW^0?go0P3oo`44lOl00?kojP3j6@00nc<00?e<003jIP00n7l00?^I
003m/`00oL`00?_V003go`00nnH00?k<003n/`H0VIT0Ogl0oVH00?i<003n<`00
nAW^0?go003_o`00o_oZ0?XI003k<`00oD`00?YV003hO`00niT00?fc003mc000
nnH00?Oo003kiP00o/`00?jc1P2IV@1oO`3nIP00oT`00?hc003i6Nh0oOl00>oo
003nonX0nQT00?/c003mC000nVH00?Qo003kV@00oK<00?g<003kiP00mol00?_V
003nc000o[<609VI07mo0?iV003nC000oS<00?TIkP3mo`80ool14?Oo0@00oOl0
0?koj`3i6@00o3<00?e<003iIP00n7l00?ZI003n/`00o<`00?gV003eo`00nnH0
0?k<1P2c/`2IV@3nO`00oVH304a<0?hc003i6Nh0oOl00?Go0@00oOl00?koj`3i
6@00o3<00?e<003iIP00n7l00?ZI003n/`00o<`00?gV003eo`00nnH00?k<1P2c
/`2IV@3nO`00oVH304a<0?hc003i6Nh0oOl00?Go0@00oOl00?koj`3i6@00o3<0
0?e<003iIP00n7l00?ZI003n/`00o<`00?gV003eo`00nnH00?k<1P2c/`2IV@3n
O`00oVH304a<0?hc003i6Nh0oOl20?oo0AKho`<0ool0o_l00?kok03i6@00o3<0
0?a<003iIP00n7l00?ZI003m/`00oL`00?gV003eo`00nnH00?k<0`2c/`3nV@<0
Ogl0oVH304a<0?hc003i6Nh0oOl00?Ko0`3oo`3no`00o_o/0?TI003l<`00o4`0
0?UV003hO`00nYT00?fc003mc000oNH00?Go003kiP00o/`30;>c0?jI0`1oO`3n
IP<0C4`0oS<00?TIkP3mo`00m_l30?oo0?ko003non`0nAT00?`c003lC000nFH0
0?Qo003jV@00oK<00?g<003miP00mOl00?_V003nc0<0/k<0oYT307mo0?iV0`1<
C03n<`00nAW^0?go0P3oo`4Cn?l30?oo0?ko003nond0nAT00?`c003lC000nFH0
0?Mo003jV@00oK<00?g<003miP00m?l00?_V003nc0T0/k<0VIT0Ogl0oVH304a<
0?hc003i6Nh0oOl00?Ko0`3oo`3no`00o_o]0?TI003l<`00o4`00?UV003gO`00
nYT00?fc003mc000oNH00?Co003kiP00o/`90;>c09VI07mo0?iV0`1<C03n<`00
nAW^0?go003fo`<0ool0o_l00?kok@3i6@00o3<00?a<003iIP00mgl00?ZI003m
/`00oL`00?gV003do`00nnH00?k<2@2c/`2IV@1oO`3nIP<0C4`0oS<00?TIkP3m
o`80ool16_So0`3oo`3no`<00?ookP3h6@00o3<00?a<003iIP00mgl00?ZI003m
/`00oL`00?gV003do`00nnH00?k<2@2c/`2IV@1oO`3nIP<0C4`0oS<00?TIkP01
ooon0?Ko0`3oo`3no`<00?ookP3h6@00o3<00?a<003iIP00mgl00?ZI003m/`00
oL`00?gV003do`00nnH00?k<2@2c/`2IV@1oO`3nIP<0C4`0oS<00?TIkP01ooon
0?Ko0`3oo`3no`<00?ookP3h6@00o3<00?a<003iIP00mgl00?ZI003m/`00oL`0
0?gV003do`00nnH00?k<2@2c/`2IV@1oO`3nIP<0C4`0oS<00?TIkP01ooon007o
o`4Cn?l30?oo0?ko003nonl0n1T00?`c003lC000mfH00?Mo003jV@00o[<00?g<
003miP00m?l00?_V003nc0T0/k<0VIT0Ogl0oVH304a<0?hc003i6Nh0oOl00?Ko
0`3oo`3no`00o_o_0?PI003l<`00o4`00?MV003gO`00nYT00?jc003mc000oNH0
0?Co003kiP00o/`90;>c09VI07mo0?iV0`1<C03n<`00nAW^0?go003fo`<0ool0
o_l00?kok`3h6@00o3<00?a<003gIP00mgl00?ZI003n/`00oL`00?gV003do`00
nnH00?k<2@2c/`2IV@1oO`3nIP<0C4`0oS<00?TIkP3mo`80ool14oSo0`3oo`3n
o`00o_o_0?TI003l<`00o4`00?IV003gO`00nYT00?jc003mc000oNH00?Co003k
iP00o/`90;>c09VI07mo0?iV0`1<C03n<`00nQW]0?go003fo`<0ool0o_l00?ko
k`3i6@00o3<00?a<003fIP00mgl00?ZI003n/`00oL`00?gV003do`00nnH00?k<
2@2c/`2IV@1oO`3nIP<0C4`0oS<00?XIk@3mo`00m_l30?oo0?ko003nonl0nAT0
0?`c003lC000mVH00?Mo003jV@00o[<00?g<003miP00m?l00?_V003nc0T0/k<0
VIT0Ogl0oVH304a<0?hc003j6Nd0oOl20?oo0@ggo`400?go003noo00nAT00?`c
003kC000mFH00?Mo003kV@00oK<00?k<003miP00m?l00?_V003nc0P0/k<0V@1o
O`3nIP00oT`00?hc003j6Nd0oOl00?Go0@00oOl00?kol03i6@00o3<00?]<003e
IP00mgl00?^I003m/`00o/`00?gV003do`00nnH00?k<202c/`2I07mo0?iV003n
C000oS<00?XIk@3mo`00mOl1003mo`00o_o`0?TI003l<`00nd`00?EV003gO`00
niT00?fc003nc000oNH00?Co003kiP00o/`80;>c09T0Ogl0oVH00?i<003n<`00
nQW]0?go0P3oo`3nlOl00?kol03i6@00o3<00?a<003dIP00mgl00?ZI003n/`00
o/`00?gV003do`00nnH00?k<202c/`2I07mo0?iV003nC000oS<00?XIk@3mo`00
kol00?kol03i6@00o3<00?a<003dIP00mgl00?ZI003n/`00o/`00?gV003do`00
nnH00?k<202c/`2I07mo0?iV003nC000oS<00?XIk@3mo`00kol00?kol03i6@00
o3<00?a<003dIP00mgl00?ZI003n/`00o/`00?gV003do`00nnH00?k<202c/`2I
07mo0?iV003nC000oS<00?XIk@3mo`80ool0no7o003noo40nAT00?`c003kC000
m6H00?Io003kV@00o[<00?k<003miP00m?l00?_V003nc0P0/k<0V@1oO`3nIP<0
C4`0oC<00?XIk@3mo`00kol00?kol@3i6@00o3<00?]<003dIP00mWl00?^I003n
/`00o/`00?gV003do`00nnH00?k<202c/`2I07mo0?iV0`1<C03m<`00nQW]0?go
003_o`00o_oa0?TI003l<`00nd`00?AV003fO`00niT00?jc003nc000oNH00?Co
003kiP00o/`80;>c09T0Ogl0oVH304a<0?dc003j6Nd0oOl20?oo0?_ao`00o_ob
0?TI003l<`00nd`00?9V003fO`00o9T00?jc003nc000oNH00??o003liP00o/`8
0;>c09T0Ogl0oVH304a<0?hc003j6N`0oOl00>oo003noo80nAT00?`c003kC000
lVH00?Io003lV@00o[<00?k<003miP00lol00?cV003nc0P0/k<0V@1oO`3nIP<0
C4`0oS<00?XIk03mo`00kol00?kolP3i6@00o3<00?]<003bIP00mWl00?bI003n
/`00o/`00?gV003co`00o>H00?k<202c/`2I07mo0?iV0`1<C03n<`00nQW/0?go
0P3oo`3hlOl00?kolP3j6@00o3<00?]<003aIP00mWl00?^I0`2c/`3nc000oNH0
0??o003liP00o/`80;>c09T0Ogl0oVH304a<0?hc003j6N`0oOl00>oo003noo80
nQT00?`c003kC000lFH00?Io003kV@<0/k<0o/`00?gV003co`00o>H00?k<202c
/`2I07mo0?iV0`1<C03n<`00nQW/0?go003_o`00o_ob0?XI003l<`00nd`00?5V
003fO`00niT30;>c0?k<003miP00lol00?cV003nc0P0/k<0V@1oO`3nIP<0C4`0
oS<00?XIk03mo`80ool0o_7o0`00oooc0?TI003l<`00nd`00?1V003fO`00o9T0
0?jc0`3<c03miP00lol00?cV003nc0L0/k<007mo0?iV003nC000oS<00?XIk03n
o`400>oo0`00oooc0?TI003l<`00nd`00?1V003fO`00o9T00?jc0`3<c03miP00
lol00?cV003nc0L0/k<007mo0?iV003nC000oS<00?XIk03no`400>oo0`00oooc
0?TI003l<`00nd`00?1V003fO`00o9T00?jc0`3<c03miP00lol00?cV003nc0L0
/k<007mo0?iV003nC000oS<00?XIk03no`<00?oo0?Sao`00o_oc0?TI003m<`00
nd`00>mV003fO`00o9T00?jc0`3<c03miP00lol00?cV003nc0L0/k<007mo0?iV
003nC000oS<00?/Ij`3mo`00kol00?kol`3i6@00oC<00?]<003_IP00mWl00?bI
003n/`<0c<`0oNH00??o003liP00o/`70;>c001oO`3nIP00oT`00?hc003k6N/0
oOl00>oo003noo<0nAT00?dc003kC000kfH00?Io003lV@00o[<30<c<0?gV003c
o`00o>H00?k<1`2c/`00Ogl0oVH00?i<003n<`00naW[0?go0P3oo`3elOl00?ko
m03i6@00oC<00?]<003]IP00mWl00?bI1P2c/`3<c03miP00lol00?cV003nc0L0
/k<007mo0?iV003nC000oS<00?/Ij`3mo`00kol00?kom03i6@00oC<00?]<003]
IP00mWl00?bI1P2c/`3<c03miP00lol00?cV003nc0L0/k<007mo0?iV003nC000
oS<00?/Ij`3mo`00kol00?kom03i6@00oC<00?]<003]IP00mWl00?bI1P2c/`3<
c03miP00lol00?cV003nc0L0/k<007mo0?iV003nC000oS<00?/Ij`3mo`80ool0
mO7o003noo@0nAT00?dc003kC000kFH00?Io003lV@H0/k<0c<`0oNH00??o003l
iP00o/`70;>c001oO`3nIP00oT`00?hc003k6N/0oOl00>oo003noo@0nAT00?dc
003kC000kFH00?Io003lV@H0/k<0c<`0oNH00??o003liP00o/`70;>c001oO`3n
IP00oT`00?hc003k6N/0oOl00>oo003noo@0nAT00?dc003kC000kFH00?Io003l
V@H0/k<0c<`0oNH00??o003liP00o/`70;>c001oO`3nIP00oT`00?hc003k6N/0
oOl20?oo0?Sao`00o_oe0?TI003m<`00nd`00>]V0@00n7l00?bI1P2c/`3<c03m
iP00m?l00?cV003nc0/0/k<0V@1oO`1VIP3nC000oS<00?/IjP3mo`00kol00?ko
m@3i6@00oC<00?]<003[IP400?Qo003lV@H0/k<0c<`0oNH00?Co003liP00o/`;
0;>c09T0Ogl0IVH0oT`00?hc003k6NX0oOl00>oo003nooD0nAT00?dc003kC000
jfH1003hO`00o9T60;>c0<c<0?gV003do`00o>H00?k<2`2c/`2I07mo06IV0?i<
003n<`00naWZ0?go0P3oo`3elOl00?komP3i6@00o3<00?a<003XIP00nGl00?bI
1P2c/`3<c03miP00m?l00?cV003nc0L0/k<0V@1o0?iV003nC000oS<00?/IjP3m
o`00kol00?komP3i6@00o3<00?a<003XIP00nGl00?bI1P2c/`3<c03miP00m?l0
0?cV003nc0L0/k<0V@1o0?iV003nC000oS<00?/IjP3mo`00kol00?komP3i6@00
o3<00?a<003XIP00nGl00?bI1P2c/`3<c03miP00m?l00?cV003nc0L0/k<0V@1o
0?iV003nC000oS<00?/IjP3mo`80ool0mO7o003nooH0nAT00?dc003kC000j6H0
0?Uo003lV@H0/k<0c<`0o>H00?Ko003liP00o/`;0;>c09VI07l0IVH0oT`00?dc
003k6NX0oOl00>oo003nooH0nAT00?dc003kC000j6H00?Uo003lV@H0/k<0c<`0
o>H00?Ko003liP00o/`;0;>c09VI07l0IVH0oT`00?dc003k6NX0oOl00>oo003n
ooH0nAT00?dc003kC000j6H00?Uo003lV@H0/k<0c<`0o>H00?Ko003liP00o/`;
0;>c09VI07l0IVH0oT`00?dc003k6NX0oOl20?oo0?Gao`00o_og0?TI003m<`00
nd`00>MV003iO`00o9T60;>c0<c<0?cV003fo`00oNH00?g<2`2c/`2I07mo06IV
0?i<003n<`00naWY0?go003_o`00o_og0?TI003m<`00nd`00>MV003iO`00o9T6
0;>c0<c<0?cV003fo`00oNH00?g<2`2c/`2I07mo06IV0?i<003n<`00naWY0?go
003_o`00o_og0?TI003m<`00nd`00>MV003iO`00o9T60;>c0<c<0?cV003fo`00
oNH00?g<2`2c/`2I07mo06IV0?i<003n<`00naWY0?go0P3oo`3klOl3003oooP0
n1T00?dc003kC000iVH00?Yo003lV@H0/k<0c<`0o>H00?Oo003liP00o/`00?jc
2`2I07mo06IV04a<0?dc003k6NT0o_l1003_o`<00?oon03h6@00oC<00?]<003V
IP00nWl00?bI1P2c/`3<c03liP00mol00?cV003nc000o[<;09T0Ogl0IVH0C4`0
oC<00?/Ij@3no`400>oo0`00oooh0?PI003m<`00nd`00>IV003jO`00o9T60;>c
0<c<0?cV003go`00o>H00?k<003n/`/0V@1oO`1VIP1<C03m<`00naWY0?ko0`00
ool0n?7o003nooP0nAT00?dc003kC000iFH00?Uo003nV@<0/k<0oL`00?gV003h
o`00o>H00?k<003n/`/0VIT0O`1VIP1<C03l<`00naWY0?go003_o`00o_oh0?TI
003m<`00nd`00>EV003iO`00oYT30;>c0?g<003miP00n?l00?cV003nc000o[<;
09VI07l0IVH0C4`0o3<00?/Ij@3mo`00kol00?kon03i6@00oC<00?]<003UIP00
nGl00?jI0`2c/`3mc000oNH00?So003liP00o/`00?jc2`2IV@1o06IV04a<0?`c
003k6NT0oOl20?oo0?Sao`00o_oi0?TI003l<`00o4`00>=V003jO`00oYT30;>c
0?g<003miP00n?l00?cV003nc000o[<;09T0Ogl0IVH0C4`0oC<00?/Ij03mo`00
kol00?kon@3i6@00o3<00?a<003SIP00nWl00?jI0`2c/`3mc000oNH00?So003l
iP00o/`00?jc2`2I07mo06IV04a<0?dc003k6NP0oOl00>oo003nooT0nAT00?`c
003lC000hfH00?Yo003nV@<0/k<0oL`00?gV003ho`00o>H00?k<003n/`/0V@1o
O`1VIP1<C03m<`00naWX0?go0P3oo`3hlOl00?kon@3i6@00oC<00?]<003SIP00
nWl00?jI0`2c/`3mc000o>H00?[o003liP00o/`00?jc2`2IV@1oO`1V04a<0?`c
003k6NP0oOl00>oo003nooT0nAT00?dc003kC000hfH00?Yo003nV@<0/k<0oL`0
0?cV003jo`00o>H00?k<003n/`/0VIT0Ogl0IP1<C03l<`00naWX0?go003_o`00
o_oi0?TI003m<`00nd`00>=V003jO`00oYT30;>c0?g<003liP00n_l00?cV003n
c000o[<;09VI07mo06H0C4`0o3<00?/Ij03mo`80ool0n?7o003nooX0nAT00?`c
003lC000hVH00?Yo003nV@<0/k<0oL`00?cV003jo`00o>H00?k<003n/`/0VIT0
O`1VIP1<C03l<`00naWX0?go003_o`00o_oj0?TI003l<`00o4`00>9V003jO`00
oYT30;>c0?g<003liP00n_l00?cV003nc000o[<;09VI07l0IVH0C4`0o3<00?/I
j03mo`00kol00?konP3i6@00o3<00?a<003RIP00nWl00?jI0`2c/`3mc000o>H0
0?[o003liP00o/`00?jc2`2IV@1o06IV04a<0?`c003k6NP0oOl20?oo0?Sao`00
o_ok0?TI003l<`00o4`00>1V003kO`00oYT30;>c0?g<003liP00nol00?cV003n
c000o[<;09VI07mo06H0C4`0o3<00?/Ii`3mo`00kol00?kon`3i6@00o3<00?a<
003PIP00ngl00?jI0`2c/`3mc000o>H00?_o003liP00o/`00?jc2`2IV@1oO`1V
04a<0?`c003k6NL0oOl00>oo003noo/0nAT00?`c003lC000h6H00?]o003nV@<0
/k<0oL`00?cV003ko`00o>H00?k<003n/`/0VIT0Ogl0IP1<C03l<`00naWW0?go
0P3oo`3hlOl00?kon`3i6@00o3<00?a<003PIP00ngl00?jI0`2c/`3mc000o>H0
0?_o003liP00o/`00?jc2`2IV@1o001V04a<0?`c003k6NL0oOl00>oo003noo/0
nAT00?`c003lC000h6H00?]o003nV@<0/k<0oL`00?cV003ko`00o>H00?k<003n
/`/0VIT0O`00IP1<C03l<`00naWW0?go003_o`00o_ok0?TI003l<`00o4`00>1V
003kO`00oYT30;>c0?g<003liP00nol00?cV003nc000o[<;09VI07l006H0C4`0
o3<00?/Ii`3mo`80ool0o_7o0`00oook0?TI003m<`00nd`00>1V003kO`00oYT3
0;>c0?c<003liP00oOl00?cV003nc000o[<509VI07l0oVH204`0o3<00?/IiP3n
o`400>oo0`00oook0?TI003m<`00nd`00>1V003kO`00oYT30;>c0?c<003liP00
oOl00?cV003nc000o[<509VI07l0oVH204`0o3<00?/IiP3no`400>oo0`00oook
0?TI003m<`00nd`00>1V003kO`00oYT30;>c0?c<003liP00oOl00?cV003nc000
o[<509VI07l0oVH204`0o3<00?/IiP3no`<00?oo0?Gao`00o_ol0?TI003l<`00
o4`00>1V003kO`00oIT30;>c0?_<003liP<0ool0o>H00?g<3`2c/`2IV@1oO`1V
IP1<C03m<`00nQWV0?go003_o`00o_ol0?TI003l<`00o4`00>1V003kO`00oIT3
0;>c0?_<003liP<0ool0o>H00?g<3`2c/`2IV@1oO`1VIP1<C03m<`00nQWV0?go
003_o`00o_ol0?TI003l<`00o4`00>1V003kO`00oIT30;>c0?_<003liP<0ool0
o>H00?g<3`2c/`2IV@1oO`1VIP1<C03m<`00nQWV0?go0P3oo`3elOl00?koo03i
6@00o3<00?a<003PIP00ngl00?jI003n/`00n/`00?cV0@00o>H00?g<003n/`D0
VIT0O`3nIP<0C4`0oC<00?/Ii@3mo`00kol00?koo03i6@00o3<00?a<003PIP00
ngl00?jI003n/`00n/`00?cV0@00o>H00?g<003n/`D0VIT0O`3nIP<0C4`0oC<0
0?/Ii@3mo`00kol00?koo03i6@00o3<00?a<003PIP00ngl00?jI003n/`00n/`0
0?cV0@00o>H00?g<003n/`D0VIT0O`3nIP<0C4`0oC<00?/Ii@3mo`80ool0ko7o
003noo`0nAT00?dc003kC000h6H00?]o003nV@00o[<00?W<003liP00oNH00?c<
2@2c/`2IV@1oO`3nIP80C03m<`00nQWU0?go003_o`00o_ol0?TI003m<`00nd`0
0>1V003kO`00oYT00?jc003ic000o>H00?gV003lc0T0/k<0VIT0Ogl0oVH204`0
oC<00?XIi@3mo`00kol00?koo03i6@00oC<00?]<003PIP00ngl00?jI003n/`00
nL`00?cV003miP00o<`90;>c09VI07mo0?iV0P1<0?dc003j6ND0oOl20?oo0>Ka
o`00o_ol0?XI003l<`00o4`00=mV003kO`00oYT00?jc003hc000n>H00?g<2@2c
/`2IV@1oO`3nIP<0C4`0oS<00?XIi03mo`00kol00?koo03j6@00o3<00?a<003O
IP00ngl00?jI003n/`00n<`00?SV003mc0T0/k<0VIT0Ogl0oVH304a<0?hc003j
6N@0oOl00>oo003noo`0nQT00?`c003lC000gfH00?]o003nV@00o[<00?S<003h
iP00oL`90;>c09VI07mo0?iV0`1<C03n<`00nQWT0?go0P3oo`3VlOl00?koo@3i
6@00oC<00?]<003PIP00ngl00?fI003n/`00ml`00?[V003mc000o[<609VI07mo
0?iV0P1<0?dc003j6N@0oOl00>oo003nood0nAT00?dc003kC000h6H00?]o003m
V@00o[<00?O<003jiP00oL`00?jc1P2IV@1oO`3nIP80C03m<`00nQWT0?go003_
o`00o_om0?TI003m<`00nd`00>1V003kO`00oIT00?jc003gc000n^H00?g<003n
/`H0VIT0Ogl0oVH204`0oC<00?XIi03mo`80ool0jO7o003nood0nAT00?dc003k
C000h6H00?]o003mV@00o[<00?K<003liP00oL`00?jc1P2IV@1oO`3nIP<0C4`0
oS<00?XIh`3mo`00kol00?koo@3i6@00oC<00?]<003PIP00ngl00?fI003n/`00
m/`00?cV003mc000o[<609VI07mo0?iV0`1<C03n<`00nQWS0?go003_o`00o_om
0?TI003m<`00nd`00>1V003kO`00oIT00?jc003fc000o>H00?g<003n/`H0VIT0
Ogl0oVH304a<0?hc003j6N<0oOl20?oo0>Kao`00o_om0?XI003m<`00nd`00=mV
003kO`00oIT00?jc003ec000o^H00?c<1P2c/`2IV@3nO`H0IVH0C4`0oS<00?TI
h`3mo`00kol00?koo@3j6@00oC<00?]<003OIP00ngl00?fI003n/`00mL`00?kV
003lc0H0/k<0VIT0oWl606IV04a<0?hc003i6N<0oOl00>oo003nood0nQT00?dc
003kC000gfH00?]o003mV@00o[<00?G<003niP00o<`60;>c09VI0?io1P1VIP1<
C03n<`00nAWS0?go0P3oo`3YlOl3003oood0nQT00?dc003kC000gfH00?]o003n
V@00oK<00?C<0P3V0?c<003n/`H0VIT0Ogl0oVH304a<0?hc003j6N80o_l1003_
o`<00?ooo@3j6@00oC<00?]<003OIP00ngl00?jI003m/`00m<`20>H0o<`00?jc
1P2IV@1oO`3nIP<0C4`0oS<00?XIhP3no`400>oo0`00ooom0?XI003m<`00nd`0
0=mV003kO`00oYT00?fc003dc080iP3lc000o[<609VI07mo0?iV0`1<C03n<`00
nQWR0?ko0`00ool0gO7o003nooh0nAT00?dc003kC000h6H00?]o003mV@00oK<0
0??<003lc000o[<309VI0?io0`1VIP3nC0<0<c<0nAWR0?go003_o`00o_on0?TI
003m<`00nd`00>1V003kO`00oIT00?fc003cc000o<`00?jc0`2IV@3nO`<0IVH0
oT`303<c0?TIhP3mo`00kol00?kooP3i6@00oC<00?]<003PIP00ngl00?fI003m
/`00ll`00?c<003n/`<0VIT0oWl306IV0?i<0`0c<`3i6N80oOl20?oo0=gao`00
o_on0?XI003m<`00nd`00=mV003kO`00oIT00?fc003cc000oL`00?jc0`2IV@3n
O`<0IVH0oT`303<c0?TIh@3mo`00kol00?kooP3j6@00oC<00?]<003OIP00ngl0
0?fI003m/`00ll`00?g<003n/`<0VIT0oWl306IV0?i<0`0c<`3i6N40oOl00>oo
003nooh0nQT00?dc003kC000gfH00?]o003mV@00oK<00??<003mc000o[<309VI
0?io0`1VIP3nC0<0<c<0nAWQ0?go0P3oo`3AlOl00?kooP3j6@00oC<00?]<003O
IP00ngl00?fI003m/`00k/`00?jc0`2IV@3nO`<0IVH0oT`303<c0?TIh@3mo`00
kol00?kooP3j6@00oC<00?]<003OIP00ngl00?fI003m/`00k/`00?jc0`2IV@3n
O`<0IVH0oT`303<c0?TIh@3mo`00kol00?kooP3j6@00oC<00?]<003OIP00ngl0
0?fI003m/`00k/`00?jc0`2IV@3nO`<0IVH0oT`303<c0?TIh@3mo`80ool0dO7o
003nooh0nQT00?dc003jC000hFH00?]o003lV@00o;<00?3<003n/`<0VIT0oWl3
06IV0?i<0`0c<`3i6N00oOl00>oo003nooh0nQT00?dc003jC000hFH00?]o003l
V@00o;<00?3<003n/`<0VIT0oWl306IV0?i<0`0c<`3i6N00oOl00>oo003nooh0
nQT00?dc003jC000hFH00?]o003lV@00o;<00?3<003n/`<0VIT0oWl306IV0?i<
0`0c<`3i6N00oOl20?oo0>3go`00o?l00?kooP3j6@00oC<00?Y<003QIP00ngl0
0?bI003l/`00lL`00?jc0`2IV@3nO`<0IVH0oT`00?hc003j6Ml0oOl00?Go003l
o`00o_on0?XI003m<`00nT`00>5V003kO`00o9T00?bc003ac000o[<309VI0?io
0`1VIP3nC000oS<00?XIg`3mo`00mOl00?co003nooh0nQT00?dc003jC000hFH0
0?]o003lV@00o;<00?7<003n/`<0VIT0oWl306IV0?i<003n<`00nQWO0?go0P3o
o`3Vn?l1003lo`00o_l1003i6@00oC<00?Y<003RIP00nWl00?bI003k/`00ll`0
0?jc0`2IV@3nO`<0IVH0oT`00?dc003j6Ml0oOl00?Ko0@00o?l00?ko0@00nAT0
0?dc003jC000hVH00?Yo003lV@00nk<00??<003n/`<0VIT0oWl306IV0?i<003m
<`00nQWO0?go003fo`400?co003no`400?TI003m<`00nT`00>9V003jO`00o9T0
0?^c003cc000o[<309VI0?io0`1VIP3nC000oC<00?XIg`3mo`80ool0hoOo003l
o`00o_l1003i6@00oC<00?U<003TIP00nWl00?^I003k/`00m<`00?jc003nV@H0
Ogl0IVH0oT`00?dc003j6Mh0oOl00?Go003lo`00o_l1003i6@00oC<00?U<003T
IP00nWl00?^I003k/`00m<`00?jc003nV@H0Ogl0IVH0oT`00?dc003j6Mh0oOl0
0?Go003lo`00o_l1003i6@00oC<00?U<003TIP00nWl00?^I003k/`00m<`00?jc
003nV@H0Ogl0IVH0oT`00?dc003j6Mh0oOl20?oo0>[go`00o?l5003oo`00nAT0
0?dc003iC000iFH00?Uo003kV@00nk<00?G<003n/`00oYT307mo0?iV003nC000
oC<00?/Ig@01ooon0?Go003lo`D00?oo003i6@00oC<00?U<003UIP00nGl00?^I
003k/`00mL`00?jc003nV@<0Ogl0oVH00?i<003m<`00naWM007oooh0mOl00?co
1@00ool00?TI003m<`00nD`00>EV003iO`00niT00?^c003ec000o[<00?jI0`1o
O`3nIP00oT`00?dc003k6Md00OoooP01ool0l`7ooo`0o_l00?co003no`400?XI
003l<`00nD`00>IV003hO`00o9T00?Vc003ic?h0o[<00?jI0`1oO`3nIP00oT`0
0?dc003j6Md0oOl00?goo03no`00o?l00?ko0@00nQT00?`c003iC000iVH00?Qo
003lV@00nK<00?W<oP3n/`00oYT307mo0?iV003nC000oC<00?XIg@3mo`00oOol
0?ko003lo`00o_l1003j6@00o3<00?U<003VIP00n7l00?bI003i/`00nLcn0?jc
003nV@<0Ogl0oVH00?i<003m<`00nQWM0?go0P3oo`3Vmol00?co003no`400?XI
003l<`00n4`00>QV003hO`00niT00?Vc003lc?h0o;<00?jI003nO`<0IVH0oT`0
0?`c003k6M`0oOl00?Go003lo`00o_l1003j6@00o3<00?Q<003XIP00n7l00?^I
003i/`00o<cn0?bc003nV@00oWl306IV0?i<003l<`00naWL0?go003eo`00o?l0
0?ko0@00nQT00?`c003hC000j6H00?Qo003kV@00nK<00?c<oP3l/`00oYT00?io
0`1VIP3nC000o3<00?/Ig03mo`80ool0gOSooP3mo`00o_l00?TI003l<`00n4`0
0>UV003gO`00niT00?Rc0@3<oP3j/`00oIT607mo06IV0?i<003l<`00nQWL0?go
003fooh0oOl00?ko003i6@00o3<00?Q<003YIP00mgl00?^I003h/`40c?h0n[<0
0?fI1P1oO`1VIP3nC000o3<00?XIg03mo`00m_on0?go003no`00nAT00?`c003h
C000jFH00?Mo003kV@00n;<10<cn0?Zc003mV@H0Ogl0IVH0oT`00?`c003j6M`0
oOl20?oo0<_ao`00o_l00?TI003l<`00n4`00>YV003fO`00niT00?Rc0@00n;<0
0?fI003nO`80IP3nC000o3<00?XIf`3mo`00kol00?ko003i6@00o3<00?Q<003Z
IP00mWl00?^I003h/`400?Rc003mV@00oWl206H0oT`00?`c003j6M/0oOl00>oo
003no`00nAT00?`c003hC000jVH00?Io003kV@00n;<1003h/`00oIT00?io0P1V
0?i<003l<`00nQWK0?go0P3oo`2llOl00?ko003i6@00o3<00?M<003/IP00mWl0
0?ZI003^/`00oIT00?io1P1VIP1<C03l<`00nQWJ0?go003_o`00o_l00?TI003l
<`00md`00>aV003fO`00nYT00>jc003mV@00oWl606IV04a<0?`c003j6MX0oOl0
0>oo003no`00nAT00?`c003gC000k6H00?Io003jV@00k[<00?fI003nO`H0IVH0
C4`0o3<00?XIfP3mo`80ool0_?7o003no`00nAT00?`c003gC000k6H00?Io003j
V@00kk<00?bI003nO`H0IVH0C4`0o3<00?XIfP3mo`00kol00?ko003i6@00o3<0
0?M<003/IP00mWl00?ZI003_/`00o9T00?io1P1VIP1<C03l<`00nQWJ0?go003_
o`00o_l00?TI003l<`00md`00>aV003fO`00nYT00>nc003lV@00oWl606IV04a<
0?`c003j6MX0oOl20?oo0;cao`00o_l00?TI003k<`00md`00>eV003fO`00nIT0
0?6c003lV@00oWl606IV04a<0?`c003j6MT0oOl00>oo003no`00nAT00?/c003g
C000kFH00?Io003iV@00lK<00?bI003nO`H0IVH0C4`0o3<00?XIf@3mo`00kol0
0?ko003i6@00nc<00?M<003]IP00mWl00?VI003a/`00o9T00?io1P1VIP1<C03l
<`00nQWI0?go0P3oo`35lOl4003oo`3h6@00nc<00?M<003_IP00m7l00?VI0@00
mK<1003lV@00oWl606IV04a<0?`c003j6MP0o_l1003_o`@00?oo0?PI003k<`00
md`00>mV003dO`00nIT1003e/`400?bI003nO`H0IVH0C4`0o3<00?XIf03no`40
0>oo1000ool0n1T00?/c003gC000kfH00?Ao003iV@400?Fc0@00o9T00?io1P1V
IP1<C03l<`00nQWH0?ko0`00ool0`_7o003no`00n1T00?/c003fC000l6H00?Ao
003gV@400?Rc003lV@400?io1P1VIP1<C03l<`00nQWG0?go003_o`00o_l00?PI
003k<`00mT`00?1V003dO`00miT1003h/`00o9T1003nO`H0IVH0C4`0o3<00?XI
e`3mo`00kol00?ko003h6@00nc<00?I<003`IP00m7l00?NI0@00n;<00?bI0@00
oWl606IV04a<0?`c003j6ML0oOl20?oo0<;ao`00o_l00?PI003j<`00md`00?1V
003dO`00mIT00?^c0@00o9T00?eo0`1VIP3nC000oC<00?XIeP3mo`00kol00?ko
003h6@00nS<00?M<003`IP00m7l00?FI003k/`400?bI003mO`<0IVH0oT`00?dc
003j6MH0oOl00>oo003no`00n1T00?Xc003gC000l6H00?Ao003eV@00nk<1003l
V@00oGl306IV0?i<003m<`00nQWF0?go0P3oo`35lOl00?ko003h6@00nS<00?I<
003aIP00m7l00?BI0@00o[<00?bI0@00oGl306IV0?i<003l<`00naWE0?go003_
o`00o_l00?PI003j<`00mT`00?5V003dO`00m9T1003n/`00o9T1003mO`<0IVH0
oT`00?`c003k6MD0oOl00>oo003no`00n1T00?Xc003fC000lFH00?Ao003dV@40
0?jc003lV@400?eo0`1VIP3nC000o3<00?/Ie@3mo`80ool0]_7o003no`400?TI
003i<`00mT`00?=V003bO`00liWn0?bI003lO`<0IVH0oT`00?`c003j6MD0oOl0
0>oo003no`400?TI003i<`00mT`00?=V003bO`00liWn0?bI003lO`<0IVH0oT`0
0?`c003j6MD0oOl00>oo003no`400?TI003i<`00mT`00?=V003bO`00liWn0?bI
003lO`<0IVH0oT`00?`c003j6MD0oOl20?oo0;3ao`00o_l1003h6@00nC<00?I<
003dIP00lWl00>fI0@00oGl4001VIP3nC000o3<00?XIe03mo`00kol00?ko0@00
n1T00?Tc003fC000m6H00?9o003]V@400?eo1000IVH0oT`00?`c003j6M@0oOl0
0>oo003no`400?PI003i<`00mT`00?AV003bO`00kIT1003mO`@006IV0?i<003l
<`00nQWD0?go0P3oo`2`lOl00?ko0@00n1T00?Tc003eC000mFH00?9o003_V@40
0?ao003nIP00oT`00?`c003j6M<0oOl00>oo003no`400?PI003i<`00mD`00?EV
003bO`00kiT1003lO`00oVH00?i<003l<`00nQWC0?go003_o`00o_l1003h6@00
nC<00?E<003eIP00lWl00>nI0@00o7l00?iV003nC000o3<00?XId`3mo`80ool0
[O7o003no`400?PI003h<`00mT`00?IV003`O`00lIT00?]o003nIP00oT`00?`c
003j6M80oOl00>oo003no`400?PI003h<`00mT`00?IV003`O`00lIT00?]o003n
IP00oT`00?`c003j6M80oOl00>oo003no`400?PI003h<`00mT`00?IV003`O`00
lIT00?]o003nIP00oT`00?`c003j6M80oOl20?oo0;?ao`D00?oo003g6@00n3<0
0?I<003gIP00l7l00?>I0@00ngl00?iV003nC000o3<00?XId@3no`400>oo1@00
ool00?LI003h<`00mT`00?MV003`O`00liT1003kO`00oVH00?i<003l<`00nQWA
0?ko0@00kol5003oo`00maT00?Pc003fC000mfH00?1o003cV@400?]o003nIP00
oT`00?`c003j6M40o_l3003oo`2clOl00?ko0@00maT00?Pc003fC000mfH00?1o
0@00nIWl0?]o0@00oVH00?e<003l<`00nQWA0?go003_o`00o_l1003g6@00n3<0
0?I<003gIP00l7l1003iVO`0ngl1003nIP00oD`00?`c003j6M40oOl00>oo003n
o`400?LI003h<`00mT`00?MV003`O`400?VIo03kO`400?iV003mC000o3<00?XI
d@3mo`80ool0W_7o003nooh0maT00?Pc003fC000mfH00>mon@3gO`00oFH00?e<
003l<`00nQW@0?go003_o`00o_on0?LI003h<`00mT`00?MV003_OoT0mgl00?eV
003mC000o3<00?XId03mo`00kol00?kooP3g6@00n3<00?I<003gIP00kgoi0?Mo
003mIP00oD`00?`c003j6M00oOl20?oo09Gao`00o_on0?HI003h<`00md`00?IV
003PO`400?eV003mC000o3<00?XIc`3mo`00kol00?kooP3f6@00n3<00?M<003f
IP00h7l1003mIP00oD`00?`c003j6Ll0oOl00>oo003nooh0mQT00?Pc003gC000
mVH00>1o0@00oFH00?e<003l<`00nQW?0?go0P3oo`2ElOl00?kooP3e6@00n3<0
0?M<003fIP400>=o003lIP00oD`00?`c003j6Lh0oOl00>oo003nooh0mAT00?Pc
003gC000mVH1003SO`00o6H00?e<003l<`00nQW>0?go003_o`00o_on0?DI003h
<`00md`00?IV0@00hgl00?aV003mC000o3<00?XIcP3mo`80ool0UO7o003nood0
mQT00?Pc003gC000m6H00>Io0@00o6H00?e<003l<`00nQW=0?go003_o`00o_om
0?HI003h<`00md`00?AV003VO`400?aV003mC000o3<00?XIc@3mo`00kol00?ko
o@3f6@00n3<00?M<003dIP00iWl1003lIP00oD`00?`c003j6Ld0oOl20?oo09_a
o`00o_om0?DI003h<`00md`00?AV0@00jWl1003lIP400?e<003l<`00nQW<0?go
003_o`00o_om0?DI003h<`00md`00?AV0@00jWl1003lIP400?e<003l<`00nQW<
0?go003_o`00o_om0?DI003h<`00md`00?AV0@00jWl1003lIP400?e<003l<`00
nQW<0?go0P3oo`2ElOl00?koo@3d6@00n3<00?M<003cIP00kGl1003kIP00o4`0
0?`c003j6L/0oOl00>oo003nood0m1T00?Pc003gC000lfH00>eo0@00nfH00?a<
003l<`00nQW;0?go003_o`00o_om0?@I003h<`00md`00?=V003]O`400?]V003l
C000o3<00?XIb`3mo`80ool0V?7o0`00oool0?DI003h<`00md`00?9V003aOoh0
nVH00?a<003l<`00nQW:0?ko0@00kol3003ooo`0mAT00?Pc003gC000lVH00?5o
oP3jIP00o4`00?`c003j6LX0o_l1003_o`<00?ooo03e6@00n3<00?M<003bIP00
lGon0?YV003lC000o3<00?XIbP3no`<00?oo09Gao`00o_ol0?@I003h<`00md`0
0?9VnP3jO`400?QV003lC000o3<00?XIb@3mo`00kol00?koo03d6@00n3<00?M<
003bI_X0nWl1003hIP00o4`00?`c003j6LT0oOl00>oo003noo`0m1T00?Pc003g
C000lVKj0?Yo0@00n6H00?a<003l<`00nQW90?go0P3oo`29lOl00?koo03c6@00
n3<00?Q<003[I_X0n6H1003lC000o3<00?TIb@3mo`00kol00?koo03c6@00n3<0
0?Q<003[I_X0n6H1003lC000o3<00?TIb@3mo`00kol00?koo03c6@00n3<00?Q<
003[I_X0n6H1003lC000o3<00?TIb@3mo`80ool0N_7o003noo/0laT00?Pc003h
C000gfKn0?]<003l<`00nAW80?go003_o`00o_ok0?<I003h<`00n4`00=mVoP3k
C000o3<00?TIb03mo`00kol00?kon`3c6@00n3<00?Q<003OI_h0nd`00?`c003i
6LP0oOl20?oo07gao`00o_ok0?<I003h<`00n4`00>=Vo@3jC0400?`c003i6LL0
oOl00>oo003noo/0laT00?Pc003hC000hfKm0?Y<0@00o3<00?TIa`3mo`00kol0
0?kon`3c6@00n3<00?Q<003SI_d0nT`1003l<`00nAW70?go0P3oo`1jlOl00?ko
nP3c6@00n3<00?Q<003YI_`0md`00?/c003i6LH0oOl00>oo003nooX0laT00?Pc
003hC000jFKl0?M<003k<`00nAW60?go003_o`00o_oj0?<I003h<`00n4`00>UV
o03gC000nc<00?TIaP3mo`80ool0N_7o003nooT0laT00?Tc003gC000kFKn0?=<
003k<`00nAW50?go003_o`00o_oi0?<I003i<`00md`00>eVoP3cC000nc<00?TI
a@3mo`00kol00?kon@3c6@00nC<00?M<003]I_h0ld`00?/c003i6LD0oOl20?oo
07[ao`00o_oh0?@I003h<`00md`00?9Vo@3cC?h0nc<00?TIa03mo`00kol00?ko
n03d6@00n3<00?M<003bI_d0ldcn0?/c003i6L@0oOl00>oo003nooP0m1T00?Pc
003gC000lVKm0?=<oP3k<`00nAW40?go0P3oo`1dlOl3003oooP0laT00?Tc003f
C?80lTcn0?Tc003i6L<0o_l1003_o`<00?oon03c6@00nC<00?I<lP3bC?h0nC<0
0?TI``3no`400>oo0`00oooh0?<I003i<`00mTcb0?9<oP3i<`00nAW30?ko0`00
ool0IO7o003nooL0laT00?Tc003MC?d0n3<1003i6L80oOl00>oo003nooL0laT0
0?Tc003MC?d0n3<1003i6L80oOl00>oo003nooL0laT00?Tc003MC?d0n3<1003i
6L80oOl20?oo06;ao`00o_of0?@I003i<`00h4cn0?Dc003h6L40oOl00>oo003n
ooH0m1T00?Tc003PC?h0mC<00?PI`@3mo`00kol00?komP3d6@00nC<00>1<oP3e
<`00n1W10?go0P3oo`1XlOl00?kom@3d6@00nC<1003TC0400?<c003h6L00oOl0
0>oo003nooD0m1T00?Tc0@00i4`1003c<`00n1W00?go003_o`00o_oe0?@I003i
<`400>A<0@00lc<00?PI`03mo`80ool0LOSooP3mo`00o_oe0?@I003g<`00id`1
003b<`00n1Vo0?go003fooh0oOl00?kom@3d6@00mc<00>M<0@00lS<00?PI_`3m
o`00m_on0?go003nooD0m1T00?Lc003WC0400?8c003h6Kl0oOl20?oo083io`00
o_l00?ko003noo@0m1T00?Lc0@00k4cn0?8c0@00n1Vn0?go003go`00o_l00?ko
003noo@0m1T00?Lc0@00k4cn0?8c0@00n1Vn0?go003go`00o_l00?ko003noo@0
m1T00?Lc0@00k4cn0?8c0@00n1Vn0?go0P3oo`23nOl00?ko003no`00o_oc0?@I
003f<`400?1<0@00lC<1003f6Kh0oOl00?Oo003no`00o_l00?kol`3d6@00mS<1
003`C0400?4c0@00mQVn0?go003go`00o_l00?ko003noo<0m1T00?Hc0@00l4`1
003a<`400?HI_P3mo`80ool0NoKo003mo`400?;o003do`00m?l1003hoo/0lOl1
003fo`400;cooP3do`00oOl1003bo`00m?l00?Co0@00n?ok0?7o0@00m_l1002l
ooh0m?l00?go0@00l_l00?Co003do`400?Son`3ao`400?Ko0@00_?on007oo`0i
0Oooo03no`00o?l0087og_l00?goo03no`00o?l0087og_l00?goo03no`00o?l0
087og_l20?oo06_ho`<0ool0o_l00?ko003Ko`00fol00=_o003Ko`00o_l00?Ko
0`3oo`3no`00o_l00=_o003Ko`00fol00=_o003no`00m_l30?oo0?ko003no`00
fol00=_o003Ko`00fol00?ko0P3oo`0QnOol0?koP@3L0?Ooo03noh40g03goo`0
o_n10=`00Ooo00Z1oh7oPOn1omco00Z1oh7oPOn1omco00Z1oh7oPOn1omco00Z1
oh7oPOn1omco00Z1oh7oPOn1omco00Z1oh7oPOn1omco00Z1oh7oPOn1omco047/
ooh0g?l00=ko0@00g?l00=cooP3Vooh0g?l00=ko0@00g?l00=cooP3Vooh0g?l0
0=ko0@00g?l00=cooP3ko`1UkOl00?ko003No`400=oo0`3oo`3No`400=go003n
o`00j?l00?ko003No`400=oo0`3oo`3No`400=go003no`00j?l00?ko003No`40
0=oo0`3oo`3No`400=go003no`00o?l0Gngo003no`00gOl00=oo0`3oo`3Mo`00
gOl00?ko003Xo`00o_l00=go003Oo`<0ool0gOl00=go003no`00j?l00?ko003M
o`00gol30?oo0=go003Mo`00o_l00?co04OZo`00g?l00=oo0`3oo`3Mo`00f_l0
0>Co003Lo`00gol30?oo0=go003Jo`00i?l00=co003Oo`<0ool0gOl00=[o003k
o`1Olool0?ko003Soo`0o_l00=oo0`3oo`3Mo`00fol00>coo03no`00hool0?ko
003Oo`<0ool0gOl00=_o003/oo`0o_l00>?oo03no`00gol30?oo0=go003Ko`00
n_l0FNco0`3oo`3Mo`00gol30?oo0=go003Lo`<0ool0iol30?oo0=go003Oo`<0
ool0gOl00=co0`3oo`3Wo`<0ool0gOl00=oo0`3oo`3Mo`00g?l30?oo0?co047]
oo`0g_on0=oo0@00gOon0=koo03Xoo`0g_on0=oo0@00gOon0=koo03Xoo`0g_on
0=oo0@00gOon0=koo03lo`0:POn1oh7oPOoLo`0:POn1oh7oPOoLo`0:POn1oh7o
POoLo`3o\>"], "Graphics",
  ImageSize->{183, 183},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{2.*Second, ContourGraphics[\"<<>>\"]}\
\>", \
"\<\
{2. Second, -ContourGraphics-}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["NIntegrate[kd,{x,-3,3},{y,-3,3}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0.993146236928539\
\>", "\<\
0.993146\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sm = smoothEpanechnikov[data]
kd = KernDichteM[{x,y},data,EpanechnikovM,sm];
ContourPlot[kd//Evaluate,{x,-2,2},{y,-2,2}]//Timing\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{0.7322860845784485, 0.4403023520828639}, \
{0.4403023520828639, 1.498285157556057}}\
\>", "\<\
{{0.732286, 0.440302}, \
{0.440302, 1.49829}}\
\>"], "Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PICT", "\<\
S2@0100Y0<h0l`0A0_l<0?ooool0:@0000@0003c0000cP000000000N00402P04
02T0cP3c09X0003oPbP000000<X0bP0000@0000004P000180000400P00<02000
0002njEP000000000000bP3:00@0:@3>0?<0900:POn1oh7oPOnSo`0:POn1oh7o
POnSo`0ElOn10<T0kon10<T0kon10<T00Ooo0B;hooh0oOl00?ko003io`00n_l0
0?Wo003io`00nOl00?[o003io`00nOl00?Wo003io`00n_l00?Wo003io`00nOl0
0?[o003io`00nOl00?Wo003io`00n_l00?ko003fooh0oOl00?ko003io`00n_l0
0?Wo003io`00nOl00?[o003io`00nOl00?Wo003io`00n_l00?Wo003io`00nOl0
0?[o003io`00nOl00?Wo003io`00n_l00?ko003fooh0oOl00?ko003io`00n_l0
0?Wo003io`00nOl00?[o003io`00nOl00?Wo003io`00n_l00?Wo003io`00nOl0
0?[o003io`00nOl00?Wo003io`00n_l00?ko0P3oo`0hnOl00?ko003no`00POo;
o`00mol00?ko003no`00POo;o`00mol00?ko003no`00POo;o`80ool0>?Wo003n
o`00o_l0087obol00?Oo003no`00o_l0087obol00?Oo003no`00o_l0087obol2
0?oo05cfo`00oOl3003oojd0maT00>Xc003h6M80o_l1003do`00oOl3003oojd0
maT00>Xc003h6M80o_l1003do`00oOl3003oojd0maT00>Xc003h6M80o_l3003o
o`1Fmol00?co003nojh0maT00>Pc003i6M80oOl00?Go003lo`00o_n^0?LI003X
<`00nAWB0?go003eo`00o?l00?ko[P3g6@00j3<00?TIdP3mo`80ool0K_So0`3o
o`3no`00o_n_0?PI0@00nS?c0?/c003i6M<0oOl00?Ko0`3oo`3no`00o_n_0?PI
0@00nS?c0?/c003i6M<0oOl00?Ko0`3oo`3no`00o_n_0?PI0@00nS?c0?/c003i
6M<0oOl20?oo06kioo`0o_l00?ko/03h6@00nC<00?=<003k<`00nQWC0?go003g
oo`0o_l00?ko/03h6@00nC<00?=<003k<`00nQWC0?go003goo`0o_l00?ko/03h
6@00nC<00?=<003k<`00nQWC0?go0P3oo`1UlOl00?ko/@3i6@400?Tc003aC000
o3<00?XId`3mo`00kol00?ko/@3i6@400?Tc003aC000o3<00?XId`3mo`00kol0
0?ko/@3i6@400?Tc003aC000o3<00?XId`3mo`80ool0H_7o003nok80nAT00?Pc
003`C000nc<00?XIe03mo`00kol00?ko/P3i6@00n3<00?1<003k<`00nQWD0?go
003_o`00o_nb0?TI003h<`00l4`00?/c003j6M@0oOl20?oo06;ao`00o_nc0?TI
003h<`00kT`00?/c003k6M@0oOl00>oo003nok<0nAT00?Pc003^C000nc<00?/I
e03mo`00kol00?ko/`3i6@00n3<00>i<003k<`00naWD0?go0P3oo`1UlOl00?ko
]03i6@00nC<1003/C000nc<00?`Ie03mo`00kol00?ko]03i6@00nC<1003/C000
nc<00?`Ie03mo`00kol00?ko]03i6@00nC<1003/C000nc<00?`Ie03mo`80ool0
J?7o0`00oone0?PI003j<`00jD`00?/c003l6MD0o_l1003_o`<00?oo]@3h6@00
nS<00>U<003k<`00o1WE0?ko0@00kol3003ookD0n1T00?Xc003YC000nc<00?`I
e@3no`<00?oo077ao`00o_ne0?TI003j<`00nT`1003aC000nc<00?`Ie@3mo`00
kol00?ko]@3i6@00nS<00?Y<0@00lD`00?/c003l6MD0oOl00>oo003nokD0nAT0
0?Xc003jC0400?5<003k<`00o1WE0?go0P3oo`1jlOl00?ko]@3j6@00nS<00?Y<
0P1VI_d0m4`00?`c003l6MD0oOl00>oo003nokD0nQT00?Xc003jC080IVKm0?A<
003l<`00o1WE0?go003_o`00o_ne0?XI003j<`00nT`206IVo@3dC000o3<00?`I
e@3mo`80ool0N_7o003nokH0nQT00?Xc003jC000nVKl0?Q<003l<`00o1WF0?go
003_o`00o_nf0?XI003j<`00nT`00?YVo03hC000o3<00?`IeP3mo`00kol00?ko
]P3j6@00nS<00?Y<003jI_`0n4`00?`c003l6MH0oOl20?oo07gao`00o_nf0?XI
003l<`400?Y<003dI_h0nd`00?`c003l6MH0oOl00>oo003nokH0nQT00?`c0@00
nT`00?AVoP3kC000o3<00?`IeP3mo`00kol00?ko]P3j6@00o3<1003jC000m6Kn
0?]<003l<`00o1WF0?go0P3oo`1jlOl00?ko]`3j6@00nc<00?Y<003`IP00o4`0
0?`c003l6MH0oOl00>oo003nokL0nQT00?/c003jC000l6H00?a<003l<`00o1WF
0?go003_o`00o_ng0?XI003k<`00nT`00?1V003lC000o3<00?`IeP3mo`80ool0
N_7o003nokL0nQT00?`c003jC000kfH00?]<003m<`00o1WF0?go003_o`00o_ng
0?XI003l<`00nT`00>mV003kC000oC<00?`IeP3mo`00kol00?ko]`3j6@00o3<0
0?Y<003_IP00nd`00?dc003l6MH0oOl20?oo07[ao`00o_ng0?/I003l<`00nT`0
0>eV003lC000oC<00?`IeP3mo`00kol00?ko]`3k6@00o3<00?Y<003]IP00o4`0
0?dc003l6MH0oOl00>oo003nokL0naT00?`c003jC000kFH00?a<003m<`00o1WF
0?go0P3oo`1jlOl00?ko^03k6@00o3<00?Y<003/IP00o4`00?dc003l6MH0oOl0
0>oo003nokP0naT00?`c003jC000k6H00?a<003m<`00o1WF0?go003_o`00o_nh
0?/I003l<`00nT`00>aV003lC000oC<00?`IeP3mo`80ool0P?7o0`00oonh0?/I
003m<`00nT`00>YV003lC000oS<00?`IeP3no`400>oo0`00oonh0?/I003m<`00
nT`00>YV003lC000oS<00?`IeP3no`400>oo0`00oonh0?/I003m<`00nT`00>YV
003lC000oS<00?`IeP3no`<00?oo07[ao`00o_nh0?`I003m<`00nT`00>UV003l
C000oS<00?`IeP3mo`00kol00?ko^03l6@00oC<00?Y<003YIP00o4`00?hc003l
6MH0oOl00>oo003nokP0o1T00?dc003jC000jFH00?a<003n<`00o1WF0?go0P3o
o`1jlOl00?ko^@3k6@00oC<00?]<003WIP00oD`00?dc003l6ML0oOl00>oo003n
okT0naT00?dc003kC000ifH00?e<003m<`00o1WG0?go003_o`00o_ni0?/I003m
<`00nd`00>MV003mC000oC<00?`Ie`3mo`80ool0RO7o003nokT0o1T00?dc003l
C0400?MV003`IP00oD`00?hc003l6ML0oOl00>oo003nokT0o1T00?dc003lC040
0?MV003`IP00oD`00?hc003l6ML0oOl00>oo003nokT0o1T00?dc003lC0400?MV
003`IP00oD`00?hc003l6ML0oOl20?oo09;ao`00o_nj0?`I003m<`00o4`00?MV
1000O`00lVH00?e<003n<`00o1WG0?go003_o`00o_nj0?`I003m<`00o4`00?MV
1000O`00lVH00?e<003n<`00o1WG0?go003_o`00o_nj0?`I003m<`00o4`00?MV
1000O`00lVH00?e<003n<`00o1WG0?go0P3oo`2ElOl00?ko^P3l6@00oS<00?a<
003gIP00o7l1003cIP00oT`00?hc003l6ML0oOl00>oo003nokX0o1T00?hc003l
C000mfH00?ao0@00lfH00?i<003n<`00o1WG0?go003_o`00o_nj0?`I003n<`00
o4`00?MV003lO`400?=V003nC000oS<00?`Ie`3mo`80ool0UO7o003nokX0oAT0
0?hc003lC000n6H1003iO`400?EV003mC0<0<c<0o1WG0?go003_o`00o_nj0?dI
003n<`00o4`00?QV0@00nGl1003eIP00oD`303<c0?`Ie`3mo`00kol00?ko^P3m
6@00oS<00?a<003hIP400?Uo0@00mFH00?e<0`0c<`3l6ML0oOl20?oo09;ao`00
o_nk0?`I0`0c<`3lC000nFH1003eO`400?IV003nC0<0<c<0o1WG0?go003_o`00
o_nk0?`I0`0c<`3lC000nFH1003eO`400?IV003nC0<0<c<0o1WG0?go003_o`00
o_nk0?`I0`0c<`3lC000nFH1003eO`400?IV003nC0<0<c<0o1WG0?go0P3oo`2B
lOl00?ko^`3l6@<0<c<0oD`00?YV0@00lGl1003hIP00oT`303<c0?`Ie`3mo`00
kol00?ko^`3l6@<0<c<0oD`00?YV0@00lGl1003hIP00oT`303<c0?`Ie`3mo`00
kol00?ko^`3l6@<0<c<0oD`00?YV0@00lGl1003hIP00oT`303<c0?`Ie`3mo`80
ool0T_7o0`00oonl0?`I0`0c<`3mC000nVH00>eo003iIP00oT`303<c0?`Ie`3n
o`400>oo0`00oonl0?`I0`0c<`3mC000nVH00>eo003iIP00oT`303<c0?`Ie`3n
o`400>oo0`00oonl0?`I0`0c<`3mC000nVH00>eo003iIP00oT`303<c0?`Ie`3n
o`<00?oo08cao`00o_nm0?`I003n<`00oT`00?YV003[O`00nFH604a<03<c0?`I
e`3mo`00kol00?ko_@3l6@00oS<00?i<003jIP00jgl00?UV1P1<C00c<`3l6ML0
oOl00>oo003nokd0o1T00?hc003nC000nVH00>]o003iIPH0C4`0<c<0o1WG0?go
0P3oo`2<lOl00?ko_P3l6@00oS<00?i<003jIP00jGl00?YV1P1<C00c<`3l6ML0
oOl00>oo003nokh0o1T00?hc003nC000nVH00>Uo003jIPH0C4`0<c<0o1WG0?go
003_o`00o_nn0?`I003n<`00oT`00?YV003YO`00nVH604a<03<c0?`Ie`3mo`80
ool0RO7o003nokl0naT00?hc0`1<C03jIP00igl00?]V1P1<C00c<`3l6ML0oOl0
0>oo003nokl0naT00?hc0`1<C03jIP00igl00?]V1P1<C00c<`3l6ML0oOl00>oo
003nokl0naT00?hc0`1<C03jIP00igl00?]V1P1<C00c<`3l6ML0oOl20?oo09Ga
o`00o_o00?/I003n<`<0C4`0nVH00?Ao003cO`00o6H604a<03<c0?`Ie`3mo`00
kol00?ko`03k6@00oS<304a<0?YV003dO`00lgl00?aV1P1<C00c<`3l6ML0oOl0
0>oo003nol00naT00?hc0`1<C03jIP00m7l00?=o003lIPH0C4`0<c<0o1WG0?go
0P3oo`2KlOl00?ko`@3k6@00oC<204`0nVH00?IooP02V@00m7l00?aV1@1<03<c
0?dIeP3mo`00kol00?ko`@3k6@00oC<204`0nVH00?IooP02V@00m7l00?aV1@1<
03<c0?dIeP3mo`00kol00?ko`@3k6@00oC<204`0nVH00?IooP02V@00m7l00?aV
1@1<03<c0?dIeP3mo`80ool0W_7o003nol80naT00?dc0P1<0?YV003gO`400?^I
003eO`00o6H504`0<c<0oAWF0?go003_o`00o_o20?/I003m<`80C03jIP00mgl1
003kV@00mGl00?aV1@1<03<c0?dIeP3mo`00kol00?ko`P3k6@00oC<204`0nVH0
0?Mo0@00niT00?Eo003lIPD0C00c<`3m6MH0oOl20?oo0:Cao`00o_o20?/I003n
<`80C03kIP400?Qo0@00n9T1003fO`00oFH504`0<c<0oAWF0?go003_o`00o_o2
0?/I003n<`80C03kIP400?Qo0@00n9T1003fO`00oFH504`0<c<0oAWF0?go003_
o`00o_o20?/I003n<`80C03kIP400?Qo0@00n9T1003fO`00oFH504`0<c<0oAWF
0?go0P3oo`2QlOl00?ko``3k6@00oS<304a<0?aV003iOoh0m9T1003gO`00oVH5
04`0<c<0oAWF0?go003_o`00o_o30?/I003n<`<0C4`0o6H00?UooP3dV@400?Mo
003nIPD0C00c<`3m6MH0oOl00>oo003nol<0naT00?hc0`1<C03lIP00nGon0?BI
0@00mgl00?iV1@1<03<c0?dIeP3mo`80ool0Y?7o0`00ooo40?/I003n<`<0C4`0
o6H00?Yo0@00kiT00?Mo003nIP@003<c0?dIeP3no`400>oo0`00ooo40?/I003n
<`<0C4`0o6H00?Yo0@00kiT00?Mo003nIP@003<c0?dIeP3no`400>oo0`00ooo4
0?/I003n<`<0C4`0o6H00?Yo0@00kiT00?Mo003nIP@003<c0?dIeP3no`<00?oo
09kao`00o_o50?/I003n<`<0C4`0o6H00?]o0@00k9T1003hO`L0IVH003<c0?dI
eP3mo`00kol00?koa@3k6@00oS<304a<0?aV003kO`400>bI0@00n7l706IV000c
<`3m6MH0oOl00>oo003nolD0naT00?hc0`1<C03lIP00ngl1003/V@400?Qo1`1V
IP00<c<0oAWF0?go0P3oo`2KlOl00?koa@3k6@H0<c<0C4`0oFH1003lO`400>RI
oP3kO`L0IVH003<c0?dIeP3mo`00kol00?koa@3k6@H0<c<0C4`0oFH1003lO`40
0>RIoP3kO`L0IVH003<c0?dIeP3mo`00kol00?koa@3k6@H0<c<0C4`0oFH1003l
O`400>RIoP3kO`L0IVH003<c0?dIeP3mo`80ool0Yo7o003nolH0naT303<c0?i<
003nIP00ngl00?6I003dV@00o7l406IV003n<`00oAWG0?go003_o`00o_o60?/I
0`0c<`3nC000oVH00?]o003aV@00m9T00?ao101VIP00oS<00?dIe`3mo`00kol0
0?koaP3k6@<0<c<0oT`00?iV003kO`00lIT00?BI003lO`@0IVH00?hc003m6ML0
oOl20?oo0;3ao`00o_o70?/I003n<`<0C4`0oVH00?]o003cVOh00K<0mIT00?ao
101VIP00oS<00?dIe`3mo`00kol00?koa`3k6@00oS<304a<0?iV003kO`00liWn
006c0?FI003lO`@0IVH00?hc003m6ML0oOl00>oo003nolL0naT00?hc0`1<C03n
IP00ngl00?>IoP01/`3eV@00o7l406IV003n<`00oAWG0?go0P3oo`2omol00?co
003nolP0naT00?dc0`1<C03nIP00o7l00?FIoP3l/`400?JI003lO`<0IP00oS<0
0?`If03mo`00mOl00?co003nolP0naT00?dc0`1<C03nIP00o7l00?FIoP3l/`40
0?JI003lO`<0IP00oS<00?`If03mo`00mOl00?co003nolP0naT00?dc0`1<C03n
IP00o7l00?FIoP3l/`400?JI003lO`<0IP00oS<00?`If03mo`80ool0`_So0@00
o?l00?kob@3k6@00oC<00?i<0`1VIP3kO`00n9Wn0?Nc003gV@00o7l406H0C03n
<`00oAWH0?go003fo`400?co003nolT0naT00?dc003nC0<0IVH0ngl00?RIoP3g
/`00miT00?ao101V04`0oS<00?dIf03mo`00m_l1003lo`00o_o90?/I003m<`00
oT`306IV0?]o003hVOh0mk<00?NI003lO`@0IP1<0?hc003m6MP0oOl20?oo0;og
o`00o?l00?kobP3j6@00oC<304a<0?iV003lO`00nYWn0?>c003gV@00oGl406H0
C03n<`00o1WI0?go003eo`00o?l00?kobP3j6@00oC<304a<0?iV003lO`00nYWn
0?>c003gV@00oGl406H0C03n<`00o1WI0?go003eo`00o?l00?kobP3j6@00oC<3
04a<0?iV003lO`00nYWn0?>c003gV@00oGl406H0C03n<`00o1WI0?go0P3oo`3D
mol00?co0`00ooo;0?XI003l<`<0C4`0oVH00?eo003jV@00mK<00?bc0@00nIT0
0?eo101V04`0oS<00?`If@3no`400?Go003lo`<00?oob`3j6@00o3<304a<0?iV
003mO`00nYT00?Fc003l/`400?VI003mO`@0IP1<0?hc003l6MT0o_l1003eo`00
o?l3003ool/0nQT00?`c0`1<C03nIP00oGl00?ZI003e/`00o;<1003iV@00oGl4
06H0C03n<`00o1WI0?ko0`00ool0e?Oo003lo`00o_o<0?XI003l<`00oT`306IV
0?eo003jV@00mk?n007<0?^c003jV@00oGl406IV003m<`00o1WJ0?go003eo`00
o?l00?koc03j6@00o3<00?i<0`1VIP3mO`00nYT00?NcoP01c03k/`00nYT00?eo
101VIP00oC<00?`IfP3mo`00mOl00?co003nol`0nQT00?`c003nC0<0IVH0oGl0
0?ZI003g/oh00L`0nk<00?ZI003mO`@0IVH00?dc003l6MX0oOl20?oo0>3go`00
o?l00?koc@3i6@00o3<304a<0?iV003mO`00niT00?Rc0@00o<`00?^c0@00niT0
0?io1@1VIP1<0?hc003l6MX0oOl00?Go003lo`00o_o=0?TI003l<`<0C4`0oVH0
0?eo003kV@00n;<1003lc000nk<1003kV@00oWl506IV04`0oS<00?`IfP3mo`00
mOl00?co003nold0nAT00?`c0`1<C03nIP00oGl00?^I003h/`400?c<003k/`40
0?^I003nO`D0IVH0C03n<`00o1WJ0?go0P3oo`3Mn?on0?go003nolh0nAT00?`c
003nC0<0IVH0oGl00?^I003i/`400?W<003j/`00o9T00?io1@1VIP1<0?dc003l
6M/0oOl00?KooP3mo`00o_o>0?TI003l<`00oT`306IV0?eo003kV@00nK<1003i
c000n[<00?bI003nO`D0IVH0C03m<`00o1WK0?go003fooh0oOl00?kocP3i6@00
o3<00?i<0`1VIP3mO`00niT00?Vc0@00nL`00?Zc003lV@00oWl506IV04`0oC<0
0?`If`3mo`80ool0dO7o003nolh0nAT00?`c003nC0<0IVH0oWl00?^I003k/oh0
m/`00?Zc0@00oIT00?io1@1V04a<0?hc003l6M/0oOl00>oo003nolh0nAT00?`c
003nC0<0IVH0oWl00?^I003k/oh0m/`00?Zc0@00oIT00?io1@1V04a<0?hc003l
6M/0oOl00>oo003nolh0nAT00?`c003nC0<0IVH0oWl00?^I003k/oh0m/`00?Zc
0@00oIT00?io1@1V04a<0?hc003l6M/0oOl20?oo0<kao`00o_o?0?TI003k<`<0
C4`0oVH307mo0?^I003l/`400?;<003j/`00oIT00?io1@1V04a<0?hc003k6M`0
oOl00>oo003noll0nAT00?/c0`1<C03nIP<0Ogl0niT00?bc0@00l/`00?Zc003m
V@00oWl506H0C4`0oS<00?/Ig03mo`00kol00?koc`3i6@00nc<304a<0?iV0`1o
O`3kV@00o;<1003bc000n[<00?fI003nO`D0IP1<C03n<`00naWL0?go0P3oo`3>
lOl00?kod03i6@00nc<00?i<0`1VIP3nO`00o9T00?bc003_c000n[<00?fI1@1o
O`1V0?i<003n<`00o1WL0?go003_o`00o_o@0?TI003k<`00oT`306IV0?io003l
V@00o;<00>o<003j/`00oIT507mo06H0oT`00?hc003l6M`0oOl00>oo003nom00
nAT00?/c003nC0<0IVH0oWl00?bI003l/`00kl`00?Zc003mV@D0Ogl0IP3nC000
oS<00?`Ig03mo`80ool0e?7o003nom00nAT00?/c003nC0<0IVH0oWl00?jI0@00
oK<1003]c000nk<00?fI1@1oO`1V0?i<003n<`00o1WL0?go003_o`00o_o@0?TI
003k<`00oT`306IV0?io003nV@400?fc0@00kL`00?^c003mV@D0Ogl0IP3nC000
oS<00?`Ig03mo`00kol00?kod03i6@00nc<00?i<0`1VIP3nO`00oYT1003m/`40
0>g<003k/`00oIT507mo06H0oT`00?hc003l6M`0oOl20?oo0<_ao`00o_oA0?TI
003k<`00oD`306IV0?io0`2IV@3l/`00jl`00?^c003mV@D0Ogl0IP3nC000oC<0
0?`Ig@3mo`00kol00?kod@3i6@00nc<00?e<0`1VIP3nO`<0VIT0o;<00>_<003k
/`00oIT507mo06H0oT`00?dc003l6Md0oOl00>oo003nom40nAT00?/c003mC0<0
IVH0oWl309VI0?bc003[c000nk<00?fI1@1oO`1V0?i<003m<`00o1WM0?go0P3o
o`3DlOl3003oom40nQT00?/c003mC0<0IVH0oWl00?jI003l/`00j/`00?bc003m
V@00oWl506H0C4`0oC<00?/IgP3no`400>oo0`00oooA0?XI003k<`00oD`306IV
0?io003nV@00o;<00>[<003l/`00oIT00?io1@1V04a<0?dc003k6Mh0o_l1003_
o`<00?ood@3j6@00nc<00?e<0`1VIP3nO`00oYT00?bc003Zc000o;<00?fI003n
O`D0IP1<C03m<`00naWN0?ko0`00ool0bo7o003nom80nAT00?`c003lC0<0IVH0
oWl309VI0?bc003Yc000nk<00?fI1@1oO`1V0?i<003m<`00naWO0?go003_o`00
o_oB0?TI003l<`00o4`306IV0?io0`2IV@3l/`00jL`00?^c003mV@D0Ogl0IP3n
C000oC<00?/Ig`3mo`00kol00?kodP3i6@00o3<00?a<0`1VIP3nO`<0VIT0o;<0
0>W<003k/`00oIT507mo06H0oT`00?dc003k6Ml0oOl20?oo0<_ao`00o_oC0?TI
003k<`00o4`306IV0?io0`2IV@3m/`00j<`00?^c003mV@D0Ogl0IP3nC000oC<0
0?TIh@3mo`00kol00?kod`3i6@00nc<00?a<0`1VIP3nO`<0VIT0oK<00>S<003k
/`00oIT507mo06H0oT`00?dc003i6N40oOl00>oo003nom<0nAT00?/c003lC0<0
IVH0oWl309VI0?fc003Xc000nk<00?fI1@1oO`1V0?i<003m<`00nAWQ0?go0P3o
o`3JlOl00?kod`3j6@00nc<00?a<003nIP<0Ogl0oYT00?fc003lc000k/`00?^c
003mV@T0Ogl0IVH0C4`0o3<00?TIhP3mo`00kol00?kod`3j6@00nc<00?a<003n
IP<0Ogl0oYT00?fc003lc000k/`00?^c003mV@T0Ogl0IVH0C4`0o3<00?TIhP3m
o`00kol00?kod`3j6@00nc<00?a<003nIP<0Ogl0oYT00?fc003lc000k/`00?^c
003mV@T0Ogl0IVH0C4`0o3<00?TIhP3mo`80ool0h?7o003nom@0nQT00?Xc003l
C0<0IVH0oWl309VI0?fc003lc040i_h0l<`00?bc003mV@00oWl506H0C4`0nc<0
0?TIh`3mo`00kol00?koe03j6@00nS<00?a<0`1VIP3nO`<0VIT0oK<00?c<0@3V
oP3`c000o;<00?fI003nO`D0IP1<C03k<`00nAWS0?go003_o`00o_oD0?XI003j
<`00o4`306IV0?io0`2IV@3m/`00o<`10>Kn0?3<003l/`00oIT00?io1@1V04a<
0?/c003i6N<0oOl20?oo0>Kao`00o_oD0?XI003k<`00nd`306IV0?io0`2IV@3m
/`00oL`00?cV0@00l/`00?bc003mV@00oWl506H0C4`0nc<00?LIi@3mo`00kol0
0?koe03j6@00nc<00?]<0`1VIP3nO`<0VIT0oK<00?g<003liP400?;<003l/`00
oIT00?io1@1V04a<0?/c003g6ND0oOl00>oo003nom@0nQT00?/c003kC0<0IVH0
oWl309VI0?fc003mc000o>H1003bc000o;<00?fI003nO`D0IP1<C03k<`00maWU
0?go0P3oo`3VlOl00?koe@3j6@00nS<00?a<003nIPH0Ogl0VIT0oK<00?g<003i
iP400?C<003l/`00oIT00?io1@1V04a<0?Xc003g6NH0oOl00>oo003nomD0nQT0
0?Xc003lC000oVH607mo09VI0?fc003mc000nNH1003dc000o;<00?fI003nO`D0
IP1<C03j<`00maWV0?go003_o`00o_oE0?XI003j<`00o4`00?iV1P1oO`2IV@3m
/`00oL`00?WV0@00m<`00?bc003mV@00oWl506H0C4`0nS<00?LIiP3mo`80ool0
ho7o003nomH0nQT00?Xc003kC000oVH607mo09VI0?jc003mc000m^Kn0?O<003k
/`00oIT507mo06H0oT`00?/c003f6NL0oOl00>oo003nomH0nQT00?Xc003kC000
oVH607mo09VI0?jc003mc000m^Kn0?O<003k/`00oIT507mo06H0oT`00?/c003f
6NL0oOl00>oo003nomH0nQT00?Xc003kC000oVH607mo09VI0?jc003mc000m^Kn
0?O<003k/`00oIT507mo06H0oT`00?/c003f6NL0oOl20?oo0>Kao`00o_oF0?XI
003j<`00nd`306IV0?io0`2IV@3n/`00o/`00?;V0@00n<`00?bc003mV@00oWl5
06H0C4`0nS<00?DIj@3mo`00kol00?koeP3j6@00nS<00?]<0`1VIP3nO`<0VIT0
o[<00?k<003biP400?S<003l/`00oIT00?io1@1V04a<0?Xc003e6NT0oOl00>oo
003nomH0nQT00?Xc003kC0<0IVH0oWl309VI0?jc003nc000l^H1003hc000o;<0
0?fI003nO`D0IP1<C03j<`00mAWY0?go0P3oo`3YlOl3003oomL0nQT00?Xc003k
C000oVH607mo09VI0?jc003nc000l>H00?S<003l/`00oIT00?io1@1V04a<0?Xc
003d6NX0o_l1003_o`<00?ooe`3j6@00nS<00?]<003nIPH0Ogl0VIT0o[<00?k<
003`iP00n<`00?bc003mV@00oWl506H0C4`0nS<00?@IjP3no`400>oo0`00oooG
0?XI003j<`00nd`00?iV1P1oO`2IV@3n/`00o/`00?3V003hc000o;<00?fI003n
O`D0IP1<C03j<`00m1WZ0?ko0`00ool0ho7o003nomL0nQT00?Xc003kC000oVH6
07mo09VI0?jc003nc000l>H00?S<003l/`00oIT00?io1@1V04a<0?Xc003c6N/0
oOl00>oo003nomL0nQT00?Xc003kC000oVH607mo09VI0?jc003nc000l>H00?S<
003l/`00oIT00?io1@1V04a<0?Xc003c6N/0oOl00>oo003nomL0nQT00?Xc003k
C000oVH607mo09VI0?jc003nc000l>H00?S<003l/`00oIT00?io1@1V04a<0?Xc
003c6N/0oOl20?oo0>?ao`00o_oH0?XI003j<`00nT`00?iV1P1oO`2IV@3n/`00
o/`00?3V003gc000o;<00?fI1@1oO`1V0?i<003j<`00m1W[0?go003_o`00o_oH
0?XI003j<`00nT`00?iV1P1oO`2IV@3n/`00o/`00?3V003gc000o;<00?fI1@1o
O`1V0?i<003j<`00m1W[0?go003_o`00o_oH0?XI003j<`00nT`00?iV1P1oO`2I
V@3n/`00o/`00?3V003gc000o;<00?fI1@1oO`1V0?i<003j<`00m1W[0?go0P3o
o`3SlOl00?kof03k6@00nS<00?U<003nIPH0Ogl0VIT0o[<00?k<003`iP00ml`0
0?bc003mV@D0Ogl0IP3nC000nS<00?@Ij`3mo`00kol00?kof03k6@00nS<00?U<
003nIPH0Ogl0VIT0o[<00?k<003`iP00ml`00?bc003mV@D0Ogl0IP3nC000nS<0
0?@Ij`3mo`00kol00?kof03k6@00nS<00?U<003nIPH0Ogl0VIT0o[<00?k<003`
iP00ml`00?bc003mV@D0Ogl0IP3nC000nS<00?@Ij`3mo`80ool0ho7o003nomT0
naT00?Xc003hC000oVH607mo09VI0?jc003nc000lNH00?G<003l/`00oYT907mo
06IV04a<0?Xc003c6N`0oOl00>oo003nomT0naT00?Xc003hC000oVH607mo09VI
0?jc003nc000lNH00?G<003l/`00oYT907mo06IV04a<0?Xc003c6N`0oOl00>oo
003nomT0naT00?Xc003hC000oVH607mo09VI0?jc003nc000lNH00?G<003l/`00
oYT907mo06IV04a<0?Xc003c6N`0oOl20?oo0>?ao`00o_oJ0?/I003i<`00n4`0
0?iV1P1oO`2IV@3n/`00o/`00?7V003dc000oK<00?fI1@1oO`1V0?i<003j<`00
m1W/0?go003_o`00o_oJ0?/I003i<`00n4`00?iV1P1oO`2IV@3n/`00o/`00?7V
003dc000oK<00?fI1@1oO`1V0?i<003j<`00m1W/0?go003_o`00o_oJ0?/I003i
<`00n4`00?iV1P1oO`2IV@3n/`00o/`00?7V003dc000oK<00?fI1@1oO`1V0?i<
003j<`00m1W/0?go0P3oo`3SlOl00?kofP3l6@00nC<00?M<003nIPH0Ogl0VIT0
o[<00?k<003aiP00m<`00?bc003nV@D0Ogl0IP3nC000nS<00?@Ik03mo`00kol0
0?kofP3l6@00nC<00?M<003nIPH0Ogl0VIT0o[<00?k<003aiP00m<`00?bc003n
V@D0Ogl0IP3nC000nS<00?@Ik03mo`00kol00?kofP3l6@00nC<00?M<003nIPH0
Ogl0VIT0o[<00?k<003aiP00m<`00?bc003nV@D0Ogl0IP3nC000nS<00?@Ik03m
o`80ool0h?7o003nom/0naT00?Xc003fC000oVH607mo09VI0?jc003nc000lNH0
0??<003m/`00oIT407l0IP3nC000nS<00?@Ik03mo`00kol00?kof`3k6@00nS<0
0?I<003nIPH0Ogl0VIT0o[<00?k<003aiP00ll`00?fc003mV@@0O`1V0?i<003j
<`00m1W/0?go003_o`00o_oK0?/I003j<`00mT`00?iV1P1oO`2IV@3n/`00o/`0
0?7V003cc000oK<00?fI101o06H0oT`00?Xc003d6N`0oOl20?oo0=gao`00o_oK
0?`I003j<`00mD`906IV07mo09VI0?jc003lc000lnH00?7<003n/`00oIT407l0
IP3mC000nS<00?DIk03mo`00kol00?kof`3l6@00nS<00?E<2@1VIP1oO`2IV@3n
/`00o<`00??V003ac000o[<00?fI101o06H0oD`00?Xc003e6N`0oOl00>oo003n
om/0o1T00?Xc003eC0T0IVH0Ogl0VIT0o[<00?c<003ciP00lL`00?jc003mV@@0
O`1V0?e<003j<`00mAW/0?go0P3oo`3SlOl3003oom`0o1T00?Xc003dC0T0IVH0
Ogl0VIT0o[<00?c<003ciP00lL`00?fc003nV@@0O`1V0?e<003j<`00mAW/0?ko
0@00kol3003oom`0o1T00?Xc003dC0T0IVH0Ogl0VIT0o[<00?c<003ciP00lL`0
0?fc003nV@@0O`1V0?e<003j<`00mAW/0?ko0@00kol3003oom`0o1T00?Xc003d
C0T0IVH0Ogl0VIT0o[<00?c<003ciP00lL`00?fc003nV@@0O`1V0?e<003j<`00
mAW/0?ko0`00ool0f_7o003nomd0o1T00?Tc003dC0T0IVH0Ogl0VIT0o[<00?c<
003ciP00l<`00?jc003mV@<006H0o4`00?Xc003f6N`0oOl00>oo003nomd0o1T0
0?Tc003dC0T0IVH0Ogl0VIT0o[<00?c<003ciP00l<`00?jc003mV@<006H0o4`0
0?Xc003f6N`0oOl00>oo003nomd0o1T00?Tc003dC0T0IVH0Ogl0VIT0o[<00?c<
003ciP00l<`00?jc003mV@<006H0o4`00?Xc003f6N`0oOl20?oo0=gao`00o_oN
0?`I003i<`00ld`906IV07mo09VI0?jc003lc000lnH00?3<003m/`00oYT407l0
IP3mC000nS<00?DIk@3mo`00kol00?kogP3l6@00nC<00?=<2@1VIP1oO`2IV@3n
/`00o<`00??V003`c000oK<00?jI101o06H0oD`00?Xc003e6Nd0oOl00>oo003n
omh0o1T00?Tc003cC0T0IVH0Ogl0VIT0o[<00?c<003ciP00l<`00?fc003nV@@0
O`1V0?e<003j<`00mAW]0?go0P3oo`3MlOl00?kog`3l6@00nC<00?9<2@1VIP1o
O`2IV@3n/`00o<`00?CV003^c000o[<00?jI101o06H0oD`00?Xc003e6Nd0oOl0
0>oo003noml0o1T00?Tc003bC0T0IVH0Ogl0VIT0o[<00?c<003diP00k/`00?jc
003nV@@0O`1V0?e<003j<`00mAW]0?go003_o`00o_oO0?`I003i<`00lT`906IV
07mo09VI0?jc003lc000m>H00>k<003n/`00oYT407l0IP3mC000nS<00?DIk@3m
o`80ool0f_7o003non00o1T00?Tc003aC0T0IVH0Ogl0VIT0o[<00?c<003diP00
kL`00?jc1`2IV@1o06H0o4`00?Xc003f6Nd0oOl00>oo003non00o1T00?Tc003a
C0T0IVH0Ogl0VIT0o[<00?c<003diP00kL`00?jc1`2IV@1o06H0o4`00?Xc003f
6Nd0oOl00>oo003non00o1T00?Tc003aC0T0IVH0Ogl0VIT0o[<00?c<003diP00
kL`00?jc1`2IV@1o06H0o4`00?Xc003f6Nd0oOl20?oo0=gao`00o_oQ0?`I0@00
nS<00?1<2@1VIP1oO`2IV@3n/`00o<`00?CV003]c000o[<709VI07l0IP3lC000
nS<00?HIk@3mo`00kol00?koh@3l6@400?Xc003`C0T0IVH0Ogl0VIT0o[<00?c<
003diP00kL`00?jc1`2IV@1o06H0o4`00?Xc003f6Nd0oOl00>oo003non40o1T1
003j<`00l4`906IV07mo09VI0?jc003lc000m>H00>g<003n/`L0VIT0O`1V0?a<
003j<`00mQW]0?go0P3oo`3MlOl00?kohP3l6@00nC<00>m<2@1VIP1oO`2IV@3m
/`00o<`00?OV0@00k<`00?jc1`2IV@1o06H0o4`00?Xc003f6Nd0oOl00>oo003n
on80o1T00?Tc003_C0T0IVH0Ogl0VIT0oK<00?c<003giP400>c<003n/`L0VIT0
O`1V0?a<003j<`00mQW]0?go003_o`00o_oR0?`I003i<`00kd`906IV07mo09VI
0?fc003lc000mnH1003/c000o[<709VI07l0IP3lC000nS<00?HIk@3mo`80ool0
h?7o003non80o1T00?Xc003_C000oVH607mo09VI0?bc003lc000nNH00>[<003n
/`P0VIT0O`1VIP3mC000nS<00?HIk@3mo`00kol00?kohP3l6@00nS<00>m<003n
IPH0Ogl0VIT0o;<00?c<003iiP00j/`00?jc202IV@1o06IV0?e<003j<`00mQW]
0?go003_o`00o_oR0?`I003j<`00kd`00?iV1P1oO`2IV@3l/`00o<`00?WV003Z
c000o[<809VI07l0IVH0oD`00?Xc003f6Nd0oOl20?oo0@Oao`<00?ooh`3l6@00
nS<00?]<0@00mT`00?iV0`1oO`3nV@00oK<00?_<003liP400??<n`3mc000o[<8
09VI07l0IVH0o4`00?/c003f6Nd0o_l1003_o`<00?ooh`3l6@00nS<00?]<0@00
mT`00?iV0`1oO`3nV@00oK<00?_<003liP400??<n`3mc000o[<809VI07l0IVH0
o4`00?/c003f6Nd0o_l1003_o`<00?ooh`3l6@00nS<00?]<0@00mT`00?iV0`1o
O`3nV@00oK<00?_<003liP400??<n`3mc000o[<809VI07l0IVH0o4`00?/c003f
6Nd0o_l3003oo`4FlOl00?koi03l6@00nc<1003kC080IVKm0?Y<003nIP<0Ogl0
oYT00?bc003kc0@0i^H00?W<n@3liP00oL`00?jc202IV@1o06IV0?a<003k<`00
mQW]0?go003_o`00o_oT0?`I003k<`400?]<0P1VI_d0nT`00?iV0`1oO`3nV@00
o;<00?_<103ViP00nLci0?cV003mc000o[<809VI07l0IVH0o4`00?/c003f6Nd0
oOl00>oo003non@0o1T00?/c0@00nd`206IVo@3jC000oVH307mo0?jI003l/`00
nl`40>KV003ic?T0o>H00?g<003n/`P0VIT0O`1VIP3lC000nc<00?HIk@3mo`80
ool12_7o003non@0o1T00?`c003jC000nVKm009<C03mIP<0Ogl0oYT00?^c003k
c0400?S<003diP00oL`00?jc202IV@1o06IV0?a<003k<`00mQW]0?go003_o`00
o_oT0?`I003l<`00nT`00?YVo@02C4`0oFH307mo0?jI003k/`00nl`1003hc000
m>H00?g<003n/`P0VIT0O`1VIP3lC000nc<00?HIk@3mo`00kol00?koi03l6@00
o3<00?Y<003jI_d00Ta<0?eV0`1oO`3nV@00nk<00?_<0@00n<`00?CV003mc000
o[<809VI07l0IVH0o4`00?/c003f6Nd0oOl20?oo0>oao`00o_oU0?`I003l<`00
nT`00?EVoP3nIP00oGl309VI0?^c003ac000lnH00?c<003n/`P0VIT0O`1VIP3m
C000nS<00?PIk03mo`00kol00?koi@3l6@00o3<00?Y<003eI_h0oVH00?eo0`2I
V@3k/`00lL`00??V003lc000o[<809VI07l0IVH0oD`00?Xc003h6N`0oOl00>oo
003nonD0o1T00?`c003jC000mFKn0?iV003mO`<0VIT0nk<00?7<003ciP00o<`0
0?jc202IV@1o06IV0?e<003j<`00n1W/0?go0P3oo`3VlOl00?koi@3l6@00oS<1
003jC000kVH00?eo0`2IV@3j/`00ll`00?;V003lc000o[<809VI07l0IVH0oD`0
0?Xc003h6N`0oOl00>oo003nonD0o1T00?hc0@00nT`00>iV003mO`<0VIT0n[<0
0??<003biP00o<`00?jc202IV@1o06IV0?e<003j<`00n1W/0?go003_o`00o_oU
0?`I003n<`400?Y<003^IP00oGl309VI0?Zc003cc000l^H00?c<003n/`P0VIT0
O`1VIP3mC000nS<00?PIk03mo`80ool0i_7o003nonH0o1T00?hc003iC000kFH0
0?eo003nV@00n[<00?G<003`iP00oL`00?jc202IV@1o06IV0?e<003j<`00n1W/
0?go003_o`00o_oV0?`I003n<`00nD`00>eV003mO`00oYT00?Zc003ec000l>H0
0?g<003n/`P0VIT0O`1VIP3mC000nS<00?PIk03mo`00kol00?koiP3l6@00oS<0
0?U<003]IP00oGl00?jI003j/`00mL`00?3V003mc000o[<809VI07l0IVH0oD`0
0?Xc003h6N`0oOl20?oo0?Ggo`400?go003nonL0o1T00?dc003jC000k6H00?eo
003nV@00n[<00?K<003_iP00oL`00?jc202IV@1o06IV0?a<003k<`00n1W/0?go
003eo`400?go003nonL0o1T00?dc003jC000k6H00?eo003nV@00n[<00?K<003_
iP00oL`00?jc202IV@1o06IV0?a<003k<`00n1W/0?go003eo`400?go003nonL0
o1T00?dc003jC000k6H00?eo003nV@00n[<00?K<003_iP00oL`00?jc202IV@1o
06IV0?a<003k<`00n1W/0?go0P3oo`3nn?l30?oo0?ko003nonL0o1T00?hc003j
C000jfH00?eo003nV@00nK<00?S<003^iP00oL`00?jc1@2IV@1o0?iV003mC000
nc<00?PIk03mo`00m_l30?oo0?ko003nonL0o1T00?hc003jC000jfH00?eo003n
V@00nK<00?S<003^iP00oL`00?jc1@2IV@1o0?iV003mC000nc<00?PIk03mo`00
m_l30?oo0?ko003nonL0o1T00?hc003jC000jfH00?eo003nV@00nK<00?S<003^
iP00oL`00?jc1@2IV@1o0?iV003mC000nc<00?PIk03mo`80ool0o_So0`3oo`3n
o`00o_oX0?`I003n<`00nT`00>YV003mO`00oYT00?Rc003jc000kNH00?g<003n
/`D0VIT0O`3nIP00oD`00?/c003h6N`0oOl00?Ko0`3oo`3no`00o_oX0?`I003n
<`00nT`00>YV003mO`00oYT00?Rc003jc000kNH00?g<003n/`D0VIT0O`3nIP00
oD`00?/c003h6N`0oOl00?Ko0`3oo`3no`00o_oX0?`I003n<`00nT`00>YV003m
O`00oYT00?Rc003jc000kNH00?g<003n/`D0VIT0O`3nIP00oD`00?/c003h6N`0
oOl20?oo0@Cho`<0ool0o_l3003oonT0naT00?hc003jC000jVH00?eo003mV@00
nK<00?_<003/iP00oL`00?jc1@2IV@1o0?iV003mC000nc<00?PIk03no`400?Ko
0`3oo`3no`<00?ooj@3k6@00oS<00?Y<003ZIP00oGl00?fI003i/`00nl`00>cV
003mc000o[<509VI07l0oVH00?e<003k<`00n1W/0?ko0@00m_l30?oo0?ko0`00
oooY0?/I003n<`00nT`00>YV003mO`00oIT00?Vc003kc000k>H00?g<003n/`D0
VIT0O`3nIP00oD`00?/c003h6N`0o_l3003oo`3nn?l30?oo0?ko003nonX0naT0
0?hc003jC000jFH00?ao003mV@00n[<00?_<003/iP00oL`00?jc1@2IV@1o0?iV
003mC000nc<00?PIk03mo`00m_l30?oo0?ko003nonX0naT00?hc003jC000jFH0
0?ao003mV@00n[<00?_<003/iP00oL`00?jc1@2IV@1o0?iV003mC000nc<00?PI
k03mo`00m_l30?oo0?ko003nonX0naT00?hc003jC000jFH00?ao003mV@00n[<0
0?_<003/iP00oL`00?jc1@2IV@1o0?iV003mC000nc<00?PIk03mo`80ool11oSo
0`3oo`3no`00o_o[0?XI0`0c<`3jC000ifH00?eo003mV@00n[<00?_<003jiP00
m>H00?g<003n/`D0VIT0O`3nIP00oD`00?`c003h6N/0oOl00?Ko0`3oo`3no`00
o_o[0?XI0`0c<`3jC000ifH00?eo003mV@00n[<00?_<003jiP00m>H00?g<003n
/`D0VIT0O`3nIP00oD`00?`c003h6N/0oOl00?Ko0`3oo`3no`00o_o[0?XI0`0c
<`3jC000ifH00?eo003mV@00n[<00?_<003jiP00m>H00?g<003n/`D0VIT0O`3n
IP00oD`00?`c003h6N/0oOl20?oo0@Ogo`400?go003non`0nQT00?hc003jC000
ifH00?ao003mV@00n[<00?c<003kiP80o`3diP00oL`80;>c09VI07l0oVH00?e<
003l<`00n1W[0?go003eo`400?go003non`0nQT00?hc003jC000ifH00?ao003m
V@00n[<00?c<003kiP80o`3diP00oL`80;>c09VI07l0oVH00?e<003l<`00n1W[
0?go003eo`400?go003non`0nQT00?hc003jC000ifH00?ao003mV@00n[<00?c<
003kiP80o`3diP00oL`80;>c09VI07l0oVH00?e<003l<`00n1W[0?go0P3oo`3h
lOl00?kok03j6@<0<c<0nT`00>IV003lO`00oIT00?Zc003lc000nnH30?oo0?GV
003mc0P0/k<0VIT0O`3nIP00oD`00?`c003h6N/0oOl00>oo003non`0nQT303<c
0?Y<003VIP00o7l00?fI003j/`00o<`00?_V0`3oo`3eiP00oL`80;>c09VI07l0
oVH00?e<003l<`00n1W[0?go003_o`00o_o/0?XI0`0c<`3jC000iVH00?ao003m
V@00n[<00?c<003kiP<0ool0mNH00?g<202c/`2IV@1o0?iV003mC000o3<00?PI
j`3mo`80ool0o_7o003nond0nQT00?hc003kC000i6H00?eo003lV@00nk<00?c<
003liP00oOl00?KV003mc0P0/k<0VIT0O`3nIP00oD`00?`c003i6NX0oOl00>oo
003nond0nQT00?hc003kC000i6H00?eo003lV@00nk<00?c<003liP00oOl00?KV
003mc0P0/k<0VIT0O`3nIP00oD`00?`c003i6NX0oOl00>oo003nond0nQT00?hc
003kC000i6H00?eo003lV@00nk<00?c<003liP00oOl00?KV003mc0P0/k<0VIT0
O`3nIP00oD`00?`c003i6NX0oOl20?oo0?kao`00o_o^0?XI003n<`00nd`00>=V
003lO`00oIT00?^c003lc000o>H00?co003giP00oL`80;>c09T0Ogl0oVH00?e<
003l<`00nAWZ0?go003_o`00o_o^0?XI003n<`00nd`00>=V003lO`00oIT00?^c
003lc000o>H00?co003giP00oL`80;>c09T0Ogl0oVH00?e<003l<`00nAWZ0?go
003_o`00o_o^0?XI003n<`00nd`00>=V003lO`00oIT00?^c003lc000o>H00?co
003giP00oL`80;>c09T0Ogl0oVH00?e<003l<`00nAWZ0?go0P3oo`3klOl00?ko
k`3i6@<0<c<0nT`00>=V003lO`00oIT00?^c003mc000nnH00?_o003hiP00oL`8
0;>c09T0Ogl0oVH00?i<003l<`00n1WZ0?go003_o`00o_o_0?TI0`0c<`3jC000
hfH00?ao003mV@00nk<00?g<003kiP00nol00?SV003mc0P0/k<0V@1oO`3nIP00
oT`00?`c003h6NX0oOl00>oo003nonl0nAT303<c0?Y<003SIP00o7l00?fI003k
/`00oL`00?_V003ko`00n>H00?g<202c/`2I07mo0?iV003nC000o3<00?PIjP3m
o`80ool0o_7o003noo00nAT00?hc003kC000hFH00?ao003mV@00o;<00?g<003l
iP00nOl00?WV003mc0P0/k<0V@1oO`3nIP00oT`00?`c003i6NT0oOl00>oo003n
oo00nAT00?hc003kC000hFH00?ao003mV@00o;<00?g<003liP00nOl00?WV003m
c0P0/k<0V@1oO`3nIP00oT`00?`c003i6NT0oOl00>oo003noo00nAT00?hc003k
C000hFH00?ao003mV@00o;<00?g<003liP00nOl00?WV003mc0P0/k<0V@1oO`3n
IP00oT`00?`c003i6NT0oOl20?oo0@7ao`<00?ool03i6@<0<c<0nd`00>1V003l
O`00oIT00?bc003mc000o>H00?So003jiP00oL`80;>c09T0Ogl0oVH00?i<003l
<`00nAWY0?ko0@00kol3003ooo00nAT303<c0?]<003PIP00o7l00?fI003l/`00
oL`00?cV003ho`00n^H00?g<202c/`2I07mo0?iV003nC000o3<00?TIj@3no`40
0>oo0`00ooo`0?TI0`0c<`3kC000h6H00?ao003mV@00o;<00?g<003liP00n?l0
0?[V003mc0P0/k<0V@1oO`3nIP00oT`00?`c003i6NT0o_l3003oo`3klOl00?ko
l@3i6@00oS<00?]<003PIP00ngl00?fI003l/`00o/`00?gV003fo`00n^H00?g<
1`2c09T0Ogl0oVH00?i<003l<`00nAWY0?go003_o`00o_oa0?TI003n<`00nd`0
0>1V003kO`00oIT00?bc003nc000oNH00?Ko003jiP00oL`70;<0V@1oO`3nIP00
oT`00?`c003i6NT0oOl00>oo003noo40nAT00?hc003kC000h6H00?]o003mV@00
o;<00?k<003miP00m_l00?[V003mc0L0/`2I07mo0?iV003nC000o3<00?TIj@3m
o`80ool0n?7o003noo80n1T303<c0?]<003NIP00o7l00?fI003l/`00o/`00?gV
003eo`00nnH00?g<1`2c09T0Ogl0oVH00?i<003m<`00nAWX0?go003_o`00o_ob
0?PI0`0c<`3kC000gVH00?ao003mV@00o;<00?k<003miP00mOl00?_V003mc0L0
/`2I07mo0?iV003nC000oC<00?TIj03mo`00kol00?kolP3h6@<0<c<0nd`00=iV
003lO`00oIT00?bc003nc000oNH00?Go003kiP00oL`70;<0V@1oO`3nIP00oT`0
0?dc003i6NP0oOl20?oo0?Sao`00o_oc0?PI0`0c<`3kC000gFH00?]o003mV@00
oK<00?k<003niP00lol00?cV003mc0L0/`2I07mo0?iV003nC000oC<00?TIj03m
o`00kol00?kol`3h6@<0<c<0nd`00=eV003kO`00oIT00?fc003nc000o^H00??o
003liP00oL`70;<0V@1oO`3nIP00oT`00?dc003i6NP0oOl00>oo003noo<0n1T3
03<c0?]<003MIP00ngl00?fI003m/`00o/`00?kV003co`00o>H00?g<1`2c09T0
Ogl0oVH00?i<003m<`00nAWX0?go0P3oo`3hlOl00?kol`3h6@<0<c<0nd`00=eV
003kO`00oIT00?fc003nc000o^H00??o003liP00oL`70;<0V@1oO`3nIP00oT`0
0?dc003i6NP0oOl00>oo003noo<0n1T303<c0?]<003MIP00ngl00?fI003m/`00
o/`00?kV003co`00o>H00?g<1`2c09T0Ogl0oVH00?i<003m<`00nAWX0?go003_
o`00o_oc0?PI0`0c<`3kC000gFH00?]o003mV@00oK<00?k<003niP00lol00?cV
003mc0L0/`2I07mo0?iV003nC000oC<00?TIj03mo`80ool0no7o003nooD0maT0
0?hc003kC000gFH00?ao003mV@00oK<00?g<003niP00m?l00?cV003mc0@0/`2I
0?io0`1VIP3mC000oC<00?XIi`3mo`00kol00?kom@3g6@00oS<00?]<003MIP00
o7l00?fI003m/`00oL`00?kV003do`00o>H00?g<102c09T0oWl306IV0?e<003m
<`00nQWW0?go003_o`00o_oe0?LI003n<`00nd`00=eV003lO`00oIT00?fc003m
c000o^H00?Co003liP00oL`40;<0V@3nO`<0IVH0oD`00?dc003j6NL0oOl20?oo
0?_ao`00o_of0?LI003m<`00nd`00=iV003kO`00oIT00?fc003nc000oNH00?Co
003liP00oL`70;<0V@1oO`3nIP00oT`00?dc003i6NL0oOl00>oo003nooH0maT0
0?dc003kC000gVH00?]o003mV@00oK<00?k<003miP00m?l00?cV003mc0L0/`2I
07mo0?iV003nC000oC<00?TIi`3mo`00kol00?komP3g6@00oC<00?]<003NIP00
ngl00?fI003m/`00o/`00?gV003do`00o>H00?g<1`2c09T0Ogl0oVH00?i<003m
<`00nAWW0?go0P3oo`3nlOl00?komP3h6@00o3<00?Y<003OIP00o7l00?fI003m
/`00oL`00?kV003co`00oNH00?g<202c09VI07mo0?iV003nC000oC<00?XIiP3m
o`00kol00?komP3h6@00o3<00?Y<003OIP00o7l00?fI003m/`00oL`00?kV003c
o`00oNH00?g<202c09VI07mo0?iV003nC000oC<00?XIiP3mo`00kol00?komP3h
6@00o3<00?Y<003OIP00o7l00?fI003m/`00oL`00?kV003co`00oNH00?g<202c
09VI07mo0?iV003nC000oC<00?XIiP3mo`80ool0o_7o003nooL0maT00?`c003j
C000gfH00?ao003mV@00oK<00?g<003niP00m?l00?cV003nc0D0/k<0V@3nO`<0
IVH0oD`00?dc003k6ND0oOl00>oo003nooL0maT00?`c003jC000gfH00?ao003m
V@00oK<00?g<003niP00m?l00?cV003nc0D0/k<0V@3nO`<0IVH0oD`00?dc003k
6ND0oOl00>oo003nooL0maT00?`c003jC000gfH00?ao003mV@00oK<00?g<003n
iP00m?l00?cV003nc0D0/k<0V@3nO`<0IVH0oD`00?dc003k6ND0oOl20?oo0@Ca
o`<00?oon03g6@00nc<00?Y<003PIP00o7l00?fI003m/`00oL`00?gV003do`00
oNH00?g<202c09VI07mo0?iV003nC000o3<00?/Ii@3no`400>oo0`00oooh0?LI
003k<`00nT`00>1V003lO`00oIT00?fc003mc000oNH00?Co003miP00oL`80;<0
VIT0Ogl0oVH00?i<003l<`00naWU0?ko0@00kol3003oooP0maT00?/c003jC000
h6H00?ao003mV@00oK<00?g<003miP00m?l00?gV003mc0P0/`2IV@1oO`3nIP00
oT`00?`c003k6ND0o_l3003oo`3nlOl00?kon03h6@00nS<00?Y<003PIP00o7l0
0?fI003m/`00oL`00?gV003eo`00o>H00?k<1@2c/`2I0?io0`1VIP3mC000oC<0
0?/Ii03mo`00kol00?kon03h6@00nS<00?Y<003PIP00o7l00?fI003m/`00oL`0
0?gV003eo`00o>H00?k<1@2c/`2I0?io0`1VIP3mC000oC<00?/Ii03mo`00kol0
0?kon03h6@00nS<00?Y<003PIP00o7l00?fI003m/`00oL`00?gV003eo`00o>H0
0?k<1@2c/`2I0?io0`1VIP3mC000oC<00?/Ii03mo`80ool12_7o003nooT0n1T0
0?Tc003jC000lVH00?1V003mO`00oIT00?fc003lc000oNH00?Go003miP00oL`5
0;<0VIT0oWl306IV0?e<003m<`00naWT0?go003_o`00o_oi0?PI003i<`00nT`0
0?9V003`IP00oGl00?fI003m/`00o<`00?gV003eo`00oNH00?g<1@2c09VI0?io
0`1VIP3mC000oC<00?/Ii03mo`00kol00?kon@3h6@00nC<00?Y<003bIP00l6H0
0?eo003mV@00oK<00?c<003miP00mOl00?gV003mc0D0/`2IV@3nO`<0IVH0oD`0
0?dc003k6N@0oOl20?oo0A3ao`00o_oj0?LI003i<`00nT`00?=V0P1o0?9V003l
O`00oIT00?fc003mc000o>H00?Ko003liP00o/`50;>c09T0oWl306IV0?e<003l
<`00o1WS0?go003_o`00o_oj0?LI003i<`00nT`00?=V0P1o0?9V003lO`00oIT0
0?fc003mc000o>H00?Ko003liP00o/`50;>c09T0oWl306IV0?e<003l<`00o1WS
0?go003_o`00o_oj0?LI003i<`00nT`00?=V0P1o0?9V003lO`00oIT00?fc003m
c000o>H00?Ko003liP00o/`50;>c09T0oWl306IV0?e<003l<`00o1WS0?go0P3o
o`4FlOl00?konP3h6@00n3<00?U<003eIP<0Ogl0lVH00?eo003mV@00oK<00?c<
003miP00mOl00?gV003nc0H0/k<0VIT0oWl306IV0?e<003m<`00o1WR0?go003_
o`00o_oj0?PI003h<`00nD`00?EV0`1oO`3bIP00oGl00?fI003m/`00o<`00?gV
003eo`00oNH00?k<1P2c/`2IV@3nO`<0IVH0oD`00?dc003l6N80oOl00>oo003n
ooX0n1T00?Pc003iC000mFH307mo0?9V003mO`00oIT00?fc003lc000oNH00?Go
003miP00o/`60;>c09VI0?io0`1VIP3mC000oC<00?`IhP3mo`80ool16O7o003n
oo/0n1T00?Lc003iC000mVH00?io003bIP00oGl00?fI003m/`00o<`00?gV003e
o`00oNH00?k<1P2c/`2IV@3nO`<0IVH0oD`00?dc003l6N80oOl00>oo003noo/0
n1T00?Lc003iC000mVH00?io003bIP00oGl00?fI003m/`00o<`00?gV003eo`00
oNH00?k<1P2c/`2IV@3nO`<0IVH0oD`00?dc003l6N80oOl00>oo003noo/0n1T0
0?Lc003iC000mVH00?io003bIP00oGl00?fI003m/`00o<`00?gV003eo`00oNH0
0?k<1P2c/`2IV@3nO`<0IVH0oD`00?dc003l6N80oOl20?oo0AWao`00o_ol0?PI
003f<`00nD`00?MV003lO`00m6H00?eo003mV@00oK<00?c<003liP00m_l00?gV
003nc0H0/k<0VIT0oWl306IV0?e<003l<`00oAWQ0?go003_o`00o_ol0?PI003f
<`00nD`00?MV003lO`00m6H00?eo003mV@00oK<00?c<003liP00m_l00?gV003n
c0H0/k<0VIT0oWl306IV0?e<003l<`00oAWQ0?go003_o`00o_ol0?PI003f<`00
nD`00?MV003lO`00m6H00?eo003mV@00oK<00?c<003liP00m_l00?gV003nc0H0
/k<0VIT0oWl306IV0?e<003l<`00oAWQ0?go0P3oo`4IlOl00?koo03h6@00mS<0
0?U<003gIP00o7l00?AV003mO`00oIT00?fc003lc000o>H00?Ko003miP00o/`6
0;>c09VI0?io0`1VIP3mC000oC<00?`Ih@3mo`00kol00?koo03h6@00mS<00?U<
003gIP00o7l00?AV003mO`00oIT00?fc003lc000o>H00?Ko003miP00o/`60;>c
09VI0?io0`1VIP3mC000oC<00?`Ih@3mo`00kol00?koo03h6@00mS<00?U<003g
IP00o7l00?AV003mO`00oIT00?fc003lc000o>H00?Ko003miP00o/`60;>c09VI
0?io0`1VIP3mC000oC<00?`Ih@3mo`80ool16O7o003noo`0nAT00?Dc003iC000
mfH00?ao003dIP00oGl00?jI003l/`00o<`00?_V003ho`00oNH00?g<1@2c09VI
0?io003nIP00oT`00?dc003l6N00oOl00>oo003noo`0nAT00?Dc003iC000mfH0
0?ao003dIP00oGl00?jI003l/`00o<`00?_V003ho`00oNH00?g<1@2c09VI0?io
003nIP00oT`00?dc003l6N00oOl00>oo003noo`0nAT00?Dc003iC000mfH00?ao
003dIP00oGl00?jI003l/`00o<`00?_V003ho`00oNH00?g<1@2c09VI0?io003n
IP00oT`00?dc003l6N00oOl20?oo0Aoao`<00?ooo@3h6@00mC<00?U<003fIP00
oGl00?AV003mO`00oYT00?bc003lc000n^H00?[o003miP00oL`60;>c09VI0?io
0`1VIP3mC000oC<00?`Ih03no`400>oo0`00ooom0?PI003e<`00nD`00?IV003m
O`00m6H00?eo003nV@00o;<00?c<003jiP00n_l00?gV003mc0H0/k<0VIT0oWl3
06IV0?e<003m<`00o1WP0?ko0@00kol3003oood0n1T00?Dc003iC000mVH00?eo
003dIP00oGl00?jI003l/`00o<`00?[V003jo`00oNH00?g<1P2c/`2IV@3nO`<0
IVH0oD`00?dc003l6N00o_l3003oo`4LlOl00?koo@3i6@00mC<00?U<003eIP00
oWl00?=V003mO`00oYT00?bc003lc000nNH1003mo`00oNH00?c<1P2c/`2IV@3n
O`<0IVH0oD`00?hc003l6Ml0oOl00>oo003nood0nAT00?Dc003iC000mFH00?io
003cIP00oGl00?jI003l/`00o<`00?WV0@00oOl00?gV003lc0H0/k<0VIT0oWl3
06IV0?e<003n<`00o1WO0?go003_o`00o_om0?TI003e<`00nD`00?EV003nO`00
lfH00?eo003nV@00o;<00?c<003iiP400?go003miP00o<`60;>c09VI0?io0`1V
IP3mC000oS<00?`Ig`3mo`80ool16O7o003nood0nAT00?Dc003iC000mFH00?io
003cIP00oGl00?jI003l/`00nl`00?SV0`3oo`3miP00o<`60;>c09VI0?io003n
IP00oT`00?dc003l6Ml0oOl00>oo003nood0nAT00?Dc003iC000mFH00?io003c
IP00oGl00?jI003l/`00nl`00?SV0`3oo`3miP00o<`60;>c09VI0?io003nIP00
oT`00?dc003l6Ml0oOl00>oo003nood0nAT00?Dc003iC000mFH00?io003cIP00
oGl00?jI003l/`00nl`00?SV0`3oo`3miP00o<`60;>c09VI0?io003nIP00oT`0
0?dc003l6Ml0oOl20?oo0A3ao`00o_om0?TI003e<`00nD`00?AV0`1oO`3cIP00
oGl00?jI003l/`00nl`00?OV0@00oNH00?c<003n/`<0VIT0oWl306IV0?e<003n
<`00naWO0?go003_o`00o_om0?TI003e<`00nD`00?AV0`1oO`3cIP00oGl00?jI
003l/`00nl`00?OV0@00oNH00?c<003n/`<0VIT0oWl306IV0?e<003n<`00naWO
0?go003_o`00o_om0?TI003e<`00nD`00?AV0`1oO`3cIP00oGl00?jI003l/`00
nl`00?OV0@00oNH00?c<003n/`<0VIT0oWl306IV0?e<003n<`00naWO0?go0P3o
o`44lOl00?koo@3j6@00m3<00?U<003dIP<0Ogl0lfH00?eo003nV@00o;<00?_<
003biP00o<`00?jc003nV@00oWl306IV0?e<003n<`00o1WN0?go003_o`00o_om
0?XI003d<`00nD`00?AV0`1oO`3cIP00oGl00?jI003l/`00nl`00?;V003lc000
o[<00?jI003nO`<0IVH0oD`00?hc003l6Mh0oOl00>oo003nood0nQT00?@c003i
C000m6H307mo0?=V003mO`00oYT00?bc003kc000l^H00?c<003n/`00oYT00?io
0`1VIP3mC000oS<00?`IgP3mo`80ool11?7o003nooh0nAT00?Dc003hC000m6H3
07mo0?9V003nO`00oYT00?fc003jc000lnH00?c<003m/`<0VIT0oWl00?iV003n
C000oC<00?`IgP3mo`00kol00?kooP3i6@00mC<00?Q<003dIP<0Ogl0lVH00?io
003nV@00oK<00?[<003ciP00o<`00?fc0`2IV@3nO`00oVH00?i<003m<`00o1WN
0?go003_o`00o_on0?TI003e<`00n4`00?AV0`1oO`3bIP00oWl00?jI003m/`00
n/`00??V003lc000oK<309VI0?io003nIP00oT`00?dc003l6Mh0oOl20?oo0@7a
o`00o_on0?TI003e<`00n4`00?=V0P1o0?9V003nO`<0VIT0o;<00?[<0@00mNH0
0?_<003m/`<0VIT0oWl00?iV003nC000oS<00?`Ig@3mo`00kol00?kooP3i6@00
mC<00?Q<003cIP80O`3bIP00oWl309VI0?bc003jc0400?GV003kc000oK<309VI
0?io003nIP00oT`00?hc003l6Md0oOl00>oo003nooh0nAT00?Dc003hC000lfH2
07l0lVH00?io0`2IV@3l/`00n/`1003eiP00nl`00?fc0`2IV@3nO`00oVH00?i<
003n<`00o1WM0?go0P3oo`3klOl00?kooP3j6@00m3<00?Q<003cIP400?5V003n
O`<0VIT0o;<00?S<o@3jiP00nl`00?fc0`2IV@3nO`00oVH00?i<003m<`00o1WM
0?go003_o`00o_on0?XI003d<`00n4`00?=V0@00lFH00?io0`2IV@3l/`00n<cm
0?[V003kc000oK<309VI0?io003nIP00oT`00?dc003l6Md0oOl00>oo003nooh0
nQT00?@c003hC000lfH1003aIP00oWl309VI0?bc003hc?d0n^H00?_<003m/`<0
VIT0oWl00?iV003nC000oC<00?`Ig@3mo`80ool10O7o0`00ooon0?XI003d<`00
nD`00?9V0@00lFH00?io0`2IV@3l/`00m<cm00;ViP3kc000o;<309VI0?io003n
IP00oT`00?hc003l6M`0o_l1003_o`<00?oooP3j6@00m3<00?U<003bIP400?5V
003nO`<0VIT0o;<00?C<o@02i^H0nl`00?bc0`2IV@3nO`00oVH00?i<003n<`00
o1WL0?ko0@00kol3003oooh0nQT00?@c003iC000lVH1003aIP00oWl309VI0?bc
003dc?d00^KV0?_<003l/`<0VIT0oWl00?iV003nC000oS<00?`Ig03no`<00?oo
0?;ao`00o_l1003i6@00mC<00?Q<003aIP00lFH00?io0`2IV@3l/`00l<cn0?c<
003l/`00oYT00?io003nIP00oT`00?hc003l6M`0oOl00>oo003no`400?TI003e
<`00n4`00?5V003aIP00oWl309VI0?bc003`c?h0o<`00?bc003nV@00oWl00?iV
003nC000oS<00?`Ig03mo`00kol00?ko0@00nAT00?Dc003hC000lFH00?5V003n
O`<0VIT0o;<00?3<oP3lc000o;<00?jI003nO`00oVH00?i<003n<`00o1WL0?go
0P3oo`3VlOl00?ko0@00nQT00?@c003hC000lFH00?5V003nO`<0VIT0o;<00>W<
003l/`00oYT00?io003nIP00oT`00?hc003l6M/0oOl00>oo003no`400?XI003d
<`00n4`00?5V003aIP00oWl309VI0?bc003Yc000o;<00?jI003nO`00oVH00?i<
003n<`00o1WK0?go003_o`00o_l1003j6@00m3<00?Q<003aIP00lFH00?io0`2I
V@3l/`00jL`00?bc003nV@00oWl00?iV003nC000oS<00?`If`3mo`80ool0f_7o
003no`400?XI003d<`00n4`00>1V003nO`<0VIT0o;<00>W<003m/`00oIT00?io
003nIP00oT`00?hc003l6M/0oOl00>oo003no`400?XI003d<`00n4`00>1V003n
O`<0VIT0o;<00>W<003m/`00oIT00?io003nIP00oT`00?hc003l6M/0oOl00>oo
003no`400?XI003d<`00n4`00>1V003nO`<0VIT0o;<00>W<003m/`00oIT00?io
003nIP00oT`00?hc003l6M/0oOl20?oo0=gao`00o_l1003j6@00m3<00?Q<003P
IP00oWl309VI0?^c0@00k<`00?fc003mV@00oWl00?iV003nC000oS<00?`IfP3m
o`00kol00?ko0@00nQT00?@c003hC000h6H00?io0`2IV@3k/`400>c<003m/`00
oIT00?io003nIP00oT`00?hc003l6MX0oOl00>oo003no`400?XI003d<`00n4`0
0>1V003nO`<0VIT0nk<1003/c000oK<00?fI003nO`00oVH00?i<003n<`00o1WJ
0?go0P3oo`3PlOl00?ko0@00nQT00?@c003hC000h6H00?io0`2IV@3i/`400?3<
0@00oK<00?fI003nO`00oVH00?i<003n<`00o1WI0?go003_o`00o_l1003j6@00
m3<00?Q<003PIP00oWl309VI0?Vc0@00l<`1003m/`00oIT00?io003nIP00oT`0
0?hc003l6MT0oOl00>oo003no`400?XI003d<`00n4`00>1V003nO`<0VIT0nK<1
003`c0400?fc003mV@00oWl00?iV003nC000oS<00?`If@3mo`80ool0jOOo003l
o`00o_l1003k6@00lc<00?Q<003QIP00oGl00?jI003h/`400?W<nP3l/`00o9T0
0?io0`1VIP3mC000oS<00?dIf03mo`00mOl00?co003no`400?/I003c<`00n4`0
0>5V003mO`00oYT00?Rc0@00nLcj0?bc003lV@00oWl306IV0?e<003n<`00oAWH
0?go003eo`00o?l00?ko0@00naT00?<c003hC000hFH00?eo003nV@00n;<1003i
c?X0o;<00?bI003nO`<0IVH0oD`00?hc003m6MP0oOl20?oo0>3ho`400?co003n
o`400?/I003c<`00n4`00>5V003mO`00oYT00?Jcn@3f/`00o9T00?io003nIP00
oT`00?hc003l6MP0oOl00?Ko0@00o?l00?ko0@00naT00?<c003hC000hFH00?eo
003nV@00m[?i0?Jc003lV@00oWl00?iV003nC000oS<00?`If03mo`00m_l1003l
o`00o_l1003k6@00lc<00?Q<003QIP00oGl00?jI003f/oT0m[<00?bI003nO`00
oVH00?i<003n<`00o1WH0?go0P3oo`3>mol00?co003no`00nQT00?<c003hC000
hFH00?eo003nV@00i;<00?bI003nO`00oVH00?i<003n<`00o1WG0?go003eo`00
o?l00?ko003j6@00lc<00?Q<003QIP00oGl00?jI003T/`00o9T00?io003nIP00
oT`00?hc003l6ML0oOl00?Go003lo`00o_l00?XI003c<`00n4`00>5V003mO`00
oYT00>Bc003lV@00oWl00?iV003nC000oS<00?`Ie`3mo`80ool0c_Oo003lo`@0
0?oo0?XI003b<`00nD`00>5V003mO`00oIWn0>Rc003lV@00oGl306IV0?i<003m
<`00oAWF0?ko0@00mOl00?co1000ool0nQT00?8c003iC000hFH00?eo003mVOh0
j;<00?bI003mO`<0IVH0oT`00?dc003m6MH0o_l1003eo`00o?l4003oo`3j6@00
lS<00?U<003QIP00oGl00?fIoP3X/`00o9T00?eo0`1VIP3nC000oC<00?dIeP3n
o`<00?oo0=/1oool0?ko003lo`00o_l00?XI003b<`00nD`00>5V003mO`00nYT1
003[/`00o9T00?eo0`1VIP3nC000oC<00?dIe@3mo`00oOol0?ko003lo`00o_l0
0?XI003b<`00nD`00>5V003mO`00nYT1003[/`00o9T00?eo0`1VIP3nC000oC<0
0?dIe@3mo`00oOol0?ko003lo`00o_l00?XI003b<`00nD`00>5V003mO`00nYT1
003[/`00o9T00?eo0`1VIP3nC000oC<00?dIe@3mo`80ool0boOo003lo`00o_l0
0?XI003b<`00nD`00>5V003mO`00n9Wn0>nc003lV@00oGl00?iV0`1<C03m<`00
o1WE0?go003eo`00o?l00?ko003j6@00lS<00?U<003QIP00oGl00?RIoP3_/`00
o9T00?eo003nIP<0C4`0oC<00?`Ie@3mo`00mOl00?co003no`00nQT00?8c003i
C000hFH00?eo003hVOh0kk<00?bI003mO`00oVH304a<0?dc003l6MD0oOl20?oo
0<Shooh0oOl00?ko003k6@00lC<00?U<003RIP00o7l00?FIoP3i/oX0o9T00?ao
1P1VIP1<C03l<`00oAWD0?go003fooh0oOl00?ko003k6@00lC<00?U<003RIP00
o7l00?FIoP3i/oX0o9T00?ao1P1VIP1<C03l<`00oAWD0?go003fooh0oOl00?ko
003k6@00lC<00?U<003RIP00o7l00?FIoP3i/oX0o9T00?ao1P1VIP1<C03l<`00
oAWD0?go0P3oo`2`lOl00?ko003k6@00lC<00?U<003RIP00o7l00?:In@3fV@00
o7l606IV04a<0?`c003m6M<0oOl00>oo003no`00naT00?4c003iC000hVH00?ao
003bVOT0mYT00?ao1P1VIP1<C03l<`00oAWC0?go003_o`00o_l00?/I003a<`00
nD`00>9V003lO`00lYWi0?JI003lO`H0IVH0C4`0o3<00?dId`3mo`80ool0W_7o
003nooXI003a<`00nD`00>9V003lO`00h9T00?ao1P1VIP1<C03l<`00oAWB0?go
003_o`00o_oj6@00lC<00?U<003RIP00o7l00>2I003lO`H0IVH0C4`0o3<00?dI
dP3mo`00kol00?konQT00?4c003iC000hVH00?ao003PV@00o7l606IV04a<0?`c
003m6M80oOl20?oo0:Cao`00o_oj6@00lC<00?U<003RIP00o7l00>:I0@00o7l0
0?iV0`1<C03m<`00o1WB0?go003_o`00o_oj6@00lC<00?U<003RIP00o7l00>:I
0@00o7l00?iV0`1<C03m<`00o1WB0?go003_o`00o_oj6@00lC<00?U<003RIP00
o7l00>:I0@00o7l00?iV0`1<C03m<`00o1WB0?go0P3oo`2QlOl00?konQT00?4c
003iC000hVH00?ao003SV@00ngl00?iV0`1<C03m<`00o1WA0?go003_o`00o_oj
6@00lC<00?U<003RIP00o7l00>>I003kO`00oVH304a<0?dc003l6M40oOl00>oo
003nooXI003a<`00nD`00>9V003lO`00hiT00?]o003nIP<0C4`0oC<00?`Id@3m
o`80ool0W_7o003nooTI003b<`00nD`00>=V003kO`00iYWn0?]o003mIP80C03m
<`00o1W@0?go003_o`00o_oi6@00lS<00?U<003SIP00ngl00>JIoP3kO`00oFH2
04`0oC<00?`Id03mo`00kol00?konAT00?8c003iC000hfH00?]o003VVOh0ngl0
0?eV0P1<0?dc003l6M00oOl20?oo0:Oao`<00?oonAT00?<c003hC000hfH00?Yo
003[VOd0nGl00?eV0`1<C03n<`00o1W?0?ko0@00kol3003oooTI003c<`00n4`0
0>=V003jO`00jiWm0?Uo003mIP<0C4`0oS<00?`Ic`3no`400>oo0`00oooi6@00
lc<00?Q<003SIP00nWl00>^Io@3iO`00oFH304a<0?hc003l6Ll0o_l3003oo`2T
lOl00?konAT00?<c003hC000hfH00?Yo003_VOd0mgl1003mIP<0C4`0oS<00?/I
c`3mo`00kol00?konAT00?<c003hC000hfH00?Yo003_VOd0mgl1003mIP<0C4`0
oS<00?/Ic`3mo`00kol00?konAT00?<c003hC000hfH00?Yo003_VOd0mgl1003m
IP<0C4`0oS<00?/Ic`3mo`80ool0XO7o003nooPI003d<`00n4`00>=V003jO`00
lYWn0?Ao003lIP<0C4`0oC<00?`IcP3mo`00kol00?kon1T00?@c003hC000hfH0
0?Yo003bVOh0m7l00?aV0`1<C03m<`00o1W>0?go003_o`00o_oh6@00m3<00?Q<
003SIP00nWl00?:IoP3dO`00o6H304a<0?dc003l6Lh0oOl20?oo0:Cao`00o_oh
6@00m3<00?Q<003TIP00nGl00?>I003bO`00o6H00?i<003n<`00o1W=0?go003_
o`00o_oh6@00m3<00?Q<003TIP00nGl00?>I003bO`00o6H00?i<003n<`00o1W=
0?go003_o`00o_oh6@00m3<00?Q<003TIP00nGl00?>I003bO`00o6H00?i<003n
<`00o1W=0?go0P3oo`2TlOl00?kon1T00?@c003hC000i6H00?Uo003dV@00lWl0
0?aV003nC000oS<00?`Ic03mo`00kol00?kon1T00?@c003hC000i6H00?Uo003d
V@00lWl00?aV003nC000oS<00?`Ic03mo`00kol00?kon1T00?@c003hC000i6H0
0?Uo003dV@00lWl00?aV003nC000oS<00?`Ic03mo`80ool0Z_7o003nooLI003e
<`00n4`00>AV003iO`00mYT1003cO`400?aV003nC000oS<00?/Ic03mo`00kol0
0?komaT00?Dc003hC000i6H00?Uo003fV@400?=o0@00o6H00?i<003n<`00naW<
0?go003_o`00o_og6@00mC<00?Q<003TIP00nGl00?JI0@00lgl1003lIP00oT`0
0?hc003k6L`0oOl20?oo0:7ao`00o_og6@00mC<00?Q<003UIP00n7l00?NI003d
Ooh0nfH00?e<0`0c<`3k6L/0oOl00>oo003nooLI003e<`00n4`00>EV003hO`00
miT00?AooP3kIP00oD`303<c0?/Ib`3mo`00kol00?komaT00?Dc003hC000iFH0
0?Qo003gV@00m7on0?]V003mC0<0<c<0naW;0?go0P3oo`2WlOl00?komaT00?Hc
003gC000iFH00?Mo003jV@400?Eo0@00nFH00?e<0`0c<`3k6LX0oOl00>oo003n
ooLI003f<`00md`00>EV003gO`00nYT1003eO`400?UV003mC0<0<c<0naW:0?go
003_o`00o_og6@00mS<00?M<003UIP00mgl00?ZI0@00mGl1003iIP00oD`303<c
0?/IbP3mo`80ool0[O7o003no`00maT00?Lc003gC000iFH00?Mo003kV@00mGl1
003hIP00oD`00?hc003l6LT0oOl00>oo003no`00maT00?Lc003gC000iFH00?Mo
003kV@00mGl1003hIP00oD`00?hc003l6LT0oOl00>oo003no`00maT00?Lc003g
C000iFH00?Mo003kV@00mGl1003hIP00oD`00?hc003l6LT0oOl20?oo0:gao`@0
0?oo0?LI003g<`00md`00>EV003gO`00o9T00?MooP3gIP00oD`00?hc003l6LP0
o_l1003_o`@00?oo0?LI003g<`00md`00>EV003gO`00o9T00?MooP3gIP00oD`0
0?hc003l6LP0o_l1003_o`@00?oo0?LI003g<`00md`00>EV003gO`00o9T00?Mo
oP3gIP00oD`00?hc003l6LP0o_l3003oo`2]lOl00?ko003g6@00mc<00?M<003U
IP00mgl00?jI0@00n7l1003eIP00o4`303<c0?/Ib03mo`00kol00?ko003g6@00
mc<00?M<003UIP00mgl00?jI0@00n7l1003eIP00o4`303<c0?/Ib03mo`00kol0
0?ko003g6@00mc<00?M<003UIP00mgl00?jI0@00n7l1003eIP00o4`303<c0?/I
b03mo`80ool0[O7o003no`400?PI003f<`00md`00?9V003fIP00mWon0?Mo003e
IP400?a<0`0c<`3k6LL0oOl00>oo003no`400?PI003f<`00md`00?9V003fIP00
mWon0?Mo003eIP400?a<0`0c<`3k6LL0oOl00>oo003no`400?PI003f<`00md`0
0?9V003fIP00mWon0?Mo003eIP400?a<0`0c<`3k6LL0oOl20?oo0:Cao`00o_on
0?PI003g<`00md`00?AV0`00C03gIP00jWl00?EV003kC0<0<c<0naW60?go003_
o`00o_on0?PI003g<`00md`00?AV0`00C03gIP00jWl00?EV003kC0<0<c<0naW6
0?go003_o`00o_on0?PI003g<`00md`00?AV0`00C03gIP00jWl00?EV003kC0<0
<c<0naW60?go0P3oo`2]lOl00?kooP3h6@00mc<00?I<003gIP400?i<003gIP00
jgl00?IV0@00nd`303<c0?/Ia@3mo`00kol00?kooP3h6@00mc<00?I<003gIP40
0?i<003gIP00jgl00?IV0@00nd`303<c0?/Ia@3mo`00kol00?kooP3h6@00mc<0
0?I<003gIP400?i<003gIP00jgl00?IV0@00nd`303<c0?/Ia@3mo`80ool0Z_7o
003nood0n1T00?Lc003gC000n6H00?a<003fIP00kGl00?IV003jC000oS<00?`I
a03mo`00kol00?koo@3h6@00mc<00?M<003hIP00o4`00?IV003]O`00mVH00?Y<
003n<`00o1W40?go003_o`00o_om0?PI003g<`00md`00?QV003lC000mVH00>eo
003fIP00nT`00?hc003l6L@0oOl20?oo0;?ao`00o_ol0?TI003g<`00mT`00?]V
0@00nT`00?IV0@00l7l00?MV0@00nT`00?hc003l6L<0oOl00>oo003noo`0nAT0
0?Lc003fC000nfH1003jC000mVH1003`O`00mfH1003jC000oS<00?`I``3mo`00
kol00?koo03i6@00mc<00?I<003kIP400?Y<003fIP400?1o003gIP400?Y<003n
<`00o1W30?go0P3oo`2clOl00?koo03h6@00n3<00?I<003mIP400?Q<003dIP40
0?Ao0@00mfH00?U<003n<`00o1W20?go003_o`00o_ol0?PI003h<`00mT`00?eV
0@00n4`00?AV0@00m7l1003gIP00nD`00?hc003l6L80oOl00>oo003noo`0n1T0
0?Pc003fC000oFH1003hC000m6H1003dO`400?MV003iC000oS<00?`I`P3mo`80
ool0/?7o0`00oook0?TI003g<`00mT`306H00?I<003bIP00mWl00?MV0@00nD`0
0?hc003l6L40o_l1003_o`<00?oon`3i6@00mc<00?I<0`1V003fC000lVH00?Io
003gIP400?U<003n<`00o1W10?ko0@00kol3003ooo/0nAT00?Lc003fC0<0IP00
mT`00?9V003fO`00mfH1003iC000oS<00?`I`@3no`<00?oo0:Cao`00o_oj0?XI
003g<`00mT`1003cC000lVH1003iO`00mfH00?Q<003m<`00o1W10?go003_o`00
o_oj0?XI003g<`00mT`1003cC000lVH1003iO`00mfH00?Q<003m<`00o1W10?go
003_o`00o_oj0?XI003g<`00mT`1003cC000lVH1003iO`00mfH00?Q<003m<`00
o1W10?go0P3oo`2HlOl00?konP3i6@00mc<00>M<003`IP400?ao003hIP400?Q<
003m<`00o1W00?go003_o`00o_oj0?TI003g<`00id`00?1V0@00o7l00?QV0@00
n4`00?dc003l6L00oOl00>oo003nooX0nAT00?Lc003WC000l6H1003lO`00n6H1
003hC000oC<00?`I`03mo`80ool0UO7o003nooT0nQT00?Hc003XC000kVH00?io
003hIP00n4`1003m<`00o1Vo0?go003_o`00o_oi0?XI003f<`00j4`00>iV003n
O`00n6H00?Q<0@00oC<00?`I_`3mo`00kol00?kon@3j6@00mS<00>Q<003^IP00
oWl00?QV003hC0400?dc003l6Kl0oOl20?oo08Kao`00o_oh0?XI003f<`00j4`0
0>iVoP3hIP00n4`00?`c003l6Kh0oOl00>oo003nooP0nQT00?Hc003XC000kVKn
0?QV003hC000o3<00?`I_P3mo`00kol00?kon03j6@00mS<00>Q<003^I_h0n6H0
0?Q<003l<`00o1Vn0?go0P3oo`1mlOl00?kon03j6@00mC?l0>e<003WI_`0nD`1
003k<`00o1Vn0?go003_o`00o_oh0?XI003e<o`0kD`00>MVo03iC0400?/c003l
6Kh0oOl00>oo003nooP0nQT00?Dco03]C000ifKl0?U<0@00nc<00?`I_P3mo`80
ool0N_7o003nooL0nQT00?4co@3`C000kVKk0?E<003j<`00o1Vm0?go003_o`00
o_og0?XI003a<od0l4`00>iVn`3eC000nS<00?`I_@3mo`00kol00?kom`3j6@00
lC?m0?1<003^I_/0mD`00?Xc003l6Kd0oOl20?oo07gao`00o_of0?XI003^<`00
l4`00?5V0@00l4`00?Xc003l6K`0oOl00>oo003nooH0nQT00>hc003`C000lFH1
003`C000nS<00?`I_03mo`00kol00?komP3j6@00kS<00?1<003aIP400?1<003j
<`00o1Vl0?go0P3oo`1mlOl00?kom03k6@00kS<00?1<003dIP400>m<003j<`00
o1Vk0?go003_o`00o_od0?/I003^<`00l4`00?AV0@00kd`00?Xc003l6K/0oOl0
0>oo003noo@0naT00>hc003`C000m6H1003_C000nS<00?`I^`3mo`80ool0P?7o
0`00oooc0?/I003^<`00l4`00?IV003^C000nS<00?`I^P3no`400>oo0`00oooc
0?/I003^<`00l4`00?IV003^C000nS<00?`I^P3no`400>oo0`00oooc0?/I003^
<`00l4`00?IV003^C000nS<00?`I^P3no`<00?oo083ao`00o_ob0?/I003^<`00
l4`00?UV0@00o4cb0?/c0@00o1Vi0?go003_o`00o_ob0?/I003^<`00l4`00?UV
0@00o4cb0?/c0@00o1Vi0?go003_o`00o_ob0?/I003^<`00l4`00?UV0@00o4cb
0?/c0@00o1Vi0?go0P3oo`1mlOl00?kol@3k6@00kS<00?1<003lIP400?]<003]
<`00naVh0?go003_o`00o_oa0?/I003^<`00l4`00?aV0@00nd`00>dc003k6KP0
oOl00>oo003noo40naT00>hc003`C000o6H1003kC000kC<00?/I^03mo`80ool0
N_7o003noo00naT00>hc003`C0@0IVH00?Y<003]<`00naVg0?go003_o`00o_o`
0?/I003^<`00l4`406IV003jC000kC<00?/I]`3mo`00kol00?kol03k6@00kS<0
0?1<101VIP00nT`00>dc003k6KL0oOl20?oo07Cao`00o_o`0?XI003^<`00l4`1
003iC000kS<1003k6KH0oOl00>oo003noo00nQT00>hc003`C0400?U<003^<`40
0?/I]P3mo`00kol00?kol03j6@00kS<00?1<0@00nD`00>hc0@00naVf0?go0P3o
o`1RlOl00?kok`3j6@00kS<00>Q<003^<`00nAVf0?go003_o`00o_o_0?XI003^
<`00j4`00>hc003i6KH0oOl00>oo003nonl0nQT00>hc003XC000kS<00?TI]P3m
o`80ool0K_SooP3mo`00o_o^0?XI003^<`00jT`00>hc003j6K@0oOl00?KooP3m
o`00o_o^0?XI003^<`00jT`00>hc003j6K@0oOl00?KooP3mo`00o_o^0?XI003^
<`00jT`00>hc003j6K@0oOl20?oo07[io`00o_l00?ko003nond0nQT00>hc003/
C000l3?n0?XI/`3mo`00mol00?ko003no`00o_o]0?XI003^<`00k4`00?0coP3j
6K<0oOl00?Oo003no`00o_l00?kok@3j6@00kS<00>a<003`<oh0nQVc0?go0P3o
o`1jnOl00?ko003no`00o_o/0?XI003^<`00kT`00?<co@3i6K40oOl00?Oo003n
o`00o_l00?kok03j6@00kS<00>i<003c<od0nAVa0?go003go`00o_l00?ko003n
on`0nQT00>hc003^C000lc?m0?TI/@3mo`80ool0OOKo003mo`400>_o003io`40
0>oo0@00l?l00?KooP3go`400:ko0@00m?l00?go0@00jol00?Wo0@00kol1003`
o`00m_on0?Oo0@00[_l1003do`00oOl1003[o`00nOl1003_o`400?3o003fooh0
mol1002^o`<00?oo03T1oool0?ko003lo`00POo;o`00oOol0?ko003lo`00POo;
o`00oOol0?ko003lo`00POo;o`80ool0JoSo0`3oo`3no`00o_l00=Ko003Fo`00
eol00=Ko003no`00m_l30?oo0?ko003no`00e_l00=Ko003Go`00e_l00?ko003f
o`<0ool0o_l00?ko003Fo`00e_l00=Oo003Fo`00o_l20?oo027ioo`0o_n10<T0
mool0?koP@390?Ooo03noh40b@01ool02X7oPOn1oh7oXol02X7oPOn1oh7oXol0
2X7oPOn1oh7oXol02X7oPOn1oh7oXol02X7oPOn1oh7oXol02X7oPOn1oh7oXol0
2X7oPOn1oh7oXol0@NcooP3Go`00fOl1003Ho`00eoon0>KooP3Go`00fOl1003H
o`00eoon0>KooP3Go`00fOl1003Ho`00eoon0?_o06G]o`00o_l00=Wo0@00f_l3
0?oo0=[o0@00f?l00?ko003Xo`00o_l00=Wo0@00f_l30?oo0=[o0@00f?l00?ko
003Xo`00o_l00=Wo0@00f_l30?oo0=[o0@00f?l00?ko003lo`1OkOl00?ko003H
o`00f_l30?oo0=Wo003Ho`00o_l00>So003no`00f?l00=[o0`3oo`3Io`00f?l0
0?ko003Xo`00o_l00=So003Jo`<0ool0fOl00=So003no`00o?l0An[o003Go`00
f_l30?oo0=Wo003Eo`00i?l00=Oo003Jo`<0ool0fOl00=Go003To`00eol00=[o
0`3oo`3Io`00eOl00?_o05ocoo`0o_l00=koo03no`00f_l30?oo0=Wo003Fo`00
k?ol0?ko003Noo`0o_l00=[o0`3oo`3Io`00e_l00>coo03no`00g_ol0?ko003J
o`<0ool0fOl00=Ko003jo`1Ik?l30?oo0=So003Jo`<0ool0fOl00=Oo0`3oo`3W
o`<0ool0f?l00=[o0`3oo`3Io`00eol30?oo0>Oo0`3oo`3Ho`00f_l30?oo0=Wo
003Go`<0ool0o?l0@Ngoo03Iooh0f_l1003Iooh0fOol0>Soo03Iooh0f_l1003I
ooh0fOol0>Soo03Iooh0f_l1003Iooh0fOol0?co00Z1oh7oPOn1oj?o00Z1oh7o
POn1oj?o00Z1oh7oPOn1oj?o0?l\>"], "Graphics",
  ImageSize->{202, 202},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1.599999999999909*Second, \
ContourGraphics[\"<<>>\"]}\
\>", "\<\
{1.6 Second, -ContourGraphics-}\
\>"], \
"Output",
  LineSpacing->{1, 0},
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Plot3D[EpanechnikovM[{x,y}]//N,{x,-2,2},{y,-2,2}] ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PICT", "\<\
Rah0100Y0>/1@`0A0_l<0?ooool0:@0000@000530000j`000000000N00402P04
02T0j`5309X0003oQ6P000000>L16P0000@0000004P000180000400P00<02000
0002njEL000000000000i`4J00@0:@3[0D<0900>POn1oh7oPOn1oh7o/ol03X7o
POn1oh7oPOn1ok?o00j1oh7oPOn1oh7oPOnco`0>POn1oh7oPOn1oh7o/ol03X7o
POn1oh7oPOn1ok?o00j1oh7oPOn1oh7oPOnco`0>POn1oh7oPOn1oh7o/ol03X7o
POn1oh7oPOn1ok?o01^8o`40087oPOoYo`40087oPOoYo`40087oh_l098Wo0P00
ood0POn1onko0P00ood0POn1onko0P00ood0POoVo`0ZR_l20?l0o?om087oPOoc
o`80o`3lood0POn1oo?o0P3o0?coo@21on[o02f;o`<0ool0n?on087oPOogo`<0
ool0n?on087oPOogo`<0ool0n?on087okOl0<hgo0@00o_l00?Goo@21oh7ooOl1
003no`00mOom087oPOomo`400?ko003eood0POoao`0/S_l00?co003aood0POn2
o`00o?l00?7oo@21oh;o003lo`00lOom087omOl0;8oo003ko`00kOom087oQol0
0?_o003]ood0POn7o`00nol00>goo@21ooWo02b@o`00n_l00>Woo@21ohco003j
o`00jOom087oS?l00?[o003Yood0POomo`0ZTOl00?Wo003Uood0POnAo`00nOl0
0>Goo@21oi7o003io`00iOom087o02fCo`400?So003Qooh0POnFo`400?So003Q
ooh0POnFo`400?So003Qooh0Q?l0:YCo003fo`00g_om087oVol00?Ko003Nood0
POnKo`00m_l00=koo@28o`0ZUOl00?Go003Jood0POnPo`00mOl00=[oo@21oj3o
003eo`00f_om08co02ZFo`00m?l00=Koo@21ojGo003do`00e_om087oYOl00?Co
003Food0T?l0;ISo0@00lol00=;oo@21oj_o0@00lol00=;oo@21oj_o0@00lol0
0=;oo@2Do`0ZVOl00?3o003?ooh0POn_o`00l?l00<oooP21ojoo003`o`00coon
09Oo02ZJo`00kol00<coo@21okCo003_o`00c?om087o]?l00>oo003<ood0Vol0
:Y_o003^o`00b?om087o^Ol00>ko0038ood0POnio`00k_l00<Soo@2Oo`0]WOl1
003]o`00a?om087o_ol1003]o`00a?om087o_ol1003]o`00a?om0:?o02ZNo`00
jol00<3oo@21olCo003[o`00`?om087oa?l00>_o0030ood0Yol0:Yoo003Zo`00
_?om087obOl00>[o002lood0POo9o`00j_l00;coo@2[o`0ZX?l00>Wo002hooh0
POo=o`00jOl00;SooP21olgo003Yo`00^?on0:ko02ZQo`00j?l00;Goo@21om;o
003Xo`00]Oom087od_l00>So002eood0/_l0;J?o0@00iol00;7oo@21omSo0@00
iol00;7oo@21omSo0@00iol00;7oo@2fo`0ZY?l00>Go002]ood0POoMo`00iOl0
0:goo@21omgo003Uo`00[Oom0;[o02ZUo`00i?l00:Woo@21on;o003To`00ZOom
087oh_l00>Co002Yood0__l0:ZKo003So`00YOom087oiol00>?o002Uood0POoW
o`00hol00:Goo@32o`0]Z?l1003Ro`00XOon087ok?l1003Ro`00XOon087ok?l1
003Ro`00XOon0<Go02ZYo`00h?l009koo@21oo7o003Po`00W_om087olOl00>3o
002Nood0bOl0:Z[o003Oo`00V_om087om_l00=oo002Jood0POofo`00gol009[o
o@3=o`0ZZol00=ko002Food0POoko`00g_l009Koo@21oo_o003No`00U_om0=7o
02V]o`400=go002Bood0POl1003Mo`00T_om087o0@00gOl009;oo@3Eo`0V[_l0
0=_o002>ooh0QOl00=_o002>ooh0QOl00=_o002>ooh0f?l09Zoo003Jo`00Room
08[o003Jo`00Room08[o003Jo`00Room0=co02J`o`00fOl008Ooo@2?o`00fOl0
08Ooo@2?o`00fOl008Ooo@3Po`0V/Ol00=So0023ood0U?l00=So0023ood0U?l0
0=So0023ood0i?l0<[?o0@00eol0087o0Oooo@2Jo`400=Oo0021o`7oood0V_l1
003Go`00POl1ooom0>So02bdo`00eOl0087onoom09oo003Eo`00POokood0Wol0
0=Go0021oo_oo@3/o`0/]Ol00=Co0021ooOooP2So`00e?l0087omoon0:?o003D
o`00POogooh0kol0;;Ko003Co`00POodood0Z?l00=?o0021ooCoo@2Xo`00dol0
087om?om0??o02nho`400=;o0021oo3oo@2^o`400=;o0021oo3oo@2^o`400=;o
0021oo3oo@3go`0/^Ol00=3o0021oncooP2bo`00d?l0087ok?on0;;o003@o`00
POo/ooh0n_l0;k[o003>o`00POo/o`400;?o003>o`00POo/o`400;?o003>o`00
POo/o`400?[o03:ko`00cOl0087okOl20?l0]?l00<go0021ongo0P3o0;Co003=
o`00POo]o`80o`3jo`0h_Ol1003<o`00POo^o`<0ool0]_l1003<o`00POo^o`<0
ool0]_l1003<o`00POo^o`<0ool0n_l0<[ko003:o`00POo^o`80o`2fo`00b_l0
087ok_l20?l0]_l00<[o0021onko0P3o0?Wo03Foo`00bOl0087okol30?oo0;Oo
0039o`00POo_o`<0ool0]ol00<Wo0021onoo0`3oo`3io`0h`?l00<So0021oo3o
003no`00^?l00<So0021oo3o003no`00^?l00<So0021oo3o003no`00nOl0>l;o
0@00aol0087ol?l00?ko002jo`400<Oo0021oo3o003no`00^_l10037o`00POo`
o`00o_l00?Wo03S3o`00aOl0087olOl00?go002ko`00aOl0087olOl00?go002k
o`00aOl0087olOl00?go003io`0ha?l00<Co0021oo;o003lo`00_?l00<Co0021
oo;o003lo`00_?l00<Co0021oo;o003lo`00nOl0><Go0033o`00POoco`00nol0
0;go0033o`00POoco`00nol00;go0033o`00POoco`00nol00?Wo03S6o`00`_l0
087olol00?_o002no`00`_l0087olol00?_o002no`00`_l0087olol00?_o003i
o`0kb?l10031o`00POodo`00nol00;oo0@00`Ol0087om?l00?_o002oo`400<7o
0021ooCo003ko`00n?l0>lWo002oo`40087om_l00?[o0030o`00_ol10021ooKo
003jo`00`?l00;oo0@00POofo`00n_l00?So04C:o`00_ol20:VYoP21ooWo003j
o`00`Ol00;oo0P2m_Oh0POoio`00n_l00<7o002oo`80j>Sn087onOl00?[o003h
o`14bol00;oo003kZOh0POomo`00nOl00<;o002oo`00nkgn087ooOl00?Wo0032
o`00_ol00?_XoP21oogo003io`00n?l0@Lgo0@00_ol00?NYo@22o`00n?l00<Co
0@00_ol00?Nmo@22o`00n?l00<Co0@00_ol00?OXo@22o`00n?l00?So04[>o`00
__l00?FY0P2YZOh0Q_l00?Oo0035o`00__l00?Fm0P2m_Oh0Q_l00?Oo0035o`00
__l00?GX0P3Xj?h0Q_l00?Oo003ho`1=col00;ko0@00mZT00?^YoP29o`00mol0
0<Ko002no`400?Jm003k_Oh0ROl00?Oo0036o`00__l1003fj000nnSn08Wo003g
o`00n?l0E]3o002no`80ZJWn0?ZY003gZOh0SOl00?Ko0037o`00__l20;fmoP3j
_@00mkgn08go003fo`00aol00;ko0P3Xj?h0n^P00?OXoP2=o`00m_l00?So077B
o`400;ko003kZOh0oZT00?JY0P2YZOh0nOok09oo003fo`00b?l1002no`00nkgn
0?jm003f_@80_Kgn0?Won`2Oo`00m_l00<So0@00__l00?_XoP3nj000m^P20>SX
oP3ioo/0Wol00?Ko003go`1^dol00;go003gZOh0mZT00?^Yn@010`?n007:0:7o
003eo`00bOl00;go003g_Oh0m[d00?^mn@01TY;n007c0:7o003eo`00bOl00;go
003gj?h0m^P00?_Xn@01c/kn007/0:7o003eo`00mol0N]Co002mo`00mZT20:VY
oP3jZ@00o:Wn0003n@3lbP00X_l00?Go003:o`00_Ol00?Jm0P2m_Oh0n[d00?bm
oP00T_T0o?<00:;o003eo`00b_l00;go003fj080j>Sn0?[X003lj?h00<ki0?c/
002Ro`00mOl00?Oo08?Eo`00_Ol00?JY003kZOh0oZT00?jYnP3mO080_03jbP40
0:Go003do`00bol00;go003f_@00nkgn0?jm003n_OX0oHl20:d0n_<1002Uo`00
m?l00<_o002mo`00m^P00?_XoP3nj000o^Sj0?gK0P3;0?[/0@00YOl00?Co003g
o`1me_l00;go0@00mjT00?NYo@02ZJT0mg`00?jl003ibP00Yol00??o003<o`00
_Ol1003g_@00mkgm00:m_@3gS`00oZd00?Wc002Wo`00lol00<co002mo`400?OX
003gj?d00^SX0?OK003nb`00nN`00:Oo003co`00mol0SmSo0@00_Ol20:VYoP3k
Z@00mJT20:VYoP3gO000oK`1003jbP400:Wo003co`00c_l1002mo`80_Kgn0?^m
003e_@80_Kgn0?N?003m[@400?[c0@00ZOl00??o003>o`400;go0P3Xj?h0nnP0
0?GX0P3Xj?h0mm/00?g;0@00n^`1002Yo`00lol00?Oo08WIo`00_?l00?^YoP02
ZJT0mJT00?jY0@00mg`00?Zl003ibP00Zol00?;o003?o`00_?l00?^moP02_Kd0
mKd00?jm0@00mhl00?Z]003il`00Zol00?;o003?o`00_?l00?_XoP02j>P0mNP0
0?kX0@00mm/00?[;003ik000Zol00?;o003go`21f_l00;co003gZOh0mZT00?jY
oP3gO000nK`1003jbP00[Ol00?7o003@o`00_?l00?NmoP3f_@00o[d203<0mhl0
0?V]0@00n_<00:go003ao`00d?l00;co003gj?h0m^P00?kX0P2j0?OK003ib`40
0?[/002]o`00lOl00?Oo08[Ko`00_?l00?JY0P2YZOh0nZT00?jYoP3gO000m[`0
0?[:oP2ao`00l?l00=7o002lo`00m[d20;fmoP3j_@00o[d203<0mhl00?J]003j
loh0/Ol00?3o003Ao`00_?l00?KX0P3Xj?h0n^P00?kX0P2j0?OK003fb`00n^cn
0;7o003`o`00mol0W=go0@00_Ol1003fZ@00njWn0?jY003nZOh0mg`00?Bl003m
b_h00>om0;Co003ao`00d_l1002mo`400?Jm003k_Oh0o[d00?jm0P0c0?N?003d
[@00oO?n003Vo@2do`00lOl00=;o0@00_Ol1003fj000nnSn0?kX003nj080^P3g
f`00m</00?g/oP00`od0]?l00?7o003fo`2Ig_l00;co0P2YZOh0nZT00?NYo@01
ZJWm0?Ml003c_?d0o>l20:VYoP2ho`00l?l00=?o002lo`80_Kgn0?Zm003g_Od0
1Kfm03<c0?N?003c[Od0o>H20;fmoP2ho`00l?l00=?o002lo`80j>Sn0?[X003g
j?d01NSX0;Zj0?OK003cbod0o<<20>SXoP2ho`00l?l00?Ko0:7Oo`00_?l00?^Y
oP3nZ@00mJT20:VYo03gO000l[`20=H0nnl1003mZOd0_Ol00>oo003Do`00_?l0
0?^moP3n_@00mKd70;fm000c<`3gS`00lZd20;D0nnH1003m_Od0_Ol00>oo003D
o`00_?l00?_XoP3nj000mNP70>SX002j^P3gf`00l//20;T0nl<1003mj?d0_Ol0
0>oo003fo`2Sh?l00;co003gZOd0mZT00?jYo03hO000lK`30=KF0?__003lZ@80
ZJWn0<3o003_o`00eOl00;co003g_Od0m[d00?jm003n<`00n8l00?6]0`2e]@3k
iP00o;d20;fmoP30o`00kol00=Go002lo`00mnSm0?KX003nj000o[X00?SK003a
b`<0^KT0nl<00?cX0P3Xj?h0`?l00>oo003fo`2eh_l1002lo`00mJT20:VYoP3j
Z@00oZWl0?]lo03b_000o]H00?[_003nZ@00njWn0<Co003^o`00eol1002lo`00
mKd20;fmoP3j_@00o[d00?hc003kSo`0lZd00?je003jiP00o[d00?^moP34o`00
k_l00=Oo0@00_?l00?GX0P3Xj?h0n^P00?kX003n^P00nm_l0?;;003n^@00n/<0
0?kX003kj?h0a?l00>ko003fo`2bhol00;_o003eZ@00njWn0?jY003nZOD0oHH1
003c_000oMH00?__0`00Z@3gZOd0bOl00>go003Ho`00^ol00?Fm003k_Oh0o[d0
0?jm003m<oX0oGH1003c[@00oKD00?_V0`00_@3g_Od0bOl00>go003Ho`00^ol0
0?GX003kj?h0o^P00?kX003m^_X0oKX1003cb`00oKT00?_30`00j03gj?d0bOl0
0>go003fo`2gi?l00;_o0@00mZT00?NYoP3nZOX0n8H30:b/0?Fl003keP00nnl1
003eZ@80ZJWn0<go003/o`00fOl00;_o0@00m[d00?NmoP3n_@00oC<1003hMP<0
SHd0mJd00?^e003kiP400?Fm0P2m_Oh0cOl00>co003Io`00^ol1003fj000mnSn
0?kX003m^P400?Rj0`2d]03eb`00nkT00?_30@00mNP20>SXoP3=o`00k?l00?Ko
0<?Uo`00^ol20:VYoP3jZ@00mZT20:VYn03gQP00oZ`1003g_000nmH00?[_003f
Z@00njWm0=7o003/o`00f_l00;_o0P2m_Oh0n[d00?Jm0P2m_Od0oS<1003gMP00
oXd1003g[@00nkD00?[V003f_@00nkgm0=7o003/o`00f_l00;_o0P3Xj?h0n^P0
0?KX0P3Xj?d0o[X1003g^P00o[@1003gb`00nkT00?[3003fj000nnSm0=7o003/
o`00m_l0aNKo002ko`00njWn0?jY003fZ@00o:Wl00530?N6003l[000nK`00?WF
003kkod0nZT00?JYo@3Fo`00k?l00=[o002ko`00nkgn0?jm003f_@00o;d00?hc
0P1;0?Mf003lS@00nJd00?Ve003ki_d0n[d00?Jmo@3Fo`00k?l00=[o002ko`00
nnSn0?kX003fj000o>P00?jj0P2d0?Nj003l]000nL/00?Vi003k`od0n^P00?KX
o@3Fo`00k?l00?Go0=GXo`400;_o003gZOd0mjT00?^Yo@02@d<0n8H00?Z/003j
_000n=H00?__0P00ZOh0oZT00?BY0P2YZOh0f_l00>_o003Lo`400;_o003g_Od0
mkd00?^m1P0c<`1;B`3hMP00nXd00?Z]003h]@00nnH2002moP3n_@00m;d20;fm
oP3Jo`00jol00=co0@00^ol00?OXo@3gj000nnP60;Zj0;Bd0?Rj003j]000n//0
0?Ri003k``800>Sn0?kX003dj080j>Sn0=[o003[o`00mOl0eNWo002jo`00mJT2
0:VYoP3kZ@00njWm0093@`3gQP00nJ`1003m_000mmH00?[_003mZOd0mJT00?^Y
oP3Mo`00jol00=go002jo`00mKd20;fmoP3k_@00nkd603<c04];0?Mf003iS@40
0?f]003g]@00n^H00?fmo@3e_@00nkgn0=go003[o`00gOl00;[o003ej080j>Sn
0?_X003kj0H0^[X0];@0mkX00?Vd0@00oL/00?Ni003j``00oNSm0?GX003kj?h0
gOl00>_o003eo`3Sj_l00;[o003eZ@00njWn00:YZ@3kZOd0oT<00?N6003g[000
o[`00?KF003kk`400?fY0P2YZOh0nJT00?NYo@3Ro`00j_l00=ko002jo`00mKd0
0?^moP02_Kd0nkd303<c0?i;003gMP00mhd00?j]003f]@00nnH1003m_@80_Kgn
0?Vm003g_Od0h_l00>[o003No`00^_l00?GX003kj?h00^SX0?_X0`2j^P3n]000
mkX00?Nd003nb`00m[T00?_30@00oNP20>SXoP3ij000mnSm0>;o003Zo`00mOl0
n@?oo`00mol1003ko`00^_l1003fZ@00mjWn0?^YoP3m@`00mhH00?J/0P2l0?CF
003kk`@00:VY0?^Yo@3nZ@00mJT20:VYoP3Vo`00jOl00??o0@00mol1003ko`00
^_l1003f_@00mkgn0?^m0P0c0?e;003gMP00mXd20:d0m;D00?_V1000_Kd0nkgm
0?jm003e_@80_Kgn0>Ko003Yo`00lol1003go`400?_o002jo`400?KX003gj?h0
nnP20;X0oK@00?Nj003f]080b`3d^@00nl<4003Xj03kj?d0o^P00?GX0P3Xj?h0
i_l00>Wo003eo`3o1?l0ool0nOl00?_o0@00^_l20:VYoP3jZ@00mZT20:VYoP01
ZJWn0?e3003gQP00m:`1003deP00n^l20:T0mZWn0?FY003kZOd0jol00>So003d
o`<0ool0nOl00?_o0@00^_l20;fmoP3j_@00m[d20;fmoP04_Kd0<`3mB`00mgH0
0?B=0@00m;D00?[V0P2m0?JmoP3e_@00nkgm0>_o003Xo`00m?l30?oo0?Wo003k
o`400;[o0P3Xj?h0n^P00?KX0P3Xj?h01>SX0;X0oK@00?Nj003d]0400?Bi003j
``80j03fj?h0mNP00?_Xo@3[o`00j?l00?Go0?44o`3oo`3jo`00n_om0;go003k
ZOh0oZT00?JY003kZOd0o4<00?N6003c[0400?CF003kk`400?BY0@2YoP3iZ@00
mZWm0>oo003Xo`00m?l30?oo0?[o003jood0_Ol00?^moP3n_@00m[d00?^mo@3l
B`00mgH00?>=0@00m;D00?_V0@00m;d10;gn0?Vm003f_Od0kol00>So003do`<0
ool0n_l00?[oo@2mo`00nnSn0?kX003fj000nnSm0?bd003g^P00lk@1003d^@00
nl<1003dj040j?h0nNP00?KXo@3_o`00j?l00?Go0@l4o`3oo`3jood0oOl3003o
ooh0`_l1003gZOd0mjT00?VY0@00nd<00?N6003d[0<0`/80m=H00?__003eZ@00
o:T1003lZ@00m:T20:VYoP3co`00iol00?Co0`3oo`3jood0oOl3003oooh0`_l1
003g_Od0mkd00?Vm0@00nd/00?Mf003dS@<0VIT0m;D00?_V003e_@00o;d1003l
_@00m;d20;fmoP3co`00iol00?Co0`3oo`3jood0oOl3003oooh0`_l1003gj?d0
mnP00?WX0@00nk@00?Nj003d]0<0[Jd0m;T00?_3003ej000o>P1003lj000m>P2
0>SXoP3co`00iol00?Go0AP4o`3oo`3jo`00o_l00?go003looh0a_l00?BY0P2Y
ZOh0njT00?RY003k@`00mhH00?>/0`32`P3deP00n^l00?NY003iZOh00JT0m:T0
0?^YoP3go`00iol00??o0`3oo`3jo`00o_l00?go003looh0a_l00?Bm0P2m_Oh0
nkd00?Rm003kB`00mgH00?>=0`2IV@3d]@00n^H00?Nm003i_Oh00Kd0m;d00?^m
oP3go`00iol00??o0`3oo`3jo`00o_l00?go003looh0a_l00?CX0P3Xj?h0nnP0
0?SX003k]000mkX00?>d0`2][@3d^@00n/<00?OX003ij?h00NP0m>P00?_XoP3g
o`00iol00?Co0AP4o`3oo`3jo`00o_l00?go003iooh0bol1003dZ@00njWn00:Y
Z@3hZ@400?]3003gQP00lj`00?k2003deP00nnon0?ZY003eZOh0mZT00?NYo@3l
o`00i_l00??o0`3oo`3jo`00o_l00?go003iooh0bol1003d_@00nkgn00:m_@3h
_@400?];003gMP00lhd00?jI003d]@00nnKn0?Zm003e_Oh0m[d00?Nmo@3lo`00
i_l00??o0`3oo`3jo`00o_l00?go003iooh0bol1003dj000nnSn00;Xj03hj040
0?^d003g^P00lk@00?j]003d^@00nl?n0?[X003ej?h0m^P00?OXo@3lo`00i_l0
0?Co0C@3ool00?go003mooh0o?l00?KooP3?o`40ZOh0mjT00?NYoP3hZ@00nT<0
0?N6003d[000o<800?CF0P3_koh00_P0ZOd00ZVY0?BY0P2YZOh0nZT00?FY0P2Y
ZOh00_oo0>Ko003bo`400?go003mooh0o?l00?KooP3?o`40_Oh0mkd00?NmoP3h
_@00nT/00?Mf003dS@00o9T00?Be0P3Vi_h00]T0_Od00[fm0?Bm0P2m_Oh0n[d0
0?Fm0P2m_Oh00_oo0>Ko003bo`400?go003mooh0o?l00?KooP3?o`40j?h0mnP0
0?OXoP3hj000n[@00?Nj003d]000o:d00?Bi0P33`oh00Z/0j?d00^SX0?CX0P3X
j?h0n^P00?GX0P3Xj?h00_oo0>Ko003do`47k?on0?GooP3Co`00o:T1003jZ@00
mZT20:VYoP3lZ@400?]3003fQP00m:`00?c2003de_h0oOP1003mZOh0mJT00?^Y
o@02ZJT0mJT00?^Yo@3Wo`00goon0?GooP3Co`00o;d1003j_@00m[d20;fmoP3l
_@400?];003fMP00m8d00?bI003d]Oh0oMT1003m_Oh0mKd00?^mo@02_Kd0mKd0
0?^mo@3Wo`00goon0?GooP3Co`00o>P1003jj000m^P20>SXoP3lj0400?^d003f
^P00m;@00?b]003d^Oh0oJ/1003mj?h0mNP00?_Xo@02j>P0mNP00?_Xo@3Wo`00
m?l10Nco003`ooh0eol00?VYoP3nZ@00mZT00?^YnP3k@`00mhH00?>/003k`P00
m]H20>80o?Sn0?fY0@2YoP3hZ@00mjWm0?JY003kZ@00oZWn0>[o003Oo`00l?on
0=Oo003i_Oh0o[d00?Jm003k_OX0nd/00?Mf003cS@00niT00?Je0P2h0?cIoP3m
_@40_Oh0n;d00?Nmo@3f_@00nkd00?jmoP3Zo`00gol00?3ooP3Go`00nNSn0?kX
003fj000nnSj0?^d003g^P00lk@00?^]003f^@80Z`3lZoh0oNP10>Sn0?SX003g
j?d0m^P00?_X003nj?h0j_l00?Co0A?/o`00kOon0=_o003eZOh0mZT00?JY0@00
nT<00?N6003c[000n/800?OF0P3R0?_h0@00oZT00?bYoP3lZ@00mJT20:VYoP3j
Z@00nZT00?fY0@2YoP3]o`00gol00>gooP3Ko`00mKgn0?Jm003f_@400?Y;003g
MP00lhd00?ZI003g]@80^03kf@400?jm003l_Oh0o;d00?Fm0P2m_Oh0n[d00?Zm
003m_@40_Oh0kOl00=oo003]ooh0fol00?GXoP3fj000m^P1003j]000mkX00?>d
003j[@00mkT20:/0nj/1003nj000o>Sn0?cX003ej080j>Sn0?[X003jj000oNP1
0>Sn0>go003do`4Yjol1003/o`400=ko003dZ@80ZJWn0?ZY003fZOh0nd<00?J6
003d[000nL800?SF0`3RhP3kn0D0i`2YZ@3iZOh00JT0mJT00?^Yo@02ZJT0nZT0
0?bY003mZOh0l?l00=ko0@00k?l1003No`00m;d20;fmoP3j_@00m[d20140nd/0
0?If003dS@00nIT00?Re0`2h^03kf@D0j02m_@3i_Oh00Kd0mKd00?^mo@02_Kd0
n[d00?bm003m_Oh0l?l00=ko0@00k?l1003No`00m>P20>SXoP3jj000m^P209h0
nk@00?Jj003d]000nJd00?Ri0`2[Z`3kZ`D0PP3Xj03ij?h00NP0mNP00?_Xo@02
j>P0n^P00?cX003mj?h0l?l00?Co0@k[o`00jOon0>;o003dZ@00njWn0?jY003e
ZOh0nd<00?N6003c[000n<800?WF003nhP00o?P40>OW003eZOh0mjT00?JYoP3k
Z@00o:T00?VYoP3co`00g_l00>WooP3Ro`00m;d00?^moP3n_@00mKd20140nd/0
0?Mf003cS@00n9T00?Ve003n^000o=T40>SX003e_Oh0mkd00?JmoP3k_@00o;d0
0?VmoP3co`00g_l00>WooP3Ro`00m>P00?_XoP3nj000mNP209h0nk@00?Nj003c
]000n:d00?Vi003nZ`00o:/408:2003ej?h0mnP00?KXoP3kj000o>P00?WXoP3c
o`00m?l15>_o003Vooh0iOl1003fZ@00mjWm0?JYoP3j@`00mhH00?>/003g`P00
nmH00?gR003kn080i`3dZ@80ZJWn0?^Y003dZ@40ZOh00ZVY0?bY003eZOh0mol0
0=go003Vooh0iOl1003f_@00mkgm0?Jm0P0A0?Y;003gMP00lhd00?NI003k]@00
oKP00?_I0P3X0?Bm0P2m_Oh0nkd00?Bm0@2moP02_Kd0o;d00?FmoP3go`00gOl0
0>KooP3Uo`400?KX003gj?d0m^P209h0n[@00?Nj003c]000mjd00?^i003mZ`00
nj/20880m>P20>SXoP3kj000m>P10>Sn00;Xj03lj000mNSn0?Oo003co`4ajol0
0>?ooP3Yo`80ZJWn0?ZY003eZ@80ZJWn0?ZYo@3k@`00nhKk0?B/003f`P00nmH0
0?cR003ln0<0inL0mZT00?^YoP02ZJT0m:T00?bYoP3lZ@00mJT20:VYo@3ko`00
gOl00>?ooP3Yo`80_Kgn0?Zm003e_@80_Kgn0?Zm0`004@3kB`00ngKk0?B=003f
V@00nkD00?bh003lf@<0j>P0m[d00?^moP02_Kd0m;d00?bmoP3l_@00mKd20;fm
o@3ko`00gOl00>?ooP3Yo`80j>Sn0?[X003ej080j>Sn0?[X0`00WP3k]000nk[k
0?Bd003f[@00nkT00?b[003lZ`<0PX80m^P00?_XoP02j>P0m>P00?cXoP3lj000
mNP20>SXo@3ko`00lol1<>_o0@00hOon0>go003kZOh0oZT00?FY003kZOh0oZWl
0?]3nP3lR0400?F/003e`P00oMH00?_R003kn080i`3gZ@00mjWn0?BY003kZ@40
ZOh00JT0mJT00?ZYo@02ool0gOl1003Qooh0kOl00?^moP3n_@00mKd00?^moP3n
_@@0014A0?];nP3lJ`400?F=003eV@00oKD00?^h003kf@80j03g_@00mkgn0?Bm
003k_@40_Oh00Kd0mKd00?Zmo@02ool0gOl1003Qooh0kOl00?_XoP3nj000mNP0
0?_XoP3nj0@009jN0?^dnP3lZP400?Fd003e[@00oKT00?^[003kZ`80PP3gj000
mnSn0?CX003kj040j?h00NP0mNP00?[Xo@02ool0lol1:>_o003Mooh0lOl00?NY
o@3fZ@00mjWi0?a30@00mXP20:@0mZ`00?C2003neP00n^800?ch103Wi`00nZT0
0?FY0@2YoP3hZ@00njT00?bYoP3fZ@00mZWn0?kooP3So`00gOon0?7o003g_Od0
m[d00?NmoP04D`0A4@3lB`400?I[0P1m0?J=003dV@00o[D00?Zh003lf@@0j>P0
0?Zm003e_@40_Oh0n;d00?^m003l_Oh0m[d00?JmoP3nooh0hol00=gooP3ao`00
mnSm0?KX003gj?h01<`0WYh0o;@1003fZP80Z@3f]000m:d00?ji003jZ`00o:/4
08:2003jj000mNP10>Sn0?SX003kj000o>Sn0?KX003fj?h0o_on0?Wo0EcZo`00
foon0?Go003eZ@80ZJWn0?ZY003eZO/0o4<206`0mhP00?jT0@00n:`00?C20`3F
eP3ihP00o?P40>OW0<cn0?jY003eZ@00o:Wn0?bY003jZ@00o:T20:VYoP3jZ@00
m:T4003oo`3no`00hol00=_ooP3eo`00mKd20;fmoP3j_@00mKd505<04A40o4/2
05`0mf/00?im0@00n8d00?BI0`2e]@3i^000o=T40>SX0?Wn0?jm003e_@00o;gn
0?bm003j_@00o;d20;fmoP3j_@00m;d4003oo`3no`00hol00=_ooP3eo`00mNP2
0>SXoP3jj000mNP50<`0WYh0o;@20:h0mjX00?jY0@00n;@00?B]0`2i^@3iZ`00
o:/408:20;3n0?kX003ej000o>Sn0?cX003jj000o>P20>SXoP3jj000m>P4003o
o`3no`00n_l1I?co0@00m_l00?go003Hooh0nOl00?FY003kZOh0oZT00?FYnP3m
@`80K03fR000o:@00?Z/003b`P80eP3ihP00noP20>L0oLcm0?JY003hZOh00JT0
nZT00?bY003kZOd00ZVY0?>Y003no`00o_l00?Go0@00m_l00?go003Hooh0nOl0
0?Fm003k_Oh0o[d00?Fm1P1C000A4@3mB`80G03fJ`00o7d00?Z=003bV@80]@3i
^000nmT20>P0oOWm0?Jm003h_Oh00Kd0n[d00?bm003k_Od00[fm0?>m003no`00
o_l00?Go0@00m_l00?go003Hooh0nOl00?GX003kj?h0o^P00?GX1P3<002NWP3m
]080[P3fZP00o:T00?Zd003b[@80^@3iZ`00nj/20880oK3m0?KX003hj?h00NP0
n^P00?cX003kj?d00^SX0??X003no`00o_l00?[o0ECmo`<0ool0n?l1003mo`40
0=KooP3no`400?FY003gZOh0mJWi0?i30`1/K03fR000nj@00?^/003a`P00mn80
0?ch0`3Wi`3mc080ZJWn0?ZY003dZOh0o:T00?bY003fZOd0mJT00?[o003eo`<0
ool0n?l1003mo`400=KooP3no`400?Fm003g_Oh0mKd305=C0?hA003nB`<0G5`0
mV/00?]m003kS@00lIT00?Nh003lf@<0j>P0oOT20;fmoP3j_@00m;gn0?bm003l
_@00m[gm0?Fm003jo`00mOl30?oo0?So0@00oOl1003Fooh0o_l1003ej000mnSn
0?GX0`3<c03nWP00o[@30:j^0?JZ003kZ@00nk@00?6]003gZ`00o:/308:20?f`
0P3Xj?h0n^P00?CXoP3lj000o>P00?KXo@3ej000n_l00?Wo0GSmo`<0ool0nOl2
0?l0oOl00=;ooP01ZJWn0?VY003eZ@40ZOh0nJWi0?i3003nK000mXP00?ZT0@00
oJ`00?72003ghP00noP20>L0o/`00?^Yo@02ZJT0ljT20:VYoP01Z@3lZ@00m:T2
0:VYoP3iZ@400?_o003do`<0ool0nOl20?l0oOl00=;ooP01_Kgn0?Vm003e_@40
_Oh0nKd305=C0?hA003nB`00oU`00?I[003jO@400?f=003aV@00mkP00?_I0P3X
0?ki003k_Od00[fm0?>m0P2m_Oh00Kd0o;d00?Bm0P2m_Oh0nKd1003ko`00m?l3
0?oo0?Wo0P3o0?go003Booh00NSXoP3ij000mNP10>Sn0?WX0`3<c03nWP00o[@0
0?j^003fZP00nZT1003m]000lJd00?N[003kZ`80PP3n/000nnSm00;Xj03cj080
j>Sn007X0?cX003dj080j>Sn0?WX0@00nol00?So0FWmo`<0ool0n_l30?oo0?go
003Aood0oZWn0?fY003eZ@00o:T1003lZOP00T=30?e/003fR000n:@30:b/0?32
0@00mn800?ch1@3Wi`3<0?JYo@3eZ@00njWm00:YZ@3dZ@00njWn0?bY003ko`<0
ool0m_l30?oo0?[o0`3oo`3mo`00dOom0?jmoP3m_@00mKd00?bm0@00o;d00?iC
003n4@<0Bd/0oE`00?I[003hO@<0SHd0l9T1003g^000o=T50>SX0?T0m[gm0?Fm
003k_Od00[fm0?Bm003k_Oh0o;d00?_o0`3oo`3fo`<0ool0n_l30?oo0?go003A
ood0o^Sn0?gX003ej000o>P1003lj000o/`00?jN0`2d]03m[P00mZX00?RY0`2d
]03`[@400?N[003lZ`D0PX80/03fj?d0mNP00?_Xo@02j>P0m>P00?_XoP3lj000
nol30?oo0?[o0E_mo`<0ool0n_ol0?ko0@00dol00?fYoP3nZOd0mJT00?VYoP00
ZOL00D<0o6`00?N8003fY080[03a`P80c03ghP00o?P40>OW003dZ@80ZJWn0?RY
003kZ@00oZWm0?FY003hZOh00ZT00?coo03fo`<0ool0n_ol0?ko0@00dol00?fm
oP3n_Od0mKd00?VmoP01_@3nD`00oA4204/0o5`00?M[003fO@80S@3aV@80WP3g
^000o=T40>SX003d_@80_Kgn0?Rm003k_@00o[gm0?Fm003h_Oh00[d00?coo03f
o`<0ool0n_ol0?ko0@00dol00?gXoP3nj?d0mNP00?WXoP01j03nc000oIh20;@0
o:h00?NZ003fZ@80]03a[@80Z@3gZ`00o:/408:2003dj080j>Sn0?SX003kj000
o^Sm0?GX003hj?h00^P00?coo03jo`57oOl30?oo0?Oo003lo`00e?l00?VYoP02
Z@2YoP3hZ@00mJWg00530?a/003fR000mJ@1003a`P80c03fhP00o?P30>OW0?FY
003kZOh0o:T00?^Y003lZ@80ZJWm0?ZY003dZ@400>_o0`3oo`3go`00o?l00=Co
003i_Oh00[d0_Oh0n;d00?Fm0@00oU<00?hA0P1;0?aL003fJ`00mGd1003aV@80
WP3f^000o=T30>SX0?Fm003k_Oh0o;d00?^m003l_@80_Kgm0?Zm003d_@400>_o
0`3oo`3go`00o?l00=Co003ij?h00^P0j?h0n>P00?GX0@00o/`00?jN0P2d0?b^
003fZP00mJT1003a[@80Z@3fZ`00o:/308:20?GX003kj?h0o>P00?_X003lj080
j>Sm0?[X003dj0400>oo0D3lo`400?go003looh0oOl00=Go003eZOh0oZT1003k
Z@00m:Wf0?]/003fR000m:@1003b`P<0c<`0mn800?ch0`3Wi`3eZ@00n:Wn006Y
0?^Y003kZ@00njWm00:YZ@3cZ@00jOl1003mo`00o?on0?go003Eo`00mKgn0?jm
0@00nkd00?Bm003nD`00oA41003kG000mV/00?Am0@00lYT309jN0?Nh003lf@<0
j>P0mKd00?RmoP01_@3k_@00nkd00?^mo@02_Kd0lkd00>Wo0@00oOl00?cooP3m
o`00eOl00?GXoP3nj0400?_X003dj000o/`00?fN0@00njh00?JZ003dZ@400?:]
0`2YZ@3gZ`00o:/308:20?GX003hj?h00NP0nnP00?_X003kj?d00^SX0??X003^
o`4SjOl00=Oo0@00mJT00?jYoP01ZJWn00:YZ@3dZOH0nV`00?J8003eY0<0/;00
m<800?k<003ghP00o?P00?kW0@00n:T00?BY0@00njT00?bY003fZOh0m:T00=Go
003Go`400?Fm003n_Oh00KfmoP02_Kd0m;d205=CoP3m4@00nU`00?I[003eO@<0
QHD0m9T00?jN003g^000o=T00?kX0@00n;d00?Bm0@00nkd00?bm003f_Oh0m;d0
0=Go003Go`400?GX003nj?h00NSXoP02j>P0m>P20<c<oP3mWP00nZh00?JZ003e
Z@<0YjL0m:d00?jY003gZ`00o:/00?j20@00n>P00?CX0@00nnP00?cX003fj?h0
m>P00>go0COYooh0f_l10:Wn0?RY003jZOh00JVYoP3eZOd00JVYn`3jK000mXP0
0?FT0`2`/03d`P00oL`00?OR003ln080inOl0?bY003cZ@40ZOh00ZVY0?bY003d
Z@40ZOh0n:T1003Eooh0f_l10;gn0?Rm003j_Oh00KfmoP3e_@H0D`00_Kd0oQ41
003jG000mV/00?Em0`25Q@3dV@00oIh00?Nh003lf@80j>Sl0?bm003c_@40_Oh0
0[fm0?bm003d_@40_Oh0n;d1003Eooh0f_l10>Sn0?SX003jj?h00NSXoP3ej0H0
c000j>P0oYh1003j[P00mZX00?FY0`2WY`3d[@00oJT00?N[003lZ`80PX;l0?cX
003cj040j?h00^SX0?cX003dj040j?h0n>P1003]o`4fjOl00=Wo003lZ@400?^Y
003fZOh00JVYoP3iZOh0oZWk0?U/003gR000m:@00?j`003e`P00oL`00?OR003l
n000o^Oj006Y0?>Y003lZOh0o:T00?FY003lZOh0o:T1003Do`00fOl00?bm0@00
nkd00?JmoP01_Kgn0?Vm0P1C0?jm003n4@400?UL003gJ`00m7d00?j5003eV@00
oIh00?Nh003lf@00o^Sj006m0?>m003l_Oh0o;d00?Fm003l_Oh0o;d1003Do`00
fOl00?cX0@00nnP00?KXoP01j>Sn0?WX0P3<0?kX003nWP400?V^003gZP00m:T0
0?jW003e[@00oJT00?N[003lZ`00oX;j007X0??X003lj?h0o>P00?GX003lj?h0
o>P1003/o`4bjOl00=[o003iZOh00ZVY0?BY0@2YoP01ZJWm0?jYoP3mZO/0nV`0
0?J8003dY000o[000?K2003kc000mn800?ch0P3WioL0m:T00?^Y0@2YoP01Z@3d
Z@00nJWn00:Y003Co`00f_l00?VmoP02_Kd0m;d10;gn006m_Od0o[gn0?fm003n
4@400?YL003fJ`00m7d00?j5003fV@00nih00?Nh003lf@80j>Sg0?Bm003k_@40
_Oh00Kd0m;d00?VmoP02_@00dol00=[o003ij?h00^SX0?CX0@3XoP01j>Sm0?kX
oP3mj000oYh1003j[P00mZX00?BY003nY`00mZd00?^Y003gZ`00o:/208:2m`3d
j000nnP10>Sn007X0?CX003ij?h00^P00>_o0AgXo`00g?l00?FYoP3eZ@00o:T1
003mZOd0njWm006Y0?Y/003fR000mJ@00?b`003g`P00nl`00?OR003ln080inOi
006YZOh0n:T00?^Y003lZOh0mZT00?FYoP3Bo`00g?l00?FmoP3e_@00o;d1003m
_Od0nkd5014A0;d0nU`00?I[003eO@00o8D00?NI003kWP00mkP00?cI0P3Xj?T0
0KfmoP3h_@00nkd00?bmoP3f_@00mKgn0=;o003Lo`00mNSn0?GX003lj0400?gX
o@3kj0D0WYh0j03j[P00mZX00?FY003lY`00mjd00?^Y003gZ`00o:/208:2n@01
j>Sn0?SX003kj000o>Sn0?KX003ej?h0jol1>>So0@00g_l00?BY0P2YZOh0nJT0
0?VYoP02ZJT0nZWm00:YZ@3jK000mXP00?FT003k/000n<800?_<003fhP00oOP0
0?kWn`3kZOh0o:T00?^Y003kZ@80ZJWn0?ZY003dZ@400=7o0@00g_l00?Bm0P2m
_Oh0nKd00?VmoP02_Kd0n[d6014A0;fm0?YL003fJ`00mGd00?^5003hV@00nih0
0?Jh003mf@00o^Sk0?^moP3l_@00nkd00?^m0P2m_Oh0n[d00?Bm0@00dOl1003N
o`00m>P20>SXoP3ij000nNSn00;Xj03jj0H0WYh0j>P0nZh00?JZ003eZ@00njL0
0?R]003kZ@00mZ/00?f[003nP_/0nnSn0?cX003kj000nnP20>SXoP3jj000m>P1
003Zo`4Vj?l00=ko003dZ@00njWm0?jY003eZOh0nZWm00:YZ@3jK000mXP00?FT
003k/000nL800?W<003ghP00o?P20>OWn`3hZOh00JT0njT00?^Y003kZOd00ZVY
0?>Y0@00dOl00=ko003d_@00nkgm0?jm003e_Oh0n[d6014A0;fm0?YL003fJ`00
mGd00?^5003iV@00nIh00?Nh003lf@80j>Sk0?RmoP01_@3k_@00nkd00?^mo@02
_Kd0lkd1003Ao`00g_l00?CX003kj?d0o^P00?GXoP3jj0H0WYh0j>P0nZh00?JZ
003eZ@00njL00?V]003iZ@00mj/00?b[0P22P_/0n>Sn007X0?_X003kj000nnSm
00;Xj03cj0400>[o0@oXo`00gol00?BY003fZOh0m:T20:VYoP3mZOh00ZVY0?U/
003gR000m:@00?Z`003j`P00nL`00?OR003ln000o^Om0?BYoP3lZ@00o:T00?JY
o@3eZ@400=3o003Oo`00m;d00?JmoP3d_@80_Kgn0?fm1@0A0;fm0?UL003gJ`00
m7d00?Z5003jV@00nIh00?Nh003lf@00o^Sm0?BmoP3l_@00o;d00?Jmo@3e_@40
0=3o003Oo`00m>P00?KXoP3dj080j>Sn0?gX1@2N0>SX0?V^003gZP00m:T00?ZW
003j[@00nJT00?N[003lZ`00oX;m0?CXoP3lj000o>P00?KXo@3ej0400>Wo0COX
o`400>7o0@2YoP3hZ@00m:T10:Wn0?RY003kZO/0oZT00?Y/003fR000m:@00?Z`
003j`P00n<`00?OR0@3hoP03l@3Wioh0ljT20:VYoP01Z@3lZ@00m:T20:VYoP3i
Z@400<oo0@00hOl10;gn0?Rm003d_@40_Oh0n;d00?^mo@014@3n_@00nU`00?I[
003dO@00nXD00?ZI003hWP00mkP10=Wn00?S0>SXoP3c_@80_Kgn006m0?bm003d
_@80_Kgn0?Vm0@00col1003Qo`40j?h0n>P00?CX0@3XoP3hj000nnSm006N0?kX
003j[P00mZX00?BY003jY`00nZd00?RY003gZ`40Zoh00l00PX;n0??X0P3Xj?h0
0NP0o>P00?CX0P3Xj?h0nNP1003Xo`4Xj?l00>7o003lZ@400?^Y003dZ@00o:T1
003kZ@00mjWn0?jY003jK000mXP00?FT003h/000o<800?O<003ghP400?ca0`00
i`3cZ@00njWm00:YZ@3cZ@00o:Wn0?bY003>o`00hOl00?bm0@00nkd00?Bm003l
_@400?^m003g_Oh0o[d00?YL003fJ`00mGd00?R5003lV@00mih00?Nh0@00o><3
003X0?>m003k_Od00[fm0?>m003l_Oh0o;d00<ko003Qo`00o>P1003kj000m>P0
0?cX0@00nnP00?OXoP3nj000nZh00?JZ003eZ@00n:L00?b]003gZ@00mj/1003l
`0<00880lnP00?_Xo@02j>P0lnP00?cXoP3lj000iol17>Oo003So`00nJWn00:Y
Z@3dZ@00nJWn00:YZ@3fZ@800:Wm0?Y/003fR000mJ@00?N`003m`P00m/`00?WR
0P3>0?_ao@3eZ@00nZT00?jYo@3eZ@00n:Wn00:Y003=o`00hol00?VmoP02_Kd0
m;d00?VmoP02_Kd0m[d2002mo@3jG000mV/00?Em003gQ@00oIT00?JN003i^080
/P3khod0mKd00?Zm003n_Od0mKd00?RmoP02_@00cOl00>?o003ij?h00^SX0?CX
003ij?h00^SX0?KX0P00j?d0nZh00?JZ003eZ@00mjL00?f]003fZ@00nJ/20;l0
nl3m0?GX003jj000o^Sm0?GX003hj?h00^P00>Oo0C7io`400?SooP3mo`00i?l0
0?FYoP3eZ@00mJT1003fZ@400?fYo@3lK000mXP00?FT003g/000oL800?K<003i
hP80cP3jl@80c<cm0?ZY003jZ@00o:T20:VYoP3iZ@00m:Wn0=oo0@00n?on0?go
003To`00mKgn0?Fm003e_@400?Jm0@00oKgm0?aL003fJ`00mGd00?N5003mV@00
mYh00?Vh0P2b0?[S0P3inOd0n[d00?Zm003l_@80_Kgn0?Vm003d_Oh0gol1003h
ooh0oOl00>Co003ej?h0mNP00?GX0@00m^P1003mj?d0o:h00?JZ003eZ@00mjL0
0?f]003fZ@00nJ/20;l0n/020;2`o@3jj000n^P00?cX0P3Xj?h0nNP00?CXoP3W
o`5Zn_l30?oo0?[o003no`00o_l1003Vo`00m:T20:VYoP3iZ@00m:T10:Wn0?VY
0@00oJT00?i/0@00oV`00?N8003dY000m[030<;20?G<003jhP00o/h00?[a003l
c?d00ZVY0?ZY003lZ@00njWn0?bY003dZ@00g_l30?oo0?[o003no`00o_l1003V
o`00m;d20;fmoP3i_@00m;d10;gn0?Vm0@00oKd00?iL0@00oU`00?M[003dO@00
mXD309VI0?FN003j^000o[800?[S003lnOd00[fm0?Zm003l_@00nkgn0?bm003d
_@00g_l30?oo0?[o003no`00o_l1003Vo`00m>P20>SXoP3ij000m>P10>Sn0?WX
0@00oNP00?j^0@00oZh00?NZ003dZ@00mZL30:f]0?FY003jZ`00o[l00?[0003l
/?d00^SX0?[X003lj000nnSn0?cX003dj000iOl1C?[o0`3oo`3jo`00o_l00?ko
003Vo`00m:T00?^Yo@3nZ@00m:T00?bYoP3lZ@00o:T00?a/oP3fR000mJ@00?F`
0`32`P3dc000nn800?g>003kl@00n<cn0?^Y003kZ@00n:Wn006Y0?BY0@00g_l3
0?oo0?[o003no`00o_l00>Ko003d_@00nkgm0?jm003d_@00o;gn0?bm003l_@00
o5cn0?I[003eO@00mHD309VI0?BN003k^000oK800?_S003hnOh0nkd00?^m003h
_Oh00Kd0m;d1003No`<0ool0n_l00?ko003no`00i_l00?CX003kj?d0o^P00?CX
003lj?h0o>P00?cX003l[_h0mZX00?FY003eY`<0[Jd0m:T00?^[003m_`00nl00
0?R`oP3kj000nnP00?SXoP01j03dj0400>Go0C7jo`<0ool0mol00?go003Wo`40
0?FY003fZOh0m:T00?RYoP01Z@3kZ@00nVcm0?V8003eY000m;020<80m<`00?cR
003lcP00n_400?S<0@2YoP3nZ@00o:T00?BY0@00m:T00=go0`3oo`3go`00oOl0
0>Oo0@00mKd00?JmoP3d_@00n;gn006m0?^m003jG?d0nF/00?Em003dQ@80V@3d
WP00o;P00?bb003jh`00n?T10;gn0?jm003l_@00m;d1003d_@00gOl30?oo0?Oo
003mo`00iol1003ej000m^Sn0?CX003hj?h00NP0nnP00?Z^o@3iZP00mJT00?BW
0P2]0?BY003lZ`00o;l00?[0003h/040j?h0o^P00?cX003dj0400?CX003To`5?
n_l30?oo0?So003lo`400>Wo0P2YZOh0nJT00?BY0@2YoP3hZ@00m:T1003lZ@00
nF`00?j8oP3lR000mJ@00?>`003bc000oN800?_>003jl@00n/`00?bYoP3lZ@00
ljT10:Wn0?RY003lo`00h_l30?oo0?So003lo`400>Wo0P2m_Oh0nKd00?Bm0@2m
oP3h_@00m;d1003l_@00nE`00?i[oP3lJ`00mGd00?>5003bWP00oKP00?^b003j
h`00n_T00?bmoP3l_@00lkd10;gn0?Rm003lo`00h_l30?oo0?So003lo`400>Wo
0P3Xj?h0nNP00?CX0@3XoP3hj000m>P1003lj000nJh00?jZoP3lZP00mJT00?>W
003bZ@00oJ/00?^o003j`000n[000?cXoP3lj000lnP10>Sn0?SX003lo`00jOl1
Io[o0`3oo`3io`<0ool0oOl00>[o003kZOh0oJT00?BY003lZ@400?^Y003cZ@00
njT00?U/003kR?h00XR80?FT003c/000l/`00?kR003jcP00nO400?c<003jZ@40
ZOh00JT0ljT00?bYoP3lZ@400?go0@00h_l30?oo0?Wo0`3oo`3mo`00j_l00?^m
oP3m_@00m;d00?bm0@00nkd00?>m003k_@00nE`00?][oP02Jf/0mGd00?>5003b
WP00o[P00?Zb003ih`00o?T00?Zm0@2moP01_@3c_@00o;gn0?bm0@00oOl1003R
o`<0ool0nOl30?oo0?go003Zo`00nnSn0?gX003dj000o>P1003kj000lnP00?_X
003i[P00nj[n00:ZZP3eZ@00ljL00?:Y003nZ`00n[l00?W0003l/000n^P10>Sn
007X0??X003lj?h0o>P1003mo`400>Wo0Cgio`400?go003noo`0oOl00>_o003g
ZOd0m:T00?VYoP02ZJT0ljT00?ZY003iK000n8Sn0?JT003b/0400?;<0`3RhP3i
cP00nO400?k<003iZ@00oJWn0?BY003iZOh00ZT00?_o003Qo`400?go003noo`0
oOl00>_o003g_Od0m;d00?VmoP02_Kd0lkd00?Zm003iG000n6_n0?Im003bQ@40
0?:N0`2h^03i/P00nN<00?ki003i_@00oKgn0?Bm003i_Oh00[d00?_o003Qo`40
0?go003noo`0oOl00>_o003gj?d0m>P00?WXoP02j>P0lnP00?[X003i[P00n:[n
0?JY003bY`400?:Y0`2[Z`3i_`00nL000?j`003ij000oNSn0?CX003ij?h00^P0
0?_o003Yo`4Li_l00>co003eZ@40ZOh0mjT00?FY0@00ljT00?VY003jK000mXP1
0:Cn0?VT003c/080V@3bc080hP3hcP00n?420<`0nJT00?bY0P2YZOh0n:T00?FY
0@00n_l00<ko003/o`00mKd10;gn0?Nm003e_@400?>m003i_@00nU`00?I[0@1m
oP3iO@00lhD207X0lYh20;P0n;800?SS0P3i0?Vm003l_@80_Kgn0?Rm003e_@40
0?[o003>o`00k?l00?GX0@3XoP3gj000mNP1003cj000nNP00?Z^003fZP40ZOh0
nJT00?>W0P2^0?:Y0P2[0?Ro003h`080/03ij000o>P20>SXoP3hj000mNP1003j
o`00jOl1:>Ko0@00k_l00?FY003lZOh0njT00?BY0@2YoP3gZ@00n:T00?Y/003k
R?/0oJCn0?bT003c/0<0VIT0ll`20>80mlh00?Sa003iZ@00o:T00?^YoP3lZ@00
m:T1003jo`00c_l1003^o`00mKd00?bmoP3k_@00m;d10;gn0?Nm003h_@00nU`0
0?][n`3mOOh0o7d00?>50`1jNP3cWP80^03g/P00n><00?Vm003l_@00nkgn0?bm
003d_@400?[o003>o`400>ko003ej000o>Sn0?_X003dj040j?h0mnP00?SX003j
[P00nj[k0?fYoP3lZ@00ljL30:j^0?>Y0P2[0?No003h`000nNP00?cX003kj?h0
o>P00?CX0@00n_l00>Wo0B;Vo`00k_l00?FY003hZOh00ZVY0?BY003lZOh0njT0
0?RY003iK?X0o9l1003kY?h00ZBT0?>`0`2IV@3bc000mLh00?Wa0@00njT00?^Y
003hZOh00JT0ljT00?Wo003>o`00k_l00?Fm003h_Oh00[fm0?Bm003l_Oh0nkd0
0?Rm003iG?X0o8`1003kOOh00Wem0?>50`1jNP3bWP00mK800?WS0@00nkd00?^m
003h_Oh00Kd0lkd00?Wo003>o`00k_l00?GX003hj?h00^SX0?CX003lj?h0nnP0
0?SX003i[_X0o;l1003kZOh00ZVY0?>W0`2^[P3bZ@00mKl00?W00@00nnP00?_X
003hj?h00NP0lnP00?Wo003Yo`4Li_l00?3o0@00mJT00?BY0@00m:T00?RYoP02
ZJT0mjT00?Y/003fW`<0W9`0nJCn0?>`003nV@00ll`00?G>003jl@80ZJWn0?jY
003lZ@00m:Wn0?FY0@00n_on0<oo003`o`400?Fm003d_@400?Bm003h_Oh00[fm
0?Nm003jG000mX`308610?UmoP3cQ@00oWX00?>N003e/P00n^<20;fmoP3n_@00
o;d00?BmoP3e_@400?[ooP3?o`00l?l1003ej000m>P1003dj000n>Sn00;Xj03g
j000nZh00?Jo0`2f]P3iZOh0ljL00?j^003cZ@00mKl00?[00P3Xj?h0o^P00?cX
003dj?h0mNP1003jooh0j_l17nKo0@00l_l10:Wn0?RY003cZ@40ZOh0n:T00?BY
0@00mZT00?a/oP3fW`00oY`00?VTo@3e/000oIT00?G<0P2P0?G>003ll@00njWn
0?bY003cZ@80ZJWn0?VY0@00a?l1003bo`40_Oh0n;d00?>m0@2moP3h_@00m;d1
003f_@00o5cn0?J<003nP@00nGgm0?F5003mNP00mIh208d0mK800?cS003k_Oh0
o;d00?>m0P2m_Oh0nKd10034o`400?;o0@3XoP3hj000lnP10>Sn0?SX003dj040
0?KX003l[_h0m[l00?jf003iZOd0mJL00?f^003eZ@80_`3e_`00o<000?_XoP3l
j000lnP20>SXoP3ij0400=oo0DWUo`00lol00?bYoP3lZ@00ljT00?bY0@00njT0
0?>Y0@2YoP3iZ@00oV`4002YZ@3fW`00oI`00?ZT003n/?h0nK000?bI003ec0<0
X:00m/h00?ca003jZ@40ZOh00JT0ljT00?^YoP3lZ@00`_l00??o003l_Oh0o;d0
0?>m003l_@400?^m003c_@40_Oh0nKd00?iL1000_Kd0mX`00?f1003jO@00oXGn
0?V5003lNP00mIh308f=0?Jb003lh`00n[d10;gn006m0?>m003k_Oh0o;d00<;o
003co`00o>Sn0?cX003cj000o>P1003kj000lnP10>Sn0?WX003n[P@00>SX0?Jo
003m]P00nZT00?jWoP3iY`00o:h00?FY0`2o_`3f_`00o<000?[X0@3XoP01j03c
j000nnSn0?cX003No`56iOl00?Co003hZOh00JT0ljT00?VYoP02ZJT0ljT00?bY
oP3mZ@00oV`00?jY003fW`00ni`1003lY000nk3n0?b`003kV@00m/`00?jP003f
cP00o_400?ZY003lZOh0m:T00?RYoP02Z@00`_l00?Co003h_Oh00Kd0lkd00?Vm
oP02_Kd0lkd00?bmoP3m_@00oU`00?jm003fS000nh41003lO@00nhGn0?b5003k
NP00mYh00?j=003f/P00o^<00?Zm003l_Oh0m;d00?RmoP02_@00`_l00?Co003h
j?h00NP0lnP00?WXoP02j>P0lnP00?cXoP3mj000oZh00?kX003f_`00nkH1003l
Z@00njOn0?bW003k[P00mZT00?jo003f_`00o/000?[X003lj?h0m>P00?SXoP02
j000g_l1:nGo003eo`00m:Wn0?FY003eZ@400?>Y003hZOh01:T0K000oJT00?JO
003iW000oJ@00?R`oP02/;00niT00?O<003lX000m/h30?7a0?ZY003lZ@80ZJWn
0?RY003dZ@400<7o003eo`00m;gn0?Fm003e_@400?>m003h_Oh01;d0G000oKd0
0?J<003iP@00oGd00?R5oP02QHD0ngX00?NN003lS@00m[830>?S0?Zm003l_@80
_Kgn0?Rm003d_@400<7o003eo`00m>Sn0?GX003ej0400??X003hj?h01>P0[P00
oNP00?Jo003i]P00oJT00?RWoP02YjL0njh00?NY003l_`00m[l30<300?[X003l
j080j>Sn0?SX003dj0400=go0AWUo`400?Oo003cZ@80ZJWn0?VY003dZ@40ZOh0
mjT00?BYoP3kZ@00mYl00?RL0`2TY03d/?h0nYT00?S<003lX000m/h20?40nZT0
0?bY003kZOh0o:T00?>Y0030o`400?Oo003c_@80_Kgn0?Vm003d_@40_Oh0mkd0
0?BmoP3k_@00mX`00?R10`1mO@3dQOh0nWX00?RN003lS@00m[820><0n[d00?bm
003k_Oh0o;d00?>m0030o`400?Oo003cj080j>Sn0?WX003dj040j?h0mnP00?CX
oP3kj000m[l00?Rf0`2YZ@3dYoh0nZh00?RY003l_`00m[l20<00n^P00?cX003k
j?h0o>P00??X003Lo`4IiOl00?Oo003cZ@00njWn0?fY003dZ@00o:Wn0?^Y003c
Z@00nZT00?JO003fW080Y03c/040VOh0oIT00?S<003kX000m/h00?ZY003kZ@00
n:Wn006Y0?>Y0@00`?l00?Oo003c_@00nkgn0?fm003d_@00o;gn0?^m003c_@00
n[d00?J<003fP@80O@3cQ@40N_h0oGX00?RN003kS@00m[800?Zm003k_@00n;gn
006m0?>m0@00`?l00?Oo003cj000nnSn0?gX003dj000o>Sn0?_X003cj000n^P0
0?Jo003f]P80Z@3cY`40[_h0oJh00?RY003k_`00m[l00?[X003kj000n>Sn007X
0??X0@00g?l14n_o0@00o?l00?Wo003cZ@00mjWm0?BY003hZOh00ZVY0?>Y003i
Z@00mYl00?FL0@00lk000?fIoP02VIT0n/`00?VP003gcP400?^Y003lZ@00m:Wn
0?BY0035o`400?co003io`00lkd00?Nmo@3d_@00n;gn00:m_@3c_@00nKd00?J<
003eP@400?>5003mN_h00WYj0?ZN003iS@00mk81003k_@00o;d00?BmoP3d_@00
aOl1003lo`00nOl00??X003gj?d0m>P00?SXoP02j>P0lnP00?WX003f_`00mKH1
003cY`00oJkn00:^[P3jZ@00nKl00?No0@00nnP00?cX003dj?h0m>P00=_o0B_/
o`<0ool0oOl00?[o0@2YoP3gZ@00mJT30:T00?JY003dZ@400?>Y003hZ@00mYl0
0?BL0@00m;000?ZIoP3jc000n:000?W>0P2YZOh00ZVY0?^Y003dZ@80ZJWn0?RY
0035o`<0ool0oOl00?[o0@2moP3g_@00mKd30;d00?Jm003d_@400?>m003h_@00
mX`00?B10@00m8D00?YjoP3jWP00n8d00?Vb0P2m_Oh00[fm0?^m003d_@80_Kgn
0?Rm0035o`<0ool0oOl00?[o0@3XoP3gj000mNP30>P00?KX003dj0400??X003h
j000m[l00?Bf0@00m:L00?Z^oP3jZ@00n;l00?Vo0P3Xj?h00^SX0?_X003dj080
j>Sn0?SX003Jo`4mk?l30?oo0?go003ko`00o:T1003jZ@00mJT00?fY0@00nJT0
0?>Y0@2YoP3gZ@00n:T00?JO003dW0<0Wil0mK000?NI0@00o<`00?RP003jcP00
njWn0?bY003dZ@00njWn0?bY0@00aOl30?oo0?go003ko`00o;d1003j_@00mKd0
0?fm0@00nKd00?>m0@2moP3g_@00n;d00?J<003dP@<0S8`0mHD00?Mj0@00o9h0
0?R=003j/P00nkgn0?bm003d_@00nkgn0?bm0@00aOl30?oo0?go003ko`00o>P1
003jj000mNP00?gX0@00nNP00??X0@3XoP3gj000n>P00?Jo003d]P<0_kl0mJL0
0?N^0@00o:T00?Ro003j_`00nnSn0?cX003dj000nnSn0?cX0@00f_l1A^co0`3o
o`3mo`00o?l00?VYoP3nZ@00mJT00?ZYoP3mZ@00ljT00?bYoP3kZ@00mjT00?JO
003dW000oYl00?N`003fV@40c?h00L`0mZ000?c>003jZ@80ZJWn006Y0?>Y003h
ZOh00:Wn0<Go0`3oo`3mo`00o?l00?VmoP3n_@00mKd00?ZmoP3m_@00lkd00?bm
oP3k_@00mkd00?J<003dP@00oX`00?N5003fNP40W_h00Ih0mXd00?bb003j_@80
_Kgn006m0?>m003h_Oh00;gn0<Go0`3oo`3mo`00o?l00?WXoP3nj000mNP00?[X
oP3mj000lnP00?cXoP3kj000mnP00?Jo003d]P00o[l00?NW003f[P40ZOh00JT0
m[l00?bo003jj080j>Sn007X0??X003hj?h00>Sn0=[o0B;/o`<0ool0oOl1003n
o`00mJWn0?FY003fZ@<00:T0ljT00?RYoP02ZJT0mZT00?JO003dW000oIl00?R`
003eV@00o/cn0?JP003ncP00nJT00?bYoP3eZ@00m:T10033o`<0ool0oOl1003n
o`00mKgn0?Fm003f_@<00;d0lkd00?RmoP02_Kd0m[d00?J<003dP@00oH`00?R5
003eNP00oYkn0?J=003n/P00nKd00?bmoP3e_@00m;d10033o`<0ool0oOl1003n
o`00mNSn0?GX003fj0<00>P0lnP00?SXoP02j>P0m^P00?Jo003d]P00oKl00?RW
003e[P00oZWn0?Jo003n_`00nNP00?cXoP3ej000m>P1003Ho`4Xk?l30?oo0?go
003no`00m:T10:Wn0?RY003cZ@400?BY003dZ@400?JY003fW`00m9`00?^O003i
/000m9T00?k<0@2PoP3hX080cP3iZ@00njT20:VYoP3hZ@00m:T10033o`<0ool0
oOl00?ko003d_@40_Oh0n;d00?>m0@00m;d00?Bm0@00m[d00?J<003dP@00nh`0
0?V5003dNP00oYh108gn0?R=0P2b0?Vm003k_@80_Kgn0?Rm003d_@400<?o0`3o
o`3mo`00o_l00?CX0@3XoP3hj000lnP1003dj000m>P1003fj000m[l00?Bf003k
_`00nJL00?B^003nZ@40_oh0n;l20;l0nNP00?_X0P3Xj?h0n>P00?CX0@00f?l1
9N_o0@00nol20?l0m:T00?bYoP3lZ@00lZT10:Wn0?RY003cZ@40ZOh0nJT00?JO
003dW000nYl00?Z`003dV@<0c<`0o:3n0?ZP003iZ@00njT00?^YoP3lZ@00m:T1
0031o`400?_o0P3o0?Bm003l_Oh0o;d00?:m0@2moP3h_@00lkd10;gn0?Vm003f
S000m8400?Z<003jQ@00m7X309jN0?b=oP3jS@00nKd00?^m003k_Oh0o;d00?Bm
0@00`Ol1003ko`80o`3dj000o>Sn0?cX003bj040j?h0n>P00??X0@3XoP3ij000
m[l00?Bf003j_`00nZL00?B^0`2YZ@3l_oh0n[l00?WX003kj000nnSn0?cX003d
j0400=Oo0A3So`400?BY003hZOh00JT0lZT00?bYoP3lZ@00ljT00?bYoP3lZ@00
mYl00?BL003jW`00n[000?>I0P3<0?VPoP3mX0400?ZY003lZ@00mjWn006Y0?>Y
002ho`400?Bm003h_Oh00Kd0l[d00?bmoP3l_@00lkd00?bmoP3l_@00mX`00?B1
003jS000nXD00?=j0P2N0?V=oP3mS@400?Zm003l_@00mkgn006m0?>m002ho`40
0?CX003hj?h00NP0l^P00?cXoP3lj000lnP00?cXoP3lj000m[l00?Bf003j_`00
nZL00?>^0P2Y0?VooP3m_`400?[X003lj000mnSn007X0??X003Fo`3khoom0?NY
003dZ@400?>Y003hZOh00JT0ljT00?RYoP01Z@3fW`00m9`00?RO003l/000lYT2
0<`0mZ3m006YZOh0oZT00?bY003cZOh0mJT1002hood0mkd00?Bm0@00lkd00?Rm
oP01_@3c_@00n;gn006m0?J<003dP@00n8`00?b5003bNP80WP3fSOd00KfmoP3n
_@00o;d00?>moP3e_@400;Soo@3gj000m>P1003cj000n>Sn007X0??X003hj?h0
0NP0m[l00?Bf003h_`00o:L00?:^0P2Y0?Joo@01j>Sn0?kX003lj000lnSn0?GX
0@00e_l0n>?o1@00ool00?ZY003cZ@40ZOh0mjT00?BY0@00m:T00?BY0@00mYl0
0?BL003gW`00oK000?6I003cX?d0oZWn0?bY003bZ@80ZJWn0?RY002go`D00?oo
003j_@00lkd10;gn0?Nm003d_@400?Bm003d_@400?J<003dP@00mh`00?f5003a
NP00lhgm0?jmoP3l_@00l[d20;fmoP3h_@00]ol5003oo`00n^P00??X0@3XoP3g
j000m>P1003dj000m>P1003f_`00m;H00?No003mY`00lJh00?>oo@3nj?h0o>P0
0?;X0P3Xj?h0n>P00=Go0AKRooh00OoooP3nZ@00ljT00?bYoP3kZ@00ljT10:Wn
0?RY003cZ@40ZOh0nIl00?BL003fW`00o[000?6I003cX000oZWn00:Y0:Wn006Y
0?:Y003kZOh0o:T00;GooP01ooon0?jm003c_@00o;gn0?^m003c_@40_Oh0n;d0
0?>m0@2moP3iS000m8400?J<003nQ@00lGX00?>=003n_Oh00[d0_Oh00Kd0l[d0
0?^moP3l_@00]Oon007oooh0o^P00??X003lj?h0nnP00??X0@3XoP3hj000lnP1
0>Sn0?Vo003d]P00m[l00?jW003a[P00lkl00?kXoP02j03XoP01j03bj000nnSn
0?cX003Do`4:gol3003oood0ljT00?RYoP02ZJT0ljT00?bYoP3lZ@00ljT00?bY
oP3mW`00m9`00?BO0`2`/03bV@40ZOh0mj000?ZY0@00oJWn0?BY003gZOh00ZT0
0;;o0`00ooom0?>m003h_Oh00[fm0?>m003l_Oh0o;d00?>m003l_Oh0oH`00?B1
003dS0<0QHD0lWX10;gn0?N=003j_@400?fmoP3d_@00mkgn00:m002bo`<00?oo
o@3cj000n>Sn00;Xj03cj000o>Sn0?cX003cj000o>Sn0?fo003d]P00m;l30:NW
0?:^0@3XoP3g_`00n^P1003mj?h0m>P00?OXoP02j000e?l12]gooP03ool00?FY
003dZ@400?>Y003hZOh00JT0ljT00?RYoP01W`3dW000lil1003bV@00o:T1003i
X000nJT00?fY0P2YZOh0n:T00?>Y0@00oOl1002eooh00ooo003e_@00m;d1003c
_@00n;gn006m0?>m003h_Oh00H`0m8400?><0@00lWX00?bm0@00nHd00?Vm003m
_@80_Kgn0?Rm003c_@400?go0@00]Oon00?oo`00mNP00?CX0@00lnP00?SXoP01
j03cj000n>Sn006o0?Bf003c_`400?:^003lj0400?Vo003ij000oNP20>SXoP3h
j000lnP1003mo`400=Wo0A3[ooh0loon00;o003hZ@00ljT10:Wn0?NY003dZ@40
0?BY003dZ@400?BL003bW`00liT00?VY0@00o:000?RY003nZ@00njWn0?bY003b
Z@400?ko0`3oo`34ooh0loon00;o003h_@00lkd10;gn0?Nm003d_@400?Bm003d
_@400?B1003bS000lgX00?Vm0@00o8d00?Rm003n_@00nkgn0?bm003b_@400?ko
0`3oo`34ooh0loon00;o003hj000lnP10>Sn0?OX003dj0400?CX003dj0400?Bf
003b_`00ljh00?WX0@00o;l00?SX003nj000nnSn0?cX003bj0400?ko0`3oo`3J
o`4Uk?l00?ko003ao`800?on0?bY003cZ@00o:Wn0?^Y003cZ@40ZOh0n:T00?>Y
0@2YoP3hW000lIl1003dV@00mjWn006P0?NY003nZ@00n:Wn006Y0?:Y0@00oOl3
0?oo0<Go003no`00lOl2003ooP3l_@00lkd00?bmoP3k_@00lkd10;gn0?Rm003c
_@40_Oh0n8400?6<0@00m7X00?NmoP01S@3g_@00o[d00?RmoP01_@3b_@400?go
0`3oo`35o`00o_l00?7o0P00ooh0o>P00??X003lj?h0nnP00??X0@3XoP3hj000
lnP10>Sn0?Rf003a_`400?B^003gj?h00Kl0mnP00?kX003hj?h00NP0l^P1003m
o`<0ool0f_l17nco003no`00koon00Go002YZ@3cZ@00n:Wn00:YZ@3cZ@00o:Wn
0?bY003cZ@00o:T1003jW000lYl20:VYoP3hV@00ljWn0?RY0`2YZ@3dZ@400?:Y
003lo`<0ool0aOl00?ko003_ooh01Ol00;fm0?>m003h_Oh00[fm0?>m003l_Oh0
o;d00?>m003l_@400?Z1003bS080_Kgn0?Qj003c_Oh0n;d30;fm0?Bm0@00l[d0
0?co0`3oo`35o`00o_l00>oooP05o`00j>P0lnP00?SXoP02j>P0lnP00?cXoP3l
j000lnP00?cX0@00n[H00?:o0P3Xj?h0n:h00??XoP3hj0<0j>P0m>P1003bj000
o?l30?oo0=[o0A3Yo`00jol4003o003cZ@00m:T1003cZ@00n:Wn006Y0?>Y003i
Z@400?bL003cW`00njWn0?bI003bZ@80ZJWn0?^Y0`2YZ@3dZ@40ZOh0mZT00?_o
0`3oo`32o`00jol4003o003c_@00m;d1003c_@00n;gn006m0?>m003i_@400?b1
003cS000nkgn0?aj003b_@80_Kgn0?^m0`2m_@3d_@40_Oh0m[d00?_o0`3oo`32
o`00jol4003o003cj000m>P1003cj000n>Sn007X0??X003ij0400?bf003c_`00
nnSn0?b^003bj080j>Sn0?_X0`3Xj03dj040j?h0m^P00?_o0`3oo`3Jo`47l_ol
0?ko003Xoo/0mjT00?>Y0`2Y003fZ@00m:Wn0?BY003gZOh00I`0lil00?NYoP01
V@3bZ@00njWn0?jY0P2Y0?BY003lZ@400?RY003ko`<0ool0bool0?ko003Xoo/0
mkd00?>m0`2m003f_@00m;gn0?Bm003g_Oh00H40lh`00?NmoP01NP3b_@00nkgn
0?jm0P2m0?Bm003l_@400?Rm003ko`<0ool0bool0?ko003Xoo/0mnP00??X0`3X
003fj000m>Sn0?CX003gj?h00KH0lkl00?OXoP01[P3bj000nnSn0?kX0P3X0?CX
003lj0400?SX003ko`<0ool0f_l0n>_o0`3oo`3Wo`800?on0?^Y003cZ@00oJT1
003iZ@00ljT20:VYoP3hZ@00ljWn0?BO003dZ@400?>Y003gZO`0ljT00?ZYoP3l
Z@00nOl10033o`<0ool0iol2003ooP3k_@00lkd00?fm0@00nKd00?>m0P2m_Oh0
n;d00?>moP3dS000m;d1003c_@00mkgl0?>m003j_Oh0o;d00?Wo0@00`ol30?oo
0>Oo0P00ooh0nnP00??X003mj0400?WX003cj080j>Sn0?SX003cj?h0m;l00?CX
0@00lnP00?OXo03cj000n^Sn0?cX003io`400=Wo0>o/oo`0iOon003ooP02ZJT0
ljT00?ZYoP3mZ@00ljT00?^YoP3lZ@00lZT20:VYoP3hW`00ljT10:Wn0?JY003e
ZOd0mJT00?JYoP02Z@00^_ol0>GooP00ooh00[fm0?>m003j_Oh0oKd00?>m003k
_Oh0o;d00?:m0P2m_Oh0n8`00?>m0@2moP3f_@00mKgm0?Fm003f_Oh00[d00;[o
o03Uooh00?on00;Xj03cj000n^Sn0?gX003cj000nnSn0?cX003bj080j>Sn0?Ro
003cj040j?h0m^P00?GXo@3ej000m^Sn00;X003?o`3Ab?ok0?>Y003fZ@<00:T0
ljT00?NYoP01Z@3bZ@00njWn0?bO003cZ@00o:T1003iZ@00m:T3002YZOh0n:T0
0?>Y0@00UOok0?>m003f_@<00;d0lkd00?NmoP01_@3b_@00nkgn0?b<003c_@00
o;d1003i_@00m;d3002m_Oh0n;d00?>m0@00UOok0??X003fj0<00>P0lnP00?OX
oP01j03bj000nnSn0?bo003cj000o>P1003ij000m>P3003Xj?h0n>P00??X0@00
c_l0b<Go0P00ooh0mjT00?>Y0@00m:T00?>Y0@00ljT00?NYoP01W`3cZ@00nJT1
003lZ@00ljT00?^YoP3lZ@00lZT0097o0P00ooh0mkd00?>m0@00m;d00?>m0@00
lkd00?NmoP01S03c_@00nKd1003l_@00lkd00?^moP3l_@00l[d0097o0P00ooh0
mnP00??X0@00m>P00??X0@00lnP00?OXoP01_`3cj000nNP1003lj000lnP00?_X
oP3lj000l^P00<go0<G3ooh00?om0?bY003bZ@40ZOh0n:T00?:Y0`2Y003fZ@00
ljWn0?BY003gZOh00JT0ljT1003hZOh00JT0lZT008kooP00ood0o;d00?:m0@2m
oP3h_@00l[d30;d00?Jm003c_Oh0m;d00?NmoP01_@3c_@400?RmoP01_@3b_@00
S_on003oo@3lj000l^P10>Sn0?SX003bj0<0j000m^P00??XoP3dj000mnSn007X
0??X0@00n>Sn007X0?;X003<o`32`?oj00:YZ@3bZ@00o:Wn0?bY003bZ@00oJT1
003iZ@00lZT20:VYoP3hZ@00ljWn0?BY0@00mJT1003cZ@4008_onP02_Kd0l[d0
0?bmoP3l_@00l[d00?fm0@00nKd00?:m0P2m_Oh0n;d00?>moP3d_@400?Fm0@00
lkd1002;ooX00^SX0?;X003lj?h0o>P00?;X003mj0400?WX003bj080j>Sn0?SX
003cj?h0m>P1003ej0400??X0@00c?l0e;kooP03ool00?:Y003hZOh00JT0lZT0
0?ZYoP3mZ@00lZT00?^YoP3lZ@00lZT20:VYoP3hZ@80Z@3eZ@40ZOh0mZT10029
ooh00ooo003b_@00n;gn006m0?:m003j_Oh0oKd00?:m003k_Oh0o;d00?:m0P2m
_Oh0n;d20;d0mKd10;gn0?Jm0@00ROon00?oo`00l^P00?SXoP01j03bj000n^Sn
0?gX003bj000nnSn0?cX003bj080j>Sn0?SX0P3X0?GX0@3XoP3fj0400<co0<Rk
ooh00_l00?FY003dZOh0m:T00?JY0`00Z@3bZ@00mjWn006Y0?:Y003kZOh0o:T3
0:VY0?JY003lZ@400?VY0024ooh00_l00?Fm003d_Oh0m;d00?Jm0`00_@3b_@00
mkgn006m0?:m003k_Oh0o;d30;fm0?Jm003l_@400?Vm0024ooh00_l00?GX003d
j?h0m>P00?KX0`00j03bj000mnSn007X0?;X003kj?h0o>P30>SX0?KX003lj040
0?WX003:o`2l^?ol0?RY003cZ@80ZJWn0?RY003cZOh0m:T00?>Y0@00ljT00?NY
oP01Z@3nZ@00mjT00?VY0@00o:T10021oo`0n;d00?>m0P2m_Oh0n;d00?>moP3d
_@00lkd1003c_@00mkgn006m0?jm003g_@00nKd1003l_@40087oo03hj000lnP2
0>SXoP3hj000lnSn0?CX003cj0400??X003gj?h00NP0o^P00?OX003ij0400?cX
0@00b_l0`kKon`3lZ@00ljT00?^YoP3lZ@00lZT20:VYoP3hZ@00lZT10:Wn0?JY
003dZOh00ZVY0?NY003gZOh00ZT0087oo_ok0?bm003c_@00nkgn0?bm003b_@80
_Kgn0?Rm003b_@40_Oh0m[d00?BmoP02_Kd0mkd00?NmoP02_@00POonoo/0o>P0
0??X003kj?h0o>P00?;X0P3Xj?h0n>P00?;X0@3XoP3fj000m>Sn00;Xj03gj000
mnSn00;X0039o`3>a?l00?7o1`00o`00ZJT0ljT00?NYoP01Z@3bZ@00njWn0?bY
003bZ@00o:T1003iZ@00ljT20:VYoP3hZ@00ljT1002;o`00lOl7003o002m_@3c
_@00mkgn006m0?:m003k_Oh0o;d00?:m003l_@400?Vm003c_@80_Kgn0?Rm003c
_@4008_o003ao`L00?l00>SX0??X003gj?h00NP0l^P00?_XoP3lj000l^P00?cX
0@00nNP00??X0P3Xj?h0n>P00??X0@00b?l0/lGo0@00kook0?BY003cZ@400?>Y
003gZOh00JT0lZT00?VY0@00o:T00?>Y003lZOd0o:T00?:Y0@00S?l1003_oo/0
m;d00?>m0@00lkd00?NmoP01_@3b_@00nKd1003l_@00lkd00?bmo@3l_@00l[d1
002<o`400>oon`3dj000lnP1003cj000mnSn007X0?;X003ij0400?cX003cj000
o>Sm0?cX003bj0400<So0;c4o`00k?l2003ooP3hZ@00lZT30:T00?JY003cZ@40
0?:Y003gZOh00JT0ljT00?^Y003nZOh00JT0lZWn08_o003/o`800?on0?Rm003b
_@<0_@00m[d00?>m0@00l[d00?NmoP01_@3c_@00nkd00?jmoP01_@3b_Oh0Rol0
0>co0P00ooh0n>P00?;X0`3X003fj000lnP1003bj000mnSn007X0??X003kj000
o^Sn007X0?;XoP38o`2ia?l00>[ooP00ooh0o:T00?:Y003mZ@400?VY003bZ@40
ZOh0mZT00?>YoP3dZ@00njT00?^Y0@00lZT008Wo003Zooh00?on0?bm003b_@00
oKd1003i_@00l[d10;gn0?Jm003c_Oh0m;d00?^m003k_@400?:m0029o`00j_on
003ooP3lj000l^P00?gX0@00nNP00?;X0@3XoP3fj000lnSn0?CX003kj000nnP1
003bj000a_l0f/coo03no`00ioon003ooP01Z@3bZ@00nZWn0?fY003bZ@00o:T1
003iZ@00lZT20:VYoP3hZ@00nZT00?^Y0@2YoP3fZ@40097oo03no`00ioon003o
oP01_@3b_@00n[gn0?fm003b_@00o;d1003i_@00l[d20;fmoP3h_@00n[d00?^m
0@2moP3f_@40097oo03no`00ioon003ooP01j03bj000n^Sn0?gX003bj000o>P1
003ij000l^P20>SXoP3hj000n^P00?_X0@3XoP3fj0400<Ko0<S4o`00i?l5003o
o`00ljT00?JY0`00Z@3bZ@00nJT1003lZ@00lZT00?^YoP3lZ@00nJT00?^Y003m
Z@400?RY0028o`00i?l5003oo`00lkd00?Jm0`00_@3b_@00nKd1003l_@00l[d0
0?^moP3l_@00nKd00?^m003m_@400?Rm0028o`00i?l5003oo`00lnP00?KX0`00
j03bj000nNP1003lj000l^P00?_XoP3lj000nNP00?_X003mj0400?SX0035o`2`
aOon0>?ooP02o`00mZT00?>YoP3dZ@00mZWn006Y0?:Y003gZOh00JT0nJT00?^Y
003jZOh0o:T008SooP3Sooh00_l00?Jm003c_Oh0m;d00?JmoP01_@3b_@00mkgn
006m0?Vm003k_@00n[gn0?bm0028ooh0hoon00;o003fj000lnSn0?CX003fj?h0
0NP0l^P00?OXoP01j03ij000nnP00?[XoP3lj000a?l0YJ7o1000o`00nJT00?:Y
0P2YZOh0n:T00?:YoP3dZ@00ljT1003iZ@00njT00?NYoP02Z@00POoTo`@00?l0
0?Vm003b_@80_Kgn0?Rm003b_Oh0m;d00?>m0@00nKd00?^m003g_Oh00[d0087o
i?l4003o003ij000l^P20>SXoP3hj000l^Sn0?CX003cj0400?WX003kj000mnSn
00;X0034o`2OWook0?fY003bZ@00njWn0?bY003aZ@80ZJWn0?RY003bZ@40ZOh0
o:T00?bY003cZOh0POoRoo/0oKd00?:m003k_Oh0o;d00?6m0P2m_Oh0n;d00?:m
0@2moP3l_@00o;d00?>moP21on;on`3mj000l^P00?_XoP3lj000lNP20>SXoP3h
j000l^P10>Sn0?cX003lj000lnSn0<Co0:RLo`H00?l00:T0lZT00?NYoP01Z@3a
Z@00njWn0?bY003bZ@00o:T1003nZ@00oJT00?:Y0021omgo1P00o`00_@3b_@00
mkgn006m0?6m003k_Oh0o;d00?:m003l_@400?jm003m_@00l[d0087ogOl6003o
003X0?;X003gj?h00NP0lNP00?_XoP3lj000l^P00?cX0@00o^P00?gX003bj000
`_l0PI[onP3eZ@00ljT1003bZ@00mjWn006Y0?6Y003jZOd0oJT00?>Y0@00POoK
ooX0mKd00?>m0@00l[d00?NmoP01_@3a_@00n[gm0?fm003c_@40087ofooj0?GX
003cj0400?;X003gj?h00NP0lNP00?[Xo@3mj000lnP10032o`1kUook0?RY003b
Z@40ZOh0mJT00?BY0@00lZT00?JYoP01Z@3bZ@00POoGoo/0n;d00?:m0@2moP3e
_@00m;d1003b_@00m[gn006m0?:m0021omOon`3hj000l^P10>Sn0?GX003dj040
0?;X003fj?h00NP0l^P00<7o09JDo`800?on0?bY003bZ@00o:T1003hZ@00ljT1
0:Wn0?JY003eZ@@0ZJT00?>Y0021om?o0P00ooh0o;d00?:m003l_@400?Rm003c
_@40_Oh0m[d00?Fm102m_@00lkd0087odol2003ooP3lj000l^P00?cX0@00n>P0
0??X0@3XoP3fj000mNP40>SX003cj000`?l0Wi;ooP00ooh00JT0lZT00?VYoP3l
Z@00ljT00?bY0@00n:T00?FY102YZ@2YoP3gZ@40087odOon003ooP01_@3b_@00
nKgn0?bm003c_@00o;d1003h_@00mKd40;fm0;gn0?Nm0@00POoAooh00?on007X
0?;X003ij?h0o>P00??X003lj0400?SX003ej0@0j>P0j?h0mnP10030o`2OSoon
00;o003bZ@00mZWn006Y0?:Y003jZOh0o:T00?BY0P2Y0?bY0@00nJT1003go`00
POoIooh00_l00?:m003f_Oh00Kd0l[d00?ZmoP3l_@00m;d20;d0o;d1003i_@40
0?Oo0021omWooP02o`00l^P00?KXoP01j03bj000n^Sn0?cX003dj080j03lj040
0?WX0@00mol00<_o09J=ooh00?on0?JY003bZ@400?>Y003fZOh00JT0ljT20:T0
nZT1003lZ@00m_l10021omOooP00ooh0m[d00?:m0@00lkd00?JmoP01_@3c_@80
_@3j_@400?bm003fo`40087oeoon003ooP3fj000l^P1003cj000m^Sn007X0??X
0P3X0?[X0@00o>P00?Ko0@00bol0W9co0@00lOon00;o003iZ@00lJT10:Wn0?NY
003bZ@400?>Y0@00mjWn00:Y003eo`00POoVo`400?7ooP02o`00nKd00?6m0@2m
oP3g_@00l[d1003c_@400?NmoP02_@00mOl0087oi_l1003aooh00_l00?WX003a
j040j?h0mnP00?;X0@00lnP1003gj?h00^P00?Go003;o`2RWOl30?oo0>oo1000
o`00o:T00?6Y003lZ@400?VY003bZ@40ZOh0mZT00?>Y0@00m?l0087oiol30?oo
0>oo1000o`00o;d00?6m003l_@400?Vm003b_@40_Oh0m[d00?>m0@00m?l0087o
iol30?oo0>oo1000o`00o>P00?7X003lj0400?WX003bj040j?h0m^P00??X0@00
m?l00<_o0:FMo`<0ool0kOok006Y0?6Y003iZ@400?bY003bZ@00o:T1003hZ@00
ljT1003loo`0o_l0087oiol30?oo0>gon`01_@3a_@00nKd1003l_@00l[d00?bm
0@00n;d00?>m0@00o?ol0?ko0021onOo0`3oo`3]oo/00NP0lNP00?WX0@00o>P0
0?;X003lj0400?SX003cj0400?coo03no`00bol0UYgo0`3oo`3Zo`@00?l00?6Y
003gZOh00JT0lJT00?ZYoP3lZ@400?BY0@00lol0087oiol30?oo0>[o1000o`00
lKd00?NmoP01_@3a_@00n[gn0?bm0@00m;d1003co`00POoWo`<0ool0j_l4003o
003aj000mnSn007X0?7X003jj?h0o>P1003dj0400??o003;o`24WOl30?oo0>So
n`3eZ@00ljT1003bZ@00mZWn00>Y0:T0m:T1003dooh0POoXo`<0ool0j?ok0?Fm
003c_@400?:m003f_Oh00kd0_@3d_@400?CooP21onSo0`3oo`3Xoo/0mNP00??X
0@00l^P00?KXoP03j03X0?CX0@00m?on0<co07^Mo`<0ool0iOl4003o003hZ@00
lZT10:Wn0?JY003bZOd0mJT10021omOo0`3oo`3Uo`@00?l00?Rm003b_@40_Oh0
m[d00?:mo@3e_@40087oeol30?oo0>Go1000o`00n>P00?;X0@3XoP3fj000l^Sm
0?GX0@00^ol0MIco0@00h_ok0?bY003bZ@00o:T1003hZ@00lZT10:Wm0?NY0021
omGo0@00h_ok0?bm003b_@00o;d1003h_@00l[d10;gm0?Nm0021omGo0@00h_ok
0?cX003bj000o>P1003hj000l^P10>Sm0?OX002jo`1^POohoo/00JT0lZT00?VY
oP3lZ@00lZT30:VY0?jYoP3kZ@00POn`oo/00Kd0l[d00?VmoP3l_@00l[d30;fm
0?jmoP3k_@00POn`oo/00NP0l^P00?WXoP3lj000l^P30>SX0?kXoP3kj000^Ol0
J87omOol0?:Y003fZOh00JT0lZT00?jY003kZOh00jVY0021ojgoo03b_@00m[gn
006m0?:m003n_@00nkgn00>m_@00POn]oo`0l^P00?KXoP01j03bj000o^P00?_X
oP03j>P00;Wo05>1oo?on`3fZ@00lZT1003bZ@00oZT00?RYoP21oj[on`3f_@00
l[d1003b_@00o[d00?RmoP21oj[on`3fj000l^P1003bj000o^P00?SXoP2ho`1^
POo`o`H00?l00:T0njT00?6Y0@2YoP3fZ@00oJT00?NY0@00POnWo`H00?l00;d0
nkd00?6m0@2moP3f_@00oKd00?Nm0@00POnWo`H00?l00>P0nnP00?7X0@3XoP3f
j000oNP00?OX0@00^?l0Gh7ok_ol0?bY003aZ@00o:T1003iZ@00o:T00?NY0021
ojCoo03l_@00lKd00?bm0@00nKd00?bm003g_@00POnToo`0o>P00?7X003lj040
0?WX003lj000mnP00;Oo05b1on_oo001Z@3aZ@00nJT1003lZ@00njT00?RY0021
oj3oo001_@3a_@00nKd1003l_@00nkd00?Rm0021oj3oo001j03aj000nNP1003l
j000nnP00?SX002fo`1=POoYoo`0lJT00?NYoP01Z@3jZ@00nJT0087oWOol0?6m
003g_Oh00Kd0n[d00?Vm0021oigoo03aj000mnSn007X0?[X003ij000]Ol0Ah7o
i_ol0?FY003cZ@400?ZY003iZ@00POnJoo`0mKd00?>m0@00n[d00?Vm0021oi[o
o03ej000lnP1003jj000nNP00;Go04f1on?oo@3hZ@00lZT10:Wn0?fY003jZ@00
POnFood0n;d00?:m0@2moP3m_@00n[d0087oU_om0?SX003bj040j?h0oNP00?[X
002do`1LPOo`o`00lool0?bY003bZ@00o:Wn006Y0?^Y0@00POnSo`00lool0?bm
003b_@00o;gn006m0?^m0@00POnSo`00lool0?cX003bj000o>Sn007X0?_X0@00
]?l0D87olOl1003`oo`00JT0lJT00?VYoP3lZ@00POnSo`400?3oo001_@3a_@00
nKgn0?bm0021oj?o0@00l?ol007X0?7X003ij?h0o>P00;?o04Z1oo3o003^oo`0
lZT00?NY0@2YoP01Z@21oj7o003^oo`0l[d00?Nm0@2moP01_@21oj7o003^oo`0
l^P00?OX0@3XoP01j02bo`17POo`o`00jool0?JY003fZ@00oJT10021oj7o003[
oo`0m[d00?Jm003m_@40087oXOl00>_oo03fj000m^P00?gX0@00/_l0A87ol?l0
0>Soo@3hZ@00mZT00?fY0021oj3o003Xood0n;d00?Jm003m_@00POnPo`00j?om
0?SX003fj000oNP00;7o04B1oo3o003Voo`0o:T00?JY003mZ@00POnOo`00i_ol
0?bm003f_@00oKd0087oWol00>Koo03lj000m^P00?gX002`o`11POoaooh0i?ol
006Y0?FY003nZ@00POnOooh0i?ol006m0?Fm003n_@00POnOooh0i?ol007X0?GX
003nj000[ol0<h7ocool0?FY003nZ@40087oPOonoo`0mKd00?jm0@00POn1ooko
o03ej000o^P1002`o`0]POo<oo`0n:T30:VY087oPOoioo`0n;d30;fm087oPOoi
oo`0n>P30>SX0:ko02Z1ol[oo03jZ@80Z@21oh7om_ol0?Zm0P2m087oPOofoo`0
n^P20>P0[Ol0987oaool0?fYoP21oh7olool0?fmoP21oh7olool0?gXoP2]o`0T
POo4oo`00ZT0087oPOo_oo`00[d0087oPOo_oo`00^P00:co01R1ol;on`21oh7o
kOok087oPOo]oo/0[?l06h7o_ol10021oh7ojOl10021oh7ojOl1002[o`0HPOnd
ooh0POn1on[ooP21oh7oj_on0;Oo02B1okGo003no`00POn1onco003no`00POn1
onco003no`00^?l0987o]Ol00?ko0021oh7ok?l00?ko0021oh7ok?l00?ko002h
o`0HPOnbo`00POn1onSo0021oh7oj?l00;Oo0321olCooP3koo`0o_l0087oPOoi
ooh0nool0?ko0021oh7onOon0?_oo03no`00]_l0>H7oaOl00?ko003eo`<0ool0
POn1ooco003no`00mOl30?oo087oPOolo`00o_l00?Go0`3oo`2ho`0`POo5o`00
o_l00?Koo021oh7oo?l00?ko003foo`0POn1ooco003no`00m_ol0;So01R1ol;o
0021oh7oj?l0087oPOoXo`00Yol0687o`ol0087oPOoXo`00POn1onSo002Vo`0Q
POo4o`<0ool0POn1on_o0`3oo`21oh7ojol30?oo0:So01R1olGoo021oh7ok?ol
087oPOo/oo`0Z?l03X7oPOn1oh7oPOn1ok?o00j1oh7oPOn1oh7oPOnco`0>POn1
oh7oPOn1oh7o/ol03X7oPOn1oh7oPOn1ok?o00j1oh7oPOn1oh7oPOnco`00o`\>"], "Graphics",
  ImageSize->{282, 231},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SurfaceGraphics[\"<<>>\"]\
\>", \
"\<\
-SurfaceGraphics-\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["NIntegrate[EpanechnikovM[{x,y}],{x,-1,1},{y,-1,1}]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
NIntegrate::slwcon: Numerical integration converging too slowly; \
suspect one of the following: singularity, oscillatory integrand,
  or insufficient WorkingPrecision.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
NIntegrate::slwcon: Numerical integration converging too slowly; \
suspect one of the following: singularity, oscillatory integrand,
  or insufficient WorkingPrecision.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
NIntegrate::slwcon: Numerical integration converging too slowly; \
suspect one of the following: singularity, oscillatory integrand,
  or insufficient WorkingPrecision.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
General::stop: Further output of NIntegrate::slwcon will be \
suppressed during this calculation.\
\>", "Message",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0.999998279339306\
\>", "\<\
0.999998\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnitSphere[2]", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
Pi\
\>", "\<\
Pi\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{39, 1440}, {0, 878}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{653, 681},
WindowMargins->{{Automatic, 28}, {Automatic, 7}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3373627869-2632070"->{
    Cell[8585, 307, 126, 2, 22, "Print",
      CellTags->"Info3373627869-2632070"],
    Cell[8714, 311, 3233, 65, 556, "Print",
      CellTags->"Info3373627869-2632070"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3373627869-2632070", 176078, 3165}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 36, "Subsection"],
Cell[1839, 56, 6504, 235, 3246, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[8380, 296, 60, 1, 36, "Subsection"],
Cell[8443, 299, 52, 1, 26, "Input"],

Cell[CellGroupData[{
Cell[8520, 304, 62, 1, 26, "Input"],
Cell[8585, 307, 126, 2, 22, "Print",
  CellTags->"Info3373627869-2632070"],
Cell[8714, 311, 3233, 65, 556, "Print",
  CellTags->"Info3373627869-2632070"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11984, 381, 101, 4, 40, "Input"],
Cell[12088, 387, 186, 8, 36, "Output"],
Cell[12277, 397, 238, 10, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12552, 412, 67, 1, 27, "Input"],
Cell[12622, 415, 94, 5, 24, "Output"]
}, Open  ]],
Cell[12731, 423, 71, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[12827, 428, 69, 1, 27, "Input"],
Cell[12899, 431, 206, 10, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13142, 446, 184, 7, 27, "Input"],
Cell[13329, 455, 291, 10, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13657, 470, 93, 1, 27, "Input"],
Cell[13753, 473, 387, 11, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14177, 489, 109, 1, 27, "Input"],
Cell[14289, 492, 361, 11, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14687, 508, 113, 5, 57, "Input"],
Cell[14803, 515, 210, 8, 41, "Output"],
Cell[15016, 525, 295, 11, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15348, 541, 95, 1, 27, "Input"],
Cell[15446, 544, 12681, 196, 124, 12563, 193, "GraphicsData", "PICT", \
"Graphics"],
Cell[28130, 742, 118, 6, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28285, 753, 97, 1, 27, "Input"],
Cell[28385, 756, 789, 17, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29211, 778, 69, 1, 27, "Input"],
Cell[29283, 781, 228, 10, 57, "Output"]
}, Open  ]],
Cell[29526, 794, 65, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[29616, 799, 193, 5, 57, "Input"],
Cell[29812, 806, 245, 8, 24, "Output"],
Cell[30060, 816, 45219, 697, 191, 45101, 694, "GraphicsData", "PICT", \
"Graphics"],
Cell[75282, 1515, 181, 7, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75500, 1527, 83, 1, 27, "Input"],
Cell[75586, 1530, 113, 5, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75736, 1540, 187, 5, 57, "Input"],
Cell[75926, 1547, 241, 8, 24, "Output"],
Cell[76170, 1557, 48748, 751, 210, 48630, 748, "GraphicsData", "PICT", \
"Graphics"],
Cell[124921, 2310, 199, 8, 24, "Output"]
}, Open  ]],
Cell[125135, 2321, 51, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[125211, 2326, 101, 1, 27, "Input"],
Cell[125315, 2329, 48393, 745, 239, 48275, 742, "GraphicsData", "PICT", \
"Graphics"],
Cell[173711, 3076, 132, 6, 24, "Output"]
}, Open  ]],
Cell[173858, 3085, 51, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[173934, 3090, 101, 1, 27, "Input"],
Cell[174038, 3093, 229, 5, 47, "Message"],
Cell[174270, 3100, 229, 5, 47, "Message"],
Cell[174502, 3107, 229, 5, 47, "Message"],
Cell[174734, 3114, 158, 4, 34, "Message"],
Cell[174895, 3120, 113, 5, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175045, 3130, 64, 1, 27, "Input"],
Cell[175112, 3133, 92, 5, 24, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

