(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    138604,       4036]
NotebookOptionsPosition[    132444,       3839]
NotebookOutlinePosition[    133007,       3862]
CellTagsIndexPosition[    132964,       3859]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["SDE  \nStochastic \nDifferential \nEquations\n\n", "Title",
  FontColor->RGBColor[1, 0, 0]],
 "\nNonlinear Filtering and \nMaximum Likelihood Parameter Estimation of  \n\
Stochastic Differential Equations  \nwith Panel Data"
}], "Section",
 PageWidth->Infinity,
 CellChangeTimes->{{3.428225524136314*^9, 3.428225542024953*^9}, 
   3.428225747170417*^9},
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 PageWidth->Infinity],

Cell[TextData[{
 "In 1991, LSDE (Linear Stochastic Differential Equations; Singer, 1991)  \n\
was released as an SAS/IML program for  the  \nsimulation, optimal filtering \
and maximum likelihood estimation  \nof dynamic panel models.\n\nThis package \
implemented the linear continuous -discrete state space model \nwith constant \
parameter matrices and uniform sampling intervals \n(Singer, 1991, 1993; \
Hamerle, Nagl and Singer, 1991).\n\nLater, a missing data treatment was added \
to allow the estimation\nof irregularly spaced data (Singer, 1995).\n\nSince \
at that time I was dissatisfied with IML,  mainly because of the\n 2 \
-dimensional  data structures (matrices), I ported the code to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".\n\nThe modules for the linear systems are similar to the older SAS/IML \
code.\nThe data matrices (3-D tensors) have dimensions Y: (T+1) x p x N.\n \n\
Later I developed nonlinear filters (EKF, SNF, UKF, GHF, Hermite filters, \n\
Monte Carlo filters etc.), which were firstly designed for time series data \
with\ndata structure Y: (T+1) x p.\n\nApplication to a ",
 StyleBox["cross section of  N time series",
  FontColor->RGBColor[0, 0, 1]],
 " leads to the data structure\nY: N  x  (T+1) x p. \n\nIn ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", one can also form the list Y = {y1,y2,...,yN}, where each yn \ncan have \
dimensions  (Tn+1) x p. Thus, the time series of ",
 StyleBox["each panel unit n may \nhave different sample size Tn+1",
  FontColor->RGBColor[0, 0, 1]],
 " (cf. Singer, 2006e).\n\nThe different modules are explained in example \
notebooks ( /SDE/applications/)\n",
 StyleBox["and the statistical background is described in the articles  ( \
/SDE/papers/).\n\nThe modules are explained in the \[FilledSquare] reference \
section.", "NumberedTable"]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{19, Inherited}, {Inherited, Inherited}},
 TextAlignment->Left,
 TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["State Space Models", "Subsection",
 PageWidth->Infinity],

Cell[TextData[{
 "For details I refer to the ",
 StyleBox["articles  in the folder  /SDE/papers and the literature\n cited \
therein.\n",
  FontColor->RGBColor[1, 0, 0]],
 "The formulae in the sequel are ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"L", 
    StyleBox[
     AdjustmentBox["A",
      BoxBaselineShift->-0.2,
      BoxMargins->{{-0.36, -0.1}, {0, 0}}],
     FontSize->Smaller], "T", 
    AdjustmentBox["E",
     BoxBaselineShift->0.5,
     BoxMargins->{{-0.075, -0.085}, {0, 0}}], "X"}]]]],
 " pseudo code (omitting $, & etc.)\n\nThe",
 StyleBox[" ", "Outline2"],
 StyleBox["linear continuous-discrete state space model", "Outline3",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ", "Outline4",
  FontColor->RGBColor[0, 0, 1]],
 "(Jazwinski, 1970) is\n\n",
 StyleBox["dy_n(t) = A y_n(t) dt + B x_n(t) dt + G dw_n(t)              \
(system model)", "NumberedEquation"],
 "\n\nz_n(t_i) = H y_n(t_i) + D x_n(t_i) + \\epsilon_{ni}         \
(measurement model)\n\nwhere   \\epsilon_{ni}  \\sim  N(0,R) iid. is a \
discrete time white noise\nand  dw_n(t) /dt is a  ",
 StyleBox["continuous time white noise process",
  FontColor->RGBColor[0, 0, 1]],
 ".\n\nThe system model can be written as a system of vector time series\n at \
the times of measurement {t_0,t_1,...t_T}\n  (",
 StyleBox["exact discrete model",
  FontColor->RGBColor[0, 0, 1]],
 ")\n  \ny_{n,i+1} = A*_i y_{ni}  + B*_i x_{ni} + u_{ni}          (system \
model)\n\nz_{ni} = H_i y_{ni} + D_i x_{ni} + \\epsilon_{ni}       \
(measurement model)\n\nwith random  initial condition \n\n y_{n0}   \\sim \
N(\\mu,\\Sigma), i.i.d.\n \n and the nonlinear parameter matrices \n \n  A*_i \
&=& \\exp [A(t_{i+1}-t_i)]:=\\exp (A \\Deltat_i) \n  \n  B*_i &=& \
A^{-1}(\\exp (A \\Deltat_i)-I) B \n  \n  \\Omega*_i &=& \
\\int_{0}^{\\Deltat_i} \\exp (A s) G G' \\exp (A's)ds. \n  \n\n\n\nThe",
 StyleBox[" nonlinear continuous-discrete state space model",
  FontColor->RGBColor[0, 0, 1]],
 " (Jazwinski, 1970) reads\n\ndy_n(t) = f(y_n(t),x_n(t) ,t) dt  + \
g(y_n(t),x_n(t) ,t) dw_n(t)             (system model)\n\nz_n(t_i) = \
h(y_n(t_i),x_n(t_i) ,t)  + \\epsilon_{ni}                             \
(measurement model)\n\n\nIt cannot be solved explicitly, except in the linear \
case."
}], "Text",
 PageWidth->Infinity,
 CellChangeTimes->{3.4282255490478487`*^9},
 TextAlignment->Left,
 TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filtering", "Subsection",
 PageWidth->Infinity],

Cell[TextData[{
 "\nThe key tool for the estimation of the unknown parameters \[Psi] in f, g, \
h and R\nis the ",
 StyleBox["Kalman filter algorithm",
  FontColor->RGBColor[0, 0, 1]],
 ", which computes \n\n1. recursive  estimates of the states y(t)\n2. the \
likelihood function of \[Psi], i.e. p(\[Psi]; z_0,...z_T), the probability \
density of the \n    data z as function of \[Psi].\n\nIn SDE, the approximate \
nonlinear filters\n\n\[RightPointer] EKF (extended Kalman filter)\n\
\[RightPointer] SNF (second order nonlinear filter) \n\[RightPointer] HNF \
(higher order nonlinear filter; HNF(K,L)) \n\[RightPointer] UKF (unscented \
Kalman filter)\n\[RightPointer] GHF (Gauss-Hermite filter)\n\[RightPointer] \
GSF (Gaussian sum  filters; using EKF, UKF and GHF updates)\n\[RightPointer] \
FIF (Functional integral filter; simulation of Ito sample paths)\n\nare \
implemented.\n\nGeneralized Gauss-Hermite filters (using Hermite expansions \
of the filter density)\nmay be released later.\n\nAll filters can be used to \
compute the likelihood function  of  the data.\nThe maximum of  p(\[Psi]; \
z_0,...z_T) is computed by using a quasi Newton algorithm with\nnumerical \
score and secant updates for the model Hessian. \n\nThe modules for the \
linear system allow the computation of analytical score functions\nand Fisher \
information matrices (Singer, 1993, 1995).\n\n\n"
}], "Text",
 PageWidth->Infinity,
 CellChangeTimes->{{3.4282255724171057`*^9, 3.428225574186521*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Structures and File Input", "Subsection",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell["Linear Models", "Subsubsection",
 PageWidth->Infinity],

Cell["\<\

The older code ported from LSDE (old layer) used a data structure (tensor, \
nested list)
 with dimensions {T1,p,n}\
\>", "Text",
 PageWidth->Infinity,
 CellChangeTimes->{3.428225578515697*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "y", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"T1", ",", "p", ",", "n"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3", ",", "5"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Y", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"y", ",", 
     RowBox[{"{", 
      RowBox[{"T1", ",", "p", ",", "n"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Y", "//", "Dimensions"}], "\n", 
 RowBox[{"TableForm", "[", 
  RowBox[{"Y", ",", 
   RowBox[{"TableDirections", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Column", ",", "Column", ",", "Row"}], "}"}]}], ",", 
   "\[IndentingNewLine]", "                              ", 
   RowBox[{"TableAlignments", "\[Rule]", "Automatic"}], ",", 
   "\[IndentingNewLine]", "                              ", 
   RowBox[{"TableHeadings", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
   "                              ", 
   RowBox[{"TableSpacing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"6", ",", "2", ",", "4"}], "}"}]}]}], "]"}]}], "Input",
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 CellSize->{444, Inherited},
 CellLabel->"In[466]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "3", ",", "5"}], "}"}]], "Output",
 CellChangeTimes->{
  3.428225774332952*^9, {3.428225827950234*^9, 3.4282258325669727`*^9}},
 CellLabel->"Out[469]="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {GridBox[{
        {
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "1", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "1", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "1", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "2", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "2", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "2", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "3", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "3", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "3", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"1", ",", "3", ",", "5"}], "]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[2.8]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.8]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]},
     {GridBox[{
        {
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "1", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "1", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "1", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "1", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "1", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "2", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "2", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "2", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "2", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "2", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "3", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "3", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "3", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "3", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"2", ",", "3", ",", "5"}], "]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[2.8]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.8]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]},
     {GridBox[{
        {
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "1", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "1", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "1", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "1", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "1", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "2", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "2", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "2", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "2", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "2", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "3", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "3", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "3", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "3", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"3", ",", "3", ",", "5"}], "]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[2.8]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.8]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]},
     {GridBox[{
        {
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "1", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "1", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "1", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "1", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "2", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "2", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "2", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "2", ",", "5"}], "]"}]},
        {
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "3", ",", "1"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "3", ",", "3"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "3", ",", "4"}], "]"}], 
         RowBox[{"y", "[", 
          RowBox[{"4", ",", "3", ",", "5"}], "]"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[2.8]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.8]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[2.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, TableDirections -> {Column, Column, Row}, TableAlignments -> 
    Automatic, TableHeadings -> None, TableSpacing -> {6, 2, 4}]]]], "Output",\

 CellChangeTimes->{
  3.428225774332952*^9, {3.428225827950234*^9, 3.428225832576296*^9}},
 CellLabel->"Out[470]//TableForm="]
}, Open  ]],

Cell["\<\
where T1=T+1 is the number of time points t_0,...,t_T. 
Thus, for each time point t,  Y[[t]] is a (p x n) matrix, e.g..\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Y", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y", "[", 
   RowBox[{"[", "4", "]"}], "]"}], "//", "MatrixForm"}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1479]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4", "5"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "4"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "5"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "4"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "5"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "4"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "5"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1479]//MatrixForm="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4", "5"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "4"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "5"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "4"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "5"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "4"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "5"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1480]//MatrixForm="]
}, Open  ]],

Cell["\<\
The vector time series y2:  T1 x p for unit n=2 is obtained as\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"y2", "=", 
    RowBox[{"Y", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"   ", 
  RowBox[{"y2", "//", "Dimensions"}]}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1481]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}]},
      {"4", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1481]//MatrixForm="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[1482]="]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["measurements", "Input",
  FontColor->RGBColor[0, 0, 1]],
 " are called \nZ: T1 x k x n, \n\nthe latent states are \nY: T1 x p x n \n\n\
and the exgenous variables are \n\nX: T1 x q x n.\n\nThe state space model is\
\n\ndy_n(t) = A y_n(t) dt + B x_n(t) dt + G dw_n(t)               (system \
model)\n\nz_n(t_i) = H y_n(t_i) + D x_n(t_i) + \\epsilon_{ni}         \
(measurement model)\n\nThe masurements z_n(t_i):= z_{ni}: k x 1 are collected \
in the tensor Z: T1 x k x n with  a \ndimension k (k = number of measured \
variables):"
}], "Text",
 PageWidth->Infinity,
 TextAlignment->Left,
 TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "z", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"T1", ",", "k", ",", "n"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{"T1", ",", "1", ",", "n"}], "}"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"z", ",", 
     RowBox[{"{", 
      RowBox[{"T1", ",", "k", ",", "n"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Z", "//", "Dimensions"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", 
  RowBox[{"Z", ",", 
   RowBox[{"TableDirections", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Column", ",", "Column", ",", "Row"}], "}"}]}], ",", 
   "\[IndentingNewLine]", "                               ", 
   RowBox[{"TableAlignments", "\[Rule]", "Left"}], ",", "\[IndentingNewLine]",
    "                               ", 
   RowBox[{"TableHeadings", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
   "                               ", 
   RowBox[{"TableSpacing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"6", ",", "2", ",", "4"}], "}"}]}]}], "]"}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
 CellSize->{444, Inherited},
 CellLabel->"In[1483]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "1", ",", "5"}], "}"}]], "Output",
 CellLabel->"Out[1486]="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {GridBox[{
          {GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"1", ",", "1", ",", "1"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"1", ",", "1", ",", "2"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"1", ",", "1", ",", "3"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"1", ",", "1", ",", "4"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"1", ",", "1", ",", "5"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.8]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.8]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {GridBox[{
       {GridBox[{
          {GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"2", ",", "1", ",", "1"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"2", ",", "1", ",", "2"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"2", ",", "1", ",", "3"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"2", ",", "1", ",", "4"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"2", ",", "1", ",", "5"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.8]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.8]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {GridBox[{
       {GridBox[{
          {GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"3", ",", "1", ",", "1"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"3", ",", "1", ",", "2"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"3", ",", "1", ",", "3"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"3", ",", "1", ",", "4"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"3", ",", "1", ",", "5"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.8]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.8]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {GridBox[{
       {GridBox[{
          {GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"4", ",", "1", ",", "1"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"4", ",", "1", ",", "2"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"4", ",", "1", ",", "3"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"4", ",", "1", ",", "4"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
             {
              RowBox[{"z", "[", 
               RowBox[{"4", ",", "1", ",", "5"}], "]"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
              "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.8]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.8]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[2.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{{
      z[1, 1, 1], 
      z[1, 1, 2], 
      z[1, 1, 3], 
      z[1, 1, 4], 
      z[1, 1, 5]}}, {{
      z[2, 1, 1], 
      z[2, 1, 2], 
      z[2, 1, 3], 
      z[2, 1, 4], 
      z[2, 1, 5]}}, {{
      z[3, 1, 1], 
      z[3, 1, 2], 
      z[3, 1, 3], 
      z[3, 1, 4], 
      z[3, 1, 5]}}, {{
      z[4, 1, 1], 
      z[4, 1, 2], 
      z[4, 1, 3], 
      z[4, 1, 4], 
      z[4, 1, 5]}}}, TableDirections -> {Column, Column, Row}, 
   TableAlignments -> Left, TableHeadings -> None, 
   TableSpacing -> {6, 2, 4}]]], "Output",
 CellLabel->"Out[1487]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonlinear Models", "Subsubsection",
 PageWidth->Infinity],

Cell["\<\
The nonlinear modules use a different data structure, 
which is obtained from a collection of  time series 

Y = {y1,...,yN}: N x T1 x p, 

where yn = {yn0,...,ynT}: T1 x p. Thus

 yn=Y[[n]]: T1 x p
 
is a vector time series of the nth panel unit. 
The nonlinear modules usually work on time series and the panel structure
is an N-fold replication of individual time series analysis
 (but with cross restrictions between panel units).

The transformation of the old and new matrices is a simple transposition:

{T1, p, N} \[RightArrow] {N, T1, p} 
{  2, 3, 1}.

Thus we use the permutation {2,3,1}, i.e. T1 goes to dim 2, p goes to dim 3 \
and N goes to dim 1:\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Ynew", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Y", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], 
  "  "}], "\[IndentingNewLine]", 
 RowBox[{"Ynew", "//", "Dimensions"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"n", ",", "T1", ",", "p"}], "}"}], "\[IndentingNewLine]"}], "Input",\

 PageWidth->Infinity,
 CellLabel->"In[1488]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "1"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "1"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "4"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "4"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "4"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "4"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "5"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "5"}], "]"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellLabel->"Out[1488]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "4", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[1489]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "4", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[1490]="]
}, Open  ]],

Cell["\<\
Indeed, the  dimensions of the new data matrix are {N,T1,p}= {5,4,3}.

The reverse operation is {N,T1,p}->{T1,p,N}:\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Yold", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Ynew", ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}]}], 
  "  "}], "\[IndentingNewLine]", 
 RowBox[{"Yold", "//", "Dimensions"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"T1", ",", "p", ",", " ", "n"}], 
  "}"}], "\[IndentingNewLine]"}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1494]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "5"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "5"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "5"}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "5"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "4"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "5"}], "]"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellLabel->"Out[1494]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "3", ",", "5"}], "}"}]], "Output",
 CellLabel->"Out[1495]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "3", ",", "5"}], "}"}]], "Output",
 CellLabel->"Out[1496]="]
}, Open  ]],

Cell["\<\
The main advantage of the 3-dimensional list (tensor) structure is the simple
picking of subtensors, e.g the data of unit nn=3 at time tt=2:\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nn", "=", "3"}], ";", 
  RowBox[{"tt", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Yold", "[", 
  RowBox[{"[", 
   RowBox[{"tt", ",", "All", ",", "nn"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Ynew", "[", 
  RowBox[{"[", 
   RowBox[{"nn", ",", "tt", ",", "All"}], "]"}], "]"}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1497]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"2", ",", "1", ",", "3"}], "]"}], ",", 
   RowBox[{"y", "[", 
    RowBox[{"2", ",", "2", ",", "3"}], "]"}], ",", 
   RowBox[{"y", "[", 
    RowBox[{"2", ",", "3", ",", "3"}], "]"}]}], "}"}]], "Output",
 CellLabel->"Out[1498]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"2", ",", "1", ",", "3"}], "]"}], ",", 
   RowBox[{"y", "[", 
    RowBox[{"2", ",", "2", ",", "3"}], "]"}], ",", 
   RowBox[{"y", "[", 
    RowBox[{"2", ",", "3", ",", "3"}], "]"}]}], "}"}]], "Output",
 CellLabel->"Out[1499]="]
}, Open  ]],

Cell["or the data for panel units {1,3} at time 1", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nn", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}]}], ";", 
  RowBox[{"tt", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Yold", "[", 
   RowBox[{"[", 
    RowBox[{"tt", ",", "All", ",", "nn"}], "]"}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ynew", "[", 
   RowBox[{"[", 
    RowBox[{"nn", ",", "tt", ",", "All"}], "]"}], "]"}], "//", 
  "MatrixForm"}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1500]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1501]//MatrixForm="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1502]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2-Dimensional Data and File Input of  Data Sets", "Subsubsection",
 PageWidth->Infinity],

Cell["\<\
Usually, data are 2-dimensional data structures, where the dimensions are
layed out as rows and columns. For example, the tensor  indices 
{n,t,p}, n=1,...,N; t=0,...T; p=1,...P
may be distributed as  N rows and T*P columns\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "y", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"T1", ",", "P", ",", "n"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{"4", ",", "3", ",", "5"}], "}"}]}], ";"}], " ", 
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "write", " ", "n", " ", "since", " ", "N", " ", "is", " ", "protected"}], 
    " ", "*)"}],
   FontColor->RGBColor[1, 0, 0]]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Y1", "=", 
    RowBox[{"Array", "[", 
     RowBox[{"y", ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "T1", ",", "P"}], "}"}]}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"flatten", "[", 
     RowBox[{"Y1", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "//", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{"Flatten", ",", "Y1"}], "]"}], "//", "MatrixForm"}], "*)"}]}], 
  RowBox[{"(*", 
   RowBox[{"the", " ", "same"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flatten", "[", 
   RowBox[{"Y1", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "//", "Dimensions"}]}], "Input",\

 PageWidth->Infinity,
 CellLabel->"In[1503]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4", "5", "6", "7", "8", 
       "9", "10", "11", "12"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "3"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "3"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "3"}], "]"}]},
      {"4", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "3"}], "]"}]},
      {"5", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "3"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1506]//MatrixForm="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "12"}], "}"}]], "Output",
 CellLabel->"Out[1507]="]
}, Open  ]],

Cell[TextData[{
 "Thus, the panel units n=1,..,5  are the rows, \nand  each row n is the \
vector y[[n,t,p]], t=1,...,4;  p= 1,...3.\nNote that the index p runs faster \
than the index t. \nSuch data set may be obtained by joining the data sets\n\
Yt: N x P for the several time points t, i.e. [Y0|Y1|...|YT].\nThis would be \
a natural structure from a cross sectional point of view,\ni.e. in each row \
we have the variables of statistical unit n as column entries.\n\nIn ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notation this reads\n"
}], "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"<<", 
   StyleBox[
    RowBox[{"LinearAlgebra", 
     StyleBox["`", "MB"], "MatrixManipulation", 
     StyleBox["`", "MB"]}]]}], 
  StyleBox["\[IndentingNewLine]", "MB"]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendRows", "[", 
   RowBox[{
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "All"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3", ",", "All"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "4", ",", "All"}], "]"}], "]"}]}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendRows", "[", 
   RowBox[{
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2", ",", "All"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3", ",", "All"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "4", ",", "All"}], "]"}], "]"}]}], "]"}], "//", 
  "Dimensions"}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1508]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4", "5", "6", "7", "8", 
       "9", "10", "11", "12"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "3"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "3"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "3"}], "]"}]},
      {"4", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "3"}], "]"}]},
      {"5", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "3"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1509]//MatrixForm="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "12"}], "}"}]], "Output",
 CellLabel->"Out[1510]="]
}, Open  ]],

Cell["\<\
Alternatively, one may  have the panel data for each variable p seperately, \
i.e. Y1[[All,All,p]]: N x T1.
From this the data set   [Y1|Y1|...|YP] may be obtained.\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AppendRows", "[", 
   RowBox[{
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}]}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendRows", "[", 
   RowBox[{
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"Y1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}]}], "]"}], "//", 
  "Dimensions"}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1511]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4", "5", "6", "7", "8", 
       "9", "10", "11", "12"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "3"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "3"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "3"}], "]"}]},
      {"4", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "3"}], "]"}]},
      {"5", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "3"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "3"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1511]//MatrixForm="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "12"}], "}"}]], "Output",
 CellLabel->"Out[1512]="]
}, Open  ]],

Cell["\<\
Here, the index t runs faster.

It happens very often, that N vector time series Yn: T1 x p are joined \
together underneath, i.e
[Y1|Y2|...|YN]' : N*T1 x p\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Y2", "=", 
    RowBox[{"AppendColumns", "[", 
     RowBox[{
      RowBox[{"Y1", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
      RowBox[{"Y1", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
      RowBox[{"Y1", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
      RowBox[{"Y1", "[", 
       RowBox[{"[", 
        RowBox[{"4", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
      RowBox[{"Y1", "[", 
       RowBox[{"[", 
        RowBox[{"5", ",", "All", ",", "All"}], "]"}], "]"}]}], "]"}]}], ")"}],
   "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"  ", 
  RowBox[{"Y2", "//", "Dimensions"}]}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1513]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3"},
      {"1", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "1", ",", "3"}], "]"}]},
      {"2", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}]},
      {"3", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "3", ",", "3"}], "]"}]},
      {"4", 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"1", ",", "4", ",", "3"}], "]"}]},
      {"5", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "1", ",", "3"}], "]"}]},
      {"6", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "2", ",", "3"}], "]"}]},
      {"7", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "3", ",", "3"}], "]"}]},
      {"8", 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"2", ",", "4", ",", "3"}], "]"}]},
      {"9", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "1", ",", "3"}], "]"}]},
      {"10", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "2", ",", "3"}], "]"}]},
      {"11", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "3", ",", "3"}], "]"}]},
      {"12", 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"3", ",", "4", ",", "3"}], "]"}]},
      {"13", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "1", ",", "3"}], "]"}]},
      {"14", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "2", ",", "3"}], "]"}]},
      {"15", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "3", ",", "3"}], "]"}]},
      {"16", 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"4", ",", "4", ",", "3"}], "]"}]},
      {"17", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "1", ",", "3"}], "]"}]},
      {"18", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "2", ",", "3"}], "]"}]},
      {"19", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "3", ",", "3"}], "]"}]},
      {"20", 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "1"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "2"}], "]"}], 
       RowBox[{"y", "[", 
        RowBox[{"5", ",", "4", ",", "3"}], "]"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1513]//MatrixForm="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[1514]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Y2", "//", "InputForm"}]], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1520]:="],

Cell["\<\
{{y[1, 1, 1], y[1, 1, 2], y[1, 1, 3]}, {y[1, 2, 1], y[1, 2, 2], y[1, 2, 3]}, 
 {y[1, 3, 1], y[1, 3, 2], y[1, 3, 3]}, {y[1, 4, 1], y[1, 4, 2], y[1, 4, 3]}, 
 {y[2, 1, 1], y[2, 1, 2], y[2, 1, 3]}, {y[2, 2, 1], y[2, 2, 2], y[2, 2, 3]}, 
 {y[2, 3, 1], y[2, 3, 2], y[2, 3, 3]}, {y[2, 4, 1], y[2, 4, 2], y[2, 4, 3]}, 
 {y[3, 1, 1], y[3, 1, 2], y[3, 1, 3]}, {y[3, 2, 1], y[3, 2, 2], y[3, 2, 3]}, 
 {y[3, 3, 1], y[3, 3, 2], y[3, 3, 3]}, {y[3, 4, 1], y[3, 4, 2], y[3, 4, 3]}, 
 {y[4, 1, 1], y[4, 1, 2], y[4, 1, 3]}, {y[4, 2, 1], y[4, 2, 2], y[4, 2, 3]}, 
 {y[4, 3, 1], y[4, 3, 2], y[4, 3, 3]}, {y[4, 4, 1], y[4, 4, 2], y[4, 4, 3]}, 
 {y[5, 1, 1], y[5, 1, 2], y[5, 1, 3]}, {y[5, 2, 1], y[5, 2, 2], y[5, 2, 3]}, 
 {y[5, 3, 1], y[5, 3, 2], y[5, 3, 3]}, {y[5, 4, 1], y[5, 4, 2], y[5, 4, 3]}}\
\>", "Output",
 PageWidth->Infinity,
 CellLabel->"Out[1520]//InputForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</SDE/data/\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SetOptions", "[", 
  RowBox[{"TableForm", ",", 
   RowBox[{"TableDirections", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Column", ",", "Row"}], "}"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", "None"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<dataset\>\"", ",", "Y2", ",", "\"\<CSV\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"!!", "\"\<dataset\>\""}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1516]:="],

Cell[BoxData["\<\"/SDE/data\"\>"], "Output",
 CellLabel->"Out[1516]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TableAlignments", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TableDepth", "\[Rule]", "\[Infinity]"}], ",", 
   RowBox[{"TableDirections", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Column", ",", "Row"}], "}"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", "None"}], ",", 
   RowBox[{"TableSpacing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "1"}], "}"}]}]}], "}"}]], "Output",
 CellLabel->"Out[1517]="],

Cell[BoxData["\<\"dataset\"\>"], "Output",
 CellLabel->"Out[1518]="],

Cell["\<\
\"y[1, 1, 1]\",\"y[1, 1, 2]\",\"y[1, 1, 3]\"
\"y[1, 2, 1]\",\"y[1, 2, 2]\",\"y[1, 2, 3]\"
\"y[1, 3, 1]\",\"y[1, 3, 2]\",\"y[1, 3, 3]\"
\"y[1, 4, 1]\",\"y[1, 4, 2]\",\"y[1, 4, 3]\"
\"y[2, 1, 1]\",\"y[2, 1, 2]\",\"y[2, 1, 3]\"
\"y[2, 2, 1]\",\"y[2, 2, 2]\",\"y[2, 2, 3]\"
\"y[2, 3, 1]\",\"y[2, 3, 2]\",\"y[2, 3, 3]\"
\"y[2, 4, 1]\",\"y[2, 4, 2]\",\"y[2, 4, 3]\"
\"y[3, 1, 1]\",\"y[3, 1, 2]\",\"y[3, 1, 3]\"
\"y[3, 2, 1]\",\"y[3, 2, 2]\",\"y[3, 2, 3]\"
\"y[3, 3, 1]\",\"y[3, 3, 2]\",\"y[3, 3, 3]\"
\"y[3, 4, 1]\",\"y[3, 4, 2]\",\"y[3, 4, 3]\"
\"y[4, 1, 1]\",\"y[4, 1, 2]\",\"y[4, 1, 3]\"
\"y[4, 2, 1]\",\"y[4, 2, 2]\",\"y[4, 2, 3]\"
\"y[4, 3, 1]\",\"y[4, 3, 2]\",\"y[4, 3, 3]\"
\"y[4, 4, 1]\",\"y[4, 4, 2]\",\"y[4, 4, 3]\"
\"y[5, 1, 1]\",\"y[5, 1, 2]\",\"y[5, 1, 3]\"
\"y[5, 2, 1]\",\"y[5, 2, 2]\",\"y[5, 2, 3]\"
\"y[5, 3, 1]\",\"y[5, 3, 2]\",\"y[5, 3, 3]\"
\"y[5, 4, 1]\",\"y[5, 4, 2]\",\"y[5, 4, 3]\"\
\>", "Print",
 PageWidth->Infinity,
 CellLabel->"From In[1516]:="]
}, Open  ]],

Cell["This data set can be input from a file using", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Y2in", "=", 
    RowBox[{"Import", "[", 
     RowBox[{"\"\<dataset\>\"", ",", "\"\<CSV\>\""}], "]"}]}], ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"Y2in", "//", "Dimensions"}], "\[IndentingNewLine]"}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1521]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3"},
      {"1", "\<\"y[1, 1, 1]\"\>", "\<\"y[1, 1, 2]\"\>", "\<\"y[1, 1, \
3]\"\>"},
      {"2", "\<\"y[1, 2, 1]\"\>", "\<\"y[1, 2, 2]\"\>", "\<\"y[1, 2, \
3]\"\>"},
      {"3", "\<\"y[1, 3, 1]\"\>", "\<\"y[1, 3, 2]\"\>", "\<\"y[1, 3, \
3]\"\>"},
      {"4", "\<\"y[1, 4, 1]\"\>", "\<\"y[1, 4, 2]\"\>", "\<\"y[1, 4, \
3]\"\>"},
      {"5", "\<\"y[2, 1, 1]\"\>", "\<\"y[2, 1, 2]\"\>", "\<\"y[2, 1, \
3]\"\>"},
      {"6", "\<\"y[2, 2, 1]\"\>", "\<\"y[2, 2, 2]\"\>", "\<\"y[2, 2, \
3]\"\>"},
      {"7", "\<\"y[2, 3, 1]\"\>", "\<\"y[2, 3, 2]\"\>", "\<\"y[2, 3, \
3]\"\>"},
      {"8", "\<\"y[2, 4, 1]\"\>", "\<\"y[2, 4, 2]\"\>", "\<\"y[2, 4, \
3]\"\>"},
      {"9", "\<\"y[3, 1, 1]\"\>", "\<\"y[3, 1, 2]\"\>", "\<\"y[3, 1, \
3]\"\>"},
      {"10", "\<\"y[3, 2, 1]\"\>", "\<\"y[3, 2, 2]\"\>", "\<\"y[3, 2, \
3]\"\>"},
      {"11", "\<\"y[3, 3, 1]\"\>", "\<\"y[3, 3, 2]\"\>", "\<\"y[3, 3, \
3]\"\>"},
      {"12", "\<\"y[3, 4, 1]\"\>", "\<\"y[3, 4, 2]\"\>", "\<\"y[3, 4, \
3]\"\>"},
      {"13", "\<\"y[4, 1, 1]\"\>", "\<\"y[4, 1, 2]\"\>", "\<\"y[4, 1, \
3]\"\>"},
      {"14", "\<\"y[4, 2, 1]\"\>", "\<\"y[4, 2, 2]\"\>", "\<\"y[4, 2, \
3]\"\>"},
      {"15", "\<\"y[4, 3, 1]\"\>", "\<\"y[4, 3, 2]\"\>", "\<\"y[4, 3, \
3]\"\>"},
      {"16", "\<\"y[4, 4, 1]\"\>", "\<\"y[4, 4, 2]\"\>", "\<\"y[4, 4, \
3]\"\>"},
      {"17", "\<\"y[5, 1, 1]\"\>", "\<\"y[5, 1, 2]\"\>", "\<\"y[5, 1, \
3]\"\>"},
      {"18", "\<\"y[5, 2, 1]\"\>", "\<\"y[5, 2, 2]\"\>", "\<\"y[5, 2, \
3]\"\>"},
      {"19", "\<\"y[5, 3, 1]\"\>", "\<\"y[5, 3, 2]\"\>", "\<\"y[5, 3, \
3]\"\>"},
      {"20", "\<\"y[5, 4, 1]\"\>", "\<\"y[5, 4, 2]\"\>", "\<\"y[5, 4, \
3]\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1521]//MatrixForm="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[1522]="]
}, Open  ]],

Cell["\<\
You can reshape the matrix to the required tensor structure by writing\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Y3", "=", 
  RowBox[{"Shape", "[", 
   RowBox[{"Y2in", ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "T1", ",", "p"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Y3", "//", "Dimensions"}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1523]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\<\"y[1, 1, 1]\"\>", ",", "\<\"y[1, 1, 2]\"\>", 
       ",", "\<\"y[1, 1, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[1, 2, 1]\"\>", ",", "\<\"y[1, 2, 2]\"\>", 
       ",", "\<\"y[1, 2, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[1, 3, 1]\"\>", ",", "\<\"y[1, 3, 2]\"\>", 
       ",", "\<\"y[1, 3, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[1, 4, 1]\"\>", ",", "\<\"y[1, 4, 2]\"\>", 
       ",", "\<\"y[1, 4, 3]\"\>"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\<\"y[2, 1, 1]\"\>", ",", "\<\"y[2, 1, 2]\"\>", 
       ",", "\<\"y[2, 1, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[2, 2, 1]\"\>", ",", "\<\"y[2, 2, 2]\"\>", 
       ",", "\<\"y[2, 2, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[2, 3, 1]\"\>", ",", "\<\"y[2, 3, 2]\"\>", 
       ",", "\<\"y[2, 3, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[2, 4, 1]\"\>", ",", "\<\"y[2, 4, 2]\"\>", 
       ",", "\<\"y[2, 4, 3]\"\>"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\<\"y[3, 1, 1]\"\>", ",", "\<\"y[3, 1, 2]\"\>", 
       ",", "\<\"y[3, 1, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[3, 2, 1]\"\>", ",", "\<\"y[3, 2, 2]\"\>", 
       ",", "\<\"y[3, 2, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[3, 3, 1]\"\>", ",", "\<\"y[3, 3, 2]\"\>", 
       ",", "\<\"y[3, 3, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[3, 4, 1]\"\>", ",", "\<\"y[3, 4, 2]\"\>", 
       ",", "\<\"y[3, 4, 3]\"\>"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\<\"y[4, 1, 1]\"\>", ",", "\<\"y[4, 1, 2]\"\>", 
       ",", "\<\"y[4, 1, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[4, 2, 1]\"\>", ",", "\<\"y[4, 2, 2]\"\>", 
       ",", "\<\"y[4, 2, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[4, 3, 1]\"\>", ",", "\<\"y[4, 3, 2]\"\>", 
       ",", "\<\"y[4, 3, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[4, 4, 1]\"\>", ",", "\<\"y[4, 4, 2]\"\>", 
       ",", "\<\"y[4, 4, 3]\"\>"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\<\"y[5, 1, 1]\"\>", ",", "\<\"y[5, 1, 2]\"\>", 
       ",", "\<\"y[5, 1, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[5, 2, 1]\"\>", ",", "\<\"y[5, 2, 2]\"\>", 
       ",", "\<\"y[5, 2, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[5, 3, 1]\"\>", ",", "\<\"y[5, 3, 2]\"\>", 
       ",", "\<\"y[5, 3, 3]\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\<\"y[5, 4, 1]\"\>", ",", "\<\"y[5, 4, 2]\"\>", 
       ",", "\<\"y[5, 4, 3]\"\>"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[1523]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "4", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[1524]="]
}, Open  ]],

Cell["Numerical data can be read as well:", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Y4", "=", 
  RowBox[{"Shape", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"60", "//", "Range"}], "//", "N"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "*", "T1"}], ",", "P"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1525]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "2.`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", "5.`", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.`", ",", "8.`", ",", "9.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", "11.`", ",", "12.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13.`", ",", "14.`", ",", "15.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16.`", ",", "17.`", ",", "18.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19.`", ",", "20.`", ",", "21.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22.`", ",", "23.`", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"25.`", ",", "26.`", ",", "27.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28.`", ",", "29.`", ",", "30.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", "32.`", ",", "33.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"34.`", ",", "35.`", ",", "36.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"37.`", ",", "38.`", ",", "39.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"40.`", ",", "41.`", ",", "42.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"43.`", ",", "44.`", ",", "45.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"46.`", ",", "47.`", ",", "48.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49.`", ",", "50.`", ",", "51.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"52.`", ",", "53.`", ",", "54.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"55.`", ",", "56.`", ",", "57.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"58.`", ",", "59.`", ",", "60.`"}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[1525]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Y4", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "=", "\"\<miss\>\""}], ";", "  ", 
  
  RowBox[{"(*", " ", 
   RowBox[{"missing", " ", "data", " ", "code"}], " ", "*)"}]}]], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1526]:="],

Cell[CellGroupData[{

Cell[BoxData["Y4"], "Input",
 CellLabel->"In[1527]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"miss\"\>", ",", "2.`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", "5.`", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.`", ",", "8.`", ",", "9.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", "11.`", ",", "12.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13.`", ",", "14.`", ",", "15.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16.`", ",", "17.`", ",", "18.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19.`", ",", "20.`", ",", "21.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22.`", ",", "23.`", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"25.`", ",", "26.`", ",", "27.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28.`", ",", "29.`", ",", "30.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", "32.`", ",", "33.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"34.`", ",", "35.`", ",", "36.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"37.`", ",", "38.`", ",", "39.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"40.`", ",", "41.`", ",", "42.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"43.`", ",", "44.`", ",", "45.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"46.`", ",", "47.`", ",", "48.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49.`", ",", "50.`", ",", "51.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"52.`", ",", "53.`", ",", "54.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"55.`", ",", "56.`", ",", "57.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"58.`", ",", "59.`", ",", "60.`"}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[1527]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</SDE/data/\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SetOptions", "[", 
  RowBox[{"TableForm", ",", 
   RowBox[{"TableDirections", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Column", ",", "Row"}], "}"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", "None"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<dataset1\>\"", ",", "Y4", ",", "\"\<Table\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"!!", "\"\<dataset1\>\""}]}], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1528]:="],

Cell[BoxData["\<\"/SDE/data\"\>"], "Output",
 CellLabel->"Out[1528]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TableAlignments", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TableDepth", "\[Rule]", "\[Infinity]"}], ",", 
   RowBox[{"TableDirections", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Column", ",", "Row"}], "}"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", "None"}], ",", 
   RowBox[{"TableSpacing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "1"}], "}"}]}]}], "}"}]], "Output",
 CellLabel->"Out[1529]="],

Cell[BoxData["\<\"dataset1\"\>"], "Output",
 CellLabel->"Out[1530]="],

Cell["\<\
miss   2.   3.
4.   5.   6.
7.   8.   9.
10.   11.   12.
13.   14.   15.
16.   17.   18.
19.   20.   21.
22.   23.   24.
25.   26.   27.
28.   29.   30.
31.   32.   33.
34.   35.   36.
37.   38.   39.
40.   41.   42.
43.   44.   45.
46.   47.   48.
49.   50.   51.
52.   53.   54.
55.   56.   57.
58.   59.   60.\
\>", "Print",
 PageWidth->Infinity,
 CellLabel->"From In[1528]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{"\"\<dataset1\>\"", ",", "\"\<Table\>\""}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 PageWidth->Infinity,
 CellLabel->"In[1532]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3"},
      {"1", "\<\"miss\"\>", "2.`", "3.`"},
      {"2", "4.`", "5.`", "6.`"},
      {"3", "7.`", "8.`", "9.`"},
      {"4", "10.`", "11.`", "12.`"},
      {"5", "13.`", "14.`", "15.`"},
      {"6", "16.`", "17.`", "18.`"},
      {"7", "19.`", "20.`", "21.`"},
      {"8", "22.`", "23.`", "24.`"},
      {"9", "25.`", "26.`", "27.`"},
      {"10", "28.`", "29.`", "30.`"},
      {"11", "31.`", "32.`", "33.`"},
      {"12", "34.`", "35.`", "36.`"},
      {"13", "37.`", "38.`", "39.`"},
      {"14", "40.`", "41.`", "42.`"},
      {"15", "43.`", "44.`", "45.`"},
      {"16", "46.`", "47.`", "48.`"},
      {"17", "49.`", "50.`", "51.`"},
      {"18", "52.`", "53.`", "54.`"},
      {"19", "55.`", "56.`", "57.`"},
      {"20", "58.`", "59.`", "60.`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[1532]//MatrixForm="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference", "Subsection",
 PageWidth->Infinity],

Cell["\<\
Mathematica code is written in Courier.
The functons have 4 parameters (lists): data, parameters, system and \
miscellaneous.\
\>", "Text",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell["BFGS", "Subsubsection",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}},
 CellLabel->"(Local) In[179]:="],

Cell[TextData[{
 "      ",
 StyleBox["Purpose",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 ": ML estimation of the parameter vector Theta with the BFGS algorithm,\n    \
  using the BFGS secant update as model Hessian."
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{9, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Definition:",
  FontWeight->"Bold"],
 "\n",
 StyleBox["(******************************************************************\
******)\n",
  FontFamily->"Courier"],
 StyleBox["BFGS",
  FontFamily->"Courier",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["[data_,\n     {THETA0_,F0_},\n     \
{system_,{Lik_,LikN_,Score_,Hesse_}},\n     \
{misc_,KMAX_,{EPS1_,EPS2_},OPTION_,PRINT_}]\n\
(************************************************************************)",
  FontFamily->"Courier"]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Input Parameters: ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["data:",
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox[" {{Z1,X1},...,{ZN,XN}}.",
  FontFamily->"Courier",
  FontColor->GrayLevel[0]],
 StyleBox["\nZn: T1n x k is the endogenous time series of the nth panel unit.\
\nXn: T1n x q is the exogenous time series of the nth panel unit.\n",
  FontColor->GrayLevel[0]],
 StyleBox["THETA0: ",
  FontWeight->"Bold"],
 StyleBox["u",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[". ",
  FontWeight->"Bold"],
 StyleBox["Initial value of the parameter vector.\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["F0: ",
  FontWeight->"Bold"],
 StyleBox["u x u",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[". ",
  FontWeight->"Bold"],
 StyleBox["Initial value of the BFGS update. Use ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["IdentityMatrix[u]",
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["\nor some approximation of the Fisher information matrix  \n(e.g. \
negative Hessian).\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["system:",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[" vector of system functions corresponding to the likelihood \n\
function LikN. For example, using EKF, \n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["system=",
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_}.",
  FontFamily->"Courier"],
 "\n",
 StyleBox["Lik:",
  FontWeight->"Bold"],
 " Name of likelihood function (don`t change).\n",
 StyleBox["LikN:",
  FontWeight->"Bold"],
 " Name of individual likelihood function (EKF, UKF, etc).\n",
 StyleBox["Score:",
  FontWeight->"Bold"],
 " Name of score function (don`t change).\n",
 StyleBox["Hesse:",
  FontWeight->"Bold"],
 " Name of model Hessian (",
 StyleBox["Hesse",
  FontFamily->"Courier"],
 " or ",
 StyleBox["FisherInformation",
  FontFamily->"Courier"],
 ")\n",
 StyleBox["misc:",
  FontWeight->"Bold"],
 " miscellanous parameters of LikN (e.g. {miss,option}: \nmiss = missing data \
code; option = 1: compute likelihood).\n",
 StyleBox["KMAX:",
  FontWeight->"Bold"],
 " maximal number of iterations.\n",
 StyleBox["EPS1:",
  FontWeight->"Bold"],
 " convergence bound ",
 StyleBox["Max[Abs[S]]<EPS1",
  FontFamily->"Courier"],
 " \n",
 StyleBox["EPS2:",
  FontWeight->"Bold"],
 " convergence bound ",
 StyleBox["Max[Abs[STEP]]<EPS2 ",
  FontFamily->"Courier"]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["\nOutput Parameters:\n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Theta:",
  FontWeight->"Bold"],
 " Final estimate (ML estimate after convergence) after KMAX iterations.\n",
 StyleBox["COV:",
  FontWeight->"Bold"],
 " Asymptotic covariance matrix (=",
 StyleBox["Inverse[F]",
  FontFamily->"Courier"],
 ").\n",
 StyleBox["LIKI:",
  FontWeight->"Bold"],
 " sequence of likelihood values.\n",
 StyleBox["Thetai:",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 " sequence of parameter values.\n",
 StyleBox["Scorei:",
  FontWeight->"Bold"],
 " sequence of score (gradient) values.\n",
 StyleBox["k: ",
  FontWeight->"Bold"],
 "maximum number of iterations\n",
 StyleBox["ReturnCode: ",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 "\n     ",
 StyleBox["If[Max[Abs[S   ]]<EPS1,Print[\"ReturnCode = 1\"];ReturnCode = 1];\n\
  If[Max[Abs[STEP]]<EPS2,Print[\"ReturnCode = 2\"];ReturnCode = 2];\n  \
If[Max[Abs[S   ]]<EPS1 && \n     Max[Abs[STEP]]<EPS2,Print[\"ReturnCode = \
3\"];ReturnCode = 3];\n  If[LIKNEU - LIKALT < 0,Print[\"ReturnCode = \
4\"];ReturnCode = 4;Break[]]; \n  End of iteration if n",
  FontFamily->"Courier"],
 "o improvement in step reduction.\n   "
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{28, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Global settings:",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n        \nFDIGITS=Round[-Log[10,$MachineEpsilon]];\nTYP=1;\n\
YMAX=1000.; (*reset value in EKF etc. to control filter divergencies*)\n\
ANALGRAD=False;\nFACTOR=1.0;\nMAXSTEP=0.1; (*use other values to tune \
performance*)\nCSEED=-999;\nSCALING=1;\nSTEPREDUCE=4; (*use other values to \
tune performance*)\nFISHER=False;\nPRINT={1,1,1,1,1,1,1,1} (*print all*)\n\
OVERFLOW=False;\nSHIFT$=10^-8;",
  FontFamily->"Courier"]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 "You can use a scaling vector ",
 StyleBox["SCALING={s1,s2,...,su}",
  FontFamily->"Courier"],
 " \nif some parameters strongly deviate from 1. For example, if\n",
 StyleBox["ThetaTrue={2,0.01}",
  FontFamily->"Courier"],
 ", one may define ",
 StyleBox["SCALING={1,0.01} ",
  FontFamily->"Courier"],
 "and\nuse",
 StyleBox[" Theta=",
  FontFamily->"Courier"],
 StyleBox["ThetaTrue",
  FontFamily->"Courier"],
 StyleBox["/SCALING. ",
  FontFamily->"Courier"],
 "After convergence, you can\ntransform back to the original",
 StyleBox[" ",
  FontFamily->"Courier"],
 StyleBox["ThetaTrue=",
  FontFamily->"Courier"],
 StyleBox["Theta*SCALING.",
  FontFamily->"Courier"]
}], "Text",
 PageWidth->Infinity]
}, Open  ]],

Cell[CellGroupData[{

Cell["EKF", "Subsubsection",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}},
 CellLabel->"(Local) In[179]:="],

Cell[TextData[{
 "      ",
 StyleBox["Purpose",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 ": Extended Kalman filter. Approximate computation of filtered states, \
filter errors and likelihood."
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{9, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Definition:",
  FontWeight->"Bold"],
 "\n",
 StyleBox["(***************************************************************)\t\
\t\t \n",
  FontFamily->"Courier"],
 StyleBox["EKF",
  FontFamily->"Courier",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["[{Z_,X_},\n     Theta_,\n    \
{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_},\n    {miss_,option_:1}]\n\
(***************************************************************)",
  FontFamily->"Courier"],
 "\t"
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Input Parameters: ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["{Z,X}: ",
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox["Z: T1 x k is an endogenous time series. X: T1 x q is an exogenous \
time series.\n",
  FontColor->GrayLevel[0]],
 StyleBox["THETA: ",
  FontWeight->"Bold"],
 StyleBox["u",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[".   ",
  FontWeight->"Bold"],
 StyleBox["V",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["alue of the parameter vector.\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["{f_,Df_,g_,h_,Dh_,R_,mue_,sigma_,dt_}",
  FontWeight->"Bold"],
 StyleBox[":  ",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["vector of system functions.",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "\n",
 StyleBox["miss: ",
  FontWeight->"Bold"],
 StyleBox[" missing data code\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["option",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[": = 1 computation of likelihood only\n             = 2: \
computation of  filtered states , filter error and likelihood : ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "{YF,PF,lik}\n             = 4 ",
 StyleBox["computation of likelihood ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and innovation: {lik,inno}\n             = 5 ",
 StyleBox["computation of likelihood (sum) ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and  t th contribution : {lik,likvec}"
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["\nOutput Parameters:\n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["option",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[": = 1 computation of likelihood only:  ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["lik",
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["\n             = 2: computation of  filtered states , filter error \
and likelihood : ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["{YF,PF,lik}",
  FontFamily->"Courier"],
 "\n             = 4 ",
 StyleBox["computation of likelihood ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and innovation: ",
 StyleBox["{lik,inno}",
  FontFamily->"Courier"],
 "\n             = 5 ",
 StyleBox["computation of likelihood (sum) ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and conditional ",
 StyleBox["likelihood",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 " vector: ",
 StyleBox["{lik,likvec}",
  FontFamily->"Courier"],
 StyleBox["\n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{28, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["UKF", "Subsubsection",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}},
 CellLabel->"(Local) In[179]:="],

Cell[TextData[{
 "      ",
 StyleBox["Purpose",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 ": Unscented Kalman filter. Approximate computation of filtered states, \
filter errors and likelihood."
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{9, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["Definition:",
  FontWeight->"Bold"],
 "\n",
 StyleBox["(***************************************************************)\t\
\t\t \n",
  FontFamily->"Courier"],
 StyleBox["UKF",
  FontFamily->"Courier",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["[{Z_,X_},\n     Theta_,\n    \
{f_,g_,h_,R_,mue_,sigma_,dt_,kappa_,messupdate_:MessUpUKF,\n     \
timeupdate_:TimeUpUKF1},\n    {miss_,option_:1}]:=",
  FontFamily->"Courier"],
 StyleBox["\n\
(***************************************************************)",
  FontFamily->"Courier"],
 "\t"
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}},
 CellChangeTimes->{{3.4282256320060377`*^9, 3.428225632705315*^9}}],

Cell[TextData[{
 StyleBox["Input Parameters: ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["{Z,X}: ",
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox["Z: T1 x k is an endogenous time series. X: T1 x q is an exogenous \
time series.\n",
  FontColor->GrayLevel[0]],
 StyleBox["THETA: ",
  FontWeight->"Bold"],
 StyleBox["u",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[".   ",
  FontWeight->"Bold"],
 StyleBox["Value of the parameter vector.\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["{f_,g_,h_,R_,mue_,sigma_,dt_,kappa_,messupdate_:MessUpUKF,\
timeupdate_:TimeUpUKF1}",
  FontWeight->"Bold"],
 StyleBox[":",
  FontWeight->"Bold"],
 StyleBox["  ",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["vector of system functions.",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "\n",
 StyleBox["miss: ",
  FontWeight->"Bold"],
 StyleBox[" missing data code\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["option",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[": = 1 computation of likelihood only\n             = 2: \
computation of  filtered states , filter error and likelihood : ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "{YF,PF,lik}\n             = 4 ",
 StyleBox["computation of likelihood ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and innovation: {lik,inno}\n             = 5 ",
 StyleBox["computation of likelihood (sum) ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and  t th contribution : {lik,likvec}"
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
 StyleBox["\nOutput Parameters:\n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["option",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[": = 1 computation of likelihood only:  ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["lik",
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["\n             = 2: computation of  filtered states , filter error \
and likelihood : ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["{YF,PF,lik}",
  FontFamily->"Courier"],
 "\n             = 4 ",
 StyleBox["computation of likelihood ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and innovation: ",
 StyleBox["{lik,inno}",
  FontFamily->"Courier"],
 "\n             = 5 ",
 StyleBox["computation of likelihood (sum) ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 "and conditional ",
 StyleBox["likelihood",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 " vector: ",
 StyleBox["{lik,likvec}",
  FontFamily->"Courier"],
 StyleBox["\n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{28, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell["to be continued, see definitions in Kalman.exakt.impl.nb etc", \
"Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bibliography", "Subsection",
 PageWidth->Infinity],

Cell[TextData[{
 StyleBox["Hamerle, A. and Singer, H. (1993). Kalman Filtering and maximum \
likelihood\nestimation of stochastic di",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["erential equations using panel data, in\nJ. Oud and R. van \
Blokland-Vogelesang (eds), Advances in longitudinal\nand multivariate \
analysis in the behavioral sciences, ITS, Nijmegen,\npp. 3\[Dash]26.\n\n\
Hamerle, A., Nagl, W. and Singer, H. (1991). Problems with the estimation\nof \
stochastic di",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["erential equations using structural equations models,\nJournal of \
Mathematical Sociology 16, 3: 201\[Dash]220.\n\nHamerle, A., Nagl, W. and \
Singer, H. (1993). Identification and estimation of\ncontinuous time dynamic \
systems with exogenous variables using panel\ndata, Econometric Theory 9: 283\
\[Dash]295.\n\nJazwinski, A. (1970). Stochastic Processes and Filtering \
Theory, Academic\nPress, New York.\n\nSinger, H. (1991). LSDE - A program \
package for the simulation, graphical\ndisplay, optimal filtering and maximum \
likelihood estimation of Linear\nStochastic Di",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["erential Equations, User\[OpenCurlyQuote]s guide, Meersburg.\n\n\
Singer, H. (1992a). Zeitkontinuierliche Dynamische Systeme, Campus-\nVerlag, \
Frankfurt a.M./New York.\n\nSinger, H. (1992b). Dynamic structural equations \
in discrete and continuous\ntime, in G. Haag, U. Mueller and K. Troitzsch \
(eds), Economic Evolution\nand Demographic Change, Springer, Berlin, \
Heidelberg, New York,\npp. 306\[Dash]320.\n\nSinger, H. (1992c). Continuous \
time dynamical systems with discrete data,\nerrors of measurement and \
individual specific e",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["ects, in F. Faulbaum\n(ed.), Advances in Statistical Software, G. \
Fischer, pp. 153\[Dash]159.\n\nSinger, H. (1992d). The aliasing phenomenon in \
visual terms, Journal of\nMathematical Sociology 17, 1: 39\[Dash]49.\n\n\
Singer, H. (1993). Continuous-time dynamical systems with sampled data,\n\
errors of measurement and unobserved components, Journal of Time\nSeries \
Analysis 14, 5: 527\[Dash]545.\n\nSinger, H. (1995). Analytical score \
function for irregularly sampled continuous\ntime stochastic processes with \
control variables and missing values,\nEconometric Theory 11: 721\[Dash]735.\n\
\nSinger, H. (1996). Continuous-time dynamic models for panel data, in U. \
Engel\nand J. Reinecke (eds), Analysis of Change, de Gruyter, Berlin, New\n\
York, pp. 113\[Dash]133.\n\nSinger, H. (1998). Continuous Panel Models with \
Time Dependent Parameters,\nJournal of Mathematical Sociology 23: \
77\[Dash]98.\n\nSinger, H. (1999). Finanzmarkt\[ODoubleDot]konometrie. \
Zeitstetige Systeme und ihre\nAnwendung in \[CapitalODoubleDot]konometrie und \
empirischer Kapitalmarktforschung,\nPhysica-Verlag, Heidelberg.\n\nSinger, H. \
(2002). Parameter Estimation of Nonlinear Stochastic Di",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["erential\nEquations: Simulated Maximum Likelihood vs. Extended \
Kalman Filter\nand It\[OHat]-Taylor Expansion, Journal of Computational and \
Graphical\nStatistics 11,4: 972\[Dash]995.\n\nSinger, H. (2003a). Nonlinear \
Continuous-Discrete Filtering and ML Estimation\nusing Kernel Density \
Estimates and Functional Integrals, Journal\nof Mathematical Sociology.\n\n\
Singer, H. (2003b). Simulated Maximum Likelihood in Nonlinear Continuous-\n\
Discrete State Space Models: Importance Sampling by Approximate\nSmoothing, \
Computational Statistics 18,1: 79\[Dash]106.\n\nSinger, H. (2004c). A Survey \
of Estimation Methods for Stochastic Differential\nEquations, in C. van \
Dijkum, J. Blasius, H. Kleijer and\nB. Van Hilten (eds), Sixth International \
Conference on Social Science\nMethodology, Netherlands Institute for the \
Social Sciences (SISWO), CD\nROM, ISBN 90-6706-176-x.\n\nSinger, H. (2006a). \
Continuous-Discrete Unscented Kalman Filtering,\nDiskussionsbeitr",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["ge Fachbereich Wirtschaftswissenschaft\n384, FernUniversit",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["t in Hagen. http://www.",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "fernuni-hagen",
 StyleBox[".de/FBWIWI/forschung/\nbeitraege/pdf/db384.pdf.\n\nSinger, H. \
(2006b). Generalized Gauss-Hermite Filtering for Multivariate\nDi",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["usion Processes, Diskussionsbeitr",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["ge Fachbereich Wirtschaftswissenschaft\n402, FernUniversit",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["t in Hagen. http://www.",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "fernuni-hagen",
 StyleBox[".de/FBWIWI/forschung/\nbeitraege/pdf/db402.pdf.\n\nSinger, H. \
(2006c). Moment Equations and Hermite Expansion for Nonlinear\nStochastic Di",
  
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["erential Equations with Application to Stock Price\nModels, \
Computational Statistics 21,3: in print.",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\n\n",
 StyleBox["Singer, H. (2006d). Nonlinear Continuous Time Modeling Approaches\n\
in Panel Research, Diskussionsbeitr",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["ge Fachbereich Wirtschaftswissenschaft\n398, FernUniversit",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["t in Hagen. http://www.",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "fernuni-hagen",
 StyleBox[".de/FBWIWI/forschung/\nbeitraege/pdf/db398.pdf.\n\nSinger, H. \
(2007a). Stochastic Di",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "ff",
 StyleBox["erential Equation Models with Sampled\nData, in K. van Montfort, \
H. Oud and A. Satorra (eds), Longitudinal\nModels in the Behavioral and \
related Sciences, The European Association\nof Methodology (EAM) Methodology \
and Statistics series, vol. II,\nErlbaum publishers.\n\nSinger, H. (2007b). \
Nonlinear Continuous Time Modeling Approaches in\nPanel Research, Statistica \
Neerlandica.\n\n",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox["Singer, H. (2008a). Generalized Gauss-Hermite Filtering, Advances \
in Statistical\nAnalysis 92, 2: 179\[Dash]195.",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox["\n\nSinger, H. and Hautzinger, M. (1988). Kausalattributionen, \
Depressivit",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\[ADoubleDot]",
 StyleBox["t\nund kritische Lebensereignisse als Stochastischer Proze\[SZ], \
in D. Kammer\nand M. Hautzinger (eds), Kognitive Depressionsforschung, Huber, \
Bern,\nStuttgart, Toronto, pp. 42\[Dash]56.",
  FontFamily->"Geneva",
  FontWeight->"Plain",
  FontColor->GrayLevel[0]]
}], "Text",
 PageWidth->Infinity,
 CellMargins->{{60, Inherited}, {Inherited, Inherited}},
 TextAlignment->Left,
 TextJustification->0]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{635, 787},
WindowMargins->{{5, Automatic}, {Automatic, 2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FontFamily->"Arial",
FontSize->12,
FontWeight->"Normal",
Magnification->1.,
FontColor->RGBColor[0.160784, 0.101961, 0.0627451],
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (May 21, 2008)",
StyleDefinitions->"ArticleClassic.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 411, 9, 380, "Section"],
Cell[CellGroupData[{
Cell[1026, 36, 56, 1, 40, "Subsection"],
Cell[1085, 39, 1974, 35, 536, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3096, 79, 62, 1, 40, "Subsection"],
Cell[3161, 82, 2364, 53, 712, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5562, 140, 53, 1, 40, "Subsection"],
Cell[5618, 143, 1485, 23, 520, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7140, 171, 74, 1, 40, "Subsection"],
Cell[CellGroupData[{
Cell[7239, 176, 60, 1, 30, "Subsubsection"],
Cell[7302, 179, 204, 7, 56, "Text"],
Cell[CellGroupData[{
Cell[7531, 190, 1189, 31, 131, "Input"],
Cell[8723, 223, 201, 5, 25, "Output"],
Cell[8927, 230, 7586, 202, 319, "Output"]
}, Open  ]],
Cell[16528, 435, 165, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[16718, 443, 276, 9, 41, "Input"],
Cell[16997, 454, 2142, 58, 70, "Output"],
Cell[19142, 514, 2142, 58, 70, "Output"]
}, Open  ]],
Cell[21299, 575, 108, 3, 24, "Text"],
Cell[CellGroupData[{
Cell[21432, 582, 338, 11, 41, "Input"],
Cell[21773, 595, 1914, 53, 84, "Output"],
Cell[23690, 650, 99, 3, 25, "Output"]
}, Open  ]],
Cell[23804, 656, 646, 14, 296, "Text"],
Cell[CellGroupData[{
Cell[24475, 674, 1291, 35, 131, "Input"],
Cell[25769, 711, 109, 3, 25, "Output"],
Cell[25881, 716, 17487, 460, 159, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43417, 1182, 63, 1, 30, "Subsubsection"],
Cell[43483, 1185, 706, 23, 328, "Text"],
Cell[CellGroupData[{
Cell[44214, 1212, 431, 13, 71, "Input"],
Cell[44648, 1227, 6057, 174, 86, "Output"],
Cell[50708, 1403, 109, 3, 25, "Output"],
Cell[50820, 1408, 109, 3, 25, "Output"]
}, Open  ]],
Cell[50944, 1414, 161, 5, 56, "Text"],
Cell[CellGroupData[{
Cell[51130, 1423, 440, 13, 71, "Input"],
Cell[51573, 1438, 5674, 156, 101, "Output"],
Cell[57250, 1596, 109, 3, 25, "Output"],
Cell[57362, 1601, 109, 3, 25, "Output"]
}, Open  ]],
Cell[57486, 1607, 186, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[57697, 1615, 393, 12, 56, "Input"],
Cell[58093, 1629, 301, 9, 25, "Output"],
Cell[58397, 1640, 301, 9, 25, "Output"]
}, Open  ]],
Cell[58713, 1652, 81, 1, 24, "Text"],
Cell[CellGroupData[{
Cell[58819, 1657, 520, 17, 56, "Input"],
Cell[59342, 1676, 1434, 40, 70, "Output"],
Cell[60779, 1718, 1426, 39, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62254, 1763, 94, 1, 30, "Subsubsection"],
Cell[62351, 1766, 269, 6, 72, "Text"],
Cell[CellGroupData[{
Cell[62645, 1776, 1295, 45, 116, "Input"],
Cell[63943, 1823, 5679, 151, 98, "Output"],
Cell[69625, 1976, 100, 3, 25, "Output"]
}, Open  ]],
Cell[69740, 1982, 585, 11, 168, "Text"],
Cell[CellGroupData[{
Cell[70350, 1997, 1339, 41, 71, "Input"],
Cell[71692, 2040, 5679, 151, 98, "Output"],
Cell[77374, 2193, 100, 3, 25, "Output"]
}, Open  ]],
Cell[77489, 2199, 210, 5, 40, "Text"],
Cell[CellGroupData[{
Cell[77724, 2208, 905, 28, 41, "Input"],
Cell[78632, 2238, 5679, 151, 98, "Output"],
Cell[84314, 2391, 100, 3, 25, "Output"]
}, Open  ]],
Cell[84429, 2397, 202, 7, 72, "Text"],
Cell[CellGroupData[{
Cell[84656, 2408, 858, 25, 41, "Input"],
Cell[85517, 2435, 5829, 165, 308, "Output"],
Cell[91349, 2602, 100, 3, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91486, 2610, 107, 3, 25, "Input"],
Cell[91596, 2615, 863, 13, 142, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92496, 2633, 571, 15, 71, "Input"],
Cell[93070, 2650, 70, 1, 25, "Output"],
Cell[93143, 2653, 479, 12, 25, "Output"],
Cell[93625, 2667, 68, 1, 25, "Output"],
Cell[93696, 2670, 977, 23, 267, "Print"]
}, Open  ]],
Cell[94688, 2696, 82, 1, 24, "Text"],
Cell[CellGroupData[{
Cell[94795, 2701, 333, 9, 56, "Input"],
Cell[95131, 2712, 2569, 65, 308, "Output"],
Cell[97703, 2779, 100, 3, 25, "Output"]
}, Open  ]],
Cell[97818, 2785, 116, 3, 24, "Text"],
Cell[CellGroupData[{
Cell[97959, 2792, 286, 9, 41, "Input"],
Cell[98248, 2803, 2914, 73, 86, "Output"],
Cell[101165, 2878, 109, 3, 25, "Output"]
}, Open  ]],
Cell[101289, 2884, 73, 1, 24, "Text"],
Cell[CellGroupData[{
Cell[101387, 2889, 291, 10, 25, "Input"],
Cell[101681, 2901, 1630, 43, 56, "Output"]
}, Open  ]],
Cell[103326, 2947, 302, 10, 25, "Input"],
Cell[CellGroupData[{
Cell[103653, 2961, 54, 1, 25, "Input"],
Cell[103710, 2964, 1639, 43, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105386, 3012, 575, 15, 71, "Input"],
Cell[105964, 3029, 70, 1, 25, "Output"],
Cell[106037, 3032, 479, 12, 25, "Output"],
Cell[106519, 3046, 69, 1, 25, "Output"],
Cell[106591, 3049, 390, 23, 267, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107018, 3077, 194, 6, 25, "Input"],
Cell[107215, 3085, 1689, 45, 309, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[108965, 3137, 53, 1, 40, "Subsection"],
Cell[109021, 3140, 171, 5, 40, "Text"],
Cell[CellGroupData[{
Cell[109217, 3149, 141, 3, 42, "Subsubsection"],
Cell[109361, 3154, 334, 9, 40, "Text"],
Cell[109698, 3165, 598, 17, 108, "Text"],
Cell[110299, 3184, 2900, 95, 342, "Text"],
Cell[113202, 3281, 1354, 39, 272, "Text"],
Cell[114559, 3322, 624, 13, 220, "Text"],
Cell[115186, 3337, 717, 25, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115940, 3367, 140, 3, 42, "Subsubsection"],
Cell[116083, 3372, 309, 9, 24, "Text"],
Cell[116395, 3383, 560, 17, 110, "Text"],
Cell[116958, 3402, 1861, 57, 168, "Text"],
Cell[118822, 3461, 1328, 43, 152, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120187, 3509, 140, 3, 42, "Subsubsection"],
Cell[120330, 3514, 310, 9, 24, "Text"],
Cell[120643, 3525, 723, 21, 124, "Text"],
Cell[121369, 3548, 1862, 57, 168, "Text"],
Cell[123234, 3607, 1328, 43, 152, "Text"]
}, Open  ]],
Cell[124577, 3653, 87, 1, 30, "Subsubsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124701, 3659, 56, 1, 40, "Subsection"],
Cell[124760, 3662, 7656, 173, 1860, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

